(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    779764,      23557]
NotebookOptionsPosition[    770333,      23403]
NotebookOutlinePosition[    771020,      23429]
CellTagsIndexPosition[    770932,      23424]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Load Optica", "SubsubsectionIcon",
 CellChangeTimes->{{3.7452935458645697`*^9, 
  3.7452935464722*^9}},ExpressionUUID->"f1c24be5-c154-445b-b950-acb3e019791c"],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Optica`Optica`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.745290932364974*^9, 3.745290936872039*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"12a082e9-158c-49af-8ade-5b7c7736f195"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Arbitrary Precision Calculations", "SubsectionIcon",ExpressionUUID->"a40f6c74-e359-4bda-bbb1-704ba4b4fb56"],

Cell[TextData[{
 "Both ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 " and ",
 StyleBox["Wavica",
  FontSlant->"Italic"],
 " permit the use of abitrary precision calculations. This is controlled with \
the ",
 StyleBox["RayTracePrecision", "Input"],
 " option:"
}], "Text",ExpressionUUID->"c58dcaf7-983b-453b-b235-cf406f55a926"],

Cell[CellGroupData[{

Cell["?RayTracePrecision", "Input",
 CellLabel->"In[2]:=",ExpressionUUID->"9b700b31-0698-40f7-be6a-e0e740f52937"],

Cell[BoxData["\<\"RayTracePrecision -> precision gives the number of decimal \
digits of precision used for ray-tracing.\"\>"], "Print",
 CellTags->
  "Info3334565137-3359157",ExpressionUUID->"55d5504a-4b1d-4a78-bcb5-\
cb9b90ee8220"]
}, Open  ]],

Cell["\<\
To illustrate this, we will work with the following optical system:\
\>", "Text",ExpressionUUID->"daaebc82-8484-4895-bff1-24eee1f41d9b"],

Cell[CellGroupData[{

Cell["\<\
sys = {WedgeOfRays[20],Move[PlanoConvexLens[100,50,10,CurvatureDirection->\
Back],90],Move[Screen[{50,50}],150]}\
\>", "Input",
 CellLabel->"In[14]:=",ExpressionUUID->"ec2e949a-c574-4752-ae5b-63f12c51949d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"WedgeOfRays", "[", "20", "]"}],
      HoldForm],
     FontColor->RGBColor[0, 0.392187, 0]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"PlanoConvexLens", "[", 
         RowBox[{"100", ",", "50", ",", "10", ",", 
          RowBox[{"{", 
           RowBox[{"CurvatureDirection", "\[Rule]", "Back"}], "}"}]}], "]"}], 
        ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0, 0.392187, 0]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"50", ",", "50"}], "}"}], "]"}], ",", "150.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0, 0.392187, 0]],
    DisplayForm]}], "}"}]], "Output",
 CellLabel->"Out[14]=",ExpressionUUID->"c2a27611-f080-4b19-8d95-271d7098c98d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboPlot[sys];", "Input",
 CellLabel->"In[15]:=",ExpressionUUID->"d17b6ecb-1487-4af1-9260-6344dec8281a"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .67912 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0224888 1.02249 -0.150431 1.02249 [
[ 0 0 0 0 ]
[ 1 .67912 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .67912 L
0 .67912 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.62394 .34325 m
.613 .30737 L
s
.613 .30737 m
.63144 .30143 L
s
.613 .30737 m
.59908 .27326 L
s
.63124 .37875 m
.62394 .34325 L
s
.62394 .34325 m
.64242 .3374 L
s
.59908 .27326 m
.61754 .26723 L
s
.59908 .27326 m
.58301 .24299 L
s
.63144 .30143 m
.64242 .3374 L
s
.61754 .26723 m
.63144 .30143 L
s
.64242 .3374 m
.6498 .37297 L
s
.63124 .37875 m
.6498 .37297 L
s
.60152 .23685 m
.61754 .26723 L
s
.58301 .24299 m
.60152 .23685 L
s
.656 .751 .92 r
.61275 .38687 m .65312 .40599 L .63444 .41172 L F
0 g
.63326 .4401 m
.63444 .41172 L
s
.63124 .37875 m
.63296 .39644 L
s
.656 .751 .92 r
.61275 .38687 m .65099 .37496 L .65312 .40599 L F
0 g
.65209 .43439 m
.65312 .40599 L
s
.6498 .37297 m
.65003 .37526 L
s
.63444 .41172 m
.65312 .40599 L
s
.544 .324 .532 r
.56574 .21847 m .60459 .24413 L .56644 .25675 L F
.56574 .21847 m .58434 .21221 L .60459 .24413 L F
0 g
.58434 .21221 m
.60152 .23685 L
s
.56574 .21847 m
.58434 .21221 L
s
.54831 .20135 m
.56574 .21847 L
s
.56705 .19499 m
.58434 .21221 L
s
.62767 .46196 m
.63326 .4401 L
s
.63326 .4401 m
.65209 .43439 L
s
.65209 .43439 m
.64667 .45625 L
s
.656 .751 .92 r
.59057 .36146 m .65099 .37496 L .61275 .38687 L F
0 g
.61275 .38687 m
.63444 .41172 L
s
.039 .916 .04 r
.11741 .4797 m
.61065 .38446 L
s
.61065 .38446 m
.65102 .37509 L
s
.544 .324 .532 r
.56644 .25675 m .61677 .2796 L .56716 .29575 L F
.56644 .25675 m .60459 .24413 L .61677 .2796 L F
0 g
.56574 .21847 m
.56644 .25675 L
s
.58434 .21221 m
.60459 .24413 L
s
.54831 .20135 m
.56705 .19499 L
s
.54831 .20135 m
.53185 .19296 L
s
.94767 .19408 m
.97441 .43595 L
s
.82983 .01827 m
.94767 .19408 L
s
.039 .916 .04 r
.65102 .37509 m
.94188 .28468 L
s
0 0 0 r
2.5 Mabswid
.65102 .37509 Mdot
.656 .751 .92 r
.59057 .36146 m .64025 .34578 L .65099 .37496 L F
0 g
.5 Mabswid
.65099 .37496 m
.65312 .40599 L
s
.55075 .18651 m
.56705 .19499 L
s
.6179 .47571 m
.62767 .46196 L
s
.62767 .46196 m
.64667 .45625 L
s
.64667 .45625 m
.63709 .46997 L
s
.656 .751 .92 r
.5679 .33548 m .64025 .34578 L .59057 .36146 L F
0 g
.59057 .36146 m
.61275 .38687 L
s
.544 .324 .532 r
.56716 .29575 m .62162 .31828 L .5679 .33548 L F
.56716 .29575 m .61677 .2796 L .62162 .31828 L F
0 g
.56644 .25675 m
.56716 .29575 L
s
.60459 .24413 m
.61677 .2796 L
s
.53185 .19296 m
.55075 .18651 L
s
.53185 .19296 m
.51749 .19413 L
s
.53657 .18761 m
.55075 .18651 L
s
.656 .751 .92 r
.5679 .33548 m .62162 .31828 L .64025 .34578 L F
0 g
.64025 .34578 m
.65099 .37496 L
s
.60448 .48014 m
.6179 .47571 L
s
.6179 .47571 m
.63709 .46997 L
s
.63709 .46997 m
.62386 .47434 L
s
.544 .324 .532 r
.5679 .33548 m .61921 .36004 L .56864 .37595 L F
.5679 .33548 m .62162 .31828 L .61921 .36004 L F
.656 .751 .92 r
.54471 .30891 m .62162 .31828 L .5679 .33548 L F
0 0 0 r
2.5 Mabswid
.5679 .33548 Mdot
.039 .916 .04 r
.5 Mabswid
.11741 .4797 m
.5679 .33548 L
s
0 g
.56716 .29575 m
.56746 .31168 L
s
.51749 .19413 m
.50629 .20511 L
s
.53657 .18761 m
.51749 .19413 L
s
.52555 .19854 m
.53657 .18761 L
s
.656 .751 .92 r
.54471 .30891 m .5952 .29251 L .62162 .31828 L F
0 0 0 r
2.5 Mabswid
.62162 .31828 Mdot
.039 .916 .04 r
.5 Mabswid
.62162 .31828 m
.90255 .22834 L
s
.5679 .33548 m
.62162 .31828 L
s
0 g
.61677 .2796 m
.62162 .31828 L
s
.62162 .31828 m
.64025 .34578 L
s
.58821 .47462 m
.60448 .48014 L
s
.60448 .48014 m
.62386 .47434 L
s
.544 .324 .532 r
.56864 .37595 m .60903 .40496 L .5694 .4172 L F
.56864 .37595 m .61921 .36004 L .60903 .40496 L F
0 g
.5679 .33548 m
.56864 .37595 L
s
.61921 .36004 m
.62162 .31828 L
s
.62386 .47434 m
.60776 .46875 L
s
.96066 .31159 m
.94173 .28448 L
s
.96066 .31159 m
.96066 .31159 L
s
.656 .751 .92 r
.52099 .28173 m .5952 .29251 L .54471 .30891 L F
0 g
.54471 .30891 m
.5679 .33548 L
s
.50629 .20511 m
.52555 .19854 L
s
.50629 .20511 m
.49915 .22544 L
s
.89076 .10918 m
.89076 .10918 L
s
.89076 .10918 m
.89462 .14814 L
s
.51859 .21886 m
.52555 .19854 L
s
.656 .751 .92 r
.52099 .28173 m .5605 .26871 L .5952 .29251 L F
.039 .916 .04 r
.11741 .4797 m
.52328 .28436 L
s
0 g
.5952 .29251 m
.62162 .31828 L
s
.58821 .47462 m
.60776 .46875 L
s
.544 .324 .532 r
.5694 .4172 m .58987 .45327 L .57018 .45924 L F
0 g
.57018 .45924 m
.58821 .47462 L
s
.544 .324 .532 r
.5694 .4172 m .60903 .40496 L .58987 .45327 L F
0 g
.56864 .37595 m
.5694 .4172 L
s
.5694 .4172 m
.57018 .45924 L
s
.60903 .40496 m
.61921 .36004 L
s
.58987 .45327 m
.60776 .46875 L
s
0 0 0 r
2.5 Mabswid
.94188 .28468 Mdot
0 g
.5 Mabswid
.94173 .28448 m
.92237 .25673 L
s
0 0 0 r
2.5 Mabswid
.52328 .28436 Mdot
.656 .751 .92 r
.49672 .25392 m .5605 .26871 L .52099 .28173 L F
0 g
.5 Mabswid
.52099 .28173 m
.54471 .30891 L
s
.58987 .45327 m
.60903 .40496 L
s
.89854 .18785 m
.89462 .14814 L
s
.51859 .21886 m
.49915 .22544 L
s
.656 .751 .92 r
.49672 .25392 m .51633 .24736 L .5605 .26871 L F
0 g
.51633 .24736 m
.5605 .26871 L
s
.49672 .25392 m
.49915 .22544 L
s
.5605 .26871 m
.5952 .29251 L
s
.039 .916 .04 r
.52328 .28436 m
.56033 .26861 L
s
0 g
.49672 .25392 m
.52099 .28173 L
s
.039 .916 .04 r
.56033 .26861 m
.86132 .16928 L
s
0 0 0 r
2.5 Mabswid
.56033 .26861 Mdot
0 g
.5 Mabswid
.51633 .24736 m
.51859 .21886 L
s
.55165 .43482 m
.57018 .45924 L
s
.57018 .45924 m
.58987 .45327 L
s
.57146 .42874 m
.58987 .45327 L
s
.92237 .25673 m
.90255 .22834 L
s
.49672 .25392 m
.51633 .24736 L
s
.49672 .25392 m
.4993 .28862 L
s
.89854 .18785 m
.90255 .22834 L
s
.53403 .40302 m
.55165 .43482 L
s
.55165 .43482 m
.57146 .42874 L
s
.51633 .24736 m
.51904 .28211 L
s
.97441 .43595 m
.85121 .26732 L
s
.57146 .42874 m
.5539 .39682 L
s
.4993 .28862 m
.51904 .28211 L
s
.4993 .28862 m
.5068 .327 L
s
.51868 .36614 m
.53403 .40302 L
s
.53403 .40302 m
.5539 .39682 L
s
.52663 .32058 m
.51904 .28211 L
s
.5068 .327 m
.51868 .36614 L
s
.52663 .32058 m
.5068 .327 L
s
.51868 .36614 m
.53855 .35982 L
s
.5539 .39682 m
.53855 .35982 L
s
0 0 0 r
2.5 Mabswid
.90255 .22834 Mdot
0 g
.5 Mabswid
.90663 .26962 m
.90255 .22834 L
s
.90255 .22834 m
.88226 .19927 L
s
.53855 .35982 m
.52663 .32058 L
s
.85121 .26732 m
.82983 .01827 L
s
.90663 .26962 m
.91079 .31173 L
s
.88226 .19927 m
.86148 .1695 L
s
.91504 .35469 m
.91079 .31173 L
s
.86148 .1695 m
.8402 .13901 L
s
0 0 0 r
2.5 Mabswid
.86132 .16928 Mdot
0 g
.5 Mabswid
.91504 .35469 m
.91504 .35469 L
s
.8402 .13901 m
.8402 .13901 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{437.47874165430267`, 297.10546875},
 ImageMargins->0,
 CellLabel->"From In[15]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{102., 538.}, {671., 375.}} -> {-0.20704586420898063, \
0.9885747829220037, 0.0022438823536631188, \
0.0022438823536631188}},ExpressionUUID->"bec5f790-c4e3-48f1-95bc-\
7f55426d0295"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Arbitrary Precision Calculations in ",
 StyleBox["Rayica",
  FontSlant->"Italic"]
}], "SubsectionIcon",ExpressionUUID->"0f8643fb-6443-4419-93f9-b08c5366be3f"],

Cell[TextData[{
 "In ",
 StyleBox["Rayica",
  FontSlant->"Italic"],
 ", both the ",
 StyleBox["TurboPlot", "Input"],
 " and ",
 StyleBox["TurboTrace", "Input"],
 " functions support arbitrary precision calculations. In its default mode, \
however, all calculations are carried out in machine precision of 16 decimal \
places. Here is a default calculation of the optical length of the rays \
traced to the final screen surface:"
}], "Text",ExpressionUUID->"4a835959-78c6-4838-a6d3-536aa17bf0cb"],

Cell[CellGroupData[{

Cell["TurboTrace[sys,OpticalLength]//InputForm", "Input",
 CellLabel->"In[6]:=",ExpressionUUID->"221f8583-fcc2-4529-af7b-98cfa60962cb"],

Cell["{155.2594749592117, 155.23244752966428, 155.2594749592117}", "Output",
 CellLabel->
  "Out[6]//InputForm=",ExpressionUUID->"654a5ca6-aad8-4a96-88b5-870cc39bb388"]
}, Open  ]],

Cell[TextData[{
 "Next, we use ",
 StyleBox["RayTracePrecision->50", "Input"],
 " to repeat the above calculation with 50 decimal places of precision:"
}], "Text",ExpressionUUID->"17bc8269-9b04-4f63-9af1-9294bb659b15"],

Cell[CellGroupData[{

Cell["TurboTrace[sys,OpticalLength,RayTracePrecision->50]", "Input",
 CellLabel->"In[7]:=",ExpressionUUID->"540e2212-617d-4989-8790-81dafb49e7da"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "155.259474947573901666175818636139183393839888978834732853702`47.\
875917318972164", ",", 
   "155.232447518638721991153023889871698547914633582534753936173`49.\
606237256279734", ",", 
   "155.259474947573901666175818636139183393839888978834732853702`47.\
875917318972164"}], "}"}]], "Output",
 CellLabel->"Out[7]=",ExpressionUUID->"224389ed-a940-4aa4-acd2-c2a0811540e1"]
}, Open  ]],

Cell[TextData[{
 "We can use ",
 StyleBox["TurboTrace", "Input"],
 " with ",
 StyleBox["OutputType->RayTraceFunction", "Input"],
 " to extract a ray-trace function model of the system. Again, we use ",
 StyleBox["RayTracePrecision->50", "Input"],
 ". This model is stored in a variable called ",
 StyleBox["res", "Input"],
 "."
}], "Text",ExpressionUUID->"17755b88-c29d-4cf4-876e-7518f7dae9ab"],

Cell[CellGroupData[{

Cell["\<\
res = RayTraceFunction/.TurboTrace[sys,OpticalLength,OutputType->\
RayTraceFunction,RayTracePrecision->50]\
\>", "Input",
 CellLabel->"In[8]:=",ExpressionUUID->"93de173d-b4bb-4943-b98b-102318de105d"],

Cell[BoxData["\<\"RayTraceFunction[{$inputrays}, -raytrace code: 111232 \
Bytes- : RayTracePrecision -> 50]\"\>"], "Output",
 CellLabel->"Out[8]=",ExpressionUUID->"861419b3-2b92-4ab7-bac8-2cf17ee26876"]
}, Open  ]],

Cell[TextData[{
 "This stored ",
 StyleBox["RayTraceFunction", "Input"],
 " can now make new calculations with different light source models. Here we \
use a ",
 StyleBox["LineOfRays", "Input"],
 " and ",
 StyleBox["WedgeOfRays", "Input"],
 " in separate calculations."
}], "Text",ExpressionUUID->"41c43e70-1af0-4492-8f61-cbb6bca0ccc6"],

Cell[CellGroupData[{

Cell["res[LineOfRays[20]]", "Input",
 CellLabel->"In[9]:=",ExpressionUUID->"9b4bf6a4-48f3-417a-8c2f-772b79f31ef7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "155.000005077442143626971785416070154101281859153591468673576`49.\
24123730261394", ",", 
   "155.232447518638721991153023889871698547914633582534753936173`49.\
606237256279734", ",", 
   "155.000005077442143626971785416070154101281859153591468673576`49.\
24123730261394"}], "}"}]], "Output",
 CellLabel->"Out[9]=",ExpressionUUID->"711234df-1c75-483f-a96a-ff79cf2f0f5b"]
}, Open  ]],

Cell[CellGroupData[{

Cell["res[WedgeOfRays[20]]", "Input",
 CellLabel->"In[10]:=",ExpressionUUID->"81e3ab02-ecb8-4cb5-bf6a-fd13d00294d0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "155.259474947573901666175818636139183393839888978834732853702`47.\
875917318972164", ",", 
   "155.232447518638721991153023889871698547914633582534753936173`49.\
606237256279734", ",", 
   "155.259474947573901666175818636139183393839888978834732853702`47.\
875917318972164"}], "}"}]], "Output",
 CellLabel->"Out[10]=",ExpressionUUID->"a05f5ec8-d46b-4ee4-861f-36da6332a0a4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Arbitrary Precision Calculations in ",
 StyleBox["Wavica",
  FontSlant->"Italic"]
}], "SubsectionIcon",ExpressionUUID->"992480c7-7194-4e63-958b-949315e67e29"],

Cell[TextData[{
 "Most functions in ",
 StyleBox["Wavica",
  FontSlant->"Italic"],
 " supports arbitrary precision control. This includes: ",
 StyleBox["SymbolicTrace", "Input"],
 ", ",
 StyleBox["FindInterference", "Input"],
 ", ",
 StyleBox["GaussianPlot", "Input"],
 ", ",
 StyleBox["GaussianTrace", "Input"],
 ", ",
 StyleBox["FindABCDMatrix", "Input"],
 " , ",
 StyleBox["ZernikeFit", "Input"],
 ", and ",
 StyleBox["FindWaveFronts", "Input"],
 ". For remaining discussion, we will examine the use of ",
 StyleBox["FindWaveFronts", "Input"],
 " and ",
 StyleBox["GaussianPlot", "Input"],
 "."
}], "Text",ExpressionUUID->"17002cae-d316-48a7-a004-629ee37b81b6"],

Cell[CellGroupData[{

Cell["FindWaveFronts in one dimension", "SubsubsectionIcon",ExpressionUUID->"063d93be-132e-4b1a-990b-3cbf1272b8c0"],

Cell[TextData[{
 "Here is the default behavior of ",
 StyleBox["FindWaveFronts", "Input"],
 ". This calculation shows the one-dimensional wavefront at the final screen \
surface in the system."
}], "Text",ExpressionUUID->"7aa4cd7f-904b-42f6-aa8a-3a240dabb20b"],

Cell[CellGroupData[{

Cell["FindWaveFronts[sys]", "Input",ExpressionUUID->"1a249aed-f4b0-4657-ac40-6bbff6442f89"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface Location : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentNumber", "\[Rule]", "2"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1"}], ",", 
     RowBox[{"WaveFrontID", "\[Rule]", "1"}], ",", 
     RowBox[{"Source", "\[Rule]", "1"}]}], "}"}]}],
  SequenceForm[
  "Surface Location : ", {
   ComponentNumber -> 2, SurfaceNumber -> 1, WaveFrontID -> 1, Source -> 1}],
  Editable->False]], "Print",ExpressionUUID->"44a71fbd-d5ad-4ed2-8198-\
f0e3fa7a30f7"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0284656 -3387.18 21.8202 [
[.07302 -0.0125 -9 -9 ]
[.07302 -0.0125 9 0 ]
[.21534 -0.0125 -9 -9 ]
[.21534 -0.0125 9 0 ]
[.35767 -0.0125 -6 -9 ]
[.35767 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64233 -0.0125 -3 -9 ]
[.64233 -0.0125 3 0 ]
[.78466 -0.0125 -6 -9 ]
[.78466 -0.0125 6 0 ]
[.92698 -0.0125 -6 -9 ]
[.92698 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06927 -42 -4.5 ]
[-0.0125 .06927 0 4.5 ]
[-0.0125 .17837 -36 -4.5 ]
[-0.0125 .17837 0 4.5 ]
[-0.0125 .28747 -42 -4.5 ]
[-0.0125 .28747 0 4.5 ]
[-0.0125 .39657 -36 -4.5 ]
[-0.0125 .39657 0 4.5 ]
[-0.0125 .50567 -42 -4.5 ]
[-0.0125 .50567 0 4.5 ]
[-0.0125 .61478 -36 -4.5 ]
[-0.0125 .61478 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07302 0 m
.07302 .00625 L
s
[(-15)] .07302 -0.0125 0 1 Mshowa
.21534 0 m
.21534 .00625 L
s
[(-10)] .21534 -0.0125 0 1 Mshowa
.35767 0 m
.35767 .00625 L
s
[(-5)] .35767 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64233 0 m
.64233 .00625 L
s
[(5)] .64233 -0.0125 0 1 Mshowa
.78466 0 m
.78466 .00625 L
s
[(10)] .78466 -0.0125 0 1 Mshowa
.92698 0 m
.92698 .00625 L
s
[(15)] .92698 -0.0125 0 1 Mshowa
.125 Mabswid
.10148 0 m
.10148 .00375 L
s
.12995 0 m
.12995 .00375 L
s
.15841 0 m
.15841 .00375 L
s
.18688 0 m
.18688 .00375 L
s
.24381 0 m
.24381 .00375 L
s
.27228 0 m
.27228 .00375 L
s
.30074 0 m
.30074 .00375 L
s
.32921 0 m
.32921 .00375 L
s
.38614 0 m
.38614 .00375 L
s
.4146 0 m
.4146 .00375 L
s
.44307 0 m
.44307 .00375 L
s
.47153 0 m
.47153 .00375 L
s
.52847 0 m
.52847 .00375 L
s
.55693 0 m
.55693 .00375 L
s
.5854 0 m
.5854 .00375 L
s
.61386 0 m
.61386 .00375 L
s
.67079 0 m
.67079 .00375 L
s
.69926 0 m
.69926 .00375 L
s
.72772 0 m
.72772 .00375 L
s
.75619 0 m
.75619 .00375 L
s
.81312 0 m
.81312 .00375 L
s
.84159 0 m
.84159 .00375 L
s
.87005 0 m
.87005 .00375 L
s
.89852 0 m
.89852 .00375 L
s
.04455 0 m
.04455 .00375 L
s
.01608 0 m
.01608 .00375 L
s
.95545 0 m
.95545 .00375 L
s
.98392 0 m
.98392 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06927 m
.00625 .06927 L
s
[(155.235)] -0.0125 .06927 1 0 Mshowa
0 .17837 m
.00625 .17837 L
s
[(155.24)] -0.0125 .17837 1 0 Mshowa
0 .28747 m
.00625 .28747 L
s
[(155.245)] -0.0125 .28747 1 0 Mshowa
0 .39657 m
.00625 .39657 L
s
[(155.25)] -0.0125 .39657 1 0 Mshowa
0 .50567 m
.00625 .50567 L
s
[(155.255)] -0.0125 .50567 1 0 Mshowa
0 .61478 m
.00625 .61478 L
s
[(155.26)] -0.0125 .61478 1 0 Mshowa
.125 Mabswid
0 .09109 m
.00375 .09109 L
s
0 .11291 m
.00375 .11291 L
s
0 .13473 m
.00375 .13473 L
s
0 .15655 m
.00375 .15655 L
s
0 .20019 m
.00375 .20019 L
s
0 .22201 m
.00375 .22201 L
s
0 .24383 m
.00375 .24383 L
s
0 .26565 m
.00375 .26565 L
s
0 .30929 m
.00375 .30929 L
s
0 .33111 m
.00375 .33111 L
s
0 .35293 m
.00375 .35293 L
s
0 .37475 m
.00375 .37475 L
s
0 .41839 m
.00375 .41839 L
s
0 .44021 m
.00375 .44021 L
s
0 .46203 m
.00375 .46203 L
s
0 .48385 m
.00375 .48385 L
s
0 .52749 m
.00375 .52749 L
s
0 .54931 m
.00375 .54931 L
s
0 .57114 m
.00375 .57114 L
s
0 .59296 m
.00375 .59296 L
s
0 .04745 m
.00375 .04745 L
s
0 .02563 m
.00375 .02563 L
s
0 .00381 m
.00375 .00381 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07302 .61178 m
.07302 .61803 L
s
.21534 .61178 m
.21534 .61803 L
s
.35767 .61178 m
.35767 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64233 .61178 m
.64233 .61803 L
s
.78466 .61178 m
.78466 .61803 L
s
.92698 .61178 m
.92698 .61803 L
s
.125 Mabswid
.10148 .61428 m
.10148 .61803 L
s
.12995 .61428 m
.12995 .61803 L
s
.15841 .61428 m
.15841 .61803 L
s
.18688 .61428 m
.18688 .61803 L
s
.24381 .61428 m
.24381 .61803 L
s
.27228 .61428 m
.27228 .61803 L
s
.30074 .61428 m
.30074 .61803 L
s
.32921 .61428 m
.32921 .61803 L
s
.38614 .61428 m
.38614 .61803 L
s
.4146 .61428 m
.4146 .61803 L
s
.44307 .61428 m
.44307 .61803 L
s
.47153 .61428 m
.47153 .61803 L
s
.52847 .61428 m
.52847 .61803 L
s
.55693 .61428 m
.55693 .61803 L
s
.5854 .61428 m
.5854 .61803 L
s
.61386 .61428 m
.61386 .61803 L
s
.67079 .61428 m
.67079 .61803 L
s
.69926 .61428 m
.69926 .61803 L
s
.72772 .61428 m
.72772 .61803 L
s
.75619 .61428 m
.75619 .61803 L
s
.81312 .61428 m
.81312 .61803 L
s
.84159 .61428 m
.84159 .61803 L
s
.87005 .61428 m
.87005 .61803 L
s
.89852 .61428 m
.89852 .61803 L
s
.04455 .61428 m
.04455 .61803 L
s
.01608 .61428 m
.01608 .61803 L
s
.95545 .61428 m
.95545 .61803 L
s
.98392 .61428 m
.98392 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06927 m
1 .06927 L
s
.99375 .17837 m
1 .17837 L
s
.99375 .28747 m
1 .28747 L
s
.99375 .39657 m
1 .39657 L
s
.99375 .50567 m
1 .50567 L
s
.99375 .61478 m
1 .61478 L
s
.125 Mabswid
.99625 .09109 m
1 .09109 L
s
.99625 .11291 m
1 .11291 L
s
.99625 .13473 m
1 .13473 L
s
.99625 .15655 m
1 .15655 L
s
.99625 .20019 m
1 .20019 L
s
.99625 .22201 m
1 .22201 L
s
.99625 .24383 m
1 .24383 L
s
.99625 .26565 m
1 .26565 L
s
.99625 .30929 m
1 .30929 L
s
.99625 .33111 m
1 .33111 L
s
.99625 .35293 m
1 .35293 L
s
.99625 .37475 m
1 .37475 L
s
.99625 .41839 m
1 .41839 L
s
.99625 .44021 m
1 .44021 L
s
.99625 .46203 m
1 .46203 L
s
.99625 .48385 m
1 .48385 L
s
.99625 .52749 m
1 .52749 L
s
.99625 .54931 m
1 .54931 L
s
.99625 .57114 m
1 .57114 L
s
.99625 .59296 m
1 .59296 L
s
.99625 .04745 m
1 .04745 L
s
.99625 .02563 m
1 .02563 L
s
.99625 .00381 m
1 .00381 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .06927 m
1 .06927 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.97619 .60332 Mdot
.94697 .58474 Mdot
.91743 .55331 Mdot
.88759 .51189 Mdot
.85748 .46316 Mdot
.82714 .40964 Mdot
.79658 .35362 Mdot
.76584 .29721 Mdot
.73494 .24229 Mdot
.70389 .19055 Mdot
.67272 .14347 Mdot
.64146 .1023 Mdot
.6101 .06811 Mdot
.57869 .04173 Mdot
.54723 .02379 Mdot
.51575 .01472 Mdot
.48425 .01472 Mdot
.45277 .02379 Mdot
.42131 .04173 Mdot
.3899 .06811 Mdot
.35854 .1023 Mdot
.32728 .14347 Mdot
.29611 .19055 Mdot
.26506 .24229 Mdot
.23416 .29721 Mdot
.20342 .35362 Mdot
.17286 .40964 Mdot
.14252 .46316 Mdot
.11241 .51189 Mdot
.08257 .55331 Mdot
.05303 .58474 Mdot
.02381 .60332 Mdot
.5 Mabswid
.02381 .60332 m
.03837 .59406 L
.04579 .58935 L
.04987 .58675 L
.05187 .58548 L
.05372 .58401 L
.05574 .58185 L
.05794 .57952 L
.06178 .57543 L
.06929 .56744 L
.08634 .54808 L
.11681 .50478 L
.1461 .45685 L
.17729 .40153 L
.20731 .34649 L
.23922 .28821 L
.26996 .23412 L
.29953 .18538 L
.331 .13857 L
.36129 .0993 L
.39349 .06509 L
.40964 .05153 L
.42451 .0399 L
.43994 .0311 L
.44748 .02681 L
.45077 .02493 L
.45167 .02442 L
.45251 .02394 L
.45338 .02361 L
.45435 .02333 L
.45623 .02279 L
.45796 .02229 L
.46138 .02131 L
.46892 .01913 L
.47672 .01689 L
.48097 .01566 L
.48203 .01535 L
.48304 .01506 L
.48394 .0148 L
.48492 .01472 L
.48583 .01472 L
.4868 .01472 L
.48853 .01472 L
.49238 .01472 L
.50055 .01472 L
.50803 .01472 L
.51131 .01472 L
.51303 .01472 L
.51398 .01472 L
.51487 .01472 L
Mistroke
.51589 .01476 L
.51682 .01502 L
.51862 .01554 L
.52218 .01657 L
.53003 .01883 L
.53679 .02078 L
.54421 .02292 L
.5461 .02346 L
.54665 .02362 L
.54716 .02377 L
.54813 .0243 L
.55178 .02638 L
.55978 .03094 L
.57409 .0391 L
.60381 .06282 L
.63542 .09572 L
.66586 .13443 L
.69513 .17731 L
.72629 .22788 L
.75628 .28022 L
.78818 .33819 L
.81889 .39452 L
.84844 .44721 L
.87988 .49941 L
.91015 .54321 L
.92559 .562 L
.94232 .57979 L
.95845 .59204 L
.97331 .60149 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{145., 432.}, {373., 196.}} -> {-45.167268815394706, \
155.26592361335227, 0.1452561682183674, \
0.0001894943209519967}},ExpressionUUID->"aa6d3689-7f0b-4aff-863c-\
2921af87781c"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0284656 -1.36833 0.66001 [
[.07302 -0.0125 -9 -9 ]
[.07302 -0.0125 9 0 ]
[.21534 -0.0125 -9 -9 ]
[.21534 -0.0125 9 0 ]
[.35767 -0.0125 -6 -9 ]
[.35767 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64233 -0.0125 -3 -9 ]
[.64233 -0.0125 3 0 ]
[.78466 -0.0125 -6 -9 ]
[.78466 -0.0125 6 0 ]
[.92698 -0.0125 -6 -9 ]
[.92698 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0837 -18 -4.5 ]
[-0.0125 .0837 0 4.5 ]
[-0.0125 .2157 -18 -4.5 ]
[-0.0125 .2157 0 4.5 ]
[-0.0125 .3477 -18 -4.5 ]
[-0.0125 .3477 0 4.5 ]
[-0.0125 .4797 -18 -4.5 ]
[-0.0125 .4797 0 4.5 ]
[-0.0125 .6117 -6 -4.5 ]
[-0.0125 .6117 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07302 0 m
.07302 .00625 L
s
[(-15)] .07302 -0.0125 0 1 Mshowa
.21534 0 m
.21534 .00625 L
s
[(-10)] .21534 -0.0125 0 1 Mshowa
.35767 0 m
.35767 .00625 L
s
[(-5)] .35767 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64233 0 m
.64233 .00625 L
s
[(5)] .64233 -0.0125 0 1 Mshowa
.78466 0 m
.78466 .00625 L
s
[(10)] .78466 -0.0125 0 1 Mshowa
.92698 0 m
.92698 .00625 L
s
[(15)] .92698 -0.0125 0 1 Mshowa
.125 Mabswid
.10148 0 m
.10148 .00375 L
s
.12995 0 m
.12995 .00375 L
s
.15841 0 m
.15841 .00375 L
s
.18688 0 m
.18688 .00375 L
s
.24381 0 m
.24381 .00375 L
s
.27228 0 m
.27228 .00375 L
s
.30074 0 m
.30074 .00375 L
s
.32921 0 m
.32921 .00375 L
s
.38614 0 m
.38614 .00375 L
s
.4146 0 m
.4146 .00375 L
s
.44307 0 m
.44307 .00375 L
s
.47153 0 m
.47153 .00375 L
s
.52847 0 m
.52847 .00375 L
s
.55693 0 m
.55693 .00375 L
s
.5854 0 m
.5854 .00375 L
s
.61386 0 m
.61386 .00375 L
s
.67079 0 m
.67079 .00375 L
s
.69926 0 m
.69926 .00375 L
s
.72772 0 m
.72772 .00375 L
s
.75619 0 m
.75619 .00375 L
s
.81312 0 m
.81312 .00375 L
s
.84159 0 m
.84159 .00375 L
s
.87005 0 m
.87005 .00375 L
s
.89852 0 m
.89852 .00375 L
s
.04455 0 m
.04455 .00375 L
s
.01608 0 m
.01608 .00375 L
s
.95545 0 m
.95545 .00375 L
s
.98392 0 m
.98392 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0837 m
.00625 .0837 L
s
[(2.2)] -0.0125 .0837 1 0 Mshowa
0 .2157 m
.00625 .2157 L
s
[(2.4)] -0.0125 .2157 1 0 Mshowa
0 .3477 m
.00625 .3477 L
s
[(2.6)] -0.0125 .3477 1 0 Mshowa
0 .4797 m
.00625 .4797 L
s
[(2.8)] -0.0125 .4797 1 0 Mshowa
0 .6117 m
.00625 .6117 L
s
[(3)] -0.0125 .6117 1 0 Mshowa
.125 Mabswid
0 .1167 m
.00375 .1167 L
s
0 .1497 m
.00375 .1497 L
s
0 .1827 m
.00375 .1827 L
s
0 .2487 m
.00375 .2487 L
s
0 .2817 m
.00375 .2817 L
s
0 .3147 m
.00375 .3147 L
s
0 .3807 m
.00375 .3807 L
s
0 .4137 m
.00375 .4137 L
s
0 .4467 m
.00375 .4467 L
s
0 .5127 m
.00375 .5127 L
s
0 .5457 m
.00375 .5457 L
s
0 .5787 m
.00375 .5787 L
s
0 .0507 m
.00375 .0507 L
s
0 .01769 m
.00375 .01769 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07302 .61178 m
.07302 .61803 L
s
.21534 .61178 m
.21534 .61803 L
s
.35767 .61178 m
.35767 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64233 .61178 m
.64233 .61803 L
s
.78466 .61178 m
.78466 .61803 L
s
.92698 .61178 m
.92698 .61803 L
s
.125 Mabswid
.10148 .61428 m
.10148 .61803 L
s
.12995 .61428 m
.12995 .61803 L
s
.15841 .61428 m
.15841 .61803 L
s
.18688 .61428 m
.18688 .61803 L
s
.24381 .61428 m
.24381 .61803 L
s
.27228 .61428 m
.27228 .61803 L
s
.30074 .61428 m
.30074 .61803 L
s
.32921 .61428 m
.32921 .61803 L
s
.38614 .61428 m
.38614 .61803 L
s
.4146 .61428 m
.4146 .61803 L
s
.44307 .61428 m
.44307 .61803 L
s
.47153 .61428 m
.47153 .61803 L
s
.52847 .61428 m
.52847 .61803 L
s
.55693 .61428 m
.55693 .61803 L
s
.5854 .61428 m
.5854 .61803 L
s
.61386 .61428 m
.61386 .61803 L
s
.67079 .61428 m
.67079 .61803 L
s
.69926 .61428 m
.69926 .61803 L
s
.72772 .61428 m
.72772 .61803 L
s
.75619 .61428 m
.75619 .61803 L
s
.81312 .61428 m
.81312 .61803 L
s
.84159 .61428 m
.84159 .61803 L
s
.87005 .61428 m
.87005 .61803 L
s
.89852 .61428 m
.89852 .61803 L
s
.04455 .61428 m
.04455 .61803 L
s
.01608 .61428 m
.01608 .61803 L
s
.95545 .61428 m
.95545 .61803 L
s
.98392 .61428 m
.98392 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0837 m
1 .0837 L
s
.99375 .2157 m
1 .2157 L
s
.99375 .3477 m
1 .3477 L
s
.99375 .4797 m
1 .4797 L
s
.99375 .6117 m
1 .6117 L
s
.125 Mabswid
.99625 .1167 m
1 .1167 L
s
.99625 .1497 m
1 .1497 L
s
.99625 .1827 m
1 .1827 L
s
.99625 .2487 m
1 .2487 L
s
.99625 .2817 m
1 .2817 L
s
.99625 .3147 m
1 .3147 L
s
.99625 .3807 m
1 .3807 L
s
.99625 .4137 m
1 .4137 L
s
.99625 .4467 m
1 .4467 L
s
.99625 .5127 m
1 .5127 L
s
.99625 .5457 m
1 .5457 L
s
.99625 .5787 m
1 .5787 L
s
.99625 .0507 m
1 .0507 L
s
.99625 .01769 m
1 .01769 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .0837 m
1 .0837 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .03562 m
.03837 .29638 L
.05372 .49288 L
.05761 .54273 L
.05815 .54961 L
.05874 .55708 L
.05929 .56414 L
.0598 .56548 L
.06076 .56665 L
.06178 .5679 L
.06929 .57704 L
.0775 .58705 L
.08203 .59257 L
.08634 .59782 L
.08817 .60004 L
.08917 .60127 L
.09012 .60234 L
.09066 .60206 L
.09124 .60175 L
.09225 .60122 L
.09424 .60019 L
.10146 .59643 L
.11563 .58905 L
.14738 .57247 L
.17795 .5583 L
.20735 .54646 L
.23864 .53551 L
.26876 .5265 L
.30079 .51836 L
.33163 .51186 L
.36131 .50676 L
.39288 .50239 L
.40856 .50074 L
.42328 .49936 L
.43735 .49835 L
.45251 .49743 L
.45609 .49721 L
.45704 .49715 L
.45806 .49709 L
.45903 .49704 L
.45992 .49702 L
.46212 .49696 L
.46412 .4969 L
.46802 .4968 L
.47646 .49656 L
.48059 .49645 L
.48436 .49635 L
.48608 .4963 L
.48795 .49625 L
.48881 .49623 L
Mistroke
.48972 .49621 L
.49058 .49621 L
.49136 .49622 L
.49888 .49626 L
.50721 .4963 L
.51086 .49632 L
.51486 .49634 L
.51668 .49635 L
.51768 .49636 L
.51862 .49636 L
.5195 .49637 L
.52046 .49638 L
.52133 .49641 L
.52213 .49645 L
.52979 .49674 L
.53812 .49705 L
.54592 .49735 L
.54932 .49748 L
.55015 .49751 L
.55103 .49755 L
.552 .49762 L
.5529 .49768 L
.55681 .49796 L
.5604 .49822 L
.57636 .49936 L
.60853 .50257 L
.63953 .5068 L
.66935 .51198 L
.70107 .5187 L
.73161 .52649 L
.76098 .5353 L
.79226 .54619 L
.82235 .55833 L
.85435 .57319 L
.88517 .58972 L
.89926 .59569 L
.90728 .59875 L
.91121 .60025 L
.91482 .60162 L
.91668 .60233 L
.9184 .60299 L
.91927 .60332 L
.92021 .60131 L
.92074 .59956 L
.92124 .5979 L
.92218 .5948 L
.93011 .5686 L
.93801 .54254 L
.94233 .52828 L
.94637 .51493 L
Mistroke
.94819 .50892 L
.94909 .50596 L
.94992 .50321 L
.95087 .49095 L
.95138 .48148 L
.95191 .47139 L
.95374 .4371 L
.96185 .28455 L
.97613 .01593 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{145., 432.}, {557., 380.}} -> {-42.47803953249685, \
4.3275785553772765, 0.1420751461069072, \
0.006127565156620016}},ExpressionUUID->"56ebce11-de08-447e-b8e6-d0eb3374c6e8"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0284656 0.0147151 0.0116083 [
[.07302 -0.0125 -9 -9 ]
[.07302 -0.0125 9 0 ]
[.21534 -0.0125 -9 -9 ]
[.21534 -0.0125 9 0 ]
[.35767 -0.0125 -6 -9 ]
[.35767 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64233 -0.0125 -3 -9 ]
[.64233 -0.0125 3 0 ]
[.78466 -0.0125 -6 -9 ]
[.78466 -0.0125 6 0 ]
[.92698 -0.0125 -6 -9 ]
[.92698 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1308 -12 -4.5 ]
[-0.0125 .1308 0 4.5 ]
[-0.0125 .24688 -12 -4.5 ]
[-0.0125 .24688 0 4.5 ]
[-0.0125 .36296 -12 -4.5 ]
[-0.0125 .36296 0 4.5 ]
[-0.0125 .47905 -12 -4.5 ]
[-0.0125 .47905 0 4.5 ]
[-0.0125 .59513 -12 -4.5 ]
[-0.0125 .59513 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07302 0 m
.07302 .00625 L
s
[(-15)] .07302 -0.0125 0 1 Mshowa
.21534 0 m
.21534 .00625 L
s
[(-10)] .21534 -0.0125 0 1 Mshowa
.35767 0 m
.35767 .00625 L
s
[(-5)] .35767 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64233 0 m
.64233 .00625 L
s
[(5)] .64233 -0.0125 0 1 Mshowa
.78466 0 m
.78466 .00625 L
s
[(10)] .78466 -0.0125 0 1 Mshowa
.92698 0 m
.92698 .00625 L
s
[(15)] .92698 -0.0125 0 1 Mshowa
.125 Mabswid
.10148 0 m
.10148 .00375 L
s
.12995 0 m
.12995 .00375 L
s
.15841 0 m
.15841 .00375 L
s
.18688 0 m
.18688 .00375 L
s
.24381 0 m
.24381 .00375 L
s
.27228 0 m
.27228 .00375 L
s
.30074 0 m
.30074 .00375 L
s
.32921 0 m
.32921 .00375 L
s
.38614 0 m
.38614 .00375 L
s
.4146 0 m
.4146 .00375 L
s
.44307 0 m
.44307 .00375 L
s
.47153 0 m
.47153 .00375 L
s
.52847 0 m
.52847 .00375 L
s
.55693 0 m
.55693 .00375 L
s
.5854 0 m
.5854 .00375 L
s
.61386 0 m
.61386 .00375 L
s
.67079 0 m
.67079 .00375 L
s
.69926 0 m
.69926 .00375 L
s
.72772 0 m
.72772 .00375 L
s
.75619 0 m
.75619 .00375 L
s
.81312 0 m
.81312 .00375 L
s
.84159 0 m
.84159 .00375 L
s
.87005 0 m
.87005 .00375 L
s
.89852 0 m
.89852 .00375 L
s
.04455 0 m
.04455 .00375 L
s
.01608 0 m
.01608 .00375 L
s
.95545 0 m
.95545 .00375 L
s
.98392 0 m
.98392 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1308 m
.00625 .1308 L
s
[(10)] -0.0125 .1308 1 0 Mshowa
0 .24688 m
.00625 .24688 L
s
[(20)] -0.0125 .24688 1 0 Mshowa
0 .36296 m
.00625 .36296 L
s
[(30)] -0.0125 .36296 1 0 Mshowa
0 .47905 m
.00625 .47905 L
s
[(40)] -0.0125 .47905 1 0 Mshowa
0 .59513 m
.00625 .59513 L
s
[(50)] -0.0125 .59513 1 0 Mshowa
.125 Mabswid
0 .03793 m
.00375 .03793 L
s
0 .06115 m
.00375 .06115 L
s
0 .08437 m
.00375 .08437 L
s
0 .10758 m
.00375 .10758 L
s
0 .15402 m
.00375 .15402 L
s
0 .17723 m
.00375 .17723 L
s
0 .20045 m
.00375 .20045 L
s
0 .22367 m
.00375 .22367 L
s
0 .2701 m
.00375 .2701 L
s
0 .29331 m
.00375 .29331 L
s
0 .31653 m
.00375 .31653 L
s
0 .33975 m
.00375 .33975 L
s
0 .38618 m
.00375 .38618 L
s
0 .4094 m
.00375 .4094 L
s
0 .43261 m
.00375 .43261 L
s
0 .45583 m
.00375 .45583 L
s
0 .50226 m
.00375 .50226 L
s
0 .52548 m
.00375 .52548 L
s
0 .5487 m
.00375 .5487 L
s
0 .57191 m
.00375 .57191 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07302 .61178 m
.07302 .61803 L
s
.21534 .61178 m
.21534 .61803 L
s
.35767 .61178 m
.35767 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64233 .61178 m
.64233 .61803 L
s
.78466 .61178 m
.78466 .61803 L
s
.92698 .61178 m
.92698 .61803 L
s
.125 Mabswid
.10148 .61428 m
.10148 .61803 L
s
.12995 .61428 m
.12995 .61803 L
s
.15841 .61428 m
.15841 .61803 L
s
.18688 .61428 m
.18688 .61803 L
s
.24381 .61428 m
.24381 .61803 L
s
.27228 .61428 m
.27228 .61803 L
s
.30074 .61428 m
.30074 .61803 L
s
.32921 .61428 m
.32921 .61803 L
s
.38614 .61428 m
.38614 .61803 L
s
.4146 .61428 m
.4146 .61803 L
s
.44307 .61428 m
.44307 .61803 L
s
.47153 .61428 m
.47153 .61803 L
s
.52847 .61428 m
.52847 .61803 L
s
.55693 .61428 m
.55693 .61803 L
s
.5854 .61428 m
.5854 .61803 L
s
.61386 .61428 m
.61386 .61803 L
s
.67079 .61428 m
.67079 .61803 L
s
.69926 .61428 m
.69926 .61803 L
s
.72772 .61428 m
.72772 .61803 L
s
.75619 .61428 m
.75619 .61803 L
s
.81312 .61428 m
.81312 .61803 L
s
.84159 .61428 m
.84159 .61803 L
s
.87005 .61428 m
.87005 .61803 L
s
.89852 .61428 m
.89852 .61803 L
s
.04455 .61428 m
.04455 .61803 L
s
.01608 .61428 m
.01608 .61803 L
s
.95545 .61428 m
.95545 .61803 L
s
.98392 .61428 m
.98392 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1308 m
1 .1308 L
s
.99375 .24688 m
1 .24688 L
s
.99375 .36296 m
1 .36296 L
s
.99375 .47905 m
1 .47905 L
s
.99375 .59513 m
1 .59513 L
s
.125 Mabswid
.99625 .03793 m
1 .03793 L
s
.99625 .06115 m
1 .06115 L
s
.99625 .08437 m
1 .08437 L
s
.99625 .10758 m
1 .10758 L
s
.99625 .15402 m
1 .15402 L
s
.99625 .17723 m
1 .17723 L
s
.99625 .20045 m
1 .20045 L
s
.99625 .22367 m
1 .22367 L
s
.99625 .2701 m
1 .2701 L
s
.99625 .29331 m
1 .29331 L
s
.99625 .31653 m
1 .31653 L
s
.99625 .33975 m
1 .33975 L
s
.99625 .38618 m
1 .38618 L
s
.99625 .4094 m
1 .4094 L
s
.99625 .43261 m
1 .43261 L
s
.99625 .45583 m
1 .45583 L
s
.99625 .50226 m
1 .50226 L
s
.99625 .52548 m
1 .52548 L
s
.99625 .5487 m
1 .5487 L
s
.99625 .57191 m
1 .57191 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.97619 .60332 Mdot
.94697 .58474 Mdot
.91743 .55331 Mdot
.88759 .51189 Mdot
.85748 .46316 Mdot
.82714 .40964 Mdot
.79658 .35362 Mdot
.76584 .29721 Mdot
.73494 .24229 Mdot
.70389 .19055 Mdot
.67272 .14347 Mdot
.64146 .1023 Mdot
.6101 .06811 Mdot
.57869 .04173 Mdot
.54723 .02379 Mdot
.51575 .01472 Mdot
.48425 .01472 Mdot
.45277 .02379 Mdot
.42131 .04173 Mdot
.3899 .06811 Mdot
.35854 .1023 Mdot
.32728 .14347 Mdot
.29611 .19055 Mdot
.26506 .24229 Mdot
.23416 .29721 Mdot
.20342 .35362 Mdot
.17286 .40964 Mdot
.14252 .46316 Mdot
.11241 .51189 Mdot
.08257 .55331 Mdot
.05303 .58474 Mdot
.02381 .60332 Mdot
.5 Mabswid
.02381 .60332 m
.03837 .59406 L
.04579 .58935 L
.04987 .58675 L
.05187 .58548 L
.05372 .58401 L
.05574 .58185 L
.05794 .57952 L
.06178 .57543 L
.06929 .56744 L
.08634 .54808 L
.11681 .50478 L
.1461 .45685 L
.17729 .40153 L
.20731 .34649 L
.23922 .28821 L
.26996 .23412 L
.29953 .18538 L
.331 .13857 L
.36129 .0993 L
.39349 .06509 L
.40964 .05153 L
.42451 .0399 L
.43994 .0311 L
.44748 .02681 L
.45077 .02493 L
.45167 .02442 L
.45251 .02394 L
.45338 .02361 L
.45435 .02333 L
.45623 .02279 L
.45796 .02229 L
.46138 .02131 L
.46892 .01913 L
.47672 .01689 L
.48097 .01566 L
.48203 .01535 L
.48304 .01506 L
.48394 .0148 L
.48492 .01472 L
.48583 .01472 L
.4868 .01472 L
.48762 .01472 L
.48853 .01472 L
.48949 .01472 L
.49003 .01472 L
.49052 .01472 L
.49148 .01472 L
.49238 .01472 L
.49337 .01472 L
Mistroke
.49391 .01472 L
.49441 .01472 L
.49538 .01472 L
.49629 .01472 L
.49681 .01472 L
.49736 .01472 L
.49834 .01472 L
.49888 .01472 L
.49939 .01472 L
.49995 .01472 L
.50055 .01472 L
.50151 .01472 L
.50239 .01472 L
.50337 .01472 L
.50386 .01472 L
.5044 .01472 L
.50531 .01472 L
.50628 .01472 L
.5072 .01472 L
.50805 .01472 L
.50887 .01472 L
.50964 .01472 L
.51048 .01472 L
.51137 .01472 L
.51232 .01472 L
.51321 .01472 L
.51401 .01472 L
.51487 .01472 L
.51583 .01474 L
.51671 .01499 L
.51867 .01556 L
.52222 .01658 L
.53029 .01891 L
.53876 .02135 L
.54248 .02242 L
.54446 .02299 L
.5455 .02329 L
.54659 .0236 L
.54751 .02395 L
.54852 .02452 L
.55028 .02553 L
.55375 .0275 L
.56135 .03184 L
.56976 .03664 L
.57742 .041 L
.58521 .0472 L
.59258 .05339 L
.60879 .06701 L
.63855 .09913 L
.6702 .14015 L
Mistroke
.70068 .1857 L
.72999 .23404 L
.7612 .28895 L
.79123 .34379 L
.82316 .40235 L
.85392 .45688 L
.8835 .50528 L
.91498 .54992 L
.92955 .56621 L
.93721 .57435 L
.94529 .58296 L
.94925 .58619 L
.95358 .58895 L
.96121 .59379 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{145., 432.}, {232., 56.}} -> {-42.31657517539038, \
14.133393657736539, 0.14297435589239393, \
0.35059834989537914}},ExpressionUUID->"0970782e-12f3-46ae-b0ea-139c83d904c4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ComponentNumber", "\[Rule]", "2"}], ",", 
    RowBox[{"Energy", "\[Rule]", "100.`"}], ",", 
    RowBox[{"Offset", "\[Rule]", "155.23249973805085`"}], ",", 
    RowBox[{"OpticalLengthFunction", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "16.728633726259073`"}], ",", "16.728633726259073`"}],
           "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
      False,
      Editable->False]}], ",", 
    RowBox[{"OpticalPathDifference", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "16.728633726259073`"}], ",", "16.728633726259073`"}],
           "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
      False,
      Editable->False]}], ",", 
    RowBox[{"OpticalPathRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"155.23249973805085`", ",", "155.2594749592117`"}], "}"}]}], 
    ",", 
    RowBox[{"OutputGraphics", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OpticalLengthFunction", "\[Rule]", 
        RowBox[{"(", 
         TagBox[
          RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
          False,
          Editable->False], ")"}]}], ",", 
       RowBox[{"WaveFrontIntensity", "\[Rule]", 
        RowBox[{"(", 
         TagBox[
          RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
          False,
          Editable->False], ")"}]}], ",", 
       RowBox[{"OpticalPathDifference", "\[Rule]", 
        RowBox[{"(", 
         TagBox[
          RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
          False,
          Editable->False], ")"}]}]}], "}"}]}], ",", 
    RowBox[{"RayBoundary", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "16.728633726259073`"}], ",", "16.728633726259073`"}], 
      "}"}]}], ",", 
    RowBox[{"RefractiveIndex", "\[Rule]", "1.0002694514570802`"}], ",", 
    RowBox[{"Source", "\[Rule]", "1"}], ",", 
    RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
    RowBox[{"SurfaceNumber", "\[Rule]", "1"}], ",", 
    RowBox[{"WaveFrontID", "\[Rule]", "1"}], ",", 
    RowBox[{"WaveFrontIntensity", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "20.876444774042767`"}], ",", "20.135689522592383`"}],
           "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
      False,
      Editable->False]}], ",", 
    RowBox[{"WaveLength", "\[Rule]", "0.532`"}], ",", 
    RowBox[{"WaveTilt", "\[Rule]", "WaveTilt"}]}], "}"}], "}"}]], "Output",Exp\
ressionUUID->"2aa7c747-3929-4f7e-8872-a9c76941dd02"]
}, Open  ]],

Cell[TextData[{
 "Here is the same calculation with ",
 StyleBox["RayTracePrecision->50", "Input"],
 "."
}], "Text",ExpressionUUID->"d3839665-09f6-4321-b574-efbea8d51702"],

Cell[CellGroupData[{

Cell["wav = FindWaveFronts[sys,RayTracePrecision->50]", "Input",ExpressionUUID->"a1c8e8e5-7ac2-48e8-9812-6d9b1384838c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface Location : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentNumber", "\[Rule]", "2"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1"}], ",", 
     RowBox[{"WaveFrontID", "\[Rule]", "1"}], ",", 
     RowBox[{"Source", "\[Rule]", "1"}]}], "}"}]}],
  SequenceForm[
  "Surface Location : ", {
   ComponentNumber -> 2, SurfaceNumber -> 1, WaveFrontID -> 1, Source -> 1}],
  Editable->False]], "Print",ExpressionUUID->"4878dabf-74ae-4e05-8373-\
89c71059af74"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0284656 -3387.18 21.8202 [
[.07302 -0.0125 -9 -9 ]
[.07302 -0.0125 9 0 ]
[.21534 -0.0125 -9 -9 ]
[.21534 -0.0125 9 0 ]
[.35767 -0.0125 -6 -9 ]
[.35767 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64233 -0.0125 -3 -9 ]
[.64233 -0.0125 3 0 ]
[.78466 -0.0125 -6 -9 ]
[.78466 -0.0125 6 0 ]
[.92698 -0.0125 -6 -9 ]
[.92698 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06927 -42 -4.5 ]
[-0.0125 .06927 0 4.5 ]
[-0.0125 .17837 -36 -4.5 ]
[-0.0125 .17837 0 4.5 ]
[-0.0125 .28747 -42 -4.5 ]
[-0.0125 .28747 0 4.5 ]
[-0.0125 .39657 -36 -4.5 ]
[-0.0125 .39657 0 4.5 ]
[-0.0125 .50567 -42 -4.5 ]
[-0.0125 .50567 0 4.5 ]
[-0.0125 .61478 -36 -4.5 ]
[-0.0125 .61478 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -117 0 ]
[.5 .63053 117 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07302 0 m
.07302 .00625 L
s
[(-15)] .07302 -0.0125 0 1 Mshowa
.21534 0 m
.21534 .00625 L
s
[(-10)] .21534 -0.0125 0 1 Mshowa
.35767 0 m
.35767 .00625 L
s
[(-5)] .35767 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64233 0 m
.64233 .00625 L
s
[(5)] .64233 -0.0125 0 1 Mshowa
.78466 0 m
.78466 .00625 L
s
[(10)] .78466 -0.0125 0 1 Mshowa
.92698 0 m
.92698 .00625 L
s
[(15)] .92698 -0.0125 0 1 Mshowa
.125 Mabswid
.10148 0 m
.10148 .00375 L
s
.12995 0 m
.12995 .00375 L
s
.15841 0 m
.15841 .00375 L
s
.18688 0 m
.18688 .00375 L
s
.24381 0 m
.24381 .00375 L
s
.27228 0 m
.27228 .00375 L
s
.30074 0 m
.30074 .00375 L
s
.32921 0 m
.32921 .00375 L
s
.38614 0 m
.38614 .00375 L
s
.4146 0 m
.4146 .00375 L
s
.44307 0 m
.44307 .00375 L
s
.47153 0 m
.47153 .00375 L
s
.52847 0 m
.52847 .00375 L
s
.55693 0 m
.55693 .00375 L
s
.5854 0 m
.5854 .00375 L
s
.61386 0 m
.61386 .00375 L
s
.67079 0 m
.67079 .00375 L
s
.69926 0 m
.69926 .00375 L
s
.72772 0 m
.72772 .00375 L
s
.75619 0 m
.75619 .00375 L
s
.81312 0 m
.81312 .00375 L
s
.84159 0 m
.84159 .00375 L
s
.87005 0 m
.87005 .00375 L
s
.89852 0 m
.89852 .00375 L
s
.04455 0 m
.04455 .00375 L
s
.01608 0 m
.01608 .00375 L
s
.95545 0 m
.95545 .00375 L
s
.98392 0 m
.98392 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06927 m
.00625 .06927 L
s
[(155.235)] -0.0125 .06927 1 0 Mshowa
0 .17837 m
.00625 .17837 L
s
[(155.24)] -0.0125 .17837 1 0 Mshowa
0 .28747 m
.00625 .28747 L
s
[(155.245)] -0.0125 .28747 1 0 Mshowa
0 .39657 m
.00625 .39657 L
s
[(155.25)] -0.0125 .39657 1 0 Mshowa
0 .50567 m
.00625 .50567 L
s
[(155.255)] -0.0125 .50567 1 0 Mshowa
0 .61478 m
.00625 .61478 L
s
[(155.26)] -0.0125 .61478 1 0 Mshowa
.125 Mabswid
0 .09109 m
.00375 .09109 L
s
0 .11291 m
.00375 .11291 L
s
0 .13473 m
.00375 .13473 L
s
0 .15655 m
.00375 .15655 L
s
0 .20019 m
.00375 .20019 L
s
0 .22201 m
.00375 .22201 L
s
0 .24383 m
.00375 .24383 L
s
0 .26565 m
.00375 .26565 L
s
0 .30929 m
.00375 .30929 L
s
0 .33111 m
.00375 .33111 L
s
0 .35293 m
.00375 .35293 L
s
0 .37475 m
.00375 .37475 L
s
0 .41839 m
.00375 .41839 L
s
0 .44021 m
.00375 .44021 L
s
0 .46203 m
.00375 .46203 L
s
0 .48385 m
.00375 .48385 L
s
0 .52749 m
.00375 .52749 L
s
0 .54932 m
.00375 .54932 L
s
0 .57114 m
.00375 .57114 L
s
0 .59296 m
.00375 .59296 L
s
0 .04745 m
.00375 .04745 L
s
0 .02563 m
.00375 .02563 L
s
0 .00381 m
.00375 .00381 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07302 .61178 m
.07302 .61803 L
s
.21534 .61178 m
.21534 .61803 L
s
.35767 .61178 m
.35767 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64233 .61178 m
.64233 .61803 L
s
.78466 .61178 m
.78466 .61803 L
s
.92698 .61178 m
.92698 .61803 L
s
.125 Mabswid
.10148 .61428 m
.10148 .61803 L
s
.12995 .61428 m
.12995 .61803 L
s
.15841 .61428 m
.15841 .61803 L
s
.18688 .61428 m
.18688 .61803 L
s
.24381 .61428 m
.24381 .61803 L
s
.27228 .61428 m
.27228 .61803 L
s
.30074 .61428 m
.30074 .61803 L
s
.32921 .61428 m
.32921 .61803 L
s
.38614 .61428 m
.38614 .61803 L
s
.4146 .61428 m
.4146 .61803 L
s
.44307 .61428 m
.44307 .61803 L
s
.47153 .61428 m
.47153 .61803 L
s
.52847 .61428 m
.52847 .61803 L
s
.55693 .61428 m
.55693 .61803 L
s
.5854 .61428 m
.5854 .61803 L
s
.61386 .61428 m
.61386 .61803 L
s
.67079 .61428 m
.67079 .61803 L
s
.69926 .61428 m
.69926 .61803 L
s
.72772 .61428 m
.72772 .61803 L
s
.75619 .61428 m
.75619 .61803 L
s
.81312 .61428 m
.81312 .61803 L
s
.84159 .61428 m
.84159 .61803 L
s
.87005 .61428 m
.87005 .61803 L
s
.89852 .61428 m
.89852 .61803 L
s
.04455 .61428 m
.04455 .61803 L
s
.01608 .61428 m
.01608 .61803 L
s
.95545 .61428 m
.95545 .61803 L
s
.98392 .61428 m
.98392 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06927 m
1 .06927 L
s
.99375 .17837 m
1 .17837 L
s
.99375 .28747 m
1 .28747 L
s
.99375 .39657 m
1 .39657 L
s
.99375 .50567 m
1 .50567 L
s
.99375 .61478 m
1 .61478 L
s
.125 Mabswid
.99625 .09109 m
1 .09109 L
s
.99625 .11291 m
1 .11291 L
s
.99625 .13473 m
1 .13473 L
s
.99625 .15655 m
1 .15655 L
s
.99625 .20019 m
1 .20019 L
s
.99625 .22201 m
1 .22201 L
s
.99625 .24383 m
1 .24383 L
s
.99625 .26565 m
1 .26565 L
s
.99625 .30929 m
1 .30929 L
s
.99625 .33111 m
1 .33111 L
s
.99625 .35293 m
1 .35293 L
s
.99625 .37475 m
1 .37475 L
s
.99625 .41839 m
1 .41839 L
s
.99625 .44021 m
1 .44021 L
s
.99625 .46203 m
1 .46203 L
s
.99625 .48385 m
1 .48385 L
s
.99625 .52749 m
1 .52749 L
s
.99625 .54932 m
1 .54932 L
s
.99625 .57114 m
1 .57114 L
s
.99625 .59296 m
1 .59296 L
s
.99625 .04745 m
1 .04745 L
s
.99625 .02563 m
1 .02563 L
s
.99625 .00381 m
1 .00381 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .06927 m
1 .06927 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Length \\(absolute distance\\))] .5 .63053 0 -1 Mshowa
.01 w
.97619 .60332 Mdot
.94697 .58474 Mdot
.91743 .55331 Mdot
.88759 .51189 Mdot
.85748 .46316 Mdot
.82714 .40964 Mdot
.79658 .35362 Mdot
.76584 .29721 Mdot
.73494 .24229 Mdot
.70389 .19055 Mdot
.67272 .14347 Mdot
.64146 .1023 Mdot
.6101 .06811 Mdot
.57869 .04173 Mdot
.54723 .02379 Mdot
.51575 .01472 Mdot
.48425 .01472 Mdot
.45277 .02379 Mdot
.42131 .04173 Mdot
.3899 .06811 Mdot
.35854 .1023 Mdot
.32728 .14347 Mdot
.29611 .19055 Mdot
.26506 .24229 Mdot
.23416 .29721 Mdot
.20342 .35362 Mdot
.17286 .40964 Mdot
.14252 .46316 Mdot
.11241 .51189 Mdot
.08257 .55331 Mdot
.05303 .58474 Mdot
.02381 .60332 Mdot
.5 Mabswid
.02381 .60332 m
.03837 .59406 L
.04579 .58935 L
.04987 .58675 L
.05187 .58548 L
.05372 .58401 L
.05574 .58185 L
.05794 .57952 L
.06178 .57543 L
.06929 .56744 L
.08634 .54808 L
.11681 .50478 L
.1461 .45685 L
.17729 .40153 L
.20731 .34649 L
.23922 .28821 L
.26996 .23412 L
.29953 .18538 L
.331 .13857 L
.36129 .0993 L
.39349 .06509 L
.40964 .05153 L
.42451 .0399 L
.43994 .0311 L
.44748 .02681 L
.45077 .02493 L
.45167 .02442 L
.45251 .02394 L
.45338 .02361 L
.45435 .02333 L
.45623 .02279 L
.45796 .02229 L
.46138 .02131 L
.46892 .01913 L
.47672 .01689 L
.48097 .01566 L
.48203 .01535 L
.48304 .01506 L
.48394 .0148 L
.48492 .01472 L
.48583 .01472 L
.4868 .01472 L
.48853 .01472 L
.49238 .01472 L
.50055 .01472 L
.50803 .01472 L
.51131 .01472 L
.51303 .01472 L
.51398 .01472 L
.51487 .01472 L
Mistroke
.51589 .01476 L
.51682 .01502 L
.51862 .01554 L
.52218 .01657 L
.53003 .01883 L
.53679 .02078 L
.54421 .02292 L
.5461 .02346 L
.54665 .02362 L
.54716 .02377 L
.54813 .0243 L
.55178 .02638 L
.55978 .03094 L
.57409 .0391 L
.60381 .06282 L
.63542 .09572 L
.66586 .13443 L
.69513 .17731 L
.72629 .22788 L
.75628 .28022 L
.78818 .33819 L
.81889 .39452 L
.84844 .44721 L
.87988 .49941 L
.91015 .54321 L
.92559 .562 L
.94232 .57979 L
.95845 .59204 L
.97331 .60149 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{145., 432.}, {232., 56.}} -> {-45.167268815394706, \
155.23948915557946, 0.1452561682183674, \
0.0001894943209519967}},ExpressionUUID->"9cf38bf0-7b71-4e6f-9368-\
7c20d95942a6"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0284656 -1.36833 0.66001 [
[.07302 -0.0125 -9 -9 ]
[.07302 -0.0125 9 0 ]
[.21534 -0.0125 -9 -9 ]
[.21534 -0.0125 9 0 ]
[.35767 -0.0125 -6 -9 ]
[.35767 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64233 -0.0125 -3 -9 ]
[.64233 -0.0125 3 0 ]
[.78466 -0.0125 -6 -9 ]
[.78466 -0.0125 6 0 ]
[.92698 -0.0125 -6 -9 ]
[.92698 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .0837 -18 -4.5 ]
[-0.0125 .0837 0 4.5 ]
[-0.0125 .2157 -18 -4.5 ]
[-0.0125 .2157 0 4.5 ]
[-0.0125 .3477 -18 -4.5 ]
[-0.0125 .3477 0 4.5 ]
[-0.0125 .4797 -18 -4.5 ]
[-0.0125 .4797 0 4.5 ]
[-0.0125 .6117 -6 -4.5 ]
[-0.0125 .6117 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -57 0 ]
[.5 .63053 57 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07302 0 m
.07302 .00625 L
s
[(-15)] .07302 -0.0125 0 1 Mshowa
.21534 0 m
.21534 .00625 L
s
[(-10)] .21534 -0.0125 0 1 Mshowa
.35767 0 m
.35767 .00625 L
s
[(-5)] .35767 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64233 0 m
.64233 .00625 L
s
[(5)] .64233 -0.0125 0 1 Mshowa
.78466 0 m
.78466 .00625 L
s
[(10)] .78466 -0.0125 0 1 Mshowa
.92698 0 m
.92698 .00625 L
s
[(15)] .92698 -0.0125 0 1 Mshowa
.125 Mabswid
.10148 0 m
.10148 .00375 L
s
.12995 0 m
.12995 .00375 L
s
.15841 0 m
.15841 .00375 L
s
.18688 0 m
.18688 .00375 L
s
.24381 0 m
.24381 .00375 L
s
.27228 0 m
.27228 .00375 L
s
.30074 0 m
.30074 .00375 L
s
.32921 0 m
.32921 .00375 L
s
.38614 0 m
.38614 .00375 L
s
.4146 0 m
.4146 .00375 L
s
.44307 0 m
.44307 .00375 L
s
.47153 0 m
.47153 .00375 L
s
.52847 0 m
.52847 .00375 L
s
.55693 0 m
.55693 .00375 L
s
.5854 0 m
.5854 .00375 L
s
.61386 0 m
.61386 .00375 L
s
.67079 0 m
.67079 .00375 L
s
.69926 0 m
.69926 .00375 L
s
.72772 0 m
.72772 .00375 L
s
.75619 0 m
.75619 .00375 L
s
.81312 0 m
.81312 .00375 L
s
.84159 0 m
.84159 .00375 L
s
.87005 0 m
.87005 .00375 L
s
.89852 0 m
.89852 .00375 L
s
.04455 0 m
.04455 .00375 L
s
.01608 0 m
.01608 .00375 L
s
.95545 0 m
.95545 .00375 L
s
.98392 0 m
.98392 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .0837 m
.00625 .0837 L
s
[(2.2)] -0.0125 .0837 1 0 Mshowa
0 .2157 m
.00625 .2157 L
s
[(2.4)] -0.0125 .2157 1 0 Mshowa
0 .3477 m
.00625 .3477 L
s
[(2.6)] -0.0125 .3477 1 0 Mshowa
0 .4797 m
.00625 .4797 L
s
[(2.8)] -0.0125 .4797 1 0 Mshowa
0 .6117 m
.00625 .6117 L
s
[(3)] -0.0125 .6117 1 0 Mshowa
.125 Mabswid
0 .1167 m
.00375 .1167 L
s
0 .1497 m
.00375 .1497 L
s
0 .1827 m
.00375 .1827 L
s
0 .2487 m
.00375 .2487 L
s
0 .2817 m
.00375 .2817 L
s
0 .3147 m
.00375 .3147 L
s
0 .3807 m
.00375 .3807 L
s
0 .4137 m
.00375 .4137 L
s
0 .4467 m
.00375 .4467 L
s
0 .5127 m
.00375 .5127 L
s
0 .5457 m
.00375 .5457 L
s
0 .5787 m
.00375 .5787 L
s
0 .0507 m
.00375 .0507 L
s
0 .01769 m
.00375 .01769 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07302 .61178 m
.07302 .61803 L
s
.21534 .61178 m
.21534 .61803 L
s
.35767 .61178 m
.35767 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64233 .61178 m
.64233 .61803 L
s
.78466 .61178 m
.78466 .61803 L
s
.92698 .61178 m
.92698 .61803 L
s
.125 Mabswid
.10148 .61428 m
.10148 .61803 L
s
.12995 .61428 m
.12995 .61803 L
s
.15841 .61428 m
.15841 .61803 L
s
.18688 .61428 m
.18688 .61803 L
s
.24381 .61428 m
.24381 .61803 L
s
.27228 .61428 m
.27228 .61803 L
s
.30074 .61428 m
.30074 .61803 L
s
.32921 .61428 m
.32921 .61803 L
s
.38614 .61428 m
.38614 .61803 L
s
.4146 .61428 m
.4146 .61803 L
s
.44307 .61428 m
.44307 .61803 L
s
.47153 .61428 m
.47153 .61803 L
s
.52847 .61428 m
.52847 .61803 L
s
.55693 .61428 m
.55693 .61803 L
s
.5854 .61428 m
.5854 .61803 L
s
.61386 .61428 m
.61386 .61803 L
s
.67079 .61428 m
.67079 .61803 L
s
.69926 .61428 m
.69926 .61803 L
s
.72772 .61428 m
.72772 .61803 L
s
.75619 .61428 m
.75619 .61803 L
s
.81312 .61428 m
.81312 .61803 L
s
.84159 .61428 m
.84159 .61803 L
s
.87005 .61428 m
.87005 .61803 L
s
.89852 .61428 m
.89852 .61803 L
s
.04455 .61428 m
.04455 .61803 L
s
.01608 .61428 m
.01608 .61803 L
s
.95545 .61428 m
.95545 .61803 L
s
.98392 .61428 m
.98392 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .0837 m
1 .0837 L
s
.99375 .2157 m
1 .2157 L
s
.99375 .3477 m
1 .3477 L
s
.99375 .4797 m
1 .4797 L
s
.99375 .6117 m
1 .6117 L
s
.125 Mabswid
.99625 .1167 m
1 .1167 L
s
.99625 .1497 m
1 .1497 L
s
.99625 .1827 m
1 .1827 L
s
.99625 .2487 m
1 .2487 L
s
.99625 .2817 m
1 .2817 L
s
.99625 .3147 m
1 .3147 L
s
.99625 .3807 m
1 .3807 L
s
.99625 .4137 m
1 .4137 L
s
.99625 .4467 m
1 .4467 L
s
.99625 .5127 m
1 .5127 L
s
.99625 .5457 m
1 .5457 L
s
.99625 .5787 m
1 .5787 L
s
.99625 .0507 m
1 .0507 L
s
.99625 .01769 m
1 .01769 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .0837 m
1 .0837 L
s
.5 0 m
.5 .61803 L
s
[(WaveFront Intensity)] .5 .63053 0 -1 Mshowa
.5 Mabswid
.02381 .03562 m
.03837 .29638 L
.05372 .49288 L
.05761 .54273 L
.05815 .54961 L
.05874 .55708 L
.05929 .56414 L
.0598 .56548 L
.06076 .56665 L
.06178 .5679 L
.06929 .57704 L
.0775 .58705 L
.08203 .59257 L
.08634 .59782 L
.08817 .60004 L
.08917 .60127 L
.09012 .60234 L
.09066 .60206 L
.09124 .60175 L
.09225 .60122 L
.09424 .60019 L
.10146 .59643 L
.11563 .58905 L
.14738 .57247 L
.17795 .5583 L
.20735 .54646 L
.23864 .53551 L
.26876 .5265 L
.30079 .51836 L
.33163 .51186 L
.36131 .50676 L
.39288 .50239 L
.40856 .50074 L
.42328 .49936 L
.43735 .49835 L
.45251 .49743 L
.45609 .49721 L
.45704 .49715 L
.45806 .49709 L
.45903 .49704 L
.45992 .49702 L
.46212 .49696 L
.46412 .4969 L
.46802 .4968 L
.47646 .49656 L
.48059 .49645 L
.48436 .49635 L
.48608 .4963 L
.48795 .49625 L
.48881 .49623 L
Mistroke
.48972 .49621 L
.49058 .49621 L
.49136 .49622 L
.49888 .49626 L
.50721 .4963 L
.51086 .49632 L
.51486 .49634 L
.51668 .49635 L
.51768 .49636 L
.51862 .49636 L
.5195 .49637 L
.52046 .49638 L
.52133 .49641 L
.52213 .49645 L
.52979 .49674 L
.53812 .49705 L
.54592 .49735 L
.54932 .49748 L
.55015 .49751 L
.55103 .49755 L
.552 .49762 L
.5529 .49768 L
.55681 .49796 L
.5604 .49822 L
.57636 .49936 L
.60853 .50257 L
.63953 .5068 L
.66935 .51198 L
.70107 .5187 L
.73161 .52649 L
.76098 .5353 L
.79226 .54619 L
.82235 .55833 L
.85435 .57319 L
.88517 .58972 L
.89926 .59569 L
.90728 .59875 L
.91121 .60025 L
.91482 .60162 L
.91668 .60233 L
.9184 .60299 L
.91927 .60332 L
.92021 .60131 L
.92074 .59956 L
.92124 .5979 L
.92218 .5948 L
.93011 .5686 L
.93801 .54254 L
.94233 .52828 L
.94637 .51493 L
Mistroke
.94819 .50892 L
.94909 .50596 L
.94992 .50321 L
.95087 .49095 L
.95138 .48148 L
.95191 .47139 L
.95374 .4371 L
.96185 .28455 L
.97613 .01593 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{145., 432.}, {416., 239.}} -> {-42.47803953249685, \
3.463591868293854, 0.1420751461069072, \
0.006127565156620016}},ExpressionUUID->"f28c17df-f99b-4353-b0e1-103c9ac844ce"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0284656 0.0147151 0.0116083 [
[.07302 -0.0125 -9 -9 ]
[.07302 -0.0125 9 0 ]
[.21534 -0.0125 -9 -9 ]
[.21534 -0.0125 9 0 ]
[.35767 -0.0125 -6 -9 ]
[.35767 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.64233 -0.0125 -3 -9 ]
[.64233 -0.0125 3 0 ]
[.78466 -0.0125 -6 -9 ]
[.78466 -0.0125 6 0 ]
[.92698 -0.0125 -6 -9 ]
[.92698 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1308 -12 -4.5 ]
[-0.0125 .1308 0 4.5 ]
[-0.0125 .24688 -12 -4.5 ]
[-0.0125 .24688 0 4.5 ]
[-0.0125 .36296 -12 -4.5 ]
[-0.0125 .36296 0 4.5 ]
[-0.0125 .47905 -12 -4.5 ]
[-0.0125 .47905 0 4.5 ]
[-0.0125 .59513 -12 -4.5 ]
[-0.0125 .59513 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -111 0 ]
[.5 .63053 111 9 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07302 0 m
.07302 .00625 L
s
[(-15)] .07302 -0.0125 0 1 Mshowa
.21534 0 m
.21534 .00625 L
s
[(-10)] .21534 -0.0125 0 1 Mshowa
.35767 0 m
.35767 .00625 L
s
[(-5)] .35767 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.64233 0 m
.64233 .00625 L
s
[(5)] .64233 -0.0125 0 1 Mshowa
.78466 0 m
.78466 .00625 L
s
[(10)] .78466 -0.0125 0 1 Mshowa
.92698 0 m
.92698 .00625 L
s
[(15)] .92698 -0.0125 0 1 Mshowa
.125 Mabswid
.10148 0 m
.10148 .00375 L
s
.12995 0 m
.12995 .00375 L
s
.15841 0 m
.15841 .00375 L
s
.18688 0 m
.18688 .00375 L
s
.24381 0 m
.24381 .00375 L
s
.27228 0 m
.27228 .00375 L
s
.30074 0 m
.30074 .00375 L
s
.32921 0 m
.32921 .00375 L
s
.38614 0 m
.38614 .00375 L
s
.4146 0 m
.4146 .00375 L
s
.44307 0 m
.44307 .00375 L
s
.47153 0 m
.47153 .00375 L
s
.52847 0 m
.52847 .00375 L
s
.55693 0 m
.55693 .00375 L
s
.5854 0 m
.5854 .00375 L
s
.61386 0 m
.61386 .00375 L
s
.67079 0 m
.67079 .00375 L
s
.69926 0 m
.69926 .00375 L
s
.72772 0 m
.72772 .00375 L
s
.75619 0 m
.75619 .00375 L
s
.81312 0 m
.81312 .00375 L
s
.84159 0 m
.84159 .00375 L
s
.87005 0 m
.87005 .00375 L
s
.89852 0 m
.89852 .00375 L
s
.04455 0 m
.04455 .00375 L
s
.01608 0 m
.01608 .00375 L
s
.95545 0 m
.95545 .00375 L
s
.98392 0 m
.98392 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1308 m
.00625 .1308 L
s
[(10)] -0.0125 .1308 1 0 Mshowa
0 .24688 m
.00625 .24688 L
s
[(20)] -0.0125 .24688 1 0 Mshowa
0 .36296 m
.00625 .36296 L
s
[(30)] -0.0125 .36296 1 0 Mshowa
0 .47905 m
.00625 .47905 L
s
[(40)] -0.0125 .47905 1 0 Mshowa
0 .59513 m
.00625 .59513 L
s
[(50)] -0.0125 .59513 1 0 Mshowa
.125 Mabswid
0 .03793 m
.00375 .03793 L
s
0 .06115 m
.00375 .06115 L
s
0 .08437 m
.00375 .08437 L
s
0 .10758 m
.00375 .10758 L
s
0 .15402 m
.00375 .15402 L
s
0 .17723 m
.00375 .17723 L
s
0 .20045 m
.00375 .20045 L
s
0 .22367 m
.00375 .22367 L
s
0 .2701 m
.00375 .2701 L
s
0 .29331 m
.00375 .29331 L
s
0 .31653 m
.00375 .31653 L
s
0 .33975 m
.00375 .33975 L
s
0 .38618 m
.00375 .38618 L
s
0 .4094 m
.00375 .4094 L
s
0 .43261 m
.00375 .43261 L
s
0 .45583 m
.00375 .45583 L
s
0 .50226 m
.00375 .50226 L
s
0 .52548 m
.00375 .52548 L
s
0 .5487 m
.00375 .5487 L
s
0 .57191 m
.00375 .57191 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.07302 .61178 m
.07302 .61803 L
s
.21534 .61178 m
.21534 .61803 L
s
.35767 .61178 m
.35767 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.64233 .61178 m
.64233 .61803 L
s
.78466 .61178 m
.78466 .61803 L
s
.92698 .61178 m
.92698 .61803 L
s
.125 Mabswid
.10148 .61428 m
.10148 .61803 L
s
.12995 .61428 m
.12995 .61803 L
s
.15841 .61428 m
.15841 .61803 L
s
.18688 .61428 m
.18688 .61803 L
s
.24381 .61428 m
.24381 .61803 L
s
.27228 .61428 m
.27228 .61803 L
s
.30074 .61428 m
.30074 .61803 L
s
.32921 .61428 m
.32921 .61803 L
s
.38614 .61428 m
.38614 .61803 L
s
.4146 .61428 m
.4146 .61803 L
s
.44307 .61428 m
.44307 .61803 L
s
.47153 .61428 m
.47153 .61803 L
s
.52847 .61428 m
.52847 .61803 L
s
.55693 .61428 m
.55693 .61803 L
s
.5854 .61428 m
.5854 .61803 L
s
.61386 .61428 m
.61386 .61803 L
s
.67079 .61428 m
.67079 .61803 L
s
.69926 .61428 m
.69926 .61803 L
s
.72772 .61428 m
.72772 .61803 L
s
.75619 .61428 m
.75619 .61803 L
s
.81312 .61428 m
.81312 .61803 L
s
.84159 .61428 m
.84159 .61803 L
s
.87005 .61428 m
.87005 .61803 L
s
.89852 .61428 m
.89852 .61803 L
s
.04455 .61428 m
.04455 .61803 L
s
.01608 .61428 m
.01608 .61803 L
s
.95545 .61428 m
.95545 .61803 L
s
.98392 .61428 m
.98392 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1308 m
1 .1308 L
s
.99375 .24688 m
1 .24688 L
s
.99375 .36296 m
1 .36296 L
s
.99375 .47905 m
1 .47905 L
s
.99375 .59513 m
1 .59513 L
s
.125 Mabswid
.99625 .03793 m
1 .03793 L
s
.99625 .06115 m
1 .06115 L
s
.99625 .08437 m
1 .08437 L
s
.99625 .10758 m
1 .10758 L
s
.99625 .15402 m
1 .15402 L
s
.99625 .17723 m
1 .17723 L
s
.99625 .20045 m
1 .20045 L
s
.99625 .22367 m
1 .22367 L
s
.99625 .2701 m
1 .2701 L
s
.99625 .29331 m
1 .29331 L
s
.99625 .31653 m
1 .31653 L
s
.99625 .33975 m
1 .33975 L
s
.99625 .38618 m
1 .38618 L
s
.99625 .4094 m
1 .4094 L
s
.99625 .43261 m
1 .43261 L
s
.99625 .45583 m
1 .45583 L
s
.99625 .50226 m
1 .50226 L
s
.99625 .52548 m
1 .52548 L
s
.99625 .5487 m
1 .5487 L
s
.99625 .57191 m
1 .57191 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
[(Optical Path Difference \\(wavelengths\\))] .5 .63053 0 -1 Mshowa
.01 w
.97619 .60332 Mdot
.94697 .58474 Mdot
.91743 .55331 Mdot
.88759 .51189 Mdot
.85748 .46316 Mdot
.82714 .40964 Mdot
.79658 .35362 Mdot
.76584 .29721 Mdot
.73494 .24229 Mdot
.70389 .19055 Mdot
.67272 .14347 Mdot
.64146 .1023 Mdot
.6101 .06811 Mdot
.57869 .04173 Mdot
.54723 .02379 Mdot
.51575 .01472 Mdot
.48425 .01472 Mdot
.45277 .02379 Mdot
.42131 .04173 Mdot
.3899 .06811 Mdot
.35854 .1023 Mdot
.32728 .14347 Mdot
.29611 .19055 Mdot
.26506 .24229 Mdot
.23416 .29721 Mdot
.20342 .35362 Mdot
.17286 .40964 Mdot
.14252 .46316 Mdot
.11241 .51189 Mdot
.08257 .55331 Mdot
.05303 .58474 Mdot
.02381 .60332 Mdot
.5 Mabswid
.02381 .60332 m
.03837 .59406 L
.04579 .58935 L
.04987 .58675 L
.05187 .58548 L
.05372 .58401 L
.05574 .58185 L
.05794 .57952 L
.06178 .57543 L
.06929 .56744 L
.08634 .54808 L
.11681 .50478 L
.1461 .45685 L
.17729 .40153 L
.20731 .34649 L
.23922 .28821 L
.26996 .23412 L
.29953 .18538 L
.331 .13857 L
.36129 .0993 L
.39349 .06509 L
.40964 .05153 L
.42451 .0399 L
.43994 .0311 L
.44748 .02681 L
.45077 .02493 L
.45167 .02442 L
.45251 .02394 L
.45338 .02361 L
.45435 .02333 L
.45623 .02279 L
.45796 .02229 L
.46138 .02131 L
.46892 .01913 L
.47672 .01689 L
.48097 .01566 L
.48203 .01535 L
.48304 .01506 L
.48394 .0148 L
.48492 .01472 L
.48583 .01472 L
.4868 .01472 L
.48762 .01472 L
.48853 .01472 L
.48949 .01472 L
.49003 .01472 L
.49052 .01472 L
.49148 .01472 L
.49238 .01472 L
.49337 .01472 L
Mistroke
.49391 .01472 L
.49441 .01472 L
.49538 .01472 L
.49629 .01472 L
.49681 .01472 L
.49736 .01472 L
.49834 .01472 L
.49888 .01472 L
.49939 .01472 L
.49995 .01472 L
.50055 .01472 L
.50151 .01472 L
.50239 .01472 L
.50337 .01472 L
.50386 .01472 L
.5044 .01472 L
.50531 .01472 L
.50628 .01472 L
.5072 .01472 L
.50805 .01472 L
.50887 .01472 L
.50964 .01472 L
.51048 .01472 L
.51137 .01472 L
.51232 .01472 L
.51321 .01472 L
.51401 .01472 L
.51487 .01472 L
.51583 .01474 L
.51671 .01499 L
.51867 .01556 L
.52222 .01658 L
.53029 .01891 L
.53876 .02135 L
.54248 .02242 L
.54446 .02299 L
.5455 .02329 L
.54659 .0236 L
.54751 .02395 L
.54852 .02452 L
.55028 .02553 L
.55375 .0275 L
.56135 .03184 L
.56976 .03664 L
.57742 .041 L
.58521 .0472 L
.59258 .05339 L
.60879 .06701 L
.63855 .09913 L
.6702 .14015 L
Mistroke
.70068 .1857 L
.72999 .23404 L
.7612 .28895 L
.79123 .34379 L
.82316 .40235 L
.85392 .45688 L
.8835 .50528 L
.91498 .54992 L
.92955 .56621 L
.93721 .57435 L
.94529 .58296 L
.94925 .58619 L
.95358 .58895 L
.96121 .59379 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{145., 432.}, {600., 423.}} -> {-42.05181409417613, \
141.89010934697154, 0.1420751461069072, \
0.3483933288268547}},ExpressionUUID->"4ce1abe7-8a3c-4679-908b-1b2e76f51ab4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"ComponentNumber", "\[Rule]", "2"}], ",", 
    RowBox[{"Energy", "\[Rule]", "100.`50."}], ",", 
    RowBox[{
    "Offset", "\[Rule]", 
     "155.232499727024594002667499459903634207016133168371541783173`47.\
94171342391833"}], ",", 
    RowBox[{"OpticalLengthFunction", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "-", "16.728633720145081219934402865050045527860452786852293190867`\
42.51444412797383"}], ",", 
           "16.728633720145081219934402865050045527860452786852293190867`42.\
51444412797383"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
      False,
      Editable->False]}], ",", 
    RowBox[{"OpticalPathDifference", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "-", "16.728633720145081219934402865050045527860452786852293190867`\
42.06837975365413"}], ",", 
           "16.728633720145081219934402865050045527860452786852293190867`42.\
06837975365413"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
      False,
      Editable->False]}], ",", 
    RowBox[{"OpticalPathRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "155.232499727024594002667499459903634207016133168371541783173`47.\
94171342391833", ",", 
       "155.259474947573901666175818636139183393839888978834732853702`47.\
875917318972164"}], "}"}]}], ",", 
    RowBox[{"OutputGraphics", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"OpticalLengthFunction", "\[Rule]", 
        RowBox[{"(", 
         TagBox[
          RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
          False,
          Editable->False], ")"}]}], ",", 
       RowBox[{"WaveFrontIntensity", "\[Rule]", 
        RowBox[{"(", 
         TagBox[
          RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
          False,
          Editable->False], ")"}]}], ",", 
       RowBox[{"OpticalPathDifference", "\[Rule]", 
        RowBox[{"(", 
         TagBox[
          RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
          False,
          Editable->False], ")"}]}]}], "}"}]}], ",", 
    RowBox[{"RayBoundary", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
       "-", "16.728633720145081219934402865050045527860452786852293190867`44.\
32007016464757"}], ",", 
       "16.728633720145081219934402865050045527860452786852293190867`44.\
32007016464757"}], "}"}]}], ",", 
    RowBox[{"RayTracePrecision", "\[Rule]", "50"}], ",", 
    RowBox[{
    "RefractiveIndex", "\[Rule]", 
     "1.0002694512365696004467895412063041991436523985939083668628192318714`\
50.30102025365448"}], ",", 
    RowBox[{"Source", "\[Rule]", "1"}], ",", 
    RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
    RowBox[{"SurfaceNumber", "\[Rule]", "1"}], ",", 
    RowBox[{"WaveFrontID", "\[Rule]", "1"}], ",", 
    RowBox[{"WaveFrontIntensity", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "20.876444766719427`"}], ",", "20.13568951492658`"}], 
          "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
      False,
      Editable->False]}], ",", 
    RowBox[{
    "WaveLength", "\[Rule]", 
     "0.5320000000000000000000000000000000000000000000000000000000000000155`\
50."}], ",", 
    RowBox[{"WaveTilt", "\[Rule]", "WaveTilt"}]}], "}"}], "}"}]], "Output",Exp\
ressionUUID->"fa2ca38f-f4dc-45f7-bb71-f906b75fb366"]
}, Open  ]],

Cell[CellGroupData[{

Cell["(OpticalPathDifference/.wav[[1]])[15]", "Input",ExpressionUUID->"93e61411-f77a-4499-a329-d5ca058c8f28"],

Cell[BoxData["47.273225331494707638360887575166965069981638886736478015552`41.\
42436196017378"], "Output",ExpressionUUID->"410f0167-df30-42b1-b165-\
5230a53fe154"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["FindWaveFronts in two dimensions", "SubsubsectionIcon",ExpressionUUID->"938d0893-c70a-41d0-9f6f-7f8fe26f9bb0"],

Cell[TextData[{
 "The previous example used a two-dimensional ",
 StyleBox["WedgeOfRays", "Input"],
 " source. Internally, this used an ",
 StyleBox["InterpolatingFunction", "Input"],
 " to model the wavefront behavior. When three-dimensional sources are used \
instead, ",
 StyleBox["FindWaveFronts", "Input"],
 " uses a Zernike-polynomial fit of the wavefront. Here is an optical system \
with the three-dimensional ",
 StyleBox["PointOfRays", "Input"],
 "."
}], "Text",ExpressionUUID->"fe43564d-075d-4f90-a102-63c32f77165a"],

Cell[CellGroupData[{

Cell["\<\
sys2D = {PointOfRays[{15,15}],Move[PlanoConvexLens[100,50,10,\
CurvatureDirection->Back],90],Move[Screen[{50,50}],150]}\
\>", "Input",
 CellLabel->"In[16]:=",ExpressionUUID->"36c55432-4f13-4980-b5f0-56c5268f9fd1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"PointOfRays", "[", 
       RowBox[{"{", 
        RowBox[{"15", ",", "15"}], "}"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0, 0.392187, 0]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"PlanoConvexLens", "[", 
         RowBox[{"100", ",", "50", ",", "10", ",", 
          RowBox[{"{", 
           RowBox[{"CurvatureDirection", "\[Rule]", "Back"}], "}"}]}], "]"}], 
        ",", "90.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0, 0.392187, 0]],
    DisplayForm], ",", 
   TagBox[
    StyleBox[
     TagBox[
      RowBox[{"Move", "[", 
       RowBox[{
        RowBox[{"Screen", "[", 
         RowBox[{"{", 
          RowBox[{"50", ",", "50"}], "}"}], "]"}], ",", "150.`"}], "]"}],
      HoldForm],
     FontColor->RGBColor[0, 0.392187, 0]],
    DisplayForm]}], "}"}]], "Output",
 CellLabel->"Out[16]=",ExpressionUUID->"c86fbfc9-0d47-4fdb-b9f6-eb80b754eed6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TurboPlot[sys2D];", "Input",
 CellLabel->"In[17]:=",ExpressionUUID->"034329ec-524a-4663-82eb-29938f6415aa"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .67912 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0224888 1.02249 -0.150431 1.02249 [
[ 0 0 0 0 ]
[ 1 .67912 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .67912 L
0 .67912 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
[ ] 0 setdash
.11741 .4797 m
.53388 .24101 L
s
.11741 .4797 m
.59883 .31716 L
s
.11741 .4797 m
.5351 .3549 L
s
.11741 .4797 m
.60172 .4294 L
s
0 g
.62394 .34325 m
.613 .30737 L
s
.613 .30737 m
.63144 .30143 L
s
.613 .30737 m
.59908 .27326 L
s
.63124 .37875 m
.62394 .34325 L
s
.62394 .34325 m
.64242 .3374 L
s
.59908 .27326 m
.61754 .26723 L
s
.59908 .27326 m
.58301 .24299 L
s
.63144 .30143 m
.64242 .3374 L
s
.61754 .26723 m
.63144 .30143 L
s
.64242 .3374 m
.6498 .37297 L
s
.63124 .37875 m
.6498 .37297 L
s
.60152 .23685 m
.61754 .26723 L
s
.58301 .24299 m
.60152 .23685 L
s
.656 .751 .92 r
.61275 .38687 m .65312 .40599 L .63444 .41172 L F
0 g
.63326 .4401 m
.63444 .41172 L
s
.63124 .37875 m
.63296 .39644 L
s
.656 .751 .92 r
.61275 .38687 m .65099 .37496 L .65312 .40599 L F
0 g
.65209 .43439 m
.65312 .40599 L
s
.6498 .37297 m
.65003 .37526 L
s
.63444 .41172 m
.65312 .40599 L
s
.039 .916 .04 r
.59883 .31716 m
.6365 .30465 L
s
.544 .324 .532 r
.56574 .21847 m .60459 .24413 L .56644 .25675 L F
.56574 .21847 m .58434 .21221 L .60459 .24413 L F
0 g
.58434 .21221 m
.60152 .23685 L
s
.56574 .21847 m
.58434 .21221 L
s
.54831 .20135 m
.56574 .21847 L
s
.039 .916 .04 r
.6365 .30465 m
.92599 .21162 L
s
0 0 0 r
2.5 Mabswid
.6365 .30465 Mdot
0 g
.5 Mabswid
.56705 .19499 m
.58434 .21221 L
s
.62767 .46196 m
.63326 .4401 L
s
.63326 .4401 m
.65209 .43439 L
s
.65209 .43439 m
.64667 .45625 L
s
.656 .751 .92 r
.59057 .36146 m .65099 .37496 L .61275 .38687 L F
0 g
.61275 .38687 m
.63444 .41172 L
s
.544 .324 .532 r
.56644 .25675 m .61677 .2796 L .56716 .29575 L F
.56644 .25675 m .60459 .24413 L .61677 .2796 L F
.039 .916 .04 r
.11741 .4797 m
.56686 .27921 L
s
0 g
.56574 .21847 m
.56644 .25675 L
s
.58434 .21221 m
.60459 .24413 L
s
.54831 .20135 m
.56705 .19499 L
s
.54831 .20135 m
.53185 .19296 L
s
.94767 .19408 m
.97441 .43595 L
s
.82983 .01827 m
.94767 .19408 L
s
.656 .751 .92 r
.59057 .36146 m .64025 .34578 L .65099 .37496 L F
.039 .916 .04 r
.11741 .4797 m
.59998 .37224 L
s
0 g
.65099 .37496 m
.65312 .40599 L
s
.55075 .18651 m
.56705 .19499 L
s
.6179 .47571 m
.62767 .46196 L
s
.62767 .46196 m
.64667 .45625 L
s
.039 .916 .04 r
.56686 .27921 m
.61151 .26112 L
s
0 g
.64667 .45625 m
.63709 .46997 L
s
.656 .751 .92 r
.5679 .33548 m .64025 .34578 L .59057 .36146 L F
.039 .916 .04 r
.59998 .37224 m
.64673 .36043 L
s
0 g
.59057 .36146 m
.61275 .38687 L
s
.039 .916 .04 r
.64673 .36043 m
.93255 .27132 L
s
0 0 0 r
2.5 Mabswid
.64673 .36043 Mdot
.544 .324 .532 r
.56716 .29575 m .62162 .31828 L .5679 .33548 L F
.56716 .29575 m .61677 .2796 L .62162 .31828 L F
0 g
.5 Mabswid
.56644 .25675 m
.56716 .29575 L
s
.60459 .24413 m
.61677 .2796 L
s
.039 .916 .04 r
.61151 .26112 m
.89648 .16699 L
s
0 0 0 r
2.5 Mabswid
.61151 .26112 Mdot
0 g
.5 Mabswid
.53185 .19296 m
.55075 .18651 L
s
.53185 .19296 m
.51749 .19413 L
s
.53657 .18761 m
.55075 .18651 L
s
.656 .751 .92 r
.5679 .33548 m .62162 .31828 L .64025 .34578 L F
0 g
.64025 .34578 m
.65099 .37496 L
s
.60448 .48014 m
.6179 .47571 L
s
.6179 .47571 m
.63709 .46997 L
s
.039 .916 .04 r
.60172 .4294 m
.64059 .42275 L
s
0 0 0 r
2.5 Mabswid
.60172 .4294 Mdot
0 g
.5 Mabswid
.63709 .46997 m
.62386 .47434 L
s
.544 .324 .532 r
.5679 .33548 m .61921 .36004 L .56864 .37595 L F
.5679 .33548 m .62162 .31828 L .61921 .36004 L F
.656 .751 .92 r
.54471 .30891 m .62162 .31828 L .5679 .33548 L F
0 0 0 r
2.5 Mabswid
.5679 .33548 Mdot
.039 .916 .04 r
.5 Mabswid
.11741 .4797 m
.5679 .33548 L
s
0 g
.56716 .29575 m
.56746 .31168 L
s
.039 .916 .04 r
.64059 .42275 m
.9386 .33174 L
s
0 0 0 r
2.5 Mabswid
.64059 .42275 Mdot
.039 .916 .04 r
.5 Mabswid
.53388 .24101 m
.56922 .22383 L
s
0 0 0 r
2.5 Mabswid
.53388 .24101 Mdot
0 g
.5 Mabswid
.51749 .19413 m
.50629 .20511 L
s
.53657 .18761 m
.51749 .19413 L
s
.52555 .19854 m
.53657 .18761 L
s
.656 .751 .92 r
.54471 .30891 m .5952 .29251 L .62162 .31828 L F
0 0 0 r
2.5 Mabswid
.62162 .31828 Mdot
.039 .916 .04 r
.5 Mabswid
.62162 .31828 m
.90255 .22834 L
s
.5679 .33548 m
.62162 .31828 L
s
0 g
.61677 .2796 m
.62162 .31828 L
s
.62162 .31828 m
.64025 .34578 L
s
.58821 .47462 m
.60448 .48014 L
s
.60448 .48014 m
.62386 .47434 L
s
.039 .916 .04 r
.56922 .22383 m
.86627 .12427 L
s
0 0 0 r
2.5 Mabswid
.56922 .22383 Mdot
.544 .324 .532 r
.56864 .37595 m .60903 .40496 L .5694 .4172 L F
.56864 .37595 m .61921 .36004 L .60903 .40496 L F
.039 .916 .04 r
.5 Mabswid
.11741 .4797 m
.56896 .39326 L
s
0 g
.5679 .33548 m
.56864 .37595 L
s
.61921 .36004 m
.62162 .31828 L
s
.62386 .47434 m
.60776 .46875 L
s
.96066 .31159 m
.94173 .28448 L
s
.96066 .31159 m
.96066 .31159 L
s
.656 .751 .92 r
.52099 .28173 m .5952 .29251 L .54471 .30891 L F
0 g
.54471 .30891 m
.5679 .33548 L
s
.039 .916 .04 r
.11741 .4797 m
.53477 .29752 L
s
0 0 0 r
2.5 Mabswid
.92599 .21162 Mdot
.039 .916 .04 r
.5 Mabswid
.56896 .39326 m
.61505 .38252 L
s
0 0 0 r
2.5 Mabswid
.56896 .39326 Mdot
0 g
.5 Mabswid
.50629 .20511 m
.52555 .19854 L
s
.50629 .20511 m
.49915 .22544 L
s
.89076 .10918 m
.89076 .10918 L
s
.89076 .10918 m
.89462 .14814 L
s
0 0 0 r
2.5 Mabswid
.53477 .29752 Mdot
0 g
.5 Mabswid
.51859 .21886 m
.52555 .19854 L
s
.656 .751 .92 r
.52099 .28173 m .5605 .26871 L .5952 .29251 L F
0 g
.5952 .29251 m
.62162 .31828 L
s
.58821 .47462 m
.60776 .46875 L
s
.544 .324 .532 r
.5694 .4172 m .58987 .45327 L .57018 .45924 L F
0 g
.57018 .45924 m
.58821 .47462 L
s
.544 .324 .532 r
.5694 .4172 m .60903 .40496 L .58987 .45327 L F
0 g
.56864 .37595 m
.5694 .4172 L
s
.5694 .4172 m
.57018 .45924 L
s
.60903 .40496 m
.61921 .36004 L
s
.039 .916 .04 r
.61505 .38252 m
.9088 .29154 L
s
0 0 0 r
2.5 Mabswid
.61505 .38252 Mdot
0 g
.5 Mabswid
.58987 .45327 m
.60776 .46875 L
s
.94173 .28448 m
.92237 .25673 L
s
.656 .751 .92 r
.49672 .25392 m .5605 .26871 L .52099 .28173 L F
0 g
.52099 .28173 m
.54471 .30891 L
s
.039 .916 .04 r
.53477 .29752 m
.57862 .28012 L
s
.57862 .28012 m
.87145 .18379 L
s
0 0 0 r
2.5 Mabswid
.57862 .28012 Mdot
0 g
.5 Mabswid
.58987 .45327 m
.60903 .40496 L
s
.89854 .18785 m
.89462 .14814 L
s
.51859 .21886 m
.49915 .22544 L
s
0 0 0 r
2.5 Mabswid
.93255 .27132 Mdot
.656 .751 .92 r
.49672 .25392 m .51633 .24736 L .5605 .26871 L F
0 g
.5 Mabswid
.51633 .24736 m
.5605 .26871 L
s
.49672 .25392 m
.49915 .22544 L
s
.5605 .26871 m
.5952 .29251 L
s
.49672 .25392 m
.52099 .28173 L
s
.51633 .24736 m
.51859 .21886 L
s
.55165 .43482 m
.57018 .45924 L
s
.57018 .45924 m
.58987 .45327 L
s
.039 .916 .04 r
.5351 .3549 m
.57152 .34375 L
s
0 0 0 r
2.5 Mabswid
.5351 .3549 Mdot
.89648 .16699 Mdot
0 g
.5 Mabswid
.57146 .42874 m
.58987 .45327 L
s
.92237 .25673 m
.90255 .22834 L
s
.49672 .25392 m
.51633 .24736 L
s
.49672 .25392 m
.4993 .28862 L
s
.89854 .18785 m
.90255 .22834 L
s
.039 .916 .04 r
.57152 .34375 m
.87755 .24616 L
s
0 0 0 r
2.5 Mabswid
.57152 .34375 Mdot
0 g
.5 Mabswid
.53403 .40302 m
.55165 .43482 L
s
.55165 .43482 m
.57146 .42874 L
s
.51633 .24736 m
.51904 .28211 L
s
.97441 .43595 m
.85121 .26732 L
s
.57146 .42874 m
.5539 .39682 L
s
.4993 .28862 m
.51904 .28211 L
s
.4993 .28862 m
.5068 .327 L
s
0 0 0 r
2.5 Mabswid
.9386 .33174 Mdot
0 g
.5 Mabswid
.51868 .36614 m
.53403 .40302 L
s
.53403 .40302 m
.5539 .39682 L
s
.52663 .32058 m
.51904 .28211 L
s
.5068 .327 m
.51868 .36614 L
s
.52663 .32058 m
.5068 .327 L
s
.51868 .36614 m
.53855 .35982 L
s
.5539 .39682 m
.53855 .35982 L
s
0 0 0 r
2.5 Mabswid
.90255 .22834 Mdot
0 g
.5 Mabswid
.90663 .26962 m
.90255 .22834 L
s
.90255 .22834 m
.88226 .19927 L
s
.53855 .35982 m
.52663 .32058 L
s
0 0 0 r
2.5 Mabswid
.86627 .12427 Mdot
0 g
.5 Mabswid
.85121 .26732 m
.82983 .01827 L
s
.90663 .26962 m
.91079 .31173 L
s
.88226 .19927 m
.86148 .1695 L
s
0 0 0 r
2.5 Mabswid
.9088 .29154 Mdot
.87145 .18379 Mdot
0 g
.5 Mabswid
.91504 .35469 m
.91079 .31173 L
s
.86148 .1695 m
.8402 .13901 L
s
.91504 .35469 m
.91504 .35469 L
s
0 0 0 r
2.5 Mabswid
.87755 .24616 Mdot
0 g
.5 Mabswid
.8402 .13901 m
.8402 .13901 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{458.7209447277807, 311.53515625},
 ImageMargins->0,
 CellLabel->"From In[17]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{102., 559.}, {389., 79.}} -> {-0.19711487521147805, \
0.31638001306626445, 0.002142545731239623, \
0.002142545731239623}},ExpressionUUID->"f653d658-9208-4899-9a63-adc6069033c3"]
}, Open  ]],

Cell[TextData[{
 "Once again, the default behavior of ",
 StyleBox["FindWaveFronts", "Input"],
 " is to make its calculation in machine precision:"
}], "Text",ExpressionUUID->"70885550-4cb0-4ddf-a29e-8136a2d680d2"],

Cell[CellGroupData[{

Cell["Timing[wav0 = FindWaveFronts[sys2D]]", "Input",ExpressionUUID->"b873214f-1215-460d-bd42-d9eabdfa2ebb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface Location : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentNumber", "\[Rule]", "2"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1"}], ",", 
     RowBox[{"WaveFrontID", "\[Rule]", "1"}], ",", 
     RowBox[{"Source", "\[Rule]", "1"}]}], "}"}]}],
  SequenceForm[
  "Surface Location : ", {
   ComponentNumber -> 2, SurfaceNumber -> 1, WaveFrontID -> 1, Source -> 1}],
  Editable->False]], "Print",ExpressionUUID->"4231de0b-e89f-4823-b23b-\
22a0ed08d223"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.40312e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -117 0 ]
[.5 .82364 117 9 ]
[.08965 .22175 -18 -8.88375 ]
[.08965 .22175 0 .11625 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60423 .01939 -10.1877 -9 ]
[.60423 .01939 1.81231 0 ]
[.73698 .05037 0 -6.2075 ]
[.73698 .05037 18 2.7925 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95739 .38791 0 -5.88802 ]
[.95739 .38791 12 3.11198 ]
[.01479 .32352 -36 -2.79172 ]
[.01479 .32352 0 6.20828 ]
[.00179 .40505 -36 -2.86096 ]
[.00179 .40505 0 6.13904 ]
[-0.01191 .49092 -36 -2.9343 ]
[-0.01191 .49092 0 6.0657 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Length \\(absolute distance\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72471 .05502 m
.71857 .05735 L
s
[(-10)] .73698 .05037 -1 .37944 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94486 .39177 m
.93859 .39371 L
s
[(10)] .95739 .38791 -1 .30845 Mshowa
.125 Mabswid
.75031 .09419 m
.74662 .09556 L
s
.775 .13196 m
.7713 .1333 L
s
.79883 .16841 m
.79512 .16972 L
s
.82184 .2036 m
.81812 .2049 L
s
.86557 .27049 m
.86184 .27174 L
s
.88636 .3023 m
.88262 .30352 L
s
.90649 .33308 m
.90274 .33428 L
s
.92597 .36289 m
.92222 .36407 L
s
.69814 .01439 m
.69447 .01581 L
s
.96316 .41977 m
.95939 .42091 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02706 .31887 m
.03319 .31654 L
s
[(155.24)] .01479 .32352 1 -0.37962 Mshowa
.01412 .40055 m
.02028 .39831 L
s
[(155.25)] .00179 .40505 1 -0.36423 Mshowa
.00048 .4866 m
.00668 .48445 L
s
[(155.26)] -0.01191 .49092 1 -0.34793 Mshowa
.125 Mabswid
.02452 .33487 m
.02821 .33348 L
s
.02196 .35104 m
.02565 .34966 L
s
.01937 .36737 m
.02307 .36601 L
s
.01676 .38388 m
.02045 .38252 L
s
.01145 .4174 m
.01515 .41607 L
s
.00875 .43443 m
.01245 .43311 L
s
.00602 .45164 m
.00973 .45032 L
s
.00326 .46903 m
.00698 .46772 L
s
.02957 .30302 m
.03325 .30162 L
s
.03206 .28734 m
.03573 .28592 L
s
.03452 .27181 m
.03819 .27039 L
s
.03695 .25644 m
.04062 .255 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.977 .099 0 r
.38757 .79726 .39809 .80491 .41556 .80118 .40517 .79141 Metetra
.972 .117 0 r
.40517 .79141 .41556 .80118 .4332 .7955 .42294 .78376 Metetra
.961 .161 0 r
.42294 .78376 .4332 .7955 .45097 .78826 .44082 .77472 Metetra
.945 .223 0 r
.44082 .77472 .45097 .78826 .46885 .77985 .45879 .76466 Metetra
.926 .297 0 r
.45879 .76466 .46885 .77985 .48683 .7706 .47684 .75391 Metetra
.904 .375 0 r
.47684 .75391 .48683 .7706 .50488 .76081 .49496 .74278 Metetra
.881 .453 0 r
.49496 .74278 .50488 .76081 .523 .75075 .51312 .73152 Metetra
.858 .527 0 r
.51312 .73152 .523 .75075 .54118 .74066 .53135 .72037 Metetra
.836 .594 0 r
.53135 .72037 .54118 .74066 .55943 .73075 .54963 .70953 Metetra
.815 .653 0 r
.54963 .70953 .55943 .73075 .57776 .72119 .56798 .69917 Metetra
.796 .702 0 r
.56798 .69917 .57776 .72119 .59618 .71213 .58641 .68944 Metetra
.78 .743 0 r
.58641 .68944 .59618 .71213 .61469 .7037 .60493 .68046 Metetra
.762 .767 0 r
.60493 .68046 .61469 .7037 .63331 .696 .62356 .67232 Metetra
.721 .758 0 r
.62356 .67232 .63331 .696 .65207 .6891 .64232 .6651 Metetra
.697 .752 0 r
.64232 .6651 .65207 .6891 .67096 .68304 .66122 .65884 Metetra
.689 .75 0 r
.66122 .65884 .67096 .68304 .69002 .67786 .68028 .65356 Metetra
.697 .752 0 r
.68028 .65356 .69002 .67786 .70925 .67356 .69952 .64929 Metetra
.721 .758 0 r
.69952 .64929 .70925 .67356 .72867 .67013 .71896 .64599 Metetra
.762 .767 0 r
.71896 .64599 .72867 .67013 .74831 .66751 .73862 .64363 Metetra
.78 .743 0 r
.73862 .64363 .74831 .66751 .76816 .66565 .75851 .64215 Metetra
.796 .702 0 r
.75851 .64215 .76816 .66565 .78824 .66446 .77864 .64146 Metetra
.815 .653 0 r
.77864 .64146 .78824 .66446 .80855 .66381 .79902 .64145 Metetra
.836 .594 0 r
.79902 .64145 .80855 .66381 .8291 .66356 .81965 .64197 Metetra
.858 .527 0 r
.81965 .64197 .8291 .66356 .84987 .66353 .84053 .64285 Metetra
.881 .453 0 r
.84053 .64285 .84987 .66353 .87085 .66351 .86165 .6439 Metetra
.904 .375 0 r
.86165 .6439 .87085 .66351 .89202 .66324 .88299 .64486 Metetra
.926 .297 0 r
.88299 .64486 .89202 .66324 .91334 .66245 .90452 .64546 Metetra
.945 .223 0 r
.90452 .64546 .91334 .66245 .93478 .6608 .92621 .64539 Metetra
.961 .161 0 r
.92621 .64539 .93478 .6608 .95627 .65794 .948 .64428 Metetra
.972 .117 0 r
.948 .64428 .95627 .65794 .97774 .65345 .96981 .64172 Metetra
.977 .099 0 r
.96981 .64172 .97774 .65345 .99909 .64688 .99158 .63727 Metetra
.972 .117 0 r
.37699 .78759 .38757 .79726 .40517 .79141 .39474 .77976 Metetra
.96 .165 0 r
.39474 .77976 .40517 .79141 .42294 .78376 .41262 .7703 Metetra
.942 .235 0 r
.41262 .7703 .42294 .78376 .44082 .77472 .43061 .75959 Metetra
.92 .318 0 r
.43061 .75959 .44082 .77472 .45879 .76466 .44868 .74802 Metetra
.895 .407 0 r
.44868 .74802 .45879 .76466 .47684 .75391 .4668 .7359 Metetra
.868 .496 0 r
.4668 .7359 .47684 .75391 .49496 .74278 .48498 .72353 Metetra
.841 .58 0 r
.48498 .72353 .49496 .74278 .51312 .73152 .50319 .71117 Metetra
.814 .657 0 r
.50319 .71117 .51312 .73152 .53135 .72037 .52146 .69905 Metetra
.788 .725 0 r
.52146 .69905 .53135 .72037 .54963 .70953 .53977 .68736 Metetra
.746 .764 0 r
.53977 .68736 .54963 .70953 .56798 .69917 .55814 .67628 Metetra
.656 .742 0 r
.55814 .67628 .56798 .69917 .58641 .68944 .57659 .66593 Metetra
.583 .724 0 r
.57659 .66593 .58641 .68944 .60493 .68046 .59512 .65644 Metetra
.527 .71 0 r
.59512 .65644 .60493 .68046 .62356 .67232 .61375 .6479 Metetra
.487 .699 0 r
.61375 .6479 .62356 .67232 .64232 .6651 .63251 .64038 Metetra
.463 .693 0 r
.63251 .64038 .64232 .6651 .66122 .65884 .65141 .63392 Metetra
.455 .691 0 r
.65141 .63392 .66122 .65884 .68028 .65356 .67048 .62855 Metetra
.463 .693 0 r
.67048 .62855 .68028 .65356 .69952 .64929 .68972 .62428 Metetra
.487 .699 0 r
.68972 .62428 .69952 .64929 .71896 .64599 .70918 .6211 Metetra
.527 .71 0 r
.70918 .6211 .71896 .64599 .73862 .64363 .72885 .61896 Metetra
.583 .724 0 r
.72885 .61896 .73862 .64363 .75851 .64215 .74876 .6178 Metetra
.656 .742 0 r
.74876 .6178 .75851 .64215 .77864 .64146 .76893 .61755 Metetra
.746 .764 0 r
.76893 .61755 .77864 .64146 .79902 .64145 .78936 .6181 Metetra
.788 .725 0 r
.78936 .6181 .79902 .64145 .81965 .64197 .81006 .61931 Metetra
.814 .657 0 r
.81006 .61931 .81965 .64197 .84053 .64285 .83103 .62101 Metetra
.841 .58 0 r
.83103 .62101 .84053 .64285 .86165 .6439 .85227 .62301 Metetra
.868 .496 0 r
.85227 .62301 .86165 .6439 .88299 .64486 .87376 .62508 Metetra
.895 .407 0 r
.87376 .62508 .88299 .64486 .90452 .64546 .89547 .62694 Metetra
.92 .318 0 r
.89547 .62694 .90452 .64546 .92621 .64539 .91738 .62829 Metetra
.942 .235 0 r
.91738 .62829 .92621 .64539 .948 .64428 .93943 .62877 Metetra
.96 .165 0 r
.93943 .62877 .948 .64428 .96981 .64172 .96156 .62797 Metetra
.972 .117 0 r
.96156 .62797 .96981 .64172 .99158 .63727 .98368 .62547 Metetra
.961 .161 0 r
.36636 .77628 .37699 .78759 .39474 .77976 .38424 .76664 Metetra
.942 .235 0 r
.38424 .76664 .39474 .77976 .41262 .7703 .40225 .7555 Metetra
.918 .325 0 r
.40225 .7555 .41262 .7703 .43061 .75959 .42034 .74327 Metetra
.89 .423 0 r
.42034 .74327 .43061 .75959 .44868 .74802 .4385 .73031 Metetra
.86 .522 0 r
.4385 .73031 .44868 .74802 .4668 .7359 .4567 .71694 Metetra
.828 .616 0 r
.4567 .71694 .4668 .7359 .48498 .72353 .47494 .70344 Metetra
.797 .702 0 r
.47494 .70344 .48498 .72353 .50319 .71117 .49321 .69009 Metetra
.754 .766 0 r
.49321 .69009 .50319 .71117 .52146 .69905 .51151 .67708 Metetra
.632 .737 0 r
.51151 .67708 .52146 .69905 .53977 .68736 .52986 .66462 Metetra
.527 .71 0 r
.52986 .66462 .53977 .68736 .55814 .67628 .54826 .65287 Metetra
.439 .686 0 r
.54826 .65287 .55814 .67628 .57659 .66593 .56672 .64196 Metetra
.369 .666 0 r
.56672 .64196 .57659 .66593 .59512 .65644 .58526 .632 Metetra
.315 .65 0 r
.58526 .632 .59512 .65644 .61375 .6479 .6039 .62309 Metetra
.277 .638 0 r
.6039 .62309 .61375 .6479 .63251 .64038 .62266 .61529 Metetra
.254 .631 0 r
.62266 .61529 .63251 .64038 .65141 .63392 .64156 .60865 Metetra
.247 .629 0 r
.64156 .60865 .65141 .63392 .67048 .62855 .66063 .60319 Metetra
.254 .631 0 r
.66063 .60319 .67048 .62855 .68972 .62428 .67988 .59891 Metetra
.277 .638 0 r
.67988 .59891 .68972 .62428 .70918 .6211 .69933 .59581 Metetra
.315 .65 0 r
.69933 .59581 .70918 .6211 .72885 .61896 .71902 .59386 Metetra
.369 .666 0 r
.71902 .59386 .72885 .61896 .74876 .6178 .73895 .59298 Metetra
.439 .686 0 r
.73895 .59298 .74876 .6178 .76893 .61755 .75915 .59312 Metetra
.527 .71 0 r
.75915 .59312 .76893 .61755 .78936 .6181 .77962 .59415 Metetra
.632 .737 0 r
.77962 .59415 .78936 .6181 .81006 .61931 .80038 .59597 Metetra
.754 .766 0 r
.80038 .59597 .81006 .61931 .83103 .62101 .82143 .59839 Metetra
.797 .702 0 r
.82143 .59839 .83103 .62101 .85227 .62301 .84276 .60124 Metetra
.828 .616 0 r
.84276 .60124 .85227 .62301 .87376 .62508 .86437 .6043 Metetra
.86 .522 0 r
.86437 .6043 .87376 .62508 .89547 .62694 .88624 .60729 Metetra
.89 .423 0 r
.88624 .60729 .89547 .62694 .91738 .62829 .90834 .60991 Metetra
.918 .325 0 r
.90834 .60991 .91738 .62829 .93943 .62877 .93062 .61182 Metetra
.942 .235 0 r
.93062 .61182 .93943 .62877 .96156 .62797 .95302 .61263 Metetra
.961 .161 0 r
.95302 .61263 .96156 .62797 .98368 .62547 .97547 .6119 Metetra
.945 .223 0 r
.35566 .7637 .36636 .77628 .38424 .76664 .37369 .7524 Metetra
.92 .318 0 r
.37369 .7524 .38424 .76664 .40225 .7555 .39181 .73974 Metetra
.89 .423 0 r
.39181 .73974 .40225 .7555 .42034 .74327 .41001 .72612 Metetra
.857 .531 0 r
.41001 .72612 .42034 .74327 .4385 .73031 .42826 .71189 Metetra
.822 .634 0 r
.42826 .71189 .4385 .73031 .4567 .71694 .44654 .69738 Metetra
.786 .729 0 r
.44654 .69738 .4567 .71694 .47494 .70344 .46485 .68287 Metetra
.689 .75 0 r
.46485 .68287 .47494 .70344 .49321 .69009 .48317 .6686 Metetra
.552 .716 0 r
.48317 .6686 .49321 .69009 .51151 .67708 .50152 .65479 Metetra
.432 .684 0 r
.50152 .65479 .51151 .67708 .52986 .66462 .5199 .64163 Metetra
.33 .655 0 r
.5199 .64163 .52986 .66462 .54826 .65287 .53832 .62927 Metetra
.247 .629 0 r
.53832 .62927 .54826 .65287 .56672 .64196 .5568 .61785 Metetra
.181 .607 0 r
.5568 .61785 .56672 .64196 .58526 .632 .57536 .60747 Metetra
.132 .59 0 r
.57536 .60747 .58526 .632 .6039 .62309 .59401 .59822 Metetra
.097 .577 0 r
.59401 .59822 .6039 .62309 .62266 .61529 .61277 .59016 Metetra
.077 .57 0 r
.61277 .59016 .62266 .61529 .64156 .60865 .63168 .58334 Metetra
.07 .567 0 r
.63168 .58334 .64156 .60865 .66063 .60319 .65074 .57778 Metetra
.077 .57 0 r
.65074 .57778 .66063 .60319 .67988 .59891 .66999 .5735 Metetra
.097 .577 0 r
.66999 .5735 .67988 .59891 .69933 .59581 .68946 .57046 Metetra
.132 .59 0 r
.68946 .57046 .69933 .59581 .71902 .59386 .70915 .56866 Metetra
.181 .607 0 r
.70915 .56866 .71902 .59386 .73895 .59298 .7291 .56802 Metetra
.247 .629 0 r
.7291 .56802 .73895 .59298 .75915 .59312 .74931 .56849 Metetra
.33 .655 0 r
.74931 .56849 .75915 .59312 .77962 .59415 .76982 .56995 Metetra
.432 .684 0 r
.76982 .56995 .77962 .59415 .80038 .59597 .79062 .57229 Metetra
.552 .716 0 r
.79062 .57229 .80038 .59597 .82143 .59839 .81174 .57535 Metetra
.689 .75 0 r
.81174 .57535 .82143 .59839 .84276 .60124 .83315 .57895 Metetra
.786 .729 0 r
.83315 .57895 .84276 .60124 .86437 .6043 .85487 .58287 Metetra
.822 .634 0 r
.85487 .58287 .86437 .6043 .88624 .60729 .87688 .58687 Metetra
.857 .531 0 r
.87688 .58687 .88624 .60729 .90834 .60991 .89914 .59063 Metetra
.89 .423 0 r
.89914 .59063 .90834 .60991 .93062 .61182 .92162 .59383 Metetra
.92 .318 0 r
.92162 .59383 .93062 .61182 .95302 .61263 .94427 .59608 Metetra
.945 .223 0 r
.94427 .59608 .95302 .61263 .97547 .6119 .96701 .59694 Metetra
.926 .297 0 r
.3449 .75018 .35566 .7637 .37369 .7524 .36306 .73737 Metetra
.895 .407 0 r
.36306 .73737 .37369 .7524 .39181 .73974 .38131 .72333 Metetra
.86 .522 0 r
.38131 .72333 .39181 .73974 .41001 .72612 .39962 .70845 Metetra
.822 .634 0 r
.39962 .70845 .41001 .72612 .42826 .71189 .41796 .69308 Metetra
.782 .738 0 r
.41796 .69308 .42826 .71189 .44654 .69738 .43632 .67754 Metetra
.657 .743 0 r
.43632 .67754 .44654 .69738 .46485 .68287 .4547 .6621 Metetra
.503 .704 0 r
.4547 .6621 .46485 .68287 .48317 .6686 .47308 .64701 Metetra
.369 .666 0 r
.47308 .64701 .48317 .6686 .50152 .65479 .49148 .63248 Metetra
.255 .631 0 r
.49148 .63248 .50152 .65479 .5199 .64163 .5099 .61869 Metetra
.16 .6 0 r
.5099 .61869 .5199 .64163 .53832 .62927 .52835 .60578 Metetra
.084 .572 0 r
.52835 .60578 .53832 .62927 .5568 .61785 .54685 .5939 Metetra
.025 .549 0 r
.54685 .5939 .5568 .61785 .57536 .60747 .56542 .58313 Metetra
0 .53 .019 r
.56542 .58313 .57536 .60747 .59401 .59822 .58408 .57357 Metetra
0 .517 .048 r
.58408 .57357 .59401 .59822 .61277 .59016 .60286 .56527 Metetra
0 .509 .066 r
.60286 .56527 .61277 .59016 .63168 .58334 .62177 .55828 Metetra
0 .506 .071 r
.62177 .55828 .63168 .58334 .65074 .57778 .64083 .55263 Metetra
0 .509 .066 r
.64083 .55263 .65074 .57778 .66999 .5735 .66009 .54831 Metetra
0 .517 .048 r
.66009 .54831 .66999 .5735 .68946 .57046 .67955 .54533 Metetra
0 .53 .019 r
.67955 .54533 .68946 .57046 .70915 .56866 .69925 .54364 Metetra
.025 .549 0 r
.69925 .54364 .70915 .56866 .7291 .56802 .71921 .54321 Metetra
.084 .572 0 r
.71921 .54321 .7291 .56802 .74931 .56849 .73945 .54395 Metetra
.16 .6 0 r
.73945 .54395 .74931 .56849 .76982 .56995 .75998 .54578 Metetra
.255 .631 0 r
.75998 .54578 .76982 .56995 .79062 .57229 .78083 .54857 Metetra
.369 .666 0 r
.78083 .54857 .79062 .57229 .81174 .57535 .80199 .55219 Metetra
.503 .704 0 r
.80199 .55219 .81174 .57535 .83315 .57895 .82348 .55645 Metetra
.657 .743 0 r
.82348 .55645 .83315 .57895 .85487 .58287 .84529 .56114 Metetra
.782 .738 0 r
.84529 .56114 .85487 .58287 .87688 .58687 .86741 .56601 Metetra
.822 .634 0 r
.86741 .56601 .87688 .58687 .89914 .59063 .88982 .57079 Metetra
.86 .522 0 r
.88982 .57079 .89914 .59063 .92162 .59383 .91248 .57513 Metetra
.895 .407 0 r
.91248 .57513 .92162 .59383 .94427 .59608 .93534 .57866 Metetra
.926 .297 0 r
.93534 .57866 .94427 .59608 .96701 .59694 .95833 .58095 Metetra
.904 .375 0 r
.33406 .73602 .3449 .75018 .36306 .73737 .35236 .72185 Metetra
.868 .496 0 r
.35236 .72185 .36306 .73737 .38131 .72333 .37073 .70656 Metetra
.828 .616 0 r
.37073 .70656 .38131 .72333 .39962 .70845 .38915 .69055 Metetra
.786 .729 0 r
.38915 .69055 .39962 .70845 .41796 .69308 .40759 .67415 Metetra
.657 .743 0 r
.40759 .67415 .41796 .69308 .43632 .67754 .42604 .65768 Metetra
.487 .699 0 r
.42604 .65768 .43632 .67754 .4547 .6621 .44448 .64142 Metetra
.338 .657 0 r
.44448 .64142 .4547 .6621 .47308 .64701 .46293 .6256 Metetra
.21 .617 0 r
.46293 .6256 .47308 .64701 .49148 .63248 .48138 .61041 Metetra
.104 .58 0 r
.48138 .61041 .49148 .63248 .5099 .61869 .49984 .59605 Metetra
.019 .546 0 r
.49984 .59605 .5099 .61869 .52835 .60578 .51833 .58265 Metetra
0 .517 .048 r
.51833 .58265 .52835 .60578 .54685 .5939 .53686 .57034 Metetra
0 .492 .099 r
.53686 .57034 .54685 .5939 .56542 .58313 .55545 .55922 Metetra
0 .472 .135 r
.55545 .55922 .56542 .58313 .58408 .57357 .57413 .54937 Metetra
0 .458 .159 r
.57413 .54937 .58408 .57357 .60286 .56527 .59291 .54085 Metetra
0 .45 .173 r
.59291 .54085 .60286 .56527 .62177 .55828 .61183 .53371 Metetra
0 .447 .178 r
.61183 .53371 .62177 .55828 .64083 .55263 .63091 .52796 Metetra
0 .45 .173 r
.63091 .52796 .64083 .55263 .66009 .54831 .65017 .52361 Metetra
0 .458 .159 r
.65017 .52361 .66009 .54831 .67955 .54533 .66964 .52066 Metetra
0 .472 .135 r
.66964 .52066 .67955 .54533 .69925 .54364 .68935 .51907 Metetra
0 .492 .099 r
.68935 .51907 .69925 .54364 .71921 .54321 .70931 .5188 Metetra
0 .517 .048 r
.70931 .5188 .71921 .54321 .73945 .54395 .72957 .51977 Metetra
.019 .546 0 r
.72957 .51977 .73945 .54395 .75998 .54578 .75012 .52191 Metetra
.104 .58 0 r
.75012 .52191 .75998 .54578 .78083 .54857 .771 .5251 Metetra
.21 .617 0 r
.771 .5251 .78083 .54857 .80199 .55219 .79221 .52919 Metetra
.338 .657 0 r
.79221 .52919 .80199 .55219 .82348 .55645 .81376 .53401 Metetra
.487 .699 0 r
.81376 .53401 .82348 .55645 .84529 .56114 .83565 .53937 Metetra
.657 .743 0 r
.83565 .53937 .84529 .56114 .86741 .56601 .85787 .54502 Metetra
.786 .729 0 r
.85787 .54502 .86741 .56601 .88982 .57079 .88041 .55068 Metetra
.828 .616 0 r
.88041 .55068 .88982 .57079 .91248 .57513 .90322 .55603 Metetra
.868 .496 0 r
.90322 .55603 .91248 .57513 .93534 .57866 .92627 .5607 Metetra
.904 .375 0 r
.92627 .5607 .93534 .57866 .95833 .58095 .9495 .56426 Metetra
.881 .453 0 r
.32313 .72149 .33406 .73602 .35236 .72185 .34156 .7061 Metetra
.841 .58 0 r
.34156 .7061 .35236 .72185 .37073 .70656 .36006 .6897 Metetra
.797 .702 0 r
.36006 .6897 .37073 .70656 .38915 .69055 .37859 .67267 Metetra
.689 .75 0 r
.37859 .67267 .38915 .69055 .40759 .67415 .39713 .65535 Metetra
.503 .704 0 r
.39713 .65535 .40759 .67415 .42604 .65768 .41567 .63806 Metetra
.338 .657 0 r
.41567 .63806 .42604 .65768 .44448 .64142 .43419 .62106 Metetra
.196 .612 0 r
.43419 .62106 .44448 .64142 .46293 .6256 .45271 .60457 Metetra
.077 .57 0 r
.45271 .60457 .46293 .6256 .48138 .61041 .47122 .58881 Metetra
0 .53 .019 r
.47122 .58881 .48138 .61041 .49984 .59605 .48973 .57393 Metetra
0 .495 .093 r
.48973 .57393 .49984 .59605 .51833 .58265 .50826 .56009 Metetra
0 .464 .15 r
.50826 .56009 .51833 .58265 .53686 .57034 .52682 .5474 Metetra
0 .438 .191 r
.52682 .5474 .53686 .57034 .55545 .55922 .54544 .53596 Metetra
0 .417 .219 r
.54544 .53596 .55545 .55922 .57413 .54937 .56414 .52585 Metetra
0 .402 .237 r
.56414 .52585 .57413 .54937 .59291 .54085 .58294 .51713 Metetra
0 .393 .247 r
.58294 .51713 .59291 .54085 .61183 .53371 .60187 .50983 Metetra
0 .39 .251 r
.60187 .50983 .61183 .53371 .63091 .52796 .62096 .50399 Metetra
0 .393 .247 r
.62096 .50399 .63091 .52796 .65017 .52361 .64023 .4996 Metetra
0 .402 .237 r
.64023 .4996 .65017 .52361 .66964 .52066 .65971 .49666 Metetra
0 .417 .219 r
.65971 .49666 .66964 .52066 .68935 .51907 .67943 .49514 Metetra
0 .438 .191 r
.67943 .49514 .68935 .51907 .70931 .5188 .69941 .495 Metetra
0 .464 .15 r
.69941 .495 .70931 .5188 .72957 .51977 .71968 .49617 Metetra
0 .495 .093 r
.71968 .49617 .72957 .51977 .75012 .52191 .74026 .49857 Metetra
0 .53 .019 r
.74026 .49857 .75012 .52191 .771 .5251 .76116 .50209 Metetra
.077 .57 0 r
.76116 .50209 .771 .5251 .79221 .52919 .78242 .50658 Metetra
.196 .612 0 r
.78242 .50658 .79221 .52919 .81376 .53401 .80402 .51189 Metetra
.338 .657 0 r
.80402 .51189 .81376 .53401 .83565 .53937 .82598 .51783 Metetra
.503 .704 0 r
.82598 .51783 .83565 .53937 .85787 .54502 .84829 .52414 Metetra
.689 .75 0 r
.84829 .52414 .85787 .54502 .88041 .55068 .87094 .53058 Metetra
.797 .702 0 r
.87094 .53058 .88041 .55068 .90322 .55603 .89389 .5368 Metetra
.841 .58 0 r
.89389 .5368 .90322 .55603 .92627 .5607 .91711 .54246 Metetra
.881 .453 0 r
.91711 .54246 .92627 .5607 .9495 .56426 .94054 .54713 Metetra
.858 .527 0 r
.31209 .70684 .32313 .72149 .34156 .7061 .33067 .69036 Metetra
.814 .657 0 r
.33067 .69036 .34156 .7061 .36006 .6897 .34929 .67297 Metetra
.754 .766 0 r
.34929 .67297 .36006 .6897 .37859 .67267 .36794 .65504 Metetra
.552 .716 0 r
.36794 .65504 .37859 .67267 .39713 .65535 .38658 .63691 Metetra
.369 .666 0 r
.38658 .63691 .39713 .65535 .41567 .63806 .40521 .61888 Metetra
.21 .617 0 r
.40521 .61888 .41567 .63806 .43419 .62106 .42382 .60122 Metetra
.077 .57 0 r
.42382 .60122 .43419 .62106 .45271 .60457 .44241 .58415 Metetra
0 .525 .031 r
.44241 .58415 .45271 .60457 .47122 .58881 .46098 .56787 Metetra
0 .484 .115 r
.46098 .56787 .47122 .58881 .48973 .57393 .47955 .55253 Metetra
0 .447 .178 r
.47955 .55253 .48973 .57393 .50826 .56009 .49813 .53829 Metetra
0 .414 .223 r
.49813 .53829 .50826 .56009 .52682 .5474 .51673 .52526 Metetra
0 .387 .254 r
.51673 .52526 .52682 .5474 .54544 .53596 .53539 .51354 Metetra
0 .366 .274 r
.53539 .51354 .54544 .53596 .56414 .52585 .55412 .50319 Metetra
0 .35 .286 r
.55412 .50319 .56414 .52585 .58294 .51713 .57294 .49427 Metetra
0 .341 .292 r
.57294 .49427 .58294 .51713 .60187 .50983 .59189 .48684 Metetra
0 .338 .294 r
.59189 .48684 .60187 .50983 .62096 .50399 .61099 .4809 Metetra
0 .341 .292 r
.61099 .4809 .62096 .50399 .64023 .4996 .63028 .47646 Metetra
0 .35 .286 r
.63028 .47646 .64023 .4996 .65971 .49666 .64977 .47353 Metetra
0 .366 .274 r
.64977 .47353 .65971 .49666 .67943 .49514 .6695 .47206 Metetra
0 .387 .254 r
.6695 .47206 .67943 .49514 .69941 .495 .6895 .47202 Metetra
0 .414 .223 r
.6895 .47202 .69941 .495 .71968 .49617 .70978 .47335 Metetra
0 .447 .178 r
.70978 .47335 .71968 .49617 .74026 .49857 .73039 .47596 Metetra
0 .484 .115 r
.73039 .47596 .74026 .49857 .76116 .50209 .75132 .47974 Metetra
0 .525 .031 r
.75132 .47974 .76116 .50209 .78242 .50658 .77261 .48458 Metetra
.077 .57 0 r
.77261 .48458 .78242 .50658 .80402 .51189 .79427 .4903 Metetra
.21 .617 0 r
.79427 .4903 .80402 .51189 .82598 .51783 .81629 .49672 Metetra
.369 .666 0 r
.81629 .49672 .82598 .51783 .84829 .52414 .83868 .50361 Metetra
.552 .716 0 r
.83868 .50361 .84829 .52414 .87094 .53058 .86143 .5107 Metetra
.754 .766 0 r
.86143 .5107 .87094 .53058 .89389 .5368 .8845 .51768 Metetra
.814 .657 0 r
.8845 .51768 .89389 .5368 .91711 .54246 .90787 .5242 Metetra
.858 .527 0 r
.90787 .5242 .91711 .54246 .94054 .54713 .93148 .52983 Metetra
.836 .594 0 r
.30094 .69226 .31209 .70684 .33067 .69036 .31965 .67483 Metetra
.788 .725 0 r
.31965 .67483 .33067 .69036 .34929 .67297 .33841 .65657 Metetra
.632 .737 0 r
.33841 .65657 .34929 .67297 .36794 .65504 .35717 .63784 Metetra
.432 .684 0 r
.35717 .63784 .36794 .65504 .38658 .63691 .37592 .619 Metetra
.255 .631 0 r
.37592 .619 .38658 .63691 .40521 .61888 .39465 .60033 Metetra
.104 .58 0 r
.39465 .60033 .40521 .61888 .42382 .60122 .41335 .58209 Metetra
0 .53 .019 r
.41335 .58209 .42382 .60122 .44241 .58415 .43202 .5645 Metetra
0 .484 .115 r
.43202 .5645 .44241 .58415 .46098 .56787 .45066 .54775 Metetra
0 .441 .186 r
.45066 .54775 .46098 .56787 .47955 .55253 .46929 .53202 Metetra
0 .402 .237 r
.46929 .53202 .47955 .55253 .49813 .53829 .48793 .51742 Metetra
0 .369 .271 r
.48793 .51742 .49813 .53829 .51673 .52526 .50658 .50409 Metetra
0 .341 .292 r
.50658 .50409 .51673 .52526 .53539 .51354 .52528 .4921 Metetra
0 .319 .304 r
.52528 .4921 .53539 .51354 .55412 .50319 .54404 .48154 Metetra
0 .296 .303 r
.54404 .48154 .55412 .50319 .57294 .49427 .5629 .47245 Metetra
0 .274 .293 r
.5629 .47245 .57294 .49427 .59189 .48684 .58187 .46488 Metetra
0 .267 .29 r
.58187 .46488 .59189 .48684 .61099 .4809 .601 .45884 Metetra
0 .274 .293 r
.601 .45884 .61099 .4809 .63028 .47646 .6203 .45436 Metetra
0 .296 .303 r
.6203 .45436 .63028 .47646 .64977 .47353 .63982 .45141 Metetra
0 .319 .304 r
.63982 .45141 .64977 .47353 .6695 .47206 .65956 .44997 Metetra
0 .341 .292 r
.65956 .44997 .6695 .47206 .6895 .47202 .67958 .45 Metetra
0 .369 .271 r
.67958 .45 .6895 .47202 .70978 .47335 .69989 .45145 Metetra
0 .402 .237 r
.69989 .45145 .70978 .47335 .73039 .47596 .72052 .45423 Metetra
0 .441 .186 r
.72052 .45423 .73039 .47596 .75132 .47974 .74148 .45824 Metetra
0 .484 .115 r
.74148 .45824 .75132 .47974 .77261 .48458 .76281 .46336 Metetra
0 .53 .019 r
.76281 .46336 .77261 .48458 .79427 .4903 .78451 .46942 Metetra
.104 .58 0 r
.78451 .46942 .79427 .4903 .81629 .49672 .8066 .47624 Metetra
.255 .631 0 r
.8066 .47624 .81629 .49672 .83868 .50361 .82906 .48361 Metetra
.432 .684 0 r
.82906 .48361 .83868 .50361 .86143 .5107 .8519 .49126 Metetra
.632 .737 0 r
.8519 .49126 .86143 .5107 .8845 .51768 .87508 .49888 Metetra
.788 .725 0 r
.87508 .49888 .8845 .51768 .90787 .5242 .89859 .50612 Metetra
.836 .594 0 r
.89859 .50612 .90787 .5242 .93148 .52983 .92236 .51258 Metetra
.815 .653 0 r
.28965 .67793 .30094 .69226 .31965 .67483 .3085 .65968 Metetra
.746 .764 0 r
.3085 .65968 .31965 .67483 .33841 .65657 .32739 .64066 Metetra
.527 .71 0 r
.32739 .64066 .33841 .65657 .35717 .63784 .34627 .62125 Metetra
.33 .655 0 r
.34627 .62125 .35717 .63784 .37592 .619 .36514 .60179 Metetra
.16 .6 0 r
.36514 .60179 .37592 .619 .39465 .60033 .38397 .58255 Metetra
.019 .546 0 r
.38397 .58255 .39465 .60033 .41335 .58209 .40277 .56381 Metetra
0 .495 .093 r
.40277 .56381 .41335 .58209 .43202 .5645 .42152 .54577 Metetra
0 .447 .178 r
.42152 .54577 .43202 .5645 .45066 .54775 .44024 .52862 Metetra
0 .402 .237 r
.44024 .52862 .45066 .54775 .46929 .53202 .45895 .51253 Metetra
0 .363 .276 r
.45895 .51253 .46929 .53202 .48793 .51742 .47764 .49762 Metetra
0 .328 .299 r
.47764 .49762 .48793 .51742 .50658 .50409 .49635 .48401 Metetra
0 .289 .299 r
.49635 .48401 .50658 .50409 .52528 .4921 .5151 .47179 Metetra
0 .239 .276 r
.5151 .47179 .52528 .4921 .54404 .48154 .53391 .46103 Metetra
0 .206 .26 r
.53391 .46103 .54404 .48154 .5629 .47245 .5528 .45178 Metetra
0 .187 .25 r
.5528 .45178 .5629 .47245 .58187 .46488 .57182 .44408 Metetra
0 .181 .247 r
.57182 .44408 .58187 .46488 .601 .45884 .59097 .43796 Metetra
0 .187 .25 r
.59097 .43796 .601 .45884 .6203 .45436 .6103 .43341 Metetra
0 .206 .26 r
.6103 .43341 .6203 .45436 .63982 .45141 .62984 .43044 Metetra
0 .239 .276 r
.62984 .43044 .63982 .45141 .65956 .44997 .64962 .42901 Metetra
0 .289 .299 r
.64962 .42901 .65956 .44997 .67958 .45 .66965 .4291 Metetra
0 .328 .299 r
.66965 .4291 .67958 .45 .69989 .45145 .68999 .43063 Metetra
0 .363 .276 r
.68999 .43063 .69989 .45145 .72052 .45423 .71064 .43354 Metetra
0 .402 .237 r
.71064 .43354 .72052 .45423 .74148 .45824 .73165 .43772 Metetra
0 .447 .178 r
.73165 .43772 .74148 .45824 .76281 .46336 .75301 .44306 Metetra
0 .495 .093 r
.75301 .44306 .76281 .46336 .78451 .46942 .77476 .4494 Metetra
.019 .546 0 r
.77476 .4494 .78451 .46942 .8066 .47624 .7969 .45656 Metetra
.16 .6 0 r
.7969 .45656 .8066 .47624 .82906 .48361 .81943 .46432 Metetra
.33 .655 0 r
.81943 .46432 .82906 .48361 .8519 .49126 .84235 .47242 Metetra
.527 .71 0 r
.84235 .47242 .8519 .49126 .87508 .49888 .86564 .48057 Metetra
.746 .764 0 r
.86564 .48057 .87508 .49888 .89859 .50612 .88927 .48842 Metetra
.815 .653 0 r
.88927 .48842 .89859 .50612 .92236 .51258 .91319 .49556 Metetra
.796 .702 0 r
.27821 .66402 .28965 .67793 .3085 .65968 .2972 .64507 Metetra
.656 .742 0 r
.2972 .64507 .3085 .65968 .32739 .64066 .31622 .6254 Metetra
.439 .686 0 r
.31622 .6254 .32739 .64066 .34627 .62125 .33523 .60541 Metetra
.247 .629 0 r
.33523 .60541 .34627 .62125 .36514 .60179 .35422 .58541 Metetra
.084 .572 0 r
.35422 .58541 .36514 .60179 .38397 .58255 .37316 .56569 Metetra
0 .517 .048 r
.37316 .56569 .38397 .58255 .40277 .56381 .39205 .54651 Metetra
0 .464 .15 r
.39205 .54651 .40277 .56381 .42152 .54577 .4109 .52807 Metetra
0 .414 .223 r
.4109 .52807 .42152 .54577 .44024 .52862 .42971 .51058 Metetra
0 .369 .271 r
.42971 .51058 .44024 .52862 .45895 .51253 .44849 .49417 Metetra
0 .328 .299 r
.44849 .49417 .45895 .51253 .47764 .49762 .46726 .47899 Metetra
0 .274 .293 r
.46726 .47899 .47764 .49762 .49635 .48401 .48604 .46514 Metetra
0 .213 .263 r
.48604 .46514 .49635 .48401 .5151 .47179 .50484 .45271 Metetra
0 .169 .24 r
.50484 .45271 .5151 .47179 .53391 .46103 .52371 .44177 Metetra
0 .141 .223 r
.52371 .44177 .53391 .46103 .5528 .45178 .54265 .43238 Metetra
0 .125 .213 r
.54265 .43238 .5528 .45178 .57182 .44408 .5617 .42456 Metetra
0 .12 .209 r
.5617 .42456 .57182 .44408 .59097 .43796 .5809 .41834 Metetra
0 .125 .213 r
.5809 .41834 .59097 .43796 .6103 .43341 .60027 .41373 Metetra
0 .141 .223 r
.60027 .41373 .6103 .43341 .62984 .43044 .61984 .41072 Metetra
0 .169 .24 r
.61984 .41072 .62984 .43044 .64962 .42901 .63964 .40929 Metetra
0 .213 .263 r
.63964 .40929 .64962 .42901 .66965 .4291 .65972 .4094 Metetra
0 .274 .293 r
.65972 .4094 .66965 .4291 .68999 .43063 .68008 .411 Metetra
0 .328 .299 r
.68008 .411 .68999 .43063 .71064 .43354 .70077 .414 Metetra
0 .369 .271 r
.70077 .414 .71064 .43354 .73165 .43772 .72181 .41832 Metetra
0 .414 .223 r
.72181 .41832 .73165 .43772 .75301 .44306 .74321 .42382 Metetra
0 .464 .15 r
.74321 .42382 .75301 .44306 .77476 .4494 .76501 .43037 Metetra
0 .517 .048 r
.76501 .43037 .77476 .4494 .7969 .45656 .78721 .43779 Metetra
.084 .572 0 r
.78721 .43779 .7969 .45656 .81943 .46432 .8098 .44586 Metetra
.247 .629 0 r
.8098 .44586 .81943 .46432 .84235 .47242 .8328 .45433 Metetra
.439 .686 0 r
.8328 .45433 .84235 .47242 .86564 .48057 .85619 .46291 Metetra
.656 .742 0 r
.85619 .46291 .86564 .48057 .88927 .48842 .87993 .47124 Metetra
.796 .702 0 r
.87993 .47124 .88927 .48842 .91319 .49556 .90398 .47894 Metetra
.78 .743 0 r
.2666 .65064 .27821 .66402 .2972 .64507 .28573 .6311 Metetra
.584 .724 0 r
.28573 .6311 .2972 .64507 .31622 .6254 .30489 .61091 Metetra
.369 .666 0 r
.30489 .61091 .31622 .6254 .33523 .60541 .32403 .59042 Metetra
.181 .607 0 r
.32403 .59042 .33523 .60541 .35422 .58541 .34314 .56997 Metetra
.025 .549 0 r
.34314 .56997 .35422 .58541 .37316 .56569 .36219 .54985 Metetra
0 .492 .099 r
.36219 .54985 .37316 .56569 .39205 .54651 .3812 .53029 Metetra
0 .438 .191 r
.3812 .53029 .39205 .54651 .4109 .52807 .40015 .51153 Metetra
0 .387 .254 r
.40015 .51153 .4109 .52807 .42971 .51058 .41905 .49373 Metetra
0 .341 .292 r
.41905 .49373 .42971 .51058 .44849 .49417 .43792 .47706 Metetra
0 .289 .299 r
.43792 .47706 .44849 .49417 .46726 .47899 .45677 .46164 Metetra
0 .213 .263 r
.45677 .46164 .46726 .47899 .48604 .46514 .47562 .44758 Metetra
0 .158 .233 r
.47562 .44758 .48604 .46514 .50484 .45271 .49449 .43496 Metetra
0 .12 .209 r
.49449 .43496 .50484 .45271 .52371 .44177 .51342 .42386 Metetra
0 .096 .192 r
.51342 .42386 .52371 .44177 .54265 .43238 .53242 .41433 Metetra
0 .082 .182 r
.53242 .41433 .54265 .43238 .5617 .42456 .55153 .40639 Metetra
0 .078 .178 r
.55153 .40639 .5617 .42456 .5809 .41834 .57077 .40009 Metetra
0 .082 .182 r
.57077 .40009 .5809 .41834 .60027 .41373 .59018 .39541 Metetra
0 .096 .192 r
.59018 .39541 .60027 .41373 .61984 .41072 .6098 .39236 Metetra
0 .12 .209 r
.6098 .39236 .61984 .41072 .63964 .40929 .62964 .39091 Metetra
0 .158 .233 r
.62964 .39091 .63964 .40929 .65972 .4094 .64975 .39102 Metetra
0 .213 .263 r
.64975 .39102 .65972 .4094 .68008 .411 .67016 .39265 Metetra
0 .289 .299 r
.67016 .39265 .68008 .411 .70077 .414 .69088 .39571 Metetra
0 .341 .292 r
.69088 .39571 .70077 .414 .72181 .41832 .71196 .40011 Metetra
0 .387 .254 r
.71196 .40011 .72181 .41832 .74321 .42382 .73342 .40574 Metetra
0 .438 .191 r
.73342 .40574 .74321 .42382 .76501 .43037 .75526 .41245 Metetra
0 .492 .099 r
.75526 .41245 .76501 .43037 .78721 .43779 .77751 .42006 Metetra
.025 .549 0 r
.77751 .42006 .78721 .43779 .8098 .44586 .80018 .42836 Metetra
.181 .607 0 r
.80018 .42836 .8098 .44586 .8328 .45433 .82325 .43711 Metetra
.369 .666 0 r
.82325 .43711 .8328 .45433 .85619 .46291 .84673 .44601 Metetra
.584 .724 0 r
.84673 .44601 .85619 .46291 .87993 .47124 .87057 .45472 Metetra
.78 .743 0 r
.87057 .45472 .87993 .47124 .90398 .47894 .89474 .46284 Metetra
.762 .767 0 r
.2548 .63789 .2666 .65064 .28573 .6311 .27408 .61789 Metetra
.527 .71 0 r
.27408 .61789 .28573 .6311 .30489 .61091 .29337 .59726 Metetra
.315 .65 0 r
.29337 .59726 .30489 .61091 .32403 .59042 .31264 .57638 Metetra
.132 .59 0 r
.31264 .57638 .32403 .59042 .34314 .56997 .33188 .55557 Metetra
0 .53 .019 r
.33188 .55557 .34314 .56997 .36219 .54985 .35106 .53511 Metetra
0 .472 .135 r
.35106 .53511 .36219 .54985 .3812 .53029 .37018 .51525 Metetra
0 .417 .219 r
.37018 .51525 .3812 .53029 .40015 .51153 .38924 .49621 Metetra
0 .366 .274 r
.38924 .49621 .40015 .51153 .41905 .49373 .40824 .47816 Metetra
0 .319 .304 r
.40824 .47816 .41905 .49373 .43792 .47706 .42721 .46125 Metetra
0 .239 .276 r
.42721 .46125 .43792 .47706 .45677 .46164 .44615 .44563 Metetra
0 .169 .24 r
.44615 .44563 .45677 .46164 .47562 .44758 .46508 .43138 Metetra
0 .12 .209 r
.46508 .43138 .47562 .44758 .49449 .43496 .48403 .41861 Metetra
0 .087 .185 r
.48403 .41861 .49449 .43496 .51342 .42386 .50303 .40736 Metetra
0 .066 .168 r
.50303 .40736 .51342 .42386 .53242 .41433 .5221 .3977 Metetra
0 .055 .157 r
.5221 .3977 .53242 .41433 .55153 .40639 .54127 .38966 Metetra
0 .051 .154 r
.54127 .38966 .55153 .40639 .57077 .40009 .56057 .38327 Metetra
0 .055 .157 r
.56057 .38327 .57077 .40009 .59018 .39541 .58004 .37852 Metetra
0 .066 .168 r
.58004 .37852 .59018 .39541 .6098 .39236 .5997 .37541 Metetra
0 .087 .185 r
.5997 .37541 .6098 .39236 .62964 .39091 .6196 .37393 Metetra
0 .12 .209 r
.6196 .37393 .62964 .39091 .64975 .39102 .63975 .37403 Metetra
0 .169 .24 r
.63975 .37403 .64975 .39102 .67016 .39265 .6602 .37566 Metetra
0 .239 .276 r
.6602 .37566 .67016 .39265 .69088 .39571 .68098 .37874 Metetra
0 .319 .304 r
.68098 .37874 .69088 .39571 .71196 .40011 .70211 .3832 Metetra
0 .366 .274 r
.70211 .3832 .71196 .40011 .73342 .40574 .72361 .3889 Metetra
0 .417 .219 r
.72361 .3889 .73342 .40574 .75526 .41245 .74551 .3957 Metetra
0 .472 .135 r
.74551 .3957 .75526 .41245 .77751 .42006 .76782 .40344 Metetra
0 .53 .019 r
.76782 .40344 .77751 .42006 .80018 .42836 .79055 .4119 Metetra
.132 .59 0 r
.79055 .4119 .80018 .42836 .82325 .43711 .8137 .42084 Metetra
.315 .65 0 r
.8137 .42084 .82325 .43711 .84673 .44601 .83726 .42997 Metetra
.527 .71 0 r
.83726 .42997 .84673 .44601 .87057 .45472 .8612 .43895 Metetra
.762 .767 0 r
.8612 .43895 .87057 .45472 .89474 .46284 .88549 .44737 Metetra
.721 .758 0 r
.2428 .62586 .2548 .63789 .27408 .61789 .26222 .60551 Metetra
.487 .699 0 r
.26222 .60551 .27408 .61789 .29337 .59726 .28165 .58455 Metetra
.277 .638 0 r
.28165 .58455 .29337 .59726 .31264 .57638 .30106 .56336 Metetra
.097 .577 0 r
.30106 .56336 .31264 .57638 .33188 .55557 .32043 .54226 Metetra
0 .517 .048 r
.32043 .54226 .33188 .55557 .35106 .53511 .33973 .52154 Metetra
0 .458 .159 r
.33973 .52154 .35106 .53511 .37018 .51525 .35898 .50144 Metetra
0 .402 .237 r
.35898 .50144 .37018 .51525 .38924 .49621 .37815 .48217 Metetra
0 .35 .286 r
.37815 .48217 .38924 .49621 .40824 .47816 .39727 .46392 Metetra
0 .296 .303 r
.39727 .46392 .40824 .47816 .42721 .46125 .41634 .44683 Metetra
0 .206 .26 r
.41634 .44683 .42721 .46125 .44615 .44563 .43538 .43103 Metetra
0 .141 .223 r
.43538 .43103 .44615 .44563 .46508 .43138 .45441 .41662 Metetra
0 .096 .192 r
.45441 .41662 .46508 .43138 .48403 .41861 .47345 .4037 Metetra
0 .066 .168 r
.47345 .4037 .48403 .41861 .50303 .40736 .49252 .39233 Metetra
0 .048 .15 r
.49252 .39233 .50303 .40736 .5221 .3977 .51167 .38256 Metetra
0 .038 .139 r
.51167 .38256 .5221 .3977 .54127 .38966 .53091 .37442 Metetra
0 .035 .136 r
.53091 .37442 .54127 .38966 .56057 .38327 .55028 .36793 Metetra
0 .038 .139 r
.55028 .36793 .56057 .38327 .58004 .37852 .56981 .36311 Metetra
0 .048 .15 r
.56981 .36311 .58004 .37852 .5997 .37541 .58954 .35994 Metetra
0 .066 .168 r
.58954 .35994 .5997 .37541 .6196 .37393 .60949 .35841 Metetra
0 .096 .192 r
.60949 .35841 .6196 .37393 .63975 .37403 .62971 .35847 Metetra
0 .141 .223 r
.62971 .35847 .63975 .37403 .6602 .37566 .65021 .36008 Metetra
0 .206 .26 r
.65021 .36008 .6602 .37566 .68098 .37874 .67104 .36316 Metetra
0 .296 .303 r
.67104 .36316 .68098 .37874 .70211 .3832 .69222 .36763 Metetra
0 .35 .286 r
.69222 .36763 .70211 .3832 .72361 .3889 .71378 .37335 Metetra
0 .402 .237 r
.71378 .37335 .72361 .3889 .74551 .3957 .73574 .38021 Metetra
0 .458 .159 r
.73574 .38021 .74551 .3957 .76782 .40344 .75812 .38801 Metetra
0 .517 .048 r
.75812 .38801 .76782 .40344 .79055 .4119 .78092 .39656 Metetra
.097 .577 0 r
.78092 .39656 .79055 .4119 .8137 .42084 .80414 .40561 Metetra
.277 .638 0 r
.80414 .40561 .8137 .42084 .83726 .42997 .82778 .41487 Metetra
.487 .699 0 r
.82778 .41487 .83726 .42997 .8612 .43895 .85182 .42401 Metetra
.721 .758 0 r
.85182 .42401 .8612 .43895 .88549 .44737 .87621 .43262 Metetra
.697 .752 0 r
.23058 .6146 .2428 .62586 .26222 .60551 .25014 .59401 Metetra
.463 .693 0 r
.25014 .59401 .26222 .60551 .28165 .58455 .26971 .57282 Metetra
.254 .631 0 r
.26971 .57282 .28165 .58455 .30106 .56336 .28926 .55141 Metetra
.077 .57 0 r
.28926 .55141 .30106 .56336 .32043 .54226 .30876 .53011 Metetra
0 .509 .066 r
.30876 .53011 .32043 .54226 .33973 .52154 .3282 .50919 Metetra
0 .45 .173 r
.3282 .50919 .33973 .52154 .35898 .50144 .34757 .48891 Metetra
0 .393 .247 r
.34757 .48891 .35898 .50144 .37815 .48217 .36687 .46947 Metetra
0 .341 .292 r
.36687 .46947 .37815 .48217 .39727 .46392 .38611 .45105 Metetra
0 .274 .293 r
.38611 .45105 .39727 .46392 .41634 .44683 .40529 .43381 Metetra
0 .187 .25 r
.40529 .43381 .41634 .44683 .43538 .43103 .42444 .41787 Metetra
0 .125 .213 r
.42444 .41787 .43538 .43103 .45441 .41662 .44357 .40334 Metetra
0 .082 .182 r
.44357 .40334 .45441 .41662 .47345 .4037 .46271 .3903 Metetra
0 .055 .157 r
.46271 .3903 .47345 .4037 .49252 .39233 .48188 .37881 Metetra
0 .038 .139 r
.48188 .37881 .49252 .39233 .51167 .38256 .50112 .36893 Metetra
0 .029 .129 r
.50112 .36893 .51167 .38256 .53091 .37442 .52044 .3607 Metetra
0 .026 .125 r
.52044 .3607 .53091 .37442 .55028 .36793 .53989 .35412 Metetra
0 .029 .129 r
.53989 .35412 .55028 .36793 .56981 .36311 .5595 .34922 Metetra
0 .038 .139 r
.5595 .34922 .56981 .36311 .58954 .35994 .57929 .34598 Metetra
0 .055 .157 r
.57929 .34598 .58954 .35994 .60949 .35841 .59932 .34439 Metetra
0 .082 .182 r
.59932 .34439 .60949 .35841 .62971 .35847 .6196 .3444 Metetra
0 .125 .213 r
.6196 .3444 .62971 .35847 .65021 .36008 .64017 .34596 Metetra
0 .187 .25 r
.64017 .34596 .65021 .36008 .67104 .36316 .66106 .34901 Metetra
0 .274 .293 r
.66106 .34901 .67104 .36316 .69222 .36763 .6823 .35345 Metetra
0 .341 .292 r
.6823 .35345 .69222 .36763 .71378 .37335 .70393 .35916 Metetra
0 .393 .247 r
.70393 .35916 .71378 .37335 .73574 .38021 .72595 .36601 Metetra
0 .45 .173 r
.72595 .36601 .73574 .38021 .75812 .38801 .7484 .37382 Metetra
0 .509 .066 r
.7484 .37382 .75812 .38801 .78092 .39656 .77127 .38239 Metetra
.077 .57 0 r
.77127 .38239 .78092 .39656 .80414 .40561 .79457 .39146 Metetra
.254 .631 0 r
.79457 .39146 .80414 .40561 .82778 .41487 .8183 .40077 Metetra
.463 .693 0 r
.8183 .40077 .82778 .41487 .85182 .42401 .84242 .40995 Metetra
.697 .752 0 r
.84242 .40995 .85182 .42401 .87621 .43262 .86692 .41863 Metetra
.689 .75 0 r
.21812 .60413 .23058 .6146 .25014 .59401 .23782 .58341 Metetra
.455 .691 0 r
.23782 .58341 .25014 .59401 .26971 .57282 .25753 .5621 Metetra
.247 .629 0 r
.25753 .5621 .26971 .57282 .28926 .55141 .27722 .54057 Metetra
.07 .567 0 r
.27722 .54057 .28926 .55141 .30876 .53011 .29686 .51914 Metetra
0 .506 .071 r
.29686 .51914 .30876 .53011 .3282 .50919 .31644 .49809 Metetra
0 .447 .178 r
.31644 .49809 .3282 .50919 .34757 .48891 .33595 .47769 Metetra
0 .39 .251 r
.33595 .47769 .34757 .48891 .36687 .46947 .35538 .45813 Metetra
0 .338 .294 r
.35538 .45813 .36687 .46947 .38611 .45105 .37474 .43959 Metetra
0 .267 .29 r
.37474 .43959 .38611 .45105 .40529 .43381 .39405 .42224 Metetra
0 .181 .247 r
.39405 .42224 .40529 .43381 .42444 .41787 .41332 .40619 Metetra
0 .12 .209 r
.41332 .40619 .42444 .41787 .44357 .40334 .43256 .39155 Metetra
0 .078 .178 r
.43256 .39155 .44357 .40334 .46271 .3903 .45181 .37841 Metetra
0 .051 .154 r
.45181 .37841 .46271 .3903 .48188 .37881 .47108 .36683 Metetra
0 .035 .136 r
.47108 .36683 .48188 .37881 .50112 .36893 .49042 .35685 Metetra
0 .026 .125 r
.49042 .35685 .50112 .36893 .52044 .3607 .50984 .34853 Metetra
0 .023 .121 r
.50984 .34853 .52044 .3607 .53989 .35412 .52938 .34187 Metetra
0 .026 .125 r
.52938 .34187 .53989 .35412 .5595 .34922 .54907 .33688 Metetra
0 .035 .136 r
.54907 .33688 .5595 .34922 .57929 .34598 .56895 .33356 Metetra
0 .051 .154 r
.56895 .33356 .57929 .34598 .59932 .34439 .58905 .33189 Metetra
0 .078 .178 r
.58905 .33189 .59932 .34439 .6196 .3444 .60941 .33183 Metetra
0 .12 .209 r
.60941 .33183 .6196 .3444 .64017 .34596 .63005 .33333 Metetra
0 .181 .247 r
.63005 .33333 .64017 .34596 .66106 .34901 .65102 .33631 Metetra
0 .267 .29 r
.65102 .33631 .66106 .34901 .6823 .35345 .67233 .34068 Metetra
0 .338 .294 r
.67233 .34068 .6823 .35345 .70393 .35916 .69403 .34634 Metetra
0 .39 .251 r
.69403 .34634 .70393 .35916 .72595 .36601 .71613 .35313 Metetra
0 .447 .178 r
.71613 .35313 .72595 .36601 .7484 .37382 .73864 .36088 Metetra
0 .506 .071 r
.73864 .36088 .7484 .37382 .77127 .38239 .76159 .3694 Metetra
.07 .567 0 r
.76159 .3694 .77127 .38239 .79457 .39146 .78498 .37843 Metetra
.247 .629 0 r
.78498 .37843 .79457 .39146 .8183 .40077 .80879 .38768 Metetra
.455 .691 0 r
.80879 .38768 .8183 .40077 .84242 .40995 .833 .39681 Metetra
.689 .75 0 r
.833 .39681 .84242 .40995 .86692 .41863 .85759 .40544 Metetra
.697 .752 0 r
.20541 .59447 .21812 .60413 .23782 .58341 .22524 .57374 Metetra
.463 .693 0 r
.22524 .57374 .23782 .58341 .25753 .5621 .2451 .5524 Metetra
.254 .631 0 r
.2451 .5524 .25753 .5621 .27722 .54057 .26493 .53083 Metetra
.077 .57 0 r
.26493 .53083 .27722 .54057 .29686 .51914 .28471 .50935 Metetra
0 .509 .066 r
.28471 .50935 .29686 .51914 .31644 .49809 .30443 .48825 Metetra
0 .45 .173 r
.30443 .48825 .31644 .49809 .33595 .47769 .32408 .46778 Metetra
0 .393 .247 r
.32408 .46778 .33595 .47769 .35538 .45813 .34365 .44816 Metetra
0 .341 .292 r
.34365 .44816 .35538 .45813 .37474 .43959 .36315 .42955 Metetra
0 .274 .293 r
.36315 .42955 .37474 .43959 .39405 .42224 .38259 .41212 Metetra
0 .187 .25 r
.38259 .41212 .39405 .42224 .41332 .40619 .40198 .396 Metetra
0 .125 .213 r
.40198 .396 .41332 .40619 .43256 .39155 .42135 .38128 Metetra
0 .082 .182 r
.42135 .38128 .43256 .39155 .45181 .37841 .44072 .36805 Metetra
0 .055 .157 r
.44072 .36805 .45181 .37841 .47108 .36683 .46011 .35638 Metetra
0 .038 .139 r
.46011 .35638 .47108 .36683 .49042 .35685 .47955 .34633 Metetra
0 .029 .129 r
.47955 .34633 .49042 .35685 .50984 .34853 .49908 .33792 Metetra
0 .026 .125 r
.49908 .33792 .50984 .34853 .52938 .34187 .51872 .33117 Metetra
0 .029 .129 r
.51872 .33117 .52938 .34187 .54907 .33688 .53851 .3261 Metetra
0 .038 .139 r
.53851 .3261 .54907 .33688 .56895 .33356 .55848 .32269 Metetra
0 .055 .157 r
.55848 .32269 .56895 .33356 .58905 .33189 .57867 .32093 Metetra
0 .082 .182 r
.57867 .32093 .58905 .33189 .60941 .33183 .59912 .32078 Metetra
0 .125 .213 r
.59912 .32078 .60941 .33183 .63005 .33333 .61985 .32218 Metetra
0 .187 .25 r
.61985 .32218 .63005 .33333 .65102 .33631 .6409 .32507 Metetra
0 .274 .293 r
.6409 .32507 .65102 .33631 .67233 .34068 .6623 .32934 Metetra
0 .341 .292 r
.6623 .32934 .67233 .34068 .69403 .34634 .68407 .33489 Metetra
0 .393 .247 r
.68407 .33489 .69403 .34634 .71613 .35313 .70625 .34158 Metetra
0 .45 .173 r
.70625 .34158 .71613 .35313 .73864 .36088 .72885 .34922 Metetra
0 .509 .066 r
.72885 .34922 .73864 .36088 .76159 .3694 .75188 .35761 Metetra
.077 .57 0 r
.75188 .35761 .76159 .3694 .78498 .37843 .77535 .36651 Metetra
.254 .631 0 r
.77535 .36651 .78498 .37843 .80879 .38768 .79924 .37562 Metetra
.463 .693 0 r
.79924 .37562 .80879 .38768 .833 .39681 .82355 .38459 Metetra
.697 .752 0 r
.82355 .38459 .833 .39681 .85759 .40544 .84823 .39305 Metetra
.721 .758 0 r
.19244 .58559 .20541 .59447 .22524 .57374 .2124 .56497 Metetra
.487 .699 0 r
.2124 .56497 .22524 .57374 .2451 .5524 .23239 .54371 Metetra
.277 .638 0 r
.23239 .54371 .2451 .5524 .26493 .53083 .25236 .52219 Metetra
.097 .577 0 r
.25236 .52219 .26493 .53083 .28471 .50935 .27229 .50075 Metetra
0 .517 .048 r
.27229 .50075 .28471 .50935 .30443 .48825 .29216 .47966 Metetra
0 .458 .159 r
.29216 .47966 .30443 .48825 .32408 .46778 .31195 .45919 Metetra
0 .402 .237 r
.31195 .45919 .32408 .46778 .34365 .44816 .33167 .43955 Metetra
0 .35 .286 r
.33167 .43955 .34365 .44816 .36315 .42955 .35131 .42092 Metetra
0 .296 .303 r
.35131 .42092 .36315 .42955 .38259 .41212 .37089 .40345 Metetra
0 .206 .26 r
.37089 .40345 .38259 .41212 .40198 .396 .39042 .38728 Metetra
0 .141 .223 r
.39042 .38728 .40198 .396 .42135 .38128 .40993 .37251 Metetra
0 .096 .192 r
.40993 .37251 .42135 .38128 .44072 .36805 .42942 .35922 Metetra
0 .066 .168 r
.42942 .35922 .44072 .36805 .46011 .35638 .44894 .34749 Metetra
0 .048 .15 r
.44894 .34749 .46011 .35638 .47955 .34633 .4685 .33736 Metetra
0 .038 .139 r
.4685 .33736 .47955 .34633 .49908 .33792 .48815 .32887 Metetra
0 .035 .136 r
.48815 .32887 .49908 .33792 .51872 .33117 .5079 .32203 Metetra
0 .038 .139 r
.5079 .32203 .51872 .33117 .53851 .3261 .5278 .31687 Metetra
0 .048 .15 r
.5278 .31687 .53851 .3261 .55848 .32269 .54788 .31337 Metetra
0 .066 .168 r
.54788 .31337 .55848 .32269 .57867 .32093 .56817 .31151 Metetra
0 .096 .192 r
.56817 .31151 .57867 .32093 .59912 .32078 .58871 .31124 Metetra
0 .141 .223 r
.58871 .31124 .59912 .32078 .61985 .32218 .60954 .31253 Metetra
0 .206 .26 r
.60954 .31253 .61985 .32218 .6409 .32507 .63068 .31529 Metetra
0 .296 .303 r
.63068 .31529 .6409 .32507 .6623 .32934 .65217 .31943 Metetra
0 .35 .286 r
.65217 .31943 .6623 .32934 .68407 .33489 .67404 .32483 Metetra
0 .402 .237 r
.67404 .32483 .68407 .33489 .70625 .34158 .69631 .33135 Metetra
0 .458 .159 r
.69631 .33135 .70625 .34158 .72885 .34922 .71899 .33882 Metetra
0 .517 .048 r
.71899 .33882 .72885 .34922 .75188 .35761 .74211 .34701 Metetra
.097 .577 0 r
.74211 .34701 .75188 .35761 .77535 .36651 .76567 .3557 Metetra
.277 .638 0 r
.76567 .3557 .77535 .36651 .79924 .37562 .78965 .36456 Metetra
.487 .699 0 r
.78965 .36456 .79924 .37562 .82355 .38459 .81404 .37328 Metetra
.721 .758 0 r
.81404 .37328 .82355 .38459 .84823 .39305 .83881 .38143 Metetra
.762 .767 0 r
.17919 .57746 .19244 .58559 .2124 .56497 .19927 .55706 Metetra
.527 .71 0 r
.19927 .55706 .2124 .56497 .23239 .54371 .21939 .53599 Metetra
.315 .65 0 r
.21939 .53599 .23239 .54371 .25236 .52219 .23951 .51462 Metetra
.132 .59 0 r
.23951 .51462 .25236 .52219 .27229 .50075 .25959 .49329 Metetra
0 .53 .019 r
.25959 .49329 .27229 .50075 .29216 .47966 .2796 .4723 Metetra
0 .472 .135 r
.2796 .4723 .29216 .47966 .31195 .45919 .29955 .45189 Metetra
0 .417 .219 r
.29955 .45189 .31195 .45919 .33167 .43955 .31941 .43229 Metetra
0 .366 .274 r
.31941 .43229 .33167 .43955 .35131 .42092 .33921 .41368 Metetra
0 .319 .304 r
.33921 .41368 .35131 .42092 .37089 .40345 .35894 .39621 Metetra
0 .239 .276 r
.35894 .39621 .37089 .40345 .39042 .38728 .37861 .38003 Metetra
0 .169 .24 r
.37861 .38003 .39042 .38728 .40993 .37251 .39826 .36523 Metetra
0 .12 .209 r
.39826 .36523 .40993 .37251 .42942 .35922 .4179 .3519 Metetra
0 .087 .185 r
.4179 .3519 .42942 .35922 .44894 .34749 .43755 .34011 Metetra
0 .066 .168 r
.43755 .34011 .44894 .34749 .4685 .33736 .45724 .32992 Metetra
0 .055 .157 r
.45724 .32992 .4685 .33736 .48815 .32887 .47702 .32135 Metetra
0 .051 .154 r
.47702 .32135 .48815 .32887 .5079 .32203 .4969 .31444 Metetra
0 .055 .157 r
.4969 .31444 .5079 .32203 .5278 .31687 .51692 .30918 Metetra
0 .066 .168 r
.51692 .30918 .5278 .31687 .54788 .31337 .53711 .30557 Metetra
0 .087 .185 r
.53711 .30557 .54788 .31337 .56817 .31151 .55752 .30359 Metetra
0 .12 .209 r
.55752 .30359 .56817 .31151 .58871 .31124 .57817 .3032 Metetra
0 .169 .24 r
.57817 .3032 .58871 .31124 .60954 .31253 .59911 .30434 Metetra
0 .239 .276 r
.59911 .30434 .60954 .31253 .63068 .31529 .62035 .30694 Metetra
0 .319 .304 r
.62035 .30694 .63068 .31529 .65217 .31943 .64195 .3109 Metetra
0 .366 .274 r
.64195 .3109 .65217 .31943 .67404 .32483 .66391 .31611 Metetra
0 .417 .219 r
.66391 .31611 .67404 .32483 .69631 .33135 .68628 .32242 Metetra
0 .472 .135 r
.68628 .32242 .69631 .33135 .71899 .33882 .70906 .32964 Metetra
0 .53 .019 r
.70906 .32964 .71899 .33882 .74211 .34701 .73227 .33757 Metetra
.132 .59 0 r
.73227 .33757 .74211 .34701 .76567 .3557 .75592 .34595 Metetra
.315 .65 0 r
.75592 .34595 .76567 .3557 .78965 .36456 .77999 .35449 Metetra
.527 .71 0 r
.77999 .35449 .78965 .36456 .81404 .37328 .80448 .36282 Metetra
.762 .767 0 r
.80448 .36282 .81404 .37328 .83881 .38143 .82934 .37056 Metetra
.78 .743 0 r
.16565 .57001 .17919 .57746 .19927 .55706 .18585 .54996 Metetra
.584 .724 0 r
.18585 .54996 .19927 .55706 .21939 .53599 .2061 .52918 Metetra
.369 .666 0 r
.2061 .52918 .21939 .53599 .23951 .51462 .22635 .50806 Metetra
.181 .607 0 r
.22635 .50806 .23951 .51462 .25959 .49329 .24657 .48693 Metetra
.025 .549 0 r
.24657 .48693 .25959 .49329 .2796 .4723 .26674 .4661 Metetra
0 .492 .099 r
.26674 .4661 .2796 .4723 .29955 .45189 .28684 .44583 Metetra
0 .438 .191 r
.28684 .44583 .29955 .45189 .31941 .43229 .30686 .42632 Metetra
0 .387 .254 r
.30686 .42632 .31941 .43229 .33921 .41368 .32681 .40778 Metetra
0 .341 .292 r
.32681 .40778 .33921 .41368 .35894 .39621 .3467 .39036 Metetra
0 .289 .299 r
.3467 .39036 .35894 .39621 .37861 .38003 .36653 .3742 Metetra
0 .213 .263 r
.36653 .3742 .37861 .38003 .39826 .36523 .38633 .3594 Metetra
0 .158 .233 r
.38633 .3594 .39826 .36523 .4179 .3519 .40612 .34605 Metetra
0 .12 .209 r
.40612 .34605 .4179 .3519 .43755 .34011 .42592 .33423 Metetra
0 .096 .192 r
.42592 .33423 .43755 .34011 .45724 .32992 .44576 .32398 Metetra
0 .082 .182 r
.44576 .32398 .45724 .32992 .47702 .32135 .46567 .31535 Metetra
0 .078 .178 r
.46567 .31535 .47702 .32135 .4969 .31444 .48568 .30835 Metetra
0 .082 .182 r
.48568 .30835 .4969 .31444 .51692 .30918 .50584 .30299 Metetra
0 .096 .192 r
.50584 .30299 .51692 .30918 .53711 .30557 .52616 .29927 Metetra
0 .12 .209 r
.52616 .29927 .53711 .30557 .55752 .30359 .5467 .29715 Metetra
0 .158 .233 r
.5467 .29715 .55752 .30359 .57817 .3032 .56747 .29661 Metetra
0 .213 .263 r
.56747 .29661 .57817 .3032 .59911 .30434 .58852 .29758 Metetra
0 .289 .299 r
.58852 .29758 .59911 .30434 .62035 .30694 .60989 .29999 Metetra
0 .341 .292 r
.60989 .29999 .62035 .30694 .64195 .3109 .63159 .30373 Metetra
0 .387 .254 r
.63159 .30373 .64195 .3109 .66391 .31611 .65367 .3087 Metetra
0 .438 .191 r
.65367 .3087 .66391 .31611 .68628 .32242 .67614 .31473 Metetra
0 .492 .099 r
.67614 .31473 .68628 .32242 .70906 .32964 .69903 .32165 Metetra
.025 .549 0 r
.69903 .32165 .70906 .32964 .73227 .33757 .72234 .32923 Metetra
.181 .607 0 r
.72234 .32923 .73227 .33757 .75592 .34595 .74609 .33722 Metetra
.369 .666 0 r
.74609 .33722 .75592 .34595 .77999 .35449 .77026 .34532 Metetra
.584 .724 0 r
.77026 .34532 .77999 .35449 .80448 .36282 .79483 .35317 Metetra
.78 .743 0 r
.79483 .35317 .80448 .36282 .82934 .37056 .81978 .36035 Metetra
.796 .702 0 r
.15183 .56315 .16565 .57001 .18585 .54996 .17213 .54358 Metetra
.656 .742 0 r
.17213 .54358 .18585 .54996 .2061 .52918 .1925 .52321 Metetra
.439 .686 0 r
.1925 .52321 .2061 .52918 .22635 .50806 .21288 .50244 Metetra
.247 .629 0 r
.21288 .50244 .22635 .50806 .24657 .48693 .23325 .48161 Metetra
.084 .572 0 r
.23325 .48161 .24657 .48693 .26674 .4661 .25356 .46102 Metetra
0 .517 .048 r
.25356 .46102 .26674 .4661 .28684 .44583 .27382 .44094 Metetra
0 .464 .15 r
.27382 .44094 .28684 .44583 .30686 .42632 .294 .42159 Metetra
0 .414 .223 r
.294 .42159 .30686 .42632 .32681 .40778 .31411 .40317 Metetra
0 .369 .271 r
.31411 .40317 .32681 .40778 .3467 .39036 .33416 .38584 Metetra
0 .328 .299 r
.33416 .38584 .3467 .39036 .36653 .3742 .35416 .36973 Metetra
0 .274 .293 r
.35416 .36973 .36653 .3742 .38633 .3594 .37412 .35496 Metetra
0 .213 .263 r
.37412 .35496 .38633 .3594 .40612 .34605 .39406 .34162 Metetra
0 .169 .24 r
.39406 .34162 .40612 .34605 .42592 .33423 .41402 .32978 Metetra
0 .141 .223 r
.41402 .32978 .42592 .33423 .44576 .32398 .43402 .31949 Metetra
0 .125 .213 r
.43402 .31949 .44576 .32398 .46567 .31535 .45408 .3108 Metetra
0 .12 .209 r
.45408 .3108 .46567 .31535 .48568 .30835 .47424 .30372 Metetra
0 .125 .213 r
.47424 .30372 .48568 .30835 .50584 .30299 .49454 .29825 Metetra
0 .141 .223 r
.49454 .29825 .50584 .30299 .52616 .29927 .51501 .2944 Metetra
0 .169 .24 r
.51501 .2944 .52616 .29927 .5467 .29715 .53568 .29214 Metetra
0 .213 .263 r
.53568 .29214 .5467 .29715 .56747 .29661 .55659 .29142 Metetra
0 .274 .293 r
.55659 .29142 .56747 .29661 .58852 .29758 .57777 .29219 Metetra
0 .328 .299 r
.57777 .29219 .58852 .29758 .60989 .29999 .59926 .29437 Metetra
0 .369 .271 r
.59926 .29437 .60989 .29999 .63159 .30373 .62109 .29786 Metetra
0 .414 .223 r
.62109 .29786 .63159 .30373 .65367 .3087 .64329 .30253 Metetra
0 .464 .15 r
.64329 .30253 .65367 .3087 .67614 .31473 .66588 .30822 Metetra
0 .517 .048 r
.66588 .30822 .67614 .31473 .69903 .32165 .68888 .31476 Metetra
.084 .572 0 r
.68888 .31476 .69903 .32165 .72234 .32923 .7123 .32192 Metetra
.247 .629 0 r
.7123 .32192 .72234 .32923 .74609 .33722 .73615 .32942 Metetra
.439 .686 0 r
.73615 .32942 .74609 .33722 .77026 .34532 .76042 .33698 Metetra
.656 .742 0 r
.76042 .33698 .77026 .34532 .79483 .35317 .78509 .34421 Metetra
.796 .702 0 r
.78509 .34421 .79483 .35317 .81978 .36035 .81011 .3507 Metetra
.815 .653 0 r
.13771 .55676 .15183 .56315 .17213 .54358 .1581 .53779 Metetra
.746 .764 0 r
.1581 .53779 .17213 .54358 .1925 .52321 .17858 .51796 Metetra
.527 .71 0 r
.17858 .51796 .1925 .52321 .21288 .50244 .19909 .49764 Metetra
.33 .655 0 r
.19909 .49764 .21288 .50244 .23325 .48161 .21959 .4772 Metetra
.16 .6 0 r
.21959 .4772 .23325 .48161 .25356 .46102 .24006 .45695 Metetra
.019 .546 0 r
.24006 .45695 .25356 .46102 .27382 .44094 .26047 .43714 Metetra
0 .495 .093 r
.26047 .43714 .27382 .44094 .294 .42159 .28081 .41802 Metetra
0 .447 .178 r
.28081 .41802 .294 .42159 .31411 .40317 .30109 .39977 Metetra
0 .402 .237 r
.30109 .39977 .31411 .40317 .33416 .38584 .32131 .38258 Metetra
0 .363 .276 r
.32131 .38258 .33416 .38584 .35416 .36973 .34147 .36657 Metetra
0 .328 .299 r
.34147 .36657 .35416 .36973 .37412 .35496 .36161 .35186 Metetra
0 .289 .299 r
.36161 .35186 .37412 .35496 .39406 .34162 .38172 .33855 Metetra
0 .239 .276 r
.38172 .33855 .39406 .34162 .41402 .32978 .40184 .32671 Metetra
0 .206 .26 r
.40184 .32671 .41402 .32978 .43402 .31949 .422 .31639 Metetra
0 .187 .25 r
.422 .31639 .43402 .31949 .45408 .3108 .44223 .30764 Metetra
0 .181 .247 r
.44223 .30764 .45408 .3108 .47424 .30372 .46255 .30047 Metetra
0 .187 .25 r
.46255 .30047 .47424 .30372 .49454 .29825 .48301 .2949 Metetra
0 .206 .26 r
.48301 .2949 .49454 .29825 .51501 .2944 .50363 .29091 Metetra
0 .239 .276 r
.50363 .29091 .51501 .2944 .53568 .29214 .52445 .28848 Metetra
0 .289 .299 r
.52445 .28848 .53568 .29214 .55659 .29142 .54551 .28756 Metetra
0 .328 .299 r
.54551 .28756 .55659 .29142 .57777 .29219 .56683 .2881 Metetra
0 .363 .276 r
.56683 .2881 .57777 .29219 .59926 .29437 .58846 .29001 Metetra
0 .402 .237 r
.58846 .29001 .59926 .29437 .62109 .29786 .61043 .29319 Metetra
0 .447 .178 r
.61043 .29319 .62109 .29786 .64329 .30253 .63275 .2975 Metetra
0 .495 .093 r
.63275 .2975 .64329 .30253 .66588 .30822 .65547 .3028 Metetra
.019 .546 0 r
.65547 .3028 .66588 .30822 .68888 .31476 .67859 .30888 Metetra
.16 .6 0 r
.67859 .30888 .68888 .31476 .7123 .32192 .70213 .31552 Metetra
.33 .655 0 r
.70213 .31552 .7123 .32192 .73615 .32942 .72609 .32245 Metetra
.527 .71 0 r
.72609 .32245 .73615 .32942 .76042 .33698 .75046 .32934 Metetra
.746 .764 0 r
.75046 .32934 .76042 .33698 .78509 .34421 .77522 .33583 Metetra
.815 .653 0 r
.77522 .33583 .78509 .34421 .81011 .3507 .80033 .34149 Metetra
.836 .594 0 r
.12331 .55067 .13771 .55676 .1581 .53779 .14377 .53247 Metetra
.788 .725 0 r
.14377 .53247 .1581 .53779 .17858 .51796 .16434 .51329 Metetra
.632 .737 0 r
.16434 .51329 .17858 .51796 .19909 .49764 .18496 .49355 Metetra
.432 .684 0 r
.18496 .49355 .19909 .49764 .21959 .4772 .2056 .47361 Metetra
.255 .631 0 r
.2056 .47361 .21959 .4772 .24006 .45695 .22621 .45377 Metetra
.104 .58 0 r
.22621 .45377 .24006 .45695 .26047 .43714 .24678 .43432 Metetra
0 .53 .019 r
.24678 .43432 .26047 .43714 .28081 .41802 .26728 .41549 Metetra
0 .484 .115 r
.26728 .41549 .28081 .41802 .30109 .39977 .28773 .39748 Metetra
0 .441 .186 r
.28773 .39748 .30109 .39977 .32131 .38258 .30812 .38047 Metetra
0 .402 .237 r
.30812 .38047 .32131 .38258 .34147 .36657 .32846 .3646 Metetra
0 .369 .271 r
.32846 .3646 .34147 .36657 .36161 .35186 .34877 .34998 Metetra
0 .341 .292 r
.34877 .34998 .36161 .35186 .38172 .33855 .36906 .33673 Metetra
0 .319 .304 r
.36906 .33673 .38172 .33855 .40184 .32671 .38936 .32491 Metetra
0 .296 .303 r
.38936 .32491 .40184 .32671 .422 .31639 .4097 .31458 Metetra
0 .274 .293 r
.4097 .31458 .422 .31639 .44223 .30764 .4301 .30577 Metetra
0 .267 .29 r
.4301 .30577 .44223 .30764 .46255 .30047 .45059 .29852 Metetra
0 .274 .293 r
.45059 .29852 .46255 .30047 .48301 .2949 .47122 .29283 Metetra
0 .296 .303 r
.47122 .29283 .48301 .2949 .50363 .29091 .492 .28869 Metetra
0 .319 .304 r
.492 .28869 .50363 .29091 .52445 .28848 .51298 .28607 Metetra
0 .341 .292 r
.51298 .28607 .52445 .28848 .54551 .28756 .5342 .28493 Metetra
0 .369 .271 r
.5342 .28493 .54551 .28756 .56683 .2881 .55568 .2852 Metetra
0 .402 .237 r
.55568 .2852 .56683 .2881 .58846 .29001 .57746 .2868 Metetra
0 .441 .186 r
.57746 .2868 .58846 .29001 .61043 .29319 .59957 .28962 Metetra
0 .484 .115 r
.59957 .28962 .61043 .29319 .63275 .2975 .62204 .29352 Metetra
0 .53 .019 r
.62204 .29352 .63275 .2975 .65547 .3028 .64489 .29835 Metetra
.104 .58 0 r
.64489 .29835 .65547 .3028 .67859 .30888 .66814 .30389 Metetra
.255 .631 0 r
.66814 .30389 .67859 .30888 .70213 .31552 .6918 .30992 Metetra
.432 .684 0 r
.6918 .30992 .70213 .31552 .72609 .32245 .71587 .31615 Metetra
.632 .737 0 r
.71587 .31615 .72609 .32245 .75046 .32934 .74035 .32226 Metetra
.788 .725 0 r
.74035 .32226 .75046 .32934 .77522 .33583 .7652 .32787 Metetra
.836 .594 0 r
.7652 .32787 .77522 .33583 .80033 .34149 .79039 .33254 Metetra
.858 .527 0 r
.10864 .54471 .12331 .55067 .14377 .53247 .12914 .52741 Metetra
.814 .657 0 r
.12914 .52741 .14377 .53247 .16434 .51329 .14979 .50904 Metetra
.754 .766 0 r
.14979 .50904 .16434 .51329 .18496 .49355 .17051 .49 Metetra
.552 .716 0 r
.17051 .49 .18496 .49355 .2056 .47361 .19127 .47066 Metetra
.369 .666 0 r
.19127 .47066 .2056 .47361 .22621 .45377 .21202 .45134 Metetra
.21 .617 0 r
.21202 .45134 .22621 .45377 .24678 .43432 .23273 .43233 Metetra
.077 .57 0 r
.23273 .43233 .24678 .43432 .26728 .41549 .2534 .41386 Metetra
0 .525 .031 r
.2534 .41386 .26728 .41549 .28773 .39748 .27402 .39616 Metetra
0 .484 .115 r
.27402 .39616 .28773 .39748 .30812 .38047 .29459 .37939 Metetra
0 .447 .178 r
.29459 .37939 .30812 .38047 .32846 .3646 .31511 .3637 Metetra
0 .414 .223 r
.31511 .3637 .32846 .3646 .34877 .34998 .3356 .34922 Metetra
0 .387 .254 r
.3356 .34922 .34877 .34998 .36906 .33673 .35607 .33605 Metetra
0 .366 .274 r
.35607 .33605 .36906 .33673 .38936 .32491 .37656 .32427 Metetra
0 .35 .286 r
.37656 .32427 .38936 .32491 .4097 .31458 .39708 .31394 Metetra
0 .341 .292 r
.39708 .31394 .4097 .31458 .4301 .30577 .41766 .3051 Metetra
0 .338 .294 r
.41766 .3051 .4301 .30577 .45059 .29852 .43834 .29776 Metetra
0 .341 .292 r
.43834 .29776 .45059 .29852 .47122 .29283 .45914 .29195 Metetra
0 .35 .286 r
.45914 .29195 .47122 .29283 .492 .28869 .4801 .28764 Metetra
0 .366 .274 r
.4801 .28764 .492 .28869 .51298 .28607 .50126 .28481 Metetra
0 .387 .254 r
.50126 .28481 .51298 .28607 .5342 .28493 .52264 .28341 Metetra
0 .414 .223 r
.52264 .28341 .5342 .28493 .55568 .2852 .54429 .28338 Metetra
0 .447 .178 r
.54429 .28338 .55568 .2852 .57746 .2868 .56623 .28462 Metetra
0 .484 .115 r
.56623 .28462 .57746 .2868 .59957 .28962 .5885 .28702 Metetra
0 .525 .031 r
.5885 .28702 .59957 .28962 .62204 .29352 .61112 .29044 Metetra
.077 .57 0 r
.61112 .29044 .62204 .29352 .64489 .29835 .63412 .29472 Metetra
.21 .617 0 r
.63412 .29472 .64489 .29835 .66814 .30389 .6575 .29963 Metetra
.369 .666 0 r
.6575 .29963 .66814 .30389 .6918 .30992 .68129 .30494 Metetra
.552 .716 0 r
.68129 .30494 .6918 .30992 .71587 .31615 .70549 .31037 Metetra
.754 .766 0 r
.70549 .31037 .71587 .31615 .74035 .32226 .73007 .31556 Metetra
.814 .657 0 r
.73007 .31556 .74035 .32226 .7652 .32787 .75502 .32014 Metetra
.858 .527 0 r
.75502 .32014 .7652 .32787 .79039 .33254 .78029 .32367 Metetra
.881 .453 0 r
.0937 .53866 .10864 .54471 .12914 .52741 .11423 .52243 Metetra
.841 .58 0 r
.11423 .52243 .12914 .52741 .14979 .50904 .13493 .505 Metetra
.797 .702 0 r
.13493 .505 .14979 .50904 .17051 .49 .15574 .48678 Metetra
.689 .75 0 r
.15574 .48678 .17051 .49 .19127 .47066 .1766 .46817 Metetra
.503 .704 0 r
.1766 .46817 .19127 .47066 .21202 .45134 .19748 .44947 Metetra
.338 .657 0 r
.19748 .44947 .21202 .45134 .23273 .43233 .21834 .43099 Metetra
.196 .612 0 r
.21834 .43099 .23273 .43233 .2534 .41386 .23916 .41298 Metetra
.077 .57 0 r
.23916 .41298 .2534 .41386 .27402 .39616 .25995 .39565 Metetra
0 .53 .019 r
.25995 .39565 .27402 .39616 .29459 .37939 .28069 .37918 Metetra
0 .495 .093 r
.28069 .37918 .29459 .37939 .31511 .3637 .3014 .36373 Metetra
0 .464 .15 r
.3014 .36373 .31511 .3637 .3356 .34922 .32207 .34943 Metetra
0 .438 .191 r
.32207 .34943 .3356 .34922 .35607 .33605 .34274 .33638 Metetra
0 .417 .219 r
.34274 .33638 .35607 .33605 .37656 .32427 .36342 .32466 Metetra
0 .402 .237 r
.36342 .32466 .37656 .32427 .39708 .31394 .38413 .31434 Metetra
0 .393 .247 r
.38413 .31434 .39708 .31394 .41766 .3051 .40491 .30546 Metetra
0 .39 .251 r
.40491 .30546 .41766 .3051 .43834 .29776 .42578 .29805 Metetra
0 .393 .247 r
.42578 .29805 .43834 .29776 .45914 .29195 .44677 .2921 Metetra
0 .402 .237 r
.44677 .2921 .45914 .29195 .4801 .28764 .46792 .28761 Metetra
0 .417 .219 r
.46792 .28761 .4801 .28764 .50126 .28481 .48926 .28454 Metetra
0 .438 .191 r
.48926 .28454 .50126 .28481 .52264 .28341 .51082 .28285 Metetra
0 .464 .15 r
.51082 .28285 .52264 .28341 .54429 .28338 .53265 .28247 Metetra
0 .495 .093 r
.53265 .28247 .54429 .28338 .56623 .28462 .55476 .2833 Metetra
0 .53 .019 r
.55476 .2833 .56623 .28462 .5885 .28702 .5772 .28522 Metetra
.077 .57 0 r
.5772 .28522 .5885 .28702 .61112 .29044 .59998 .28809 Metetra
.196 .612 0 r
.59998 .28809 .61112 .29044 .63412 .29472 .62313 .29173 Metetra
.338 .657 0 r
.62313 .29173 .63412 .29472 .6575 .29963 .64666 .29592 Metetra
.503 .704 0 r
.64666 .29592 .6575 .29963 .68129 .30494 .67059 .3004 Metetra
.689 .75 0 r
.67059 .3004 .68129 .30494 .70549 .31037 .6949 .30489 Metetra
.797 .702 0 r
.6949 .30489 .70549 .31037 .73007 .31556 .7196 .30903 Metetra
.841 .58 0 r
.7196 .30903 .73007 .31556 .75502 .32014 .74464 .31243 Metetra
.881 .453 0 r
.74464 .31243 .75502 .32014 .78029 .32367 .76998 .31463 Metetra
.904 .375 0 r
.07854 .53225 .0937 .53866 .11423 .52243 .09906 .51725 Metetra
.868 .496 0 r
.09906 .51725 .11423 .52243 .13493 .505 .11979 .50092 Metetra
.828 .616 0 r
.11979 .50092 .13493 .505 .15574 .48678 .14065 .48368 Metetra
.786 .729 0 r
.14065 .48368 .15574 .48678 .1766 .46817 .1616 .46592 Metetra
.657 .743 0 r
.1616 .46592 .1766 .46817 .19748 .44947 .18259 .44796 Metetra
.487 .699 0 r
.18259 .44796 .19748 .44947 .21834 .43099 .20359 .43011 Metetra
.338 .657 0 r
.20359 .43011 .21834 .43099 .23916 .41298 .22457 .41264 Metetra
.21 .617 0 r
.22457 .41264 .23916 .41298 .25995 .39565 .24551 .39575 Metetra
.104 .58 0 r
.24551 .39575 .25995 .39565 .28069 .37918 .26643 .37965 Metetra
.019 .546 0 r
.26643 .37965 .28069 .37918 .3014 .36373 .28732 .36449 Metetra
0 .517 .048 r
.28732 .36449 .3014 .36373 .32207 .34943 .30819 .35041 Metetra
0 .492 .099 r
.30819 .35041 .32207 .34943 .34274 .33638 .32905 .33752 Metetra
0 .472 .135 r
.32905 .33752 .34274 .33638 .36342 .32466 .34993 .3259 Metetra
0 .458 .159 r
.34993 .3259 .36342 .32466 .38413 .31434 .37084 .31561 Metetra
0 .45 .173 r
.37084 .31561 .38413 .31434 .40491 .30546 .39181 .3067 Metetra
0 .447 .178 r
.39181 .3067 .40491 .30546 .42578 .29805 .41288 .2992 Metetra
0 .45 .173 r
.41288 .2992 .42578 .29805 .44677 .2921 .43408 .29311 Metetra
0 .458 .159 r
.43408 .29311 .44677 .2921 .46792 .28761 .45542 .28842 Metetra
0 .472 .135 r
.45542 .28842 .46792 .28761 .48926 .28454 .47696 .28509 Metetra
0 .492 .099 r
.47696 .28509 .48926 .28454 .51082 .28285 .49872 .28307 Metetra
0 .517 .048 r
.49872 .28307 .51082 .28285 .53265 .28247 .52073 .28229 Metetra
.019 .546 0 r
.52073 .28229 .53265 .28247 .55476 .2833 .54303 .28265 Metetra
.104 .58 0 r
.54303 .28265 .55476 .2833 .5772 .28522 .56564 .28403 Metetra
.21 .617 0 r
.56564 .28403 .5772 .28522 .59998 .28809 .58859 .28626 Metetra
.338 .657 0 r
.58859 .28626 .59998 .28809 .62313 .29173 .6119 .28917 Metetra
.487 .699 0 r
.6119 .28917 .62313 .29173 .64666 .29592 .63559 .29252 Metetra
.657 .743 0 r
.63559 .29252 .64666 .29592 .67059 .3004 .65965 .29606 Metetra
.786 .729 0 r
.65965 .29606 .67059 .3004 .6949 .30489 .6841 .29947 Metetra
.828 .616 0 r
.6841 .29947 .6949 .30489 .7196 .30903 .7089 .3024 Metetra
.868 .496 0 r
.7089 .3024 .7196 .30903 .74464 .31243 .73404 .30445 Metetra
.904 .375 0 r
.73404 .30445 .74464 .31243 .76998 .31463 .75945 .30514 Metetra
.926 .297 0 r
.06319 .52517 .07854 .53225 .09906 .51725 .08366 .51159 Metetra
.895 .407 0 r
.08366 .51159 .09906 .51725 .11979 .50092 .10438 .49653 Metetra
.86 .522 0 r
.10438 .49653 .11979 .50092 .14065 .48368 .12528 .48041 Metetra
.822 .634 0 r
.12528 .48041 .14065 .48368 .1616 .46592 .1463 .46363 Metetra
.782 .738 0 r
.1463 .46363 .1616 .46592 .18259 .44796 .16738 .44654 Metetra
.657 .743 0 r
.16738 .44654 .18259 .44796 .20359 .43011 .1885 .42944 Metetra
.503 .704 0 r
.1885 .42944 .20359 .43011 .22457 .41264 .20961 .4126 Metetra
.369 .666 0 r
.20961 .4126 .22457 .41264 .24551 .39575 .23072 .39625 Metetra
.255 .631 0 r
.23072 .39625 .24551 .39575 .26643 .37965 .25181 .38059 Metetra
.16 .6 0 r
.25181 .38059 .26643 .37965 .28732 .36449 .27288 .36578 Metetra
.084 .572 0 r
.27288 .36578 .28732 .36449 .30819 .35041 .29393 .35197 Metetra
.025 .549 0 r
.29393 .35197 .30819 .35041 .32905 .33752 .31499 .33927 Metetra
0 .53 .019 r
.31499 .33927 .32905 .33752 .34993 .3259 .33607 .32777 Metetra
0 .517 .048 r
.33607 .32777 .34993 .3259 .37084 .31561 .35719 .31753 Metetra
0 .509 .066 r
.35719 .31753 .37084 .31561 .39181 .3067 .37837 .30861 Metetra
0 .506 .071 r
.37837 .30861 .39181 .3067 .41288 .2992 .39965 .30102 Metetra
0 .509 .066 r
.39965 .30102 .41288 .2992 .43408 .29311 .42105 .29477 Metetra
0 .517 .048 r
.42105 .29477 .43408 .29311 .45542 .28842 .44261 .28986 Metetra
0 .53 .019 r
.44261 .28986 .45542 .28842 .47696 .28509 .46435 .28624 Metetra
.025 .549 0 r
.46435 .28624 .47696 .28509 .49872 .28307 .48631 .28385 Metetra
.084 .572 0 r
.48631 .28385 .49872 .28307 .52073 .28229 .50852 .28262 Metetra
.16 .6 0 r
.50852 .28262 .52073 .28229 .54303 .28265 .53101 .28245 Metetra
.255 .631 0 r
.53101 .28245 .54303 .28265 .56564 .28403 .55381 .2832 Metetra
.369 .666 0 r
.55381 .2832 .56564 .28403 .58859 .28626 .57694 .28471 Metetra
.503 .704 0 r
.57694 .28471 .58859 .28626 .6119 .28917 .60042 .28678 Metetra
.657 .743 0 r
.60042 .28678 .6119 .28917 .63559 .29252 .62426 .28918 Metetra
.782 .738 0 r
.62426 .28918 .63559 .29252 .65965 .29606 .64848 .29163 Metetra
.822 .634 0 r
.64848 .29163 .65965 .29606 .6841 .29947 .67305 .29383 Metetra
.86 .522 0 r
.67305 .29383 .6841 .29947 .7089 .3024 .69797 .29539 Metetra
.895 .407 0 r
.69797 .29539 .7089 .3024 .73404 .30445 .72319 .2959 Metetra
.926 .297 0 r
.72319 .2959 .73404 .30445 .75945 .30514 .74867 .29489 Metetra
.945 .223 0 r
.0477 .51709 .06319 .52517 .08366 .51159 .06807 .50512 Metetra
.92 .318 0 r
.06807 .50512 .08366 .51159 .10438 .49653 .08875 .49149 Metetra
.89 .423 0 r
.08875 .49149 .10438 .49653 .12528 .48041 .10965 .47666 Metetra
.857 .531 0 r
.10965 .47666 .12528 .48041 .1463 .46363 .13071 .46102 Metetra
.822 .634 0 r
.13071 .46102 .1463 .46363 .16738 .44654 .15186 .44492 Metetra
.786 .729 0 r
.15186 .44492 .16738 .44654 .1885 .42944 .17308 .42868 Metetra
.689 .75 0 r
.17308 .42868 .1885 .42944 .20961 .4126 .19432 .41258 Metetra
.552 .716 0 r
.19432 .41258 .20961 .4126 .23072 .39625 .21557 .39685 Metetra
.432 .684 0 r
.21557 .39685 .23072 .39625 .25181 .38059 .23682 .38171 Metetra
.33 .655 0 r
.23682 .38171 .25181 .38059 .27288 .36578 .25807 .36732 Metetra
.247 .629 0 r
.25807 .36732 .27288 .36578 .29393 .35197 .27931 .35384 Metetra
.181 .607 0 r
.27931 .35384 .29393 .35197 .31499 .33927 .30057 .34138 Metetra
.132 .59 0 r
.30057 .34138 .31499 .33927 .33607 .32777 .32185 .33003 Metetra
.097 .577 0 r
.32185 .33003 .33607 .32777 .35719 .31753 .34318 .31986 Metetra
.077 .57 0 r
.34318 .31986 .35719 .31753 .37837 .30861 .36458 .31093 Metetra
.07 .567 0 r
.36458 .31093 .37837 .30861 .39965 .30102 .38607 .30325 Metetra
.077 .57 0 r
.38607 .30325 .39965 .30102 .42105 .29477 .40768 .29684 Metetra
.097 .577 0 r
.40768 .29684 .42105 .29477 .44261 .28986 .42945 .29168 Metetra
.132 .59 0 r
.42945 .29168 .44261 .28986 .46435 .28624 .45141 .28773 Metetra
.181 .607 0 r
.45141 .28773 .46435 .28624 .48631 .28385 .47358 .28493 Metetra
.247 .629 0 r
.47358 .28493 .48631 .28385 .50852 .28262 .496 .28319 Metetra
.33 .655 0 r
.496 .28319 .50852 .28262 .53101 .28245 .51869 .28241 Metetra
.432 .684 0 r
.51869 .28241 .53101 .28245 .55381 .2832 .54168 .28245 Metetra
.552 .716 0 r
.54168 .28245 .55381 .2832 .57694 .28471 .565 .28313 Metetra
.689 .75 0 r
.565 .28313 .57694 .28471 .60042 .28678 .58866 .28426 Metetra
.786 .729 0 r
.58866 .28426 .60042 .28678 .62426 .28918 .61267 .28558 Metetra
.822 .634 0 r
.61267 .28558 .62426 .28918 .64848 .29163 .63703 .28681 Metetra
.857 .531 0 r
.63703 .28681 .64848 .29163 .67305 .29383 .66174 .28762 Metetra
.89 .423 0 r
.66174 .28762 .67305 .29383 .69797 .29539 .68677 .28763 Metetra
.92 .318 0 r
.68677 .28763 .69797 .29539 .72319 .2959 .71208 .28642 Metetra
.945 .223 0 r
.71208 .28642 .72319 .2959 .74867 .29489 .73761 .28349 Metetra
.961 .161 0 r
.03213 .50762 .0477 .51709 .06807 .50512 .05236 .49744 Metetra
.942 .235 0 r
.05236 .49744 .06807 .50512 .08875 .49149 .07295 .48544 Metetra
.918 .325 0 r
.07295 .48544 .08875 .49149 .10965 .47666 .09382 .47206 Metetra
.89 .423 0 r
.09382 .47206 .10965 .47666 .13071 .46102 .11487 .4577 Metetra
.86 .522 0 r
.11487 .4577 .13071 .46102 .15186 .44492 .13607 .44274 Metetra
.828 .616 0 r
.13607 .44274 .15186 .44492 .17308 .42868 .15736 .42749 Metetra
.797 .702 0 r
.15736 .42749 .17308 .42868 .19432 .41258 .17871 .41224 Metetra
.754 .766 0 r
.17871 .41224 .19432 .41258 .21557 .39685 .20009 .39724 Metetra
.632 .737 0 r
.20009 .39724 .21557 .39685 .23682 .38171 .22149 .38271 Metetra
.527 .71 0 r
.22149 .38271 .23682 .38171 .25807 .36732 .24291 .36881 Metetra
.439 .686 0 r
.24291 .36881 .25807 .36732 .27931 .35384 .26434 .35571 Metetra
.369 .666 0 r
.26434 .35571 .27931 .35384 .30057 .34138 .28579 .34353 Metetra
.315 .65 0 r
.28579 .34353 .30057 .34138 .32185 .33003 .30727 .33237 Metetra
.277 .638 0 r
.30727 .33237 .32185 .33003 .34318 .31986 .32881 .3223 Metetra
.254 .631 0 r
.32881 .3223 .34318 .31986 .36458 .31093 .35042 .31337 Metetra
.247 .629 0 r
.35042 .31337 .36458 .31093 .38607 .30325 .37213 .3056 Metetra
.254 .631 0 r
.37213 .3056 .38607 .30325 .40768 .29684 .39397 .29901 Metetra
.277 .638 0 r
.39397 .29901 .40768 .29684 .42945 .29168 .41596 .29358 Metetra
.315 .65 0 r
.41596 .29358 .42945 .29168 .45141 .28773 .43814 .28926 Metetra
.369 .666 0 r
.43814 .28926 .45141 .28773 .47358 .28493 .46053 .28599 Metetra
.439 .686 0 r
.46053 .28599 .47358 .28493 .496 .28319 .48316 .28368 Metetra
.527 .71 0 r
.48316 .28368 .496 .28319 .51869 .28241 .50606 .28222 Metetra
.632 .737 0 r
.50606 .28222 .51869 .28241 .54168 .28245 .52926 .28145 Metetra
.754 .766 0 r
.52926 .28145 .54168 .28245 .565 .28313 .55277 .2812 Metetra
.797 .702 0 r
.55277 .2812 .565 .28313 .58866 .28426 .57661 .28125 Metetra
.828 .616 0 r
.57661 .28125 .58866 .28426 .61267 .28558 .60079 .28135 Metetra
.86 .522 0 r
.60079 .28135 .61267 .28558 .63703 .28681 .6253 .2812 Metetra
.89 .423 0 r
.6253 .2812 .63703 .28681 .66174 .28762 .65014 .28046 Metetra
.918 .325 0 r
.65014 .28046 .66174 .28762 .68677 .28763 .67528 .27874 Metetra
.942 .235 0 r
.67528 .27874 .68677 .28763 .71208 .28642 .70067 .2756 Metetra
.961 .161 0 r
.70067 .2756 .71208 .28642 .73761 .28349 .72625 .27055 Metetra
.972 .117 0 r
.01657 .4963 .03213 .50762 .05236 .49744 .0366 .48812 Metetra
.96 .165 0 r
.0366 .48812 .05236 .49744 .07295 .48544 .05705 .47794 Metetra
.942 .235 0 r
.05705 .47794 .07295 .48544 .09382 .47206 .07782 .46619 Metetra
.92 .318 0 r
.07782 .46619 .09382 .47206 .11487 .4577 .09885 .45329 Metetra
.895 .407 0 r
.09885 .45329 .11487 .4577 .13607 .44274 .12005 .43961 Metetra
.868 .496 0 r
.12005 .43961 .13607 .44274 .15736 .42749 .14139 .42549 Metetra
.841 .58 0 r
.14139 .42549 .15736 .42749 .17871 .41224 .16282 .41122 Metetra
.814 .657 0 r
.16282 .41122 .17871 .41224 .20009 .39724 .18431 .39705 Metetra
.788 .725 0 r
.18431 .39705 .20009 .39724 .22149 .38271 .20585 .38321 Metetra
.746 .764 0 r
.20585 .38321 .22149 .38271 .24291 .36881 .22742 .36989 Metetra
.656 .742 0 r
.22742 .36989 .24291 .36881 .26434 .35571 .24902 .35724 Metetra
.583 .724 0 r
.24902 .35724 .26434 .35571 .28579 .34353 .27066 .34539 Metetra
.527 .71 0 r
.27066 .34539 .28579 .34353 .30727 .33237 .29234 .33445 Metetra
.487 .699 0 r
.29234 .33445 .30727 .33237 .32881 .3223 .31409 .3245 Metetra
.463 .693 0 r
.31409 .3245 .32881 .3223 .35042 .31337 .33592 .31558 Metetra
.455 .691 0 r
.33592 .31558 .35042 .31337 .37213 .3056 .35785 .30773 Metetra
.463 .693 0 r
.35785 .30773 .37213 .3056 .39397 .29901 .37991 .30094 Metetra
.487 .699 0 r
.37991 .30094 .39397 .29901 .41596 .29358 .40213 .2952 Metetra
.527 .71 0 r
.40213 .2952 .41596 .29358 .43814 .28926 .42453 .29047 Metetra
.583 .724 0 r
.42453 .29047 .43814 .28926 .46053 .28599 .44715 .28668 Metetra
.656 .742 0 r
.44715 .28668 .46053 .28599 .48316 .28368 .47 .28372 Metetra
.746 .764 0 r
.47 .28372 .48316 .28368 .50606 .28222 .49312 .28149 Metetra
.788 .725 0 r
.49312 .28149 .50606 .28222 .52926 .28145 .51653 .27981 Metetra
.814 .657 0 r
.51653 .27981 .52926 .28145 .55277 .2812 .54024 .27851 Metetra
.841 .58 0 r
.54024 .27851 .55277 .2812 .57661 .28125 .56426 .27736 Metetra
.868 .496 0 r
.56426 .27736 .57661 .28125 .60079 .28135 .58861 .27609 Metetra
.895 .407 0 r
.58861 .27609 .60079 .28135 .6253 .2812 .61328 .27439 Metetra
.92 .318 0 r
.61328 .27439 .6253 .2812 .65014 .28046 .63825 .27192 Metetra
.942 .235 0 r
.63825 .27192 .65014 .28046 .67528 .27874 .66349 .26826 Metetra
.96 .165 0 r
.66349 .26826 .67528 .27874 .70067 .2756 .68895 .26298 Metetra
.972 .117 0 r
.68895 .26298 .70067 .2756 .72625 .27055 .71457 .25558 Metetra
.977 .099 0 r
.0011 .48266 .01657 .4963 .0366 .48812 .02087 .47669 Metetra
.972 .117 0 r
.02087 .47669 .0366 .48812 .05705 .47794 .04112 .46851 Metetra
.961 .161 0 r
.04112 .46851 .05705 .47794 .07782 .46619 .06176 .45858 Metetra
.945 .223 0 r
.06176 .45858 .07782 .46619 .09885 .45329 .0827 .44731 Metetra
.926 .297 0 r
.0827 .44731 .09885 .45329 .12005 .43961 .10387 .43508 Metetra
.904 .375 0 r
.10387 .43508 .12005 .43961 .14139 .42549 .12522 .42223 Metetra
.881 .453 0 r
.12522 .42223 .14139 .42549 .16282 .41122 .1467 .40906 Metetra
.858 .527 0 r
.1467 .40906 .16282 .41122 .18431 .39705 .16827 .39584 Metetra
.836 .594 0 r
.16827 .39584 .18431 .39705 .20585 .38321 .18992 .38279 Metetra
.815 .653 0 r
.18992 .38279 .20585 .38321 .22742 .36989 .21163 .37013 Metetra
.796 .702 0 r
.21163 .37013 .22742 .36989 .24902 .35724 .23339 .358 Metetra
.78 .743 0 r
.23339 .358 .24902 .35724 .27066 .34539 .25521 .34654 Metetra
.762 .767 0 r
.25521 .34654 .27066 .34539 .29234 .33445 .27708 .33587 Metetra
.721 .758 0 r
.27708 .33587 .29234 .33445 .31409 .3245 .29904 .32606 Metetra
.697 .752 0 r
.29904 .32606 .31409 .3245 .33592 .31558 .32108 .31716 Metetra
.689 .75 0 r
.32108 .31716 .33592 .31558 .35785 .30773 .34323 .30921 Metetra
.697 .752 0 r
.34323 .30921 .35785 .30773 .37991 .30094 .36552 .30221 Metetra
.721 .758 0 r
.36552 .30221 .37991 .30094 .40213 .2952 .38797 .29614 Metetra
.762 .767 0 r
.38797 .29614 .40213 .2952 .42453 .29047 .4106 .29095 Metetra
.78 .743 0 r
.4106 .29095 .42453 .29047 .44715 .28668 .43344 .28657 Metetra
.796 .702 0 r
.43344 .28657 .44715 .28668 .47 .28372 .45652 .28289 Metetra
.815 .653 0 r
.45652 .28289 .47 .28372 .49312 .28149 .47986 .27979 Metetra
.836 .594 0 r
.47986 .27979 .49312 .28149 .51653 .27981 .50348 .2771 Metetra
.858 .527 0 r
.50348 .2771 .51653 .27981 .54024 .27851 .52739 .27462 Metetra
.881 .453 0 r
.52739 .27462 .54024 .27851 .56426 .27736 .55161 .27212 Metetra
.904 .375 0 r
.55161 .27212 .56426 .27736 .58861 .27609 .57613 .26932 Metetra
.926 .297 0 r
.57613 .26932 .58861 .27609 .61328 .27439 .60095 .2659 Metetra
.945 .223 0 r
.60095 .2659 .61328 .27439 .63825 .27192 .62604 .26149 Metetra
.961 .161 0 r
.62604 .26149 .63825 .27192 .66349 .26826 .65138 .2557 Metetra
.972 .117 0 r
.65138 .2557 .66349 .26826 .68895 .26298 .67691 .24806 Metetra
.977 .099 0 r
.67691 .24806 .68895 .26298 .71457 .25558 .70256 .23807 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 233.562},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{145., 432.}, {288., 56.}} -> {-0.7106266823046584, \
0.23446312473461162, 0.003863407310606874, \
0.003863407310606874}},ExpressionUUID->"285fabd7-5af2-4c44-9e5c-492205829844"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -60 0 ]
[.5 .82364 60 9 ]
[.08965 .22175 -18 -8.88375 ]
[.08965 .22175 0 .11625 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60423 .01939 -10.1877 -9 ]
[.60423 .01939 1.81231 0 ]
[.73698 .05037 0 -6.2075 ]
[.73698 .05037 18 2.7925 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95739 .38791 0 -5.88802 ]
[.95739 .38791 12 3.11198 ]
[.02269 .27405 -24 -2.74987 ]
[.02269 .27405 0 6.25013 ]
[.01481 .32345 -30 -2.79165 ]
[.01481 .32345 0 6.20835 ]
[.00667 .37445 -18 -2.83493 ]
[.00667 .37445 0 6.16507 ]
[-0.00174 .42714 -30 -2.8798 ]
[-0.00174 .42714 0 6.1202 ]
[-0.01043 .4816 -24 -2.92632 ]
[-0.01043 .4816 0 6.07368 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Wave Front Intensity)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72471 .05502 m
.71857 .05735 L
s
[(-10)] .73698 .05037 -1 .37944 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94486 .39177 m
.93859 .39371 L
s
[(10)] .95739 .38791 -1 .30845 Mshowa
.125 Mabswid
.75031 .09419 m
.74662 .09556 L
s
.775 .13196 m
.7713 .1333 L
s
.79883 .16841 m
.79512 .16972 L
s
.82184 .2036 m
.81812 .2049 L
s
.86557 .27049 m
.86184 .27174 L
s
.88636 .3023 m
.88262 .30352 L
s
.90649 .33308 m
.90274 .33428 L
s
.92597 .36289 m
.92222 .36407 L
s
.69814 .01439 m
.69447 .01581 L
s
.96316 .41977 m
.95939 .42091 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03492 .26929 m
.04103 .26691 L
s
[(0.05)] .02269 .27405 1 -0.38892 Mshowa
.02707 .31879 m
.03321 .31646 L
s
[(0.075)] .01481 .32345 1 -0.37963 Mshowa
.01897 .3699 m
.02513 .36762 L
s
[(0.1)] .00667 .37445 1 -0.37001 Mshowa
.01061 .4227 m
.01678 .42047 L
s
[(0.125)] -0.00174 .42714 1 -0.36005 Mshowa
.00196 .47727 m
.00815 .47511 L
s
[(0.15)] -0.01043 .4816 1 -0.34971 Mshowa
.125 Mabswid
.03337 .27907 m
.03704 .27765 L
s
.03181 .2889 m
.03548 .28749 L
s
.03024 .2988 m
.03392 .29739 L
s
.02866 .30876 m
.03234 .30736 L
s
.02547 .32888 m
.02916 .32749 L
s
.02386 .33904 m
.02755 .33765 L
s
.02224 .34926 m
.02593 .34788 L
s
.02061 .35954 m
.0243 .35817 L
s
.01732 .38032 m
.02102 .37896 L
s
.01566 .39081 m
.01936 .38946 L
s
.01399 .40137 m
.01769 .40002 L
s
.0123 .412 m
.016 .41066 L
s
.0089 .43347 m
.01261 .43214 L
s
.00718 .44431 m
.01089 .44299 L
s
.00545 .45522 m
.00916 .45391 L
s
.00371 .46621 m
.00742 .4649 L
s
.03646 .25958 m
.04012 .25815 L
s
.00019 .48841 m
.00391 .48711 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .454 .167 r
.39279 .65964 .40417 .63098 .41929 .67752 .40743 .72342 Metetra
.301 .646 0 r
.40743 .72342 .41929 .67752 .43562 .69986 .42381 .7529 Metetra
.6 .729 0 r
.42381 .7529 .43562 .69986 .45269 .70404 .44123 .75704 Metetra
.693 .751 0 r
.44123 .75704 .45269 .70404 .47006 .70227 .45901 .75322 Metetra
.718 .757 0 r
.45901 .75322 .47006 .70227 .48758 .69934 .47692 .74814 Metetra
.731 .76 0 r
.47692 .74814 .48758 .69934 .50524 .69606 .49495 .74291 Metetra
.741 .763 0 r
.49495 .74291 .50524 .69606 .52303 .69253 .5131 .73764 Metetra
.749 .765 0 r
.5131 .73764 .52303 .69253 .54094 .68877 .53137 .73234 Metetra
.756 .766 0 r
.53137 .73234 .54094 .68877 .55899 .68479 .54975 .72703 Metetra
.762 .767 0 r
.54975 .72703 .55899 .68479 .57716 .68061 .56826 .72172 Metetra
.766 .768 0 r
.56826 .72172 .57716 .68061 .59545 .67623 .58688 .71641 Metetra
.769 .769 0 r
.58688 .71641 .59545 .67623 .61388 .67168 .60563 .71111 Metetra
.77 .768 0 r
.60563 .71111 .61388 .67168 .63242 .66697 .62451 .70583 Metetra
.77 .767 0 r
.62451 .70583 .63242 .66697 .65109 .66209 .64351 .70057 Metetra
.77 .767 0 r
.64351 .70057 .65109 .66209 .66988 .65705 .66265 .69533 Metetra
.77 .766 0 r
.66265 .69533 .66988 .65705 .68879 .65186 .68191 .69011 Metetra
.77 .766 0 r
.68191 .69011 .68879 .65186 .70782 .64651 .70131 .68491 Metetra
.77 .767 0 r
.70131 .68491 .70782 .64651 .72697 .641 .72085 .67974 Metetra
.77 .767 0 r
.72085 .67974 .72697 .641 .74625 .63532 .74053 .67458 Metetra
.77 .769 0 r
.74053 .67458 .74625 .63532 .76564 .62947 .76035 .66945 Metetra
.768 .769 0 r
.76035 .66945 .76564 .62947 .78514 .62344 .78031 .66433 Metetra
.764 .768 0 r
.78031 .66433 .78514 .62344 .80476 .61722 .80042 .65921 Metetra
.759 .767 0 r
.80042 .65921 .80476 .61722 .82449 .61078 .82068 .65409 Metetra
.753 .766 0 r
.82068 .65409 .82449 .61078 .84433 .60413 .84108 .64896 Metetra
.746 .764 0 r
.84108 .64896 .84433 .60413 .86427 .59723 .86164 .64382 Metetra
.737 .762 0 r
.86164 .64382 .86427 .59723 .88431 .59006 .88235 .63864 Metetra
.725 .759 0 r
.88235 .63864 .88431 .59006 .90444 .58258 .9032 .63339 Metetra
.709 .755 0 r
.9032 .63339 .90444 .58258 .92463 .57455 .92417 .62774 Metetra
.666 .745 0 r
.92417 .62774 .92463 .57455 .94461 .56387 .94489 .6188 Metetra
.499 .703 0 r
.94489 .6188 .94461 .56387 .9632 .54189 .96372 .5943 Metetra
.089 .574 0 r
.96372 .5943 .9632 .54189 .97837 .49525 .97779 .53506 Metetra
.14 .593 0 r
.38194 .66675 .39279 .65964 .40743 .72342 .39629 .73684 Metetra
.815 .654 0 r
.39629 .73684 .40743 .72342 .42381 .7529 .41269 .76806 Metetra
.903 .379 0 r
.41269 .76806 .42381 .7529 .44123 .75704 .4303 .7712 Metetra
.92 .318 0 r
.4303 .7712 .44123 .75704 .45901 .75322 .4483 .76581 Metetra
.919 .323 0 r
.4483 .76581 .45901 .75322 .47692 .74814 .46642 .75927 Metetra
.915 .337 0 r
.46642 .75927 .47692 .74814 .49495 .74291 .48465 .75277 Metetra
.911 .351 0 r
.48465 .75277 .49495 .74291 .5131 .73764 .50298 .7464 Metetra
.908 .363 0 r
.50298 .7464 .5131 .73764 .53137 .73234 .52142 .74016 Metetra
.905 .374 0 r
.52142 .74016 .53137 .73234 .54975 .72703 .53997 .73405 Metetra
.902 .383 0 r
.53997 .73405 .54975 .72703 .56826 .72172 .55864 .72806 Metetra
.9 .392 0 r
.55864 .72806 .56826 .72172 .58688 .71641 .57742 .72218 Metetra
.898 .398 0 r
.57742 .72218 .58688 .71641 .60563 .71111 .59633 .71644 Metetra
.896 .404 0 r
.59633 .71644 .60563 .71111 .62451 .70583 .61536 .71081 Metetra
.895 .408 0 r
.61536 .71081 .62451 .70583 .64351 .70057 .63453 .70529 Metetra
.894 .41 0 r
.63453 .70529 .64351 .70057 .66265 .69533 .65383 .69989 Metetra
.894 .411 0 r
.65383 .69989 .66265 .69533 .68191 .69011 .67326 .69461 Metetra
.894 .411 0 r
.67326 .69461 .68191 .69011 .70131 .68491 .69284 .68944 Metetra
.894 .409 0 r
.69284 .68944 .70131 .68491 .72085 .67974 .71256 .68439 Metetra
.895 .406 0 r
.71256 .68439 .72085 .67974 .74053 .67458 .73244 .67946 Metetra
.897 .401 0 r
.73244 .67946 .74053 .67458 .76035 .66945 .75246 .67465 Metetra
.898 .395 0 r
.75246 .67465 .76035 .66945 .78031 .66433 .77265 .66996 Metetra
.901 .388 0 r
.77265 .66996 .78031 .66433 .80042 .65921 .793 .6654 Metetra
.903 .379 0 r
.793 .6654 .80042 .65921 .82068 .65409 .81351 .66096 Metetra
.906 .369 0 r
.81351 .66096 .82068 .65409 .84108 .64896 .8342 .65666 Metetra
.909 .358 0 r
.8342 .65666 .84108 .64896 .86164 .64382 .85507 .6525 Metetra
.913 .345 0 r
.85507 .6525 .86164 .64382 .88235 .63864 .87613 .64848 Metetra
.917 .331 0 r
.87613 .64848 .88235 .63864 .9032 .63339 .89737 .64459 Metetra
.92 .318 0 r
.89737 .64459 .9032 .63339 .92417 .62774 .91877 .64049 Metetra
.917 .33 0 r
.91877 .64049 .92417 .62774 .94489 .6188 .93994 .63305 Metetra
.877 .469 0 r
.93994 .63305 .94489 .6188 .96372 .5943 .95911 .60862 Metetra
.618 .733 0 r
.95911 .60862 .96372 .5943 .97779 .53506 .97301 .54526 Metetra
.288 .642 0 r
.3714 .66177 .38194 .66675 .39629 .73684 .38558 .73239 Metetra
.87 .49 0 r
.38558 .73239 .39629 .73684 .41269 .76806 .40199 .76308 Metetra
.957 .178 0 r
.40199 .76308 .41269 .76806 .4303 .7712 .41969 .76553 Metetra
.971 .124 0 r
.41969 .76553 .4303 .7712 .4483 .76581 .43779 .75961 Metetra
.965 .145 0 r
.43779 .75961 .4483 .76581 .46642 .75927 .45601 .75264 Metetra
.958 .174 0 r
.45601 .75264 .46642 .75927 .48465 .75277 .47434 .74577 Metetra
.951 .2 0 r
.47434 .74577 .48465 .75277 .50298 .7464 .49277 .73908 Metetra
.946 .223 0 r
.49277 .73908 .50298 .7464 .52142 .74016 .5113 .73257 Metetra
.941 .242 0 r
.5113 .73257 .52142 .74016 .53997 .73405 .52995 .72622 Metetra
.936 .259 0 r
.52995 .72622 .53997 .73405 .55864 .72806 .54871 .72003 Metetra
.932 .273 0 r
.54871 .72003 .55864 .72806 .57742 .72218 .56759 .71398 Metetra
.929 .285 0 r
.56759 .71398 .57742 .72218 .59633 .71644 .58659 .70808 Metetra
.927 .294 0 r
.58659 .70808 .59633 .71644 .61536 .71081 .60572 .70232 Metetra
.925 .3 0 r
.60572 .70232 .61536 .71081 .63453 .70529 .62497 .6967 Metetra
.924 .304 0 r
.62497 .6967 .63453 .70529 .65383 .69989 .64437 .69121 Metetra
.924 .306 0 r
.64437 .69121 .65383 .69989 .67326 .69461 .6639 .68586 Metetra
.924 .305 0 r
.6639 .68586 .67326 .69461 .69284 .68944 .68358 .68064 Metetra
.924 .303 0 r
.68358 .68064 .69284 .68944 .71256 .68439 .7034 .67556 Metetra
.926 .297 0 r
.7034 .67556 .71256 .68439 .73244 .67946 .72338 .67061 Metetra
.928 .29 0 r
.72338 .67061 .73244 .67946 .75246 .67465 .74352 .66581 Metetra
.931 .28 0 r
.74352 .66581 .75246 .67465 .77265 .66996 .76381 .66115 Metetra
.934 .267 0 r
.76381 .66115 .77265 .66996 .793 .6654 .78428 .65665 Metetra
.938 .252 0 r
.78428 .65665 .793 .6654 .81351 .66096 .80492 .65231 Metetra
.943 .234 0 r
.80492 .65231 .81351 .66096 .8342 .65666 .82574 .64813 Metetra
.948 .213 0 r
.82574 .64813 .8342 .65666 .85507 .6525 .84674 .64414 Metetra
.954 .189 0 r
.84674 .64414 .85507 .6525 .87613 .64848 .86795 .64034 Metetra
.961 .161 0 r
.86795 .64034 .87613 .64848 .89737 .64459 .88935 .63673 Metetra
.968 .133 0 r
.88935 .63673 .89737 .64459 .91877 .64049 .91092 .633 Metetra
.969 .13 0 r
.91092 .633 .91877 .64049 .93994 .63305 .9323 .62606 Metetra
.932 .275 0 r
.9323 .62606 .93994 .63305 .95911 .60862 .95173 .60224 Metetra
.787 .727 0 r
.95173 .60224 .95911 .60862 .97301 .54526 .9659 .53893 Metetra
.322 .652 0 r
.36086 .65359 .3714 .66177 .38558 .73239 .37491 .72346 Metetra
.878 .465 0 r
.37491 .72346 .38558 .73239 .40199 .76308 .39131 .75326 Metetra
.962 .158 0 r
.39131 .75326 .40199 .76308 .41969 .76553 .40907 .7553 Metetra
.974 .11 0 r
.40907 .7553 .41969 .76553 .43779 .75961 .42724 .74923 Metetra
.968 .135 0 r
.42724 .74923 .43779 .75961 .45601 .75264 .44555 .74218 Metetra
.96 .167 0 r
.44555 .74218 .45601 .75264 .47434 .74577 .46395 .73525 Metetra
.953 .195 0 r
.46395 .73525 .47434 .74577 .49277 .73908 .48246 .72849 Metetra
.946 .219 0 r
.48246 .72849 .49277 .73908 .5113 .73257 .50107 .72192 Metetra
.941 .24 0 r
.50107 .72192 .5113 .73257 .52995 .72622 .5198 .71551 Metetra
.936 .258 0 r
.5198 .71551 .52995 .72622 .54871 .72003 .53864 .70925 Metetra
.932 .273 0 r
.53864 .70925 .54871 .72003 .56759 .71398 .5576 .70313 Metetra
.929 .285 0 r
.5576 .70313 .56759 .71398 .58659 .70808 .57668 .69717 Metetra
.927 .295 0 r
.57668 .69717 .58659 .70808 .60572 .70232 .59589 .69134 Metetra
.925 .302 0 r
.59589 .69134 .60572 .70232 .62497 .6967 .61523 .68565 Metetra
.924 .306 0 r
.61523 .68565 .62497 .6967 .64437 .69121 .63471 .68009 Metetra
.923 .308 0 r
.63471 .68009 .64437 .69121 .6639 .68586 .65433 .67467 Metetra
.923 .307 0 r
.65433 .67467 .6639 .68586 .68358 .68064 .67409 .66938 Metetra
.924 .304 0 r
.67409 .66938 .68358 .68064 .7034 .67556 .694 .66422 Metetra
.925 .299 0 r
.694 .66422 .7034 .67556 .72338 .67061 .71407 .6592 Metetra
.928 .291 0 r
.71407 .6592 .72338 .67061 .74352 .66581 .73429 .65432 Metetra
.93 .28 0 r
.73429 .65432 .74352 .66581 .76381 .66115 .75468 .64958 Metetra
.934 .267 0 r
.75468 .64958 .76381 .66115 .78428 .65665 .77524 .645 Metetra
.938 .251 0 r
.77524 .645 .78428 .65665 .80492 .65231 .79597 .64059 Metetra
.943 .231 0 r
.79597 .64059 .80492 .65231 .82574 .64813 .81688 .63633 Metetra
.949 .209 0 r
.81688 .63633 .82574 .64813 .84674 .64414 .83799 .63226 Metetra
.956 .183 0 r
.83799 .63226 .84674 .64414 .86795 .64034 .85928 .62839 Metetra
.963 .153 0 r
.85928 .62839 .86795 .64034 .88935 .63673 .88078 .6247 Metetra
.971 .121 0 r
.88078 .6247 .88935 .63673 .91092 .633 .90246 .62092 Metetra
.973 .114 0 r
.90246 .62092 .91092 .633 .9323 .62606 .92397 .61408 Metetra
.938 .252 0 r
.92397 .61408 .9323 .62606 .95173 .60224 .94361 .59077 Metetra
.796 .704 0 r
.94361 .59077 .95173 .60224 .9659 .53893 .95813 .52833 Metetra
.326 .654 0 r
.35021 .64486 .36086 .65359 .37491 .72346 .36413 .7139 Metetra
.875 .472 0 r
.36413 .7139 .37491 .72346 .39131 .75326 .38052 .74289 Metetra
.957 .177 0 r
.38052 .74289 .39131 .75326 .40907 .7553 .39834 .7446 Metetra
.968 .132 0 r
.39834 .7446 .40907 .7553 .42724 .74923 .41658 .73846 Metetra
.962 .158 0 r
.41658 .73846 .42724 .74923 .44555 .74218 .43496 .73138 Metetra
.954 .189 0 r
.43496 .73138 .44555 .74218 .46395 .73525 .45344 .72441 Metetra
.947 .216 0 r
.45344 .72441 .46395 .73525 .48246 .72849 .47203 .71762 Metetra
.941 .24 0 r
.47203 .71762 .48246 .72849 .50107 .72192 .49072 .711 Metetra
.936 .261 0 r
.49072 .711 .50107 .72192 .5198 .71551 .50952 .70455 Metetra
.931 .278 0 r
.50952 .70455 .5198 .71551 .53864 .70925 .52844 .69824 Metetra
.927 .293 0 r
.52844 .69824 .53864 .70925 .5576 .70313 .54748 .69207 Metetra
.924 .305 0 r
.54748 .69207 .5576 .70313 .57668 .69717 .56665 .68604 Metetra
.921 .314 0 r
.56665 .68604 .57668 .69717 .59589 .69134 .58594 .68016 Metetra
.92 .32 0 r
.58594 .68016 .59589 .69134 .61523 .68565 .60537 .6744 Metetra
.918 .325 0 r
.60537 .6744 .61523 .68565 .63471 .68009 .62493 .66877 Metetra
.918 .326 0 r
.62493 .66877 .63471 .68009 .65433 .67467 .64464 .66327 Metetra
.918 .326 0 r
.64464 .66327 .65433 .67467 .67409 .66938 .66448 .65791 Metetra
.919 .323 0 r
.66448 .65791 .67409 .66938 .694 .66422 .68448 .65267 Metetra
.92 .318 0 r
.68448 .65267 .694 .66422 .71407 .6592 .70464 .64757 Metetra
.922 .31 0 r
.70464 .64757 .71407 .6592 .73429 .65432 .72495 .6426 Metetra
.925 .3 0 r
.72495 .6426 .73429 .65432 .75468 .64958 .74543 .63778 Metetra
.929 .287 0 r
.74543 .63778 .75468 .64958 .77524 .645 .76608 .6331 Metetra
.933 .271 0 r
.76608 .6331 .77524 .645 .79597 .64059 .7869 .62858 Metetra
.938 .252 0 r
.7869 .62858 .79597 .64059 .81688 .63633 .80791 .62423 Metetra
.944 .23 0 r
.80791 .62423 .81688 .63633 .83799 .63226 .8291 .62005 Metetra
.95 .204 0 r
.8291 .62005 .83799 .63226 .85928 .62839 .85049 .61606 Metetra
.958 .175 0 r
.85049 .61606 .85928 .62839 .88078 .6247 .87209 .61226 Metetra
.966 .144 0 r
.87209 .61226 .88078 .6247 .90246 .62092 .89386 .60837 Metetra
.968 .136 0 r
.89386 .60837 .90246 .62092 .92397 .61408 .91549 .60153 Metetra
.934 .268 0 r
.91549 .60153 .92397 .61408 .94361 .59077 .93533 .57865 Metetra
.795 .706 0 r
.93533 .57865 .94361 .59077 .95813 .52833 .95019 .51705 Metetra
.328 .654 0 r
.33943 .63591 .35021 .64486 .36413 .7139 .35322 .70423 Metetra
.872 .483 0 r
.35322 .70423 .36413 .7139 .38052 .74289 .3696 .73251 Metetra
.952 .198 0 r
.3696 .73251 .38052 .74289 .39834 .7446 .38747 .73393 Metetra
.963 .156 0 r
.38747 .73393 .39834 .7446 .41658 .73846 .40579 .72772 Metetra
.956 .181 0 r
.40579 .72772 .41658 .73846 .43496 .73138 .42425 .7206 Metetra
.949 .211 0 r
.42425 .7206 .43496 .73138 .45344 .72441 .44281 .7136 Metetra
.942 .238 0 r
.44281 .7136 .45344 .72441 .47203 .71762 .46147 .70677 Metetra
.936 .261 0 r
.46147 .70677 .47203 .71762 .49072 .711 .48024 .70011 Metetra
.93 .281 0 r
.48024 .70011 .49072 .711 .50952 .70455 .49913 .6936 Metetra
.926 .297 0 r
.49913 .6936 .50952 .70455 .52844 .69824 .51813 .68724 Metetra
.922 .312 0 r
.51813 .68724 .52844 .69824 .54748 .69207 .53725 .68101 Metetra
.919 .323 0 r
.53725 .68101 .54748 .69207 .56665 .68604 .5565 .67493 Metetra
.916 .332 0 r
.5565 .67493 .56665 .68604 .58594 .68016 .57588 .66898 Metetra
.915 .338 0 r
.57588 .66898 .58594 .68016 .60537 .6744 .59539 .66315 Metetra
.913 .343 0 r
.59539 .66315 .60537 .6744 .62493 .66877 .61504 .65746 Metetra
.913 .344 0 r
.61504 .65746 .62493 .66877 .64464 .66327 .63483 .65189 Metetra
.913 .344 0 r
.63483 .65189 .64464 .66327 .66448 .65791 .65477 .64644 Metetra
.914 .341 0 r
.65477 .64644 .66448 .65791 .68448 .65267 .67485 .64113 Metetra
.915 .336 0 r
.67485 .64113 .68448 .65267 .70464 .64757 .6951 .63594 Metetra
.917 .328 0 r
.6951 .63594 .70464 .64757 .72495 .6426 .7155 .63089 Metetra
.92 .318 0 r
.7155 .63089 .72495 .6426 .74543 .63778 .73607 .62598 Metetra
.924 .306 0 r
.73607 .62598 .74543 .63778 .76608 .6331 .75681 .62121 Metetra
.928 .29 0 r
.75681 .62121 .76608 .6331 .7869 .62858 .77773 .61659 Metetra
.933 .272 0 r
.77773 .61659 .7869 .62858 .80791 .62423 .79883 .61213 Metetra
.938 .251 0 r
.79883 .61213 .80791 .62423 .8291 .62005 .82012 .60785 Metetra
.945 .226 0 r
.82012 .60785 .8291 .62005 .85049 .61606 .8416 .60375 Metetra
.952 .198 0 r
.8416 .60375 .85049 .61606 .87209 .61226 .86329 .59983 Metetra
.96 .168 0 r
.86329 .59983 .87209 .61226 .89386 .60837 .88517 .59583 Metetra
.962 .159 0 r
.88517 .59583 .89386 .60837 .91549 .60153 .90691 .58898 Metetra
.929 .285 0 r
.90691 .58898 .91549 .60153 .93533 .57865 .92695 .56644 Metetra
.793 .71 0 r
.92695 .56644 .93533 .57865 .95019 .51705 .94214 .50556 Metetra
.328 .654 0 r
.32852 .62679 .33943 .63591 .35322 .70423 .34217 .69449 Metetra
.869 .492 0 r
.34217 .69449 .35322 .70423 .3696 .73251 .35854 .72214 Metetra
.947 .217 0 r
.35854 .72214 .3696 .73251 .38747 .73393 .37647 .72331 Metetra
.957 .177 0 r
.37647 .72331 .38747 .73393 .40579 .72772 .39487 .71703 Metetra
.951 .201 0 r
.39487 .71703 .40579 .72772 .42425 .7206 .4134 .70987 Metetra
.944 .23 0 r
.4134 .70987 .42425 .7206 .44281 .7136 .43204 .70283 Metetra
.937 .256 0 r
.43204 .70283 .44281 .7136 .46147 .70677 .45078 .69595 Metetra
.931 .279 0 r
.45078 .69595 .46147 .70677 .48024 .70011 .46964 .68924 Metetra
.926 .298 0 r
.46964 .68924 .48024 .70011 .49913 .6936 .4886 .68268 Metetra
.921 .314 0 r
.4886 .68268 .49913 .6936 .51813 .68724 .50769 .67627 Metetra
.917 .328 0 r
.50769 .67627 .51813 .68724 .53725 .68101 .52689 .66998 Metetra
.914 .339 0 r
.52689 .66998 .53725 .68101 .5565 .67493 .54623 .66383 Metetra
.912 .348 0 r
.54623 .66383 .5565 .67493 .57588 .66898 .56569 .65781 Metetra
.91 .354 0 r
.56569 .65781 .57588 .66898 .59539 .66315 .58529 .65192 Metetra
.909 .358 0 r
.58529 .65192 .59539 .66315 .61504 .65746 .60502 .64615 Metetra
.909 .36 0 r
.60502 .64615 .61504 .65746 .63483 .65189 .6249 .64051 Metetra
.909 .359 0 r
.6249 .64051 .63483 .65189 .65477 .64644 .64493 .63499 Metetra
.909 .357 0 r
.64493 .63499 .65477 .64644 .67485 .64113 .66511 .62959 Metetra
.911 .352 0 r
.66511 .62959 .67485 .64113 .6951 .63594 .68544 .62432 Metetra
.913 .344 0 r
.68544 .62432 .6951 .63594 .7155 .63089 .70594 .61918 Metetra
.916 .335 0 r
.70594 .61918 .7155 .63089 .73607 .62598 .7266 .61418 Metetra
.919 .322 0 r
.7266 .61418 .73607 .62598 .75681 .62121 .74744 .60932 Metetra
.923 .308 0 r
.74744 .60932 .75681 .62121 .77773 .61659 .76845 .6046 Metetra
.928 .29 0 r
.76845 .6046 .77773 .61659 .79883 .61213 .78965 .60004 Metetra
.933 .269 0 r
.78965 .60004 .79883 .61213 .82012 .60785 .81103 .59566 Metetra
.94 .245 0 r
.81103 .59566 .82012 .60785 .8416 .60375 .83262 .59145 Metetra
.947 .218 0 r
.83262 .59145 .8416 .60375 .86329 .59983 .85441 .58741 Metetra
.954 .188 0 r
.85441 .58741 .86329 .59983 .88517 .59583 .87638 .58331 Metetra
.957 .179 0 r
.87638 .58331 .88517 .59583 .90691 .58898 .89824 .57643 Metetra
.925 .3 0 r
.89824 .57643 .90691 .58898 .92695 .56644 .91848 .55418 Metetra
.792 .714 0 r
.91848 .55418 .92695 .56644 .94214 .50556 .93397 .4939 Metetra
.329 .654 0 r
.31748 .6175 .32852 .62679 .34217 .69449 .33098 .68467 Metetra
.867 .501 0 r
.33098 .68467 .34217 .69449 .35854 .72214 .34734 .71179 Metetra
.943 .233 0 r
.34734 .71179 .35854 .72214 .37647 .72331 .36533 .71273 Metetra
.953 .195 0 r
.36533 .71273 .37647 .72331 .39487 .71703 .38381 .70638 Metetra
.947 .219 0 r
.38381 .70638 .39487 .71703 .4134 .70987 .40242 .69918 Metetra
.939 .247 0 r
.40242 .69918 .4134 .70987 .43204 .70283 .42114 .69208 Metetra
.933 .272 0 r
.42114 .69208 .43204 .70283 .45078 .69595 .43996 .68516 Metetra
.927 .294 0 r
.43996 .68516 .45078 .69595 .46964 .68924 .4589 .67839 Metetra
.922 .313 0 r
.4589 .67839 .46964 .68924 .4886 .68268 .47795 .67178 Metetra
.917 .329 0 r
.47795 .67178 .4886 .68268 .50769 .67627 .49712 .6653 Metetra
.913 .343 0 r
.49712 .6653 .50769 .67627 .52689 .66998 .51641 .65895 Metetra
.91 .353 0 r
.51641 .65895 .52689 .66998 .54623 .66383 .53583 .65274 Metetra
.908 .362 0 r
.53583 .65274 .54623 .66383 .56569 .65781 .55538 .64665 Metetra
.906 .368 0 r
.55538 .64665 .56569 .65781 .58529 .65192 .57506 .64069 Metetra
.905 .372 0 r
.57506 .64069 .58529 .65192 .60502 .64615 .59489 .63485 Metetra
.905 .374 0 r
.59489 .63485 .60502 .64615 .6249 .64051 .61486 .62913 Metetra
.905 .373 0 r
.61486 .62913 .6249 .64051 .64493 .63499 .63497 .62353 Metetra
.906 .37 0 r
.63497 .62353 .64493 .63499 .66511 .62959 .65525 .61806 Metetra
.907 .365 0 r
.65525 .61806 .66511 .62959 .68544 .62432 .67567 .6127 Metetra
.909 .358 0 r
.67567 .6127 .68544 .62432 .70594 .61918 .69626 .60748 Metetra
.912 .349 0 r
.69626 .60748 .70594 .61918 .7266 .61418 .71702 .60238 Metetra
.915 .337 0 r
.71702 .60238 .7266 .61418 .74744 .60932 .73795 .59743 Metetra
.919 .322 0 r
.73795 .59743 .74744 .60932 .76845 .6046 .75906 .59262 Metetra
.924 .305 0 r
.75906 .59262 .76845 .6046 .78965 .60004 .78036 .58796 Metetra
.929 .285 0 r
.78036 .58796 .78965 .60004 .81103 .59566 .80184 .58347 Metetra
.936 .261 0 r
.80184 .58347 .81103 .59566 .83262 .59145 .82353 .57915 Metetra
.943 .235 0 r
.82353 .57915 .83262 .59145 .85441 .58741 .84542 .57501 Metetra
.95 .206 0 r
.84542 .57501 .85441 .58741 .87638 .58331 .8675 .5708 Metetra
.952 .197 0 r
.8675 .5708 .87638 .58331 .89824 .57643 .88948 .56389 Metetra
.921 .314 0 r
.88948 .56389 .89824 .57643 .91848 .55418 .9099 .54187 Metetra
.79 .718 0 r
.9099 .54187 .91848 .55418 .93397 .4939 .92569 .48207 Metetra
.33 .655 0 r
.30631 .60803 .31748 .6175 .33098 .68467 .31966 .67477 Metetra
.864 .508 0 r
.31966 .67477 .33098 .68467 .34734 .71179 .336 .70144 Metetra
.939 .247 0 r
.336 .70144 .34734 .71179 .36533 .71273 .35405 .70218 Metetra
.949 .21 0 r
.35405 .70218 .36533 .71273 .38381 .70638 .3726 .69575 Metetra
.943 .234 0 r
.3726 .69575 .38381 .70638 .40242 .69918 .3913 .6885 Metetra
.936 .261 0 r
.3913 .6885 .40242 .69918 .42114 .69208 .4101 .68136 Metetra
.929 .286 0 r
.4101 .68136 .42114 .69208 .43996 .68516 .429 .67438 Metetra
.923 .308 0 r
.429 .67438 .43996 .68516 .4589 .67839 .44802 .66755 Metetra
.918 .326 0 r
.44802 .66755 .4589 .67839 .47795 .67178 .46716 .66087 Metetra
.914 .342 0 r
.46716 .66087 .47795 .67178 .49712 .6653 .48641 .65433 Metetra
.91 .355 0 r
.48641 .65433 .49712 .6653 .51641 .65895 .50579 .64792 Metetra
.907 .365 0 r
.50579 .64792 .51641 .65895 .53583 .65274 .52529 .64164 Metetra
.905 .374 0 r
.52529 .64164 .53583 .65274 .55538 .64665 .54493 .63549 Metetra
.903 .38 0 r
.54493 .63549 .55538 .64665 .57506 .64069 .56471 .62946 Metetra
.902 .383 0 r
.56471 .62946 .57506 .64069 .59489 .63485 .58462 .62354 Metetra
.901 .385 0 r
.58462 .62354 .59489 .63485 .61486 .62913 .60469 .61774 Metetra
.902 .385 0 r
.60469 .61774 .61486 .62913 .63497 .62353 .6249 .61207 Metetra
.902 .382 0 r
.6249 .61207 .63497 .62353 .65525 .61806 .64526 .60651 Metetra
.904 .377 0 r
.64526 .60651 .65525 .61806 .67567 .6127 .66578 .60107 Metetra
.906 .37 0 r
.66578 .60107 .67567 .6127 .69626 .60748 .68647 .59576 Metetra
.908 .361 0 r
.68647 .59576 .69626 .60748 .71702 .60238 .70732 .59057 Metetra
.912 .349 0 r
.70732 .59057 .71702 .60238 .73795 .59743 .72835 .58552 Metetra
.916 .335 0 r
.72835 .58552 .73795 .59743 .75906 .59262 .74956 .58062 Metetra
.92 .318 0 r
.74956 .58062 .75906 .59262 .78036 .58796 .77096 .57587 Metetra
.926 .298 0 r
.77096 .57587 .78036 .58796 .80184 .58347 .79255 .57128 Metetra
.932 .275 0 r
.79255 .57128 .80184 .58347 .82353 .57915 .81433 .56686 Metetra
.939 .249 0 r
.81433 .56686 .82353 .57915 .84542 .57501 .83633 .56261 Metetra
.946 .221 0 r
.83633 .56261 .84542 .57501 .8675 .5708 .85851 .55829 Metetra
.948 .212 0 r
.85851 .55829 .8675 .5708 .88948 .56389 .88061 .55134 Metetra
.918 .325 0 r
.88061 .55134 .88948 .56389 .9099 .54187 .90121 .52948 Metetra
.789 .721 0 r
.90121 .52948 .9099 .54187 .92569 .48207 .91729 .47007 Metetra
.33 .655 0 r
.295 .59839 .30631 .60803 .31966 .67477 .30819 .66478 Metetra
.863 .514 0 r
.30819 .66478 .31966 .67477 .336 .70144 .32451 .69109 Metetra
.936 .258 0 r
.32451 .69109 .336 .70144 .35405 .70218 .34262 .69165 Metetra
.946 .223 0 r
.34262 .69165 .35405 .70218 .3726 .69575 .36125 .68515 Metetra
.94 .246 0 r
.36125 .68515 .3726 .69575 .3913 .6885 .38003 .67784 Metetra
.932 .273 0 r
.38003 .67784 .3913 .6885 .4101 .68136 .39891 .67064 Metetra
.926 .298 0 r
.39891 .67064 .4101 .68136 .429 .67438 .4179 .6636 Metetra
.92 .319 0 r
.4179 .6636 .429 .67438 .44802 .66755 .43701 .65671 Metetra
.915 .337 0 r
.43701 .65671 .44802 .66755 .46716 .66087 .45623 .64997 Metetra
.911 .352 0 r
.45623 .64997 .46716 .66087 .48641 .65433 .47557 .64337 Metetra
.907 .365 0 r
.47557 .64337 .48641 .65433 .50579 .64792 .49503 .63688 Metetra
.904 .376 0 r
.49503 .63688 .50579 .64792 .52529 .64164 .51463 .63054 Metetra
.902 .384 0 r
.51463 .63054 .52529 .64164 .54493 .63549 .53436 .62431 Metetra
.9 .389 0 r
.53436 .62431 .54493 .63549 .56471 .62946 .55422 .6182 Metetra
.899 .393 0 r
.55422 .6182 .56471 .62946 .58462 .62354 .57423 .61221 Metetra
.899 .395 0 r
.57423 .61221 .58462 .62354 .60469 .61774 .59438 .60634 Metetra
.899 .394 0 r
.59438 .60634 .60469 .61774 .6249 .61207 .61469 .60058 Metetra
.899 .392 0 r
.61469 .60058 .6249 .61207 .64526 .60651 .63515 .59494 Metetra
.901 .387 0 r
.63515 .59494 .64526 .60651 .66578 .60107 .65577 .58942 Metetra
.903 .38 0 r
.65577 .58942 .66578 .60107 .68647 .59576 .67655 .58402 Metetra
.905 .371 0 r
.67655 .58402 .68647 .59576 .70732 .59057 .69751 .57874 Metetra
.909 .36 0 r
.69751 .57874 .70732 .59057 .72835 .58552 .71864 .5736 Metetra
.913 .346 0 r
.71864 .5736 .72835 .58552 .74956 .58062 .73995 .5686 Metetra
.917 .329 0 r
.73995 .5686 .74956 .58062 .77096 .57587 .76144 .56375 Metetra
.922 .31 0 r
.76144 .56375 .77096 .57587 .79255 .57128 .78313 .55906 Metetra
.929 .287 0 r
.78313 .55906 .79255 .57128 .81433 .56686 .80503 .55455 Metetra
.935 .262 0 r
.80503 .55455 .81433 .56686 .83633 .56261 .82713 .5502 Metetra
.943 .234 0 r
.82713 .5502 .83633 .56261 .85851 .55829 .84942 .54578 Metetra
.945 .225 0 r
.84942 .54578 .85851 .55829 .88061 .55134 .87164 .53877 Metetra
.916 .335 0 r
.87164 .53877 .88061 .55134 .90121 .52948 .89242 .51703 Metetra
.788 .724 0 r
.89242 .51703 .90121 .52948 .91729 .47007 .90878 .45789 Metetra
.33 .655 0 r
.28355 .58857 .295 .59839 .30819 .66478 .29657 .65472 Metetra
.861 .519 0 r
.29657 .65472 .30819 .66478 .32451 .69109 .31287 .68073 Metetra
.934 .268 0 r
.31287 .68073 .32451 .69109 .34262 .69165 .33104 .68114 Metetra
.943 .234 0 r
.33104 .68114 .34262 .69165 .36125 .68515 .34975 .67456 Metetra
.937 .257 0 r
.34975 .67456 .36125 .68515 .38003 .67784 .36861 .66719 Metetra
.93 .283 0 r
.36861 .66719 .38003 .67784 .39891 .67064 .38758 .65993 Metetra
.923 .307 0 r
.38758 .65993 .39891 .67064 .4179 .6636 .40666 .65282 Metetra
.918 .328 0 r
.40666 .65282 .4179 .6636 .43701 .65671 .42585 .64587 Metetra
.913 .346 0 r
.42585 .64587 .43701 .65671 .45623 .64997 .44516 .63906 Metetra
.908 .361 0 r
.44516 .63906 .45623 .64997 .47557 .64337 .46458 .63239 Metetra
.905 .374 0 r
.46458 .63239 .47557 .64337 .49503 .63688 .48414 .62583 Metetra
.902 .384 0 r
.48414 .62583 .49503 .63688 .51463 .63054 .50382 .61941 Metetra
.899 .392 0 r
.50382 .61941 .51463 .63054 .53436 .62431 .52364 .61311 Metetra
.898 .398 0 r
.52364 .61311 .53436 .62431 .55422 .6182 .5436 .60693 Metetra
.897 .401 0 r
.5436 .60693 .55422 .6182 .57423 .61221 .5637 .60086 Metetra
.896 .403 0 r
.5637 .60086 .57423 .61221 .59438 .60634 .58395 .5949 Metetra
.896 .402 0 r
.58395 .5949 .59438 .60634 .61469 .60058 .60435 .58907 Metetra
.897 .4 0 r
.60435 .58907 .61469 .60058 .63515 .59494 .62491 .58334 Metetra
.898 .395 0 r
.62491 .58334 .63515 .59494 .65577 .58942 .64563 .57773 Metetra
.9 .388 0 r
.64563 .57773 .65577 .58942 .67655 .58402 .66651 .57225 Metetra
.903 .38 0 r
.66651 .57225 .67655 .58402 .69751 .57874 .68756 .56689 Metetra
.906 .368 0 r
.68756 .56689 .69751 .57874 .71864 .5736 .70879 .56166 Metetra
.91 .355 0 r
.70879 .56166 .71864 .5736 .73995 .5686 .73021 .55656 Metetra
.915 .338 0 r
.73021 .55656 .73995 .5686 .76144 .56375 .75181 .55162 Metetra
.92 .319 0 r
.75181 .55162 .76144 .56375 .78313 .55906 .77361 .54683 Metetra
.926 .297 0 r
.77361 .54683 .78313 .55906 .80503 .55455 .79561 .54222 Metetra
.933 .272 0 r
.79561 .54222 .80503 .55455 .82713 .5502 .81782 .53776 Metetra
.94 .245 0 r
.81782 .53776 .82713 .5502 .84942 .54578 .84022 .53325 Metetra
.942 .235 0 r
.84022 .53325 .84942 .54578 .87164 .53877 .86257 .52617 Metetra
.913 .343 0 r
.86257 .52617 .87164 .53877 .89242 .51703 .88351 .5045 Metetra
.787 .726 0 r
.88351 .5045 .89242 .51703 .90878 .45789 .90014 .44554 Metetra
.33 .655 0 r
.27196 .57858 .28355 .58857 .29657 .65472 .2848 .64457 Metetra
.86 .523 0 r
.2848 .64457 .29657 .65472 .31287 .68073 .30108 .67035 Metetra
.932 .276 0 r
.30108 .67035 .31287 .68073 .33104 .68114 .31931 .67063 Metetra
.941 .242 0 r
.31931 .67063 .33104 .68114 .34975 .67456 .3381 .66398 Metetra
.935 .265 0 r
.3381 .66398 .34975 .67456 .36861 .66719 .35705 .65655 Metetra
.928 .291 0 r
.35705 .65655 .36861 .66719 .38758 .65993 .3761 .64921 Metetra
.921 .315 0 r
.3761 .64921 .38758 .65993 .40666 .65282 .39527 .64204 Metetra
.915 .335 0 r
.39527 .64204 .40666 .65282 .42585 .64587 .41454 .63502 Metetra
.911 .353 0 r
.41454 .63502 .42585 .64587 .44516 .63906 .43394 .62814 Metetra
.906 .368 0 r
.43394 .62814 .44516 .63906 .46458 .63239 .45346 .62139 Metetra
.903 .38 0 r
.45346 .62139 .46458 .63239 .48414 .62583 .4731 .61476 Metetra
.9 .39 0 r
.4731 .61476 .48414 .62583 .50382 .61941 .49288 .60827 Metetra
.898 .398 0 r
.49288 .60827 .50382 .61941 .52364 .61311 .51279 .60189 Metetra
.896 .404 0 r
.51279 .60189 .52364 .61311 .5436 .60693 .53284 .59563 Metetra
.895 .408 0 r
.53284 .59563 .5436 .60693 .5637 .60086 .55304 .58948 Metetra
.894 .409 0 r
.55304 .58948 .5637 .60086 .58395 .5949 .57338 .58344 Metetra
.895 .409 0 r
.57338 .58344 .58395 .5949 .60435 .58907 .59388 .57752 Metetra
.895 .406 0 r
.59388 .57752 .60435 .58907 .62491 .58334 .61453 .57171 Metetra
.897 .402 0 r
.61453 .57171 .62491 .58334 .64563 .57773 .63535 .56602 Metetra
.899 .395 0 r
.63535 .56602 .64563 .57773 .66651 .57225 .65633 .56045 Metetra
.901 .386 0 r
.65633 .56045 .66651 .57225 .68756 .56689 .67749 .555 Metetra
.904 .375 0 r
.67749 .555 .68756 .56689 .70879 .56166 .69883 .54968 Metetra
.908 .362 0 r
.69883 .54968 .70879 .56166 .73021 .55656 .72034 .54449 Metetra
.913 .345 0 r
.72034 .54449 .73021 .55656 .75181 .55162 .74205 .53945 Metetra
.918 .327 0 r
.74205 .53945 .75181 .55162 .77361 .54683 .76396 .53457 Metetra
.924 .305 0 r
.76396 .53457 .77361 .54683 .79561 .54222 .78607 .52986 Metetra
.931 .28 0 r
.78607 .52986 .79561 .54222 .81782 .53776 .80839 .52531 Metetra
.938 .253 0 r
.80839 .52531 .81782 .53776 .84022 .53325 .8309 .52069 Metetra
.94 .244 0 r
.8309 .52069 .84022 .53325 .86257 .52617 .85338 .51355 Metetra
.912 .349 0 r
.85338 .51355 .86257 .52617 .88351 .5045 .87449 .49189 Metetra
.787 .728 0 r
.87449 .49189 .88351 .5045 .90014 .44554 .89138 .43301 Metetra
.331 .655 0 r
.26023 .56841 .27196 .57858 .2848 .64457 .27288 .63433 Metetra
.859 .526 0 r
.27288 .63433 .2848 .64457 .30108 .67035 .28913 .65996 Metetra
.93 .281 0 r
.28913 .65996 .30108 .67035 .31931 .67063 .30742 .66013 Metetra
.939 .249 0 r
.30742 .66013 .31931 .67063 .3381 .66398 .32629 .6534 Metetra
.933 .271 0 r
.32629 .6534 .3381 .66398 .35705 .65655 .34532 .64589 Metetra
.926 .297 0 r
.34532 .64589 .35705 .65655 .3761 .64921 .36447 .63849 Metetra
.92 .321 0 r
.36447 .63849 .3761 .64921 .39527 .64204 .38372 .63124 Metetra
.914 .341 0 r
.38372 .63124 .39527 .64204 .41454 .63502 .40308 .62415 Metetra
.909 .358 0 r
.40308 .62415 .41454 .63502 .43394 .62814 .42257 .6172 Metetra
.905 .373 0 r
.42257 .6172 .43394 .62814 .45346 .62139 .44218 .61038 Metetra
.901 .385 0 r
.44218 .61038 .45346 .62139 .4731 .61476 .46192 .60367 Metetra
.898 .395 0 r
.46192 .60367 .4731 .61476 .49288 .60827 .48178 .5971 Metetra
.896 .403 0 r
.48178 .5971 .49288 .60827 .51279 .60189 .50179 .59064 Metetra
.895 .409 0 r
.50179 .59064 .51279 .60189 .53284 .59563 .52194 .5843 Metetra
.893 .412 0 r
.52194 .5843 .53284 .59563 .55304 .58948 .54223 .57806 Metetra
.893 .414 0 r
.54223 .57806 .55304 .58948 .57338 .58344 .56267 .57195 Metetra
.893 .414 0 r
.56267 .57195 .57338 .58344 .59388 .57752 .58327 .56594 Metetra
.894 .411 0 r
.58327 .56594 .59388 .57752 .61453 .57171 .60402 .56005 Metetra
.895 .407 0 r
.60402 .56005 .61453 .57171 .63535 .56602 .62494 .55427 Metetra
.897 .4 0 r
.62494 .55427 .63535 .56602 .65633 .56045 .64603 .54861 Metetra
.9 .391 0 r
.64603 .54861 .65633 .56045 .67749 .555 .66729 .54307 Metetra
.903 .38 0 r
.66729 .54307 .67749 .555 .69883 .54968 .68873 .53766 Metetra
.907 .367 0 r
.68873 .53766 .69883 .54968 .72034 .54449 .71035 .53238 Metetra
.911 .351 0 r
.71035 .53238 .72034 .54449 .74205 .53945 .73217 .52725 Metetra
.916 .332 0 r
.73217 .52725 .74205 .53945 .76396 .53457 .75418 .52227 Metetra
.922 .311 0 r
.75418 .52227 .76396 .53457 .78607 .52986 .77641 .51746 Metetra
.929 .286 0 r
.77641 .51746 .78607 .52986 .80839 .52531 .79884 .51282 Metetra
.936 .259 0 r
.79884 .51282 .80839 .52531 .8309 .52069 .82147 .5081 Metetra
.939 .25 0 r
.82147 .5081 .8309 .52069 .85338 .51355 .84407 .50088 Metetra
.91 .354 0 r
.84407 .50088 .85338 .51355 .87449 .49189 .86535 .47919 Metetra
.786 .729 0 r
.86535 .47919 .87449 .49189 .89138 .43301 .8825 .4203 Metetra
.331 .655 0 r
.24835 .55807 .26023 .56841 .27288 .63433 .2608 .624 Metetra
.858 .528 0 r
.2608 .624 .27288 .63433 .28913 .65996 .27701 .64955 Metetra
.929 .285 0 r
.27701 .64955 .28913 .65996 .30742 .66013 .29536 .64963 Metetra
.938 .253 0 r
.29536 .64963 .30742 .66013 .32629 .6534 .31432 .64282 Metetra
.932 .275 0 r
.31432 .64282 .32629 .6534 .34532 .64589 .33344 .63524 Metetra
.925 .301 0 r
.33344 .63524 .34532 .64589 .36447 .63849 .35267 .62776 Metetra
.918 .324 0 r
.35267 .62776 .36447 .63849 .38372 .63124 .37201 .62044 Metetra
.913 .345 0 r
.37201 .62044 .38372 .63124 .40308 .62415 .39147 .61327 Metetra
.908 .362 0 r
.39147 .61327 .40308 .62415 .42257 .6172 .41105 .60623 Metetra
.904 .377 0 r
.41105 .60623 .42257 .6172 .44218 .61038 .43075 .59933 Metetra
.9 .389 0 r
.43075 .59933 .44218 .61038 .46192 .60367 .45058 .59255 Metetra
.897 .399 0 r
.45058 .59255 .46192 .60367 .48178 .5971 .47054 .58589 Metetra
.895 .407 0 r
.47054 .58589 .48178 .5971 .50179 .59064 .49064 .57935 Metetra
.894 .412 0 r
.49064 .57935 .50179 .59064 .52194 .5843 .51089 .57293 Metetra
.892 .416 0 r
.51089 .57293 .52194 .5843 .54223 .57806 .53127 .56661 Metetra
.892 .417 0 r
.53127 .56661 .54223 .57806 .56267 .57195 .55182 .56041 Metetra
.892 .417 0 r
.55182 .56041 .56267 .57195 .58327 .56594 .57251 .55432 Metetra
.893 .414 0 r
.57251 .55432 .58327 .56594 .60402 .56005 .59337 .54834 Metetra
.894 .41 0 r
.59337 .54834 .60402 .56005 .62494 .55427 .61439 .54248 Metetra
.896 .403 0 r
.61439 .54248 .62494 .55427 .64603 .54861 .63558 .53673 Metetra
.899 .395 0 r
.63558 .53673 .64603 .54861 .66729 .54307 .65695 .5311 Metetra
.902 .384 0 r
.65695 .5311 .66729 .54307 .68873 .53766 .67849 .5256 Metetra
.906 .37 0 r
.67849 .5256 .68873 .53766 .71035 .53238 .70023 .52023 Metetra
.91 .355 0 r
.70023 .52023 .71035 .53238 .73217 .52725 .72216 .51501 Metetra
.915 .336 0 r
.72216 .51501 .73217 .52725 .75418 .52227 .74428 .50993 Metetra
.921 .315 0 r
.74428 .50993 .75418 .52227 .77641 .51746 .76662 .50503 Metetra
.928 .29 0 r
.76662 .50503 .77641 .51746 .79884 .51282 .78917 .50029 Metetra
.935 .264 0 r
.78917 .50029 .79884 .51282 .82147 .5081 .81192 .49548 Metetra
.937 .254 0 r
.81192 .49548 .82147 .5081 .84407 .50088 .83464 .48817 Metetra
.909 .357 0 r
.83464 .48817 .84407 .50088 .86535 .47919 .85609 .46641 Metetra
.786 .73 0 r
.85609 .46641 .86535 .47919 .8825 .4203 .87349 .40741 Metetra
.331 .655 0 r
.23632 .54755 .24835 .55807 .2608 .624 .24856 .61358 Metetra
.858 .529 0 r
.24856 .61358 .2608 .624 .27701 .64955 .26473 .63911 Metetra
.929 .287 0 r
.26473 .63911 .27701 .64955 .29536 .64963 .28313 .63913 Metetra
.937 .255 0 r
.28313 .63913 .29536 .64963 .31432 .64282 .30218 .63224 Metetra
.931 .278 0 r
.30218 .63224 .31432 .64282 .33344 .63524 .32139 .62458 Metetra
.924 .304 0 r
.32139 .62458 .33344 .63524 .35267 .62776 .34071 .61701 Metetra
.918 .327 0 r
.34071 .61701 .35267 .62776 .37201 .62044 .36015 .60961 Metetra
.912 .347 0 r
.36015 .60961 .37201 .62044 .39147 .61327 .3797 .60236 Metetra
.907 .364 0 r
.3797 .60236 .39147 .61327 .41105 .60623 .39936 .59524 Metetra
.903 .379 0 r
.39936 .59524 .41105 .60623 .43075 .59933 .41916 .58826 Metetra
.9 .391 0 r
.41916 .58826 .43075 .59933 .45058 .59255 .43908 .58139 Metetra
.897 .401 0 r
.43908 .58139 .45058 .59255 .47054 .58589 .45914 .57465 Metetra
.895 .408 0 r
.45914 .57465 .47054 .58589 .49064 .57935 .47934 .56803 Metetra
.893 .414 0 r
.47934 .56803 .49064 .57935 .51089 .57293 .49968 .56152 Metetra
.892 .418 0 r
.49968 .56152 .51089 .57293 .53127 .56661 .52017 .55512 Metetra
.892 .419 0 r
.52017 .55512 .53127 .56661 .55182 .56041 .54081 .54883 Metetra
.892 .419 0 r
.54081 .54883 .55182 .56041 .57251 .55432 .56161 .54266 Metetra
.892 .416 0 r
.56161 .54266 .57251 .55432 .59337 .54834 .58257 .53659 Metetra
.894 .412 0 r
.58257 .53659 .59337 .54834 .61439 .54248 .60369 .53064 Metetra
.896 .405 0 r
.60369 .53064 .61439 .54248 .63558 .53673 .62499 .5248 Metetra
.898 .397 0 r
.62499 .5248 .63558 .53673 .65695 .5311 .64647 .51908 Metetra
.901 .386 0 r
.64647 .51908 .65695 .5311 .67849 .5256 .66812 .51349 Metetra
.905 .372 0 r
.66812 .51349 .67849 .5256 .70023 .52023 .68997 .50804 Metetra
.91 .357 0 r
.68997 .50804 .70023 .52023 .72216 .51501 .71201 .50272 Metetra
.915 .338 0 r
.71201 .50272 .72216 .51501 .74428 .50993 .73425 .49755 Metetra
.921 .317 0 r
.73425 .49755 .74428 .50993 .76662 .50503 .7567 .49256 Metetra
.927 .292 0 r
.7567 .49256 .76662 .50503 .78917 .50029 .77937 .48772 Metetra
.934 .266 0 r
.77937 .48772 .78917 .50029 .81192 .49548 .80224 .48282 Metetra
.937 .257 0 r
.80224 .48282 .81192 .49548 .83464 .48817 .82509 .47542 Metetra
.909 .359 0 r
.82509 .47542 .83464 .48817 .85609 .46641 .8467 .45353 Metetra
.785 .73 0 r
.8467 .45353 .85609 .46641 .87349 .40741 .86435 .39433 Metetra
.331 .655 0 r
.22415 .53684 .23632 .54755 .24856 .61358 .23616 .60306 Metetra
.858 .529 0 r
.23616 .60306 .24856 .61358 .26473 .63911 .25227 .62865 Metetra
.928 .288 0 r
.25227 .62865 .26473 .63911 .28313 .63913 .27074 .62862 Metetra
.937 .256 0 r
.27074 .62862 .28313 .63913 .30218 .63224 .28987 .62165 Metetra
.931 .278 0 r
.28987 .62165 .30218 .63224 .32139 .62458 .30917 .6139 Metetra
.924 .304 0 r
.30917 .6139 .32139 .62458 .34071 .61701 .32859 .60625 Metetra
.918 .327 0 r
.32859 .60625 .34071 .61701 .36015 .60961 .34811 .59877 Metetra
.912 .347 0 r
.34811 .59877 .36015 .60961 .3797 .60236 .36776 .59143 Metetra
.907 .364 0 r
.36776 .59143 .3797 .60236 .39936 .59524 .38752 .58423 Metetra
.903 .379 0 r
.38752 .58423 .39936 .59524 .41916 .58826 .40741 .57716 Metetra
.9 .391 0 r
.40741 .57716 .41916 .58826 .43908 .58139 .42743 .5702 Metetra
.897 .401 0 r
.42743 .5702 .43908 .58139 .45914 .57465 .44759 .56338 Metetra
.895 .409 0 r
.44759 .56338 .45914 .57465 .47934 .56803 .46788 .55667 Metetra
.893 .414 0 r
.46788 .55667 .47934 .56803 .49968 .56152 .48832 .55007 Metetra
.892 .418 0 r
.48832 .55007 .49968 .56152 .52017 .55512 .50891 .54359 Metetra
.891 .419 0 r
.50891 .54359 .52017 .55512 .54081 .54883 .52965 .53721 Metetra
.892 .419 0 r
.52965 .53721 .54081 .54883 .56161 .54266 .55056 .53095 Metetra
.892 .417 0 r
.55056 .53095 .56161 .54266 .58257 .53659 .57162 .52479 Metetra
.894 .412 0 r
.57162 .52479 .58257 .53659 .60369 .53064 .59285 .51875 Metetra
.895 .406 0 r
.59285 .51875 .60369 .53064 .62499 .5248 .61426 .51282 Metetra
.898 .397 0 r
.61426 .51282 .62499 .5248 .64647 .51908 .63584 .50702 Metetra
.901 .386 0 r
.63584 .50702 .64647 .51908 .66812 .51349 .65761 .50134 Metetra
.905 .373 0 r
.65761 .50134 .66812 .51349 .68997 .50804 .67956 .49579 Metetra
.909 .357 0 r
.67956 .49579 .68997 .50804 .71201 .50272 .70172 .49038 Metetra
.915 .339 0 r
.70172 .49038 .71201 .50272 .73425 .49755 .72408 .48513 Metetra
.92 .317 0 r
.72408 .48513 .73425 .49755 .7567 .49256 .74665 .48004 Metetra
.927 .293 0 r
.74665 .48004 .7567 .49256 .77937 .48772 .76943 .47512 Metetra
.934 .266 0 r
.76943 .47512 .77937 .48772 .80224 .48282 .79243 .47012 Metetra
.937 .257 0 r
.79243 .47012 .80224 .48282 .82509 .47542 .81541 .46261 Metetra
.909 .36 0 r
.81541 .46261 .82509 .47542 .8467 .45353 .83719 .44056 Metetra
.785 .73 0 r
.83719 .44056 .8467 .45353 .86435 .39433 .85508 .38106 Metetra
.331 .655 0 r
.21182 .52595 .22415 .53684 .23616 .60306 .22359 .59245 Metetra
.858 .528 0 r
.22359 .59245 .23616 .60306 .25227 .62865 .23964 .61817 Metetra
.929 .286 0 r
.23964 .61817 .25227 .62865 .27074 .62862 .25816 .6181 Metetra
.937 .254 0 r
.25816 .6181 .27074 .62862 .28987 .62165 .27738 .61105 Metetra
.931 .277 0 r
.27738 .61105 .28987 .62165 .30917 .6139 .29678 .60321 Metetra
.924 .303 0 r
.29678 .60321 .30917 .6139 .32859 .60625 .31629 .59548 Metetra
.918 .326 0 r
.31629 .59548 .32859 .60625 .34811 .59877 .33591 .5879 Metetra
.913 .346 0 r
.33591 .5879 .34811 .59877 .36776 .59143 .35565 .58047 Metetra
.908 .363 0 r
.35565 .58047 .36776 .59143 .38752 .58423 .37551 .57318 Metetra
.904 .378 0 r
.37551 .57318 .38752 .58423 .40741 .57716 .39549 .56603 Metetra
.9 .39 0 r
.39549 .56603 .40741 .57716 .42743 .5702 .41561 .55898 Metetra
.897 .4 0 r
.41561 .55898 .42743 .5702 .44759 .56338 .43587 .55207 Metetra
.895 .408 0 r
.43587 .55207 .44759 .56338 .46788 .55667 .45626 .54527 Metetra
.893 .413 0 r
.45626 .54527 .46788 .55667 .48832 .55007 .4768 .53858 Metetra
.892 .417 0 r
.4768 .53858 .48832 .55007 .50891 .54359 .49749 .53201 Metetra
.892 .418 0 r
.49749 .53201 .50891 .54359 .52965 .53721 .51834 .52554 Metetra
.892 .418 0 r
.51834 .52554 .52965 .53721 .55056 .53095 .53935 .51919 Metetra
.893 .415 0 r
.53935 .51919 .55056 .53095 .57162 .52479 .56052 .51295 Metetra
.894 .411 0 r
.56052 .51295 .57162 .52479 .59285 .51875 .58186 .50681 Metetra
.896 .404 0 r
.58186 .50681 .59285 .51875 .61426 .51282 .60337 .5008 Metetra
.898 .396 0 r
.60337 .5008 .61426 .51282 .63584 .50702 .62506 .4949 Metetra
.902 .385 0 r
.62506 .4949 .63584 .50702 .65761 .50134 .64694 .48913 Metetra
.905 .372 0 r
.64694 .48913 .65761 .50134 .67956 .49579 .66902 .4835 Metetra
.91 .356 0 r
.66902 .4835 .67956 .49579 .70172 .49038 .69129 .478 Metetra
.915 .337 0 r
.69129 .478 .70172 .49038 .72408 .48513 .71376 .47265 Metetra
.921 .316 0 r
.71376 .47265 .72408 .48513 .74665 .48004 .73645 .46748 Metetra
.928 .291 0 r
.73645 .46748 .74665 .48004 .76943 .47512 .75936 .46246 Metetra
.935 .265 0 r
.75936 .46246 .76943 .47512 .79243 .47012 .78248 .45738 Metetra
.937 .255 0 r
.78248 .45738 .79243 .47012 .81541 .46261 .8056 .44975 Metetra
.909 .358 0 r
.8056 .44975 .81541 .46261 .83719 .44056 .82754 .42749 Metetra
.786 .73 0 r
.82754 .42749 .83719 .44056 .85508 .38106 .84567 .36759 Metetra
.331 .655 0 r
.19934 .51488 .21182 .52595 .22359 .59245 .21085 .58175 Metetra
.858 .527 0 r
.21085 .58175 .22359 .59245 .23964 .61817 .22683 .60766 Metetra
.93 .283 0 r
.22683 .60766 .23964 .61817 .25816 .6181 .2454 .60758 Metetra
.938 .251 0 r
.2454 .60758 .25816 .6181 .27738 .61105 .26471 .60045 Metetra
.932 .273 0 r
.26471 .60045 .27738 .61105 .29678 .60321 .28421 .59251 Metetra
.925 .299 0 r
.28421 .59251 .29678 .60321 .31629 .59548 .30381 .58468 Metetra
.919 .323 0 r
.30381 .58468 .31629 .59548 .33591 .5879 .32353 .57701 Metetra
.913 .343 0 r
.32353 .57701 .33591 .5879 .35565 .58047 .34336 .56949 Metetra
.909 .36 0 r
.34336 .56949 .35565 .58047 .37551 .57318 .36332 .56211 Metetra
.904 .375 0 r
.36332 .56211 .37551 .57318 .39549 .56603 .3834 .55486 Metetra
.901 .387 0 r
.3834 .55486 .39549 .56603 .41561 .55898 .40362 .54772 Metetra
.898 .397 0 r
.40362 .54772 .41561 .55898 .43587 .55207 .42398 .54072 Metetra
.896 .405 0 r
.42398 .54072 .43587 .55207 .45626 .54527 .44447 .53383 Metetra
.894 .411 0 r
.44447 .53383 .45626 .54527 .4768 .53858 .46512 .52705 Metetra
.893 .414 0 r
.46512 .52705 .4768 .53858 .49749 .53201 .48591 .52038 Metetra
.893 .416 0 r
.48591 .52038 .49749 .53201 .51834 .52554 .50686 .51383 Metetra
.893 .415 0 r
.50686 .51383 .51834 .52554 .53935 .51919 .52798 .50738 Metetra
.893 .413 0 r
.52798 .50738 .53935 .51919 .56052 .51295 .54925 .50105 Metetra
.895 .408 0 r
.54925 .50105 .56052 .51295 .58186 .50681 .5707 .49483 Metetra
.897 .402 0 r
.5707 .49483 .58186 .50681 .60337 .5008 .59233 .48872 Metetra
.899 .393 0 r
.59233 .48872 .60337 .5008 .62506 .4949 .61414 .48274 Metetra
.902 .382 0 r
.61414 .48274 .62506 .4949 .64694 .48913 .63613 .47688 Metetra
.906 .369 0 r
.63613 .47688 .64694 .48913 .66902 .4835 .65832 .47115 Metetra
.911 .353 0 r
.65832 .47115 .66902 .4835 .69129 .478 .68071 .46556 Metetra
.916 .334 0 r
.68071 .46556 .69129 .478 .71376 .47265 .70331 .46013 Metetra
.922 .313 0 r
.70331 .46013 .71376 .47265 .73645 .46748 .72612 .45486 Metetra
.928 .288 0 r
.72612 .45486 .73645 .46748 .75936 .46246 .74915 .44976 Metetra
.935 .262 0 r
.74915 .44976 .75936 .46246 .78248 .45738 .7724 .44459 Metetra
.938 .252 0 r
.7724 .44459 .78248 .45738 .8056 .44975 .79565 .43684 Metetra
.91 .356 0 r
.79565 .43684 .8056 .44975 .82754 .42749 .81776 .41432 Metetra
.786 .729 0 r
.81776 .41432 .82754 .42749 .84567 .36759 .83612 .35393 Metetra
.33 .655 0 r
.1867 .50361 .19934 .51488 .21085 .58175 .19794 .57094 Metetra
.859 .524 0 r
.19794 .57094 .21085 .58175 .22683 .60766 .21383 .59712 Metetra
.931 .278 0 r
.21383 .59712 .22683 .60766 .2454 .60758 .23246 .59706 Metetra
.94 .245 0 r
.23246 .59706 .2454 .60758 .26471 .60045 .25186 .58984 Metetra
.934 .268 0 r
.25186 .58984 .26471 .60045 .28421 .59251 .27145 .5818 Metetra
.927 .294 0 r
.27145 .5818 .28421 .59251 .30381 .58468 .29115 .57387 Metetra
.92 .318 0 r
.29115 .57387 .30381 .58468 .32353 .57701 .31097 .5661 Metetra
.915 .338 0 r
.31097 .5661 .32353 .57701 .34336 .56949 .3309 .55848 Metetra
.91 .356 0 r
.3309 .55848 .34336 .56949 .36332 .56211 .35095 .55101 Metetra
.906 .37 0 r
.35095 .55101 .36332 .56211 .3834 .55486 .37114 .54366 Metetra
.902 .383 0 r
.37114 .54366 .3834 .55486 .40362 .54772 .39146 .53643 Metetra
.899 .393 0 r
.39146 .53643 .40362 .54772 .42398 .54072 .41192 .52933 Metetra
.897 .401 0 r
.41192 .52933 .42398 .54072 .44447 .53383 .43251 .52234 Metetra
.895 .406 0 r
.43251 .52234 .44447 .53383 .46512 .52705 .45326 .51547 Metetra
.894 .41 0 r
.45326 .51547 .46512 .52705 .48591 .52038 .47416 .50871 Metetra
.894 .412 0 r
.47416 .50871 .48591 .52038 .50686 .51383 .49522 .50206 Metetra
.894 .411 0 r
.49522 .50206 .50686 .51383 .52798 .50738 .51644 .49553 Metetra
.895 .409 0 r
.51644 .49553 .52798 .50738 .54925 .50105 .53783 .4891 Metetra
.896 .404 0 r
.53783 .4891 .54925 .50105 .5707 .49483 .55939 .48279 Metetra
.898 .397 0 r
.55939 .48279 .5707 .49483 .59233 .48872 .58113 .47659 Metetra
.9 .389 0 r
.58113 .47659 .59233 .48872 .61414 .48274 .60305 .47051 Metetra
.904 .378 0 r
.60305 .47051 .61414 .48274 .63613 .47688 .62516 .46456 Metetra
.907 .364 0 r
.62516 .46456 .63613 .47688 .65832 .47115 .64747 .45875 Metetra
.912 .348 0 r
.64747 .45875 .65832 .47115 .68071 .46556 .66998 .45307 Metetra
.917 .329 0 r
.66998 .45307 .68071 .46556 .70331 .46013 .6927 .44755 Metetra
.923 .308 0 r
.6927 .44755 .70331 .46013 .72612 .45486 .71564 .4422 Metetra
.93 .283 0 r
.71564 .4422 .72612 .45486 .74915 .44976 .7388 .43701 Metetra
.937 .256 0 r
.7388 .43701 .74915 .44976 .7724 .44459 .76217 .43175 Metetra
.939 .247 0 r
.76217 .43175 .7724 .44459 .79565 .43684 .78557 .42387 Metetra
.911 .352 0 r
.78557 .42387 .79565 .43684 .81776 .41432 .80783 .40104 Metetra
.786 .728 0 r
.80783 .40104 .81776 .41432 .83612 .35393 .82643 .34006 Metetra
.33 .655 0 r
.1739 .49214 .1867 .50361 .19794 .57094 .18484 .56003 Metetra
.86 .521 0 r
.18484 .56003 .19794 .57094 .21383 .59712 .20064 .58656 Metetra
.933 .272 0 r
.20064 .58656 .21383 .59712 .23246 .59706 .21932 .58653 Metetra
.942 .238 0 r
.21932 .58653 .23246 .59706 .25186 .58984 .23881 .57923 Metetra
.936 .261 0 r
.23881 .57923 .25186 .58984 .27145 .5818 .2585 .57108 Metetra
.929 .287 0 r
.2585 .57108 .27145 .5818 .29115 .57387 .2783 .56305 Metetra
.922 .311 0 r
.2783 .56305 .29115 .57387 .31097 .5661 .29822 .55517 Metetra
.917 .332 0 r
.29822 .55517 .31097 .5661 .3309 .55848 .31825 .54745 Metetra
.912 .349 0 r
.31825 .54745 .3309 .55848 .35095 .55101 .33841 .53987 Metetra
.907 .364 0 r
.33841 .53987 .35095 .55101 .37114 .54366 .35869 .53242 Metetra
.904 .377 0 r
.35869 .53242 .37114 .54366 .39146 .53643 .37911 .52509 Metetra
.901 .387 0 r
.37911 .52509 .39146 .53643 .41192 .52933 .39967 .5179 Metetra
.899 .395 0 r
.39967 .5179 .41192 .52933 .43251 .52234 .42038 .51082 Metetra
.897 .401 0 r
.42038 .51082 .43251 .52234 .45326 .51547 .44123 .50385 Metetra
.896 .404 0 r
.44123 .50385 .45326 .51547 .47416 .50871 .46224 .49699 Metetra
.895 .406 0 r
.46224 .49699 .47416 .50871 .49522 .50206 .48341 .49025 Metetra
.896 .405 0 r
.48341 .49025 .49522 .50206 .51644 .49553 .50474 .48362 Metetra
.896 .403 0 r
.50474 .48362 .51644 .49553 .53783 .4891 .52624 .4771 Metetra
.898 .398 0 r
.52624 .4771 .53783 .4891 .55939 .48279 .54791 .47069 Metetra
.9 .392 0 r
.54791 .47069 .55939 .48279 .58113 .47659 .56976 .46441 Metetra
.902 .383 0 r
.56976 .46441 .58113 .47659 .60305 .47051 .5918 .45824 Metetra
.905 .372 0 r
.5918 .45824 .60305 .47051 .62516 .46456 .61403 .4522 Metetra
.909 .358 0 r
.61403 .4522 .62516 .46456 .64747 .45875 .63646 .44629 Metetra
.914 .342 0 r
.63646 .44629 .64747 .45875 .66998 .45307 .65909 .44053 Metetra
.919 .323 0 r
.65909 .44053 .66998 .45307 .6927 .44755 .68194 .43492 Metetra
.925 .301 0 r
.68194 .43492 .6927 .44755 .71564 .4422 .705 .42949 Metetra
.932 .276 0 r
.705 .42949 .71564 .4422 .7388 .43701 .72829 .42422 Metetra
.939 .249 0 r
.72829 .42422 .7388 .43701 .76217 .43175 .7518 .41886 Metetra
.941 .239 0 r
.7518 .41886 .76217 .43175 .78557 .42387 .77533 .41084 Metetra
.912 .346 0 r
.77533 .41084 .78557 .42387 .80783 .40104 .79776 .38766 Metetra
.787 .727 0 r
.79776 .38766 .80783 .40104 .82643 .34006 .81659 .32598 Metetra
.33 .655 0 r
.16094 .48046 .1739 .49214 .18484 .56003 .17156 .549 Metetra
.862 .516 0 r
.17156 .549 .18484 .56003 .20064 .58656 .18726 .57596 Metetra
.935 .263 0 r
.18726 .57596 .20064 .58656 .21932 .58653 .20598 .576 Metetra
.944 .228 0 r
.20598 .576 .21932 .58653 .23881 .57923 .22557 .56861 Metetra
.938 .251 0 r
.22557 .56861 .23881 .57923 .2585 .57108 .24536 .56036 Metetra
.931 .278 0 r
.24536 .56036 .2585 .57108 .2783 .56305 .26526 .55222 Metetra
.925 .302 0 r
.26526 .55222 .2783 .56305 .29822 .55517 .28527 .54424 Metetra
.919 .323 0 r
.28527 .54424 .29822 .55517 .31825 .54745 .30541 .53641 Metetra
.914 .341 0 r
.30541 .53641 .31825 .54745 .33841 .53987 .32567 .52872 Metetra
.91 .356 0 r
.32567 .52872 .33841 .53987 .35869 .53242 .34606 .52117 Metetra
.906 .369 0 r
.34606 .52117 .35869 .53242 .37911 .52509 .36659 .51374 Metetra
.903 .379 0 r
.36659 .51374 .37911 .52509 .39967 .5179 .38725 .50644 Metetra
.901 .387 0 r
.38725 .50644 .39967 .5179 .42038 .51082 .40806 .49926 Metetra
.899 .393 0 r
.40806 .49926 .42038 .51082 .44123 .50385 .42902 .49219 Metetra
.898 .397 0 r
.42902 .49219 .44123 .50385 .46224 .49699 .45014 .48524 Metetra
.898 .399 0 r
.45014 .48524 .46224 .49699 .48341 .49025 .47141 .4784 Metetra
.898 .398 0 r
.47141 .4784 .48341 .49025 .50474 .48362 .49286 .47167 Metetra
.898 .396 0 r
.49286 .47167 .50474 .48362 .52624 .4771 .51447 .46506 Metetra
.9 .391 0 r
.51447 .46506 .52624 .4771 .54791 .47069 .53626 .45856 Metetra
.902 .384 0 r
.53626 .45856 .54791 .47069 .56976 .46441 .55823 .45218 Metetra
.904 .375 0 r
.55823 .45218 .56976 .46441 .5918 .45824 .58038 .44592 Metetra
.908 .364 0 r
.58038 .44592 .5918 .45824 .61403 .4522 .60273 .4398 Metetra
.911 .35 0 r
.60273 .4398 .61403 .4522 .63646 .44629 .62529 .4338 Metetra
.916 .334 0 r
.62529 .4338 .63646 .44629 .65909 .44053 .64804 .42795 Metetra
.921 .314 0 r
.64804 .42795 .65909 .44053 .68194 .43492 .67101 .42226 Metetra
.927 .292 0 r
.67101 .42226 .68194 .43492 .705 .42949 .69421 .41674 Metetra
.934 .266 0 r
.69421 .41674 .705 .42949 .72829 .42422 .71763 .41137 Metetra
.941 .239 0 r
.71763 .41137 .72829 .42422 .7518 .41886 .74128 .40593 Metetra
.944 .23 0 r
.74128 .40593 .7518 .41886 .77533 .41084 .76495 .39776 Metetra
.915 .339 0 r
.76495 .39776 .77533 .41084 .79776 .38766 .78755 .37415 Metetra
.788 .725 0 r
.78755 .37415 .79776 .38766 .81659 .32598 .80661 .31167 Metetra
.33 .655 0 r
.14782 .46858 .16094 .48046 .17156 .549 .15809 .53787 Metetra
.864 .511 0 r
.15809 .53787 .17156 .549 .18726 .57596 .17366 .56534 Metetra
.938 .252 0 r
.17366 .56534 .18726 .57596 .20598 .576 .19243 .56547 Metetra
.947 .217 0 r
.19243 .56547 .20598 .576 .22557 .56861 .21212 .55799 Metetra
.941 .24 0 r
.21212 .55799 .22557 .56861 .24536 .56036 .23201 .54963 Metetra
.934 .267 0 r
.23201 .54963 .24536 .56036 .26526 .55222 .25201 .54137 Metetra
.927 .292 0 r
.25201 .54137 .26526 .55222 .28527 .54424 .27213 .53328 Metetra
.922 .313 0 r
.27213 .53328 .28527 .54424 .30541 .53641 .29237 .52534 Metetra
.917 .331 0 r
.29237 .52534 .30541 .53641 .32567 .52872 .31274 .51754 Metetra
.912 .347 0 r
.31274 .51754 .32567 .52872 .34606 .52117 .33323 .50988 Metetra
.909 .36 0 r
.33323 .50988 .34606 .52117 .36659 .51374 .35386 .50234 Metetra
.906 .37 0 r
.35386 .50234 .36659 .51374 .38725 .50644 .37464 .49494 Metetra
.903 .378 0 r
.37464 .49494 .38725 .50644 .40806 .49926 .39556 .48766 Metetra
.902 .384 0 r
.39556 .48766 .40806 .49926 .42902 .49219 .41663 .48049 Metetra
.901 .388 0 r
.41663 .48049 .42902 .49219 .45014 .48524 .43785 .47344 Metetra
.9 .39 0 r
.43785 .47344 .45014 .48524 .47141 .4784 .45924 .4665 Metetra
.9 .389 0 r
.45924 .4665 .47141 .4784 .49286 .47167 .4808 .45967 Metetra
.901 .386 0 r
.4808 .45967 .49286 .47167 .51447 .46506 .50252 .45296 Metetra
.902 .382 0 r
.50252 .45296 .51447 .46506 .53626 .45856 .52443 .44637 Metetra
.904 .375 0 r
.52443 .44637 .53626 .45856 .55823 .45218 .54652 .4399 Metetra
.907 .366 0 r
.54652 .4399 .55823 .45218 .58038 .44592 .56879 .43355 Metetra
.91 .354 0 r
.56879 .43355 .58038 .44592 .60273 .4398 .59127 .42733 Metetra
.914 .34 0 r
.59127 .42733 .60273 .4398 .62529 .4338 .61394 .42125 Metetra
.919 .323 0 r
.61394 .42125 .62529 .4338 .64804 .42795 .63683 .41531 Metetra
.924 .304 0 r
.63683 .41531 .64804 .42795 .67101 .42226 .65993 .40954 Metetra
.93 .281 0 r
.65993 .40954 .67101 .42226 .69421 .41674 .68325 .40393 Metetra
.937 .255 0 r
.68325 .40393 .69421 .41674 .71763 .41137 .70681 .39849 Metetra
.944 .228 0 r
.70681 .39849 .71763 .41137 .74128 .40593 .7306 .39296 Metetra
.947 .218 0 r
.7306 .39296 .74128 .40593 .76495 .39776 .75441 .38462 Metetra
.917 .33 0 r
.75441 .38462 .76495 .39776 .78755 .37415 .77718 .36055 Metetra
.789 .722 0 r
.77718 .36055 .78755 .37415 .80661 .31167 .79647 .29715 Metetra
.329 .655 0 r
.13452 .45648 .14782 .46858 .15809 .53787 .14443 .52663 Metetra
.866 .504 0 r
.14443 .52663 .15809 .53787 .17366 .56534 .15986 .55471 Metetra
.941 .24 0 r
.15986 .55471 .17366 .56534 .19243 .56547 .17867 .55496 Metetra
.951 .202 0 r
.17867 .55496 .19243 .56547 .21212 .55799 .19845 .54739 Metetra
.945 .226 0 r
.19845 .54739 .21212 .55799 .23201 .54963 .21845 .5389 Metetra
.938 .254 0 r
.21845 .5389 .23201 .54963 .25201 .54137 .23856 .53052 Metetra
.931 .279 0 r
.23856 .53052 .25201 .54137 .27213 .53328 .25879 .5223 Metetra
.925 .3 0 r
.25879 .5223 .27213 .53328 .29237 .52534 .27913 .51425 Metetra
.92 .319 0 r
.27913 .51425 .29237 .52534 .31274 .51754 .2996 .50634 Metetra
.916 .335 0 r
.2996 .50634 .31274 .51754 .33323 .50988 .32021 .49857 Metetra
.912 .348 0 r
.32021 .49857 .33323 .50988 .35386 .50234 .34095 .49092 Metetra
.909 .359 0 r
.34095 .49092 .35386 .50234 .37464 .49494 .36183 .48341 Metetra
.907 .367 0 r
.36183 .48341 .37464 .49494 .39556 .48766 .38286 .47602 Metetra
.905 .373 0 r
.38286 .47602 .39556 .48766 .41663 .48049 .40404 .46875 Metetra
.904 .377 0 r
.40404 .46875 .41663 .48049 .43785 .47344 .42538 .46159 Metetra
.903 .379 0 r
.42538 .46159 .43785 .47344 .45924 .4665 .44688 .45455 Metetra
.903 .378 0 r
.44688 .45455 .45924 .4665 .4808 .45967 .46855 .44763 Metetra
.904 .376 0 r
.46855 .44763 .4808 .45967 .50252 .45296 .49039 .44082 Metetra
.905 .371 0 r
.49039 .44082 .50252 .45296 .52443 .44637 .51242 .43413 Metetra
.907 .364 0 r
.51242 .43413 .52443 .44637 .54652 .4399 .53463 .42757 Metetra
.91 .354 0 r
.53463 .42757 .54652 .4399 .56879 .43355 .55703 .42113 Metetra
.913 .343 0 r
.55703 .42113 .56879 .43355 .59127 .42733 .57962 .41482 Metetra
.917 .328 0 r
.57962 .41482 .59127 .42733 .61394 .42125 .60243 .40865 Metetra
.922 .311 0 r
.60243 .40865 .61394 .42125 .63683 .41531 .62544 .40263 Metetra
.928 .291 0 r
.62544 .40263 .63683 .41531 .65993 .40954 .64867 .39678 Metetra
.934 .268 0 r
.64867 .39678 .65993 .40954 .68325 .40393 .67213 .39109 Metetra
.941 .242 0 r
.67213 .39109 .68325 .40393 .70681 .39849 .69583 .38557 Metetra
.948 .213 0 r
.69583 .38557 .70681 .39849 .7306 .39296 .71975 .37995 Metetra
.95 .204 0 r
.71975 .37995 .7306 .39296 .75441 .38462 .74372 .37144 Metetra
.92 .319 0 r
.74372 .37144 .75441 .38462 .77718 .36055 .76665 .34684 Metetra
.79 .719 0 r
.76665 .34684 .77718 .36055 .79647 .29715 .78617 .2824 Metetra
.329 .654 0 r
.12107 .44416 .13452 .45648 .14443 .52663 .13057 .51528 Metetra
.868 .496 0 r
.13057 .51528 .14443 .52663 .15986 .55471 .14584 .54407 Metetra
.945 .225 0 r
.14584 .54407 .15986 .55471 .17867 .55496 .16469 .54446 Metetra
.955 .186 0 r
.16469 .54446 .17867 .55496 .19845 .54739 .18457 .5368 Metetra
.949 .209 0 r
.18457 .5368 .19845 .54739 .21845 .5389 .20467 .52818 Metetra
.942 .238 0 r
.20467 .52818 .21845 .5389 .23856 .53052 .22489 .51967 Metetra
.935 .264 0 r
.22489 .51967 .23856 .53052 .25879 .5223 .24523 .51133 Metetra
.929 .286 0 r
.24523 .51133 .25879 .5223 .27913 .51425 .26568 .50315 Metetra
.924 .305 0 r
.26568 .50315 .27913 .51425 .2996 .50634 .28626 .49512 Metetra
.919 .321 0 r
.28626 .49512 .2996 .50634 .32021 .49857 .30697 .48723 Metetra
.916 .335 0 r
.30697 .48723 .32021 .49857 .34095 .49092 .32782 .47947 Metetra
.913 .346 0 r
.32782 .47947 .34095 .49092 .36183 .48341 .34882 .47184 Metetra
.91 .354 0 r
.34882 .47184 .36183 .48341 .38286 .47602 .36996 .46435 Metetra
.908 .361 0 r
.36996 .46435 .38286 .47602 .40404 .46875 .39125 .45697 Metetra
.907 .364 0 r
.39125 .45697 .40404 .46875 .42538 .46159 .41271 .44971 Metetra
.907 .366 0 r
.41271 .44971 .42538 .46159 .44688 .45455 .43432 .44257 Metetra
.907 .366 0 r
.43432 .44257 .44688 .45455 .46855 .44763 .45611 .43554 Metetra
.908 .363 0 r
.45611 .43554 .46855 .44763 .49039 .44082 .47807 .42864 Metetra
.909 .358 0 r
.47807 .42864 .49039 .44082 .51242 .43413 .50022 .42185 Metetra
.911 .351 0 r
.50022 .42185 .51242 .43413 .53463 .42757 .52255 .41519 Metetra
.914 .341 0 r
.52255 .41519 .53463 .42757 .55703 .42113 .54507 .40866 Metetra
.917 .329 0 r
.54507 .40866 .55703 .42113 .57962 .41482 .5678 .40226 Metetra
.921 .314 0 r
.5678 .40226 .57962 .41482 .60243 .40865 .59073 .39601 Metetra
.926 .297 0 r
.59073 .39601 .60243 .40865 .62544 .40263 .61388 .38991 Metetra
.931 .277 0 r
.61388 .38991 .62544 .40263 .64867 .39678 .63724 .38397 Metetra
.938 .253 0 r
.63724 .38397 .64867 .39678 .67213 .39109 .66084 .37821 Metetra
.945 .226 0 r
.66084 .37821 .67213 .39109 .69583 .38557 .68468 .37261 Metetra
.952 .197 0 r
.68468 .37261 .69583 .38557 .71975 .37995 .70875 .36692 Metetra
.955 .188 0 r
.70875 .36692 .71975 .37995 .74372 .37144 .73286 .35822 Metetra
.923 .307 0 r
.73286 .35822 .74372 .37144 .76665 .34684 .75596 .33301 Metetra
.791 .716 0 r
.75596 .33301 .76665 .34684 .78617 .2824 .77572 .26741 Metetra
.328 .654 0 r
.10744 .43161 .12107 .44416 .13057 .51528 .11652 .50381 Metetra
.871 .487 0 r
.11652 .50381 .13057 .51528 .14584 .54407 .1316 .53341 Metetra
.95 .207 0 r
.1316 .53341 .14584 .54407 .16469 .54446 .15047 .53399 Metetra
.96 .166 0 r
.15047 .53399 .16469 .54446 .18457 .5368 .17045 .52623 Metetra
.954 .19 0 r
.17045 .52623 .18457 .5368 .20467 .52818 .19067 .51747 Metetra
.946 .22 0 r
.19067 .51747 .20467 .52818 .22489 .51967 .211 .50882 Metetra
.939 .246 0 r
.211 .50882 .22489 .51967 .24523 .51133 .23145 .50035 Metetra
.933 .269 0 r
.23145 .50035 .24523 .51133 .26568 .50315 .25201 .49204 Metetra
.928 .289 0 r
.25201 .49204 .26568 .50315 .28626 .49512 .27271 .48389 Metetra
.924 .305 0 r
.27271 .48389 .28626 .49512 .30697 .48723 .29353 .47588 Metetra
.92 .319 0 r
.29353 .47588 .30697 .48723 .32782 .47947 .31449 .468 Metetra
.917 .331 0 r
.31449 .468 .32782 .47947 .34882 .47184 .3356 .46026 Metetra
.914 .339 0 r
.3356 .46026 .34882 .47184 .36996 .46435 .35685 .45265 Metetra
.913 .346 0 r
.35685 .45265 .36996 .46435 .39125 .45697 .37826 .44516 Metetra
.911 .35 0 r
.37826 .44516 .39125 .45697 .41271 .44971 .39983 .4378 Metetra
.911 .351 0 r
.39983 .4378 .41271 .44971 .43432 .44257 .42157 .43055 Metetra
.911 .351 0 r
.42157 .43055 .43432 .44257 .45611 .43554 .44347 .42342 Metetra
.912 .348 0 r
.44347 .42342 .45611 .43554 .47807 .42864 .46556 .41642 Metetra
.913 .343 0 r
.46556 .41642 .47807 .42864 .50022 .42185 .48782 .40954 Metetra
.915 .336 0 r
.48782 .40954 .50022 .42185 .52255 .41519 .51028 .40278 Metetra
.918 .326 0 r
.51028 .40278 .52255 .41519 .54507 .40866 .53293 .39616 Metetra
.921 .313 0 r
.53293 .39616 .54507 .40866 .5678 .40226 .55579 .38967 Metetra
.926 .298 0 r
.55579 .38967 .5678 .40226 .59073 .39601 .57885 .38333 Metetra
.93 .28 0 r
.57885 .38333 .59073 .39601 .61388 .38991 .60213 .37715 Metetra
.936 .259 0 r
.60213 .37715 .61388 .38991 .63724 .38397 .62563 .37113 Metetra
.942 .235 0 r
.62563 .37113 .63724 .38397 .66084 .37821 .64937 .36529 Metetra
.95 .207 0 r
.64937 .36529 .66084 .37821 .68468 .37261 .67335 .35963 Metetra
.957 .178 0 r
.67335 .35963 .68468 .37261 .70875 .36692 .69756 .35386 Metetra
.959 .169 0 r
.69756 .35386 .70875 .36692 .73286 .35822 .72183 .34496 Metetra
.927 .292 0 r
.72183 .34496 .73286 .35822 .75596 .33301 .7451 .31908 Metetra
.793 .712 0 r
.7451 .31908 .75596 .33301 .77572 .26741 .7651 .25218 Metetra
.327 .654 0 r
.09363 .41881 .10744 .43161 .11652 .50381 .10225 .49223 Metetra
.874 .477 0 r
.10225 .49223 .11652 .50381 .1316 .53341 .11713 .52275 Metetra
.955 .187 0 r
.11713 .52275 .1316 .53341 .15047 .53399 .13602 .52355 Metetra
.966 .144 0 r
.13602 .52355 .15047 .53399 .17045 .52623 .1561 .5157 Metetra
.959 .169 0 r
.1561 .5157 .17045 .52623 .19067 .51747 .17643 .5068 Metetra
.952 .199 0 r
.17643 .5068 .19067 .51747 .211 .50882 .19688 .498 Metetra
.945 .226 0 r
.19688 .498 .211 .50882 .23145 .50035 .21744 .48939 Metetra
.939 .25 0 r
.21744 .48939 .23145 .50035 .25201 .49204 .23812 .48095 Metetra
.933 .27 0 r
.23812 .48095 .25201 .49204 .27271 .48389 .25893 .47266 Metetra
.929 .287 0 r
.25893 .47266 .27271 .48389 .29353 .47588 .27986 .46453 Metetra
.925 .301 0 r
.27986 .46453 .29353 .47588 .31449 .468 .30094 .45652 Metetra
.922 .313 0 r
.30094 .45652 .31449 .468 .3356 .46026 .32216 .44867 Metetra
.919 .322 0 r
.32216 .44867 .3356 .46026 .35685 .45265 .34353 .44094 Metetra
.917 .329 0 r
.34353 .44094 .35685 .45265 .37826 .44516 .36506 .43334 Metetra
.916 .333 0 r
.36506 .43334 .37826 .44516 .39983 .4378 .38675 .42586 Metetra
.916 .335 0 r
.38675 .42586 .39983 .4378 .42157 .43055 .4086 .41851 Metetra
.916 .334 0 r
.4086 .41851 .42157 .43055 .44347 .42342 .43063 .41128 Metetra
.917 .331 0 r
.43063 .41128 .44347 .42342 .46556 .41642 .45284 .40417 Metetra
.918 .326 0 r
.45284 .40417 .46556 .41642 .48782 .40954 .47523 .39719 Metetra
.92 .318 0 r
.47523 .39719 .48782 .40954 .51028 .40278 .49781 .39034 Metetra
.923 .308 0 r
.49781 .39034 .51028 .40278 .53293 .39616 .52059 .38362 Metetra
.926 .295 0 r
.52059 .38362 .53293 .39616 .55579 .38967 .54358 .37705 Metetra
.931 .28 0 r
.54358 .37705 .55579 .38967 .57885 .38333 .56677 .37063 Metetra
.936 .261 0 r
.56677 .37063 .57885 .38333 .60213 .37715 .59019 .36437 Metetra
.941 .24 0 r
.59019 .36437 .60213 .37715 .62563 .37113 .61383 .35827 Metetra
.948 .215 0 r
.61383 .35827 .62563 .37113 .64937 .36529 .63771 .35236 Metetra
.955 .186 0 r
.63771 .35236 .64937 .36529 .67335 .35963 .66184 .34663 Metetra
.963 .155 0 r
.66184 .34663 .67335 .35963 .69756 .35386 .6862 .34078 Metetra
.965 .147 0 r
.6862 .34078 .69756 .35386 .72183 .34496 .71063 .33167 Metetra
.932 .276 0 r
.71063 .33167 .72183 .34496 .7451 .31908 .73408 .30503 Metetra
.794 .708 0 r
.73408 .30503 .7451 .31908 .7651 .25218 .75432 .23668 Metetra
.325 .653 0 r
.07968 .40564 .09363 .41881 .10225 .49223 .0878 .48032 Metetra
.877 .467 0 r
.0878 .48032 .10225 .49223 .11713 .52275 .10244 .51189 Metetra
.96 .166 0 r
.10244 .51189 .11713 .52275 .13602 .52355 .12134 .51298 Metetra
.972 .119 0 r
.12134 .51298 .13602 .52355 .1561 .5157 .14153 .50506 Metetra
.965 .145 0 r
.14153 .50506 .1561 .5157 .17643 .5068 .16197 .49602 Metetra
.958 .176 0 r
.16197 .49602 .17643 .5068 .19688 .498 .18253 .48709 Metetra
.95 .204 0 r
.18253 .48709 .19688 .498 .21744 .48939 .20321 .47834 Metetra
.944 .228 0 r
.20321 .47834 .21744 .48939 .23812 .48095 .224 .46977 Metetra
.939 .249 0 r
.224 .46977 .23812 .48095 .25893 .47266 .24492 .46135 Metetra
.934 .267 0 r
.24492 .46135 .25893 .47266 .27986 .46453 .26597 .45309 Metetra
.93 .282 0 r
.26597 .45309 .27986 .46453 .30094 .45652 .28717 .44497 Metetra
.927 .294 0 r
.28717 .44497 .30094 .45652 .32216 .44867 .30851 .43699 Metetra
.924 .303 0 r
.30851 .43699 .32216 .44867 .34353 .44094 .33 .42915 Metetra
.923 .31 0 r
.33 .42915 .34353 .44094 .36506 .43334 .35164 .42143 Metetra
.921 .314 0 r
.35164 .42143 .36506 .43334 .38675 .42586 .37345 .41384 Metetra
.921 .316 0 r
.37345 .41384 .38675 .42586 .4086 .41851 .39543 .40638 Metetra
.921 .315 0 r
.39543 .40638 .4086 .41851 .43063 .41128 .41758 .39904 Metetra
.922 .312 0 r
.41758 .39904 .43063 .41128 .45284 .40417 .43991 .39183 Metetra
.923 .307 0 r
.43991 .39183 .45284 .40417 .47523 .39719 .46243 .38475 Metetra
.925 .299 0 r
.46243 .38475 .47523 .39719 .49781 .39034 .48514 .3778 Metetra
.928 .289 0 r
.48514 .3778 .49781 .39034 .52059 .38362 .50805 .37099 Metetra
.932 .275 0 r
.50805 .37099 .52059 .38362 .54358 .37705 .53117 .36432 Metetra
.936 .259 0 r
.53117 .36432 .54358 .37705 .56677 .37063 .5545 .35781 Metetra
.941 .24 0 r
.5545 .35781 .56677 .37063 .59019 .36437 .57806 .35146 Metetra
.947 .218 0 r
.57806 .35146 .59019 .36437 .61383 .35827 .60184 .34528 Metetra
.954 .192 0 r
.60184 .34528 .61383 .35827 .63771 .35236 .62586 .33929 Metetra
.961 .162 0 r
.62586 .33929 .63771 .35236 .66184 .34663 .65014 .33348 Metetra
.969 .131 0 r
.65014 .33348 .66184 .34663 .6862 .34078 .67465 .32753 Metetra
.971 .123 0 r
.67465 .32753 .6862 .34078 .71063 .33167 .69923 .31815 Metetra
.936 .258 0 r
.69923 .31815 .71063 .33167 .73408 .30503 .72286 .29066 Metetra
.796 .704 0 r
.72286 .29066 .73408 .30503 .75432 .23668 .74335 .22075 Metetra
.31 .649 0 r
.06575 .3908 .07968 .40564 .0878 .48032 .07341 .46625 Metetra
.876 .47 0 r
.07341 .46625 .0878 .48032 .10244 .51189 .08779 .4988 Metetra
.962 .158 0 r
.08779 .4988 .10244 .51189 .12134 .51298 .10667 .50036 Metetra
.975 .107 0 r
.10667 .50036 .12134 .51298 .14153 .50506 .12692 .49259 Metetra
.969 .131 0 r
.12692 .49259 .14153 .50506 .16197 .49602 .14745 .48359 Metetra
.961 .162 0 r
.14745 .48359 .16197 .49602 .18253 .48709 .1681 .47466 Metetra
.954 .19 0 r
.1681 .47466 .18253 .48709 .20321 .47834 .18887 .4659 Metetra
.948 .214 0 r
.18887 .4659 .20321 .47834 .224 .46977 .20977 .45729 Metetra
.943 .235 0 r
.20977 .45729 .224 .46977 .24492 .46135 .23079 .44883 Metetra
.938 .252 0 r
.23079 .44883 .24492 .46135 .26597 .45309 .25195 .4405 Metetra
.934 .267 0 r
.25195 .4405 .26597 .45309 .28717 .44497 .27325 .4323 Metetra
.931 .279 0 r
.27325 .4323 .28717 .44497 .30851 .43699 .2947 .42424 Metetra
.928 .289 0 r
.2947 .42424 .30851 .43699 .33 .42915 .3163 .41631 Metetra
.926 .295 0 r
.3163 .41631 .33 .42915 .35164 .42143 .33805 .4085 Metetra
.925 .3 0 r
.33805 .4085 .35164 .42143 .37345 .41384 .35998 .4008 Metetra
.925 .301 0 r
.35998 .4008 .37345 .41384 .39543 .40638 .38207 .39323 Metetra
.925 .301 0 r
.38207 .39323 .39543 .40638 .41758 .39904 .40434 .38578 Metetra
.926 .298 0 r
.40434 .38578 .41758 .39904 .43991 .39183 .4268 .37844 Metetra
.927 .293 0 r
.4268 .37844 .43991 .39183 .46243 .38475 .44944 .37123 Metetra
.929 .285 0 r
.44944 .37123 .46243 .38475 .48514 .3778 .47227 .36414 Metetra
.932 .274 0 r
.47227 .36414 .48514 .3778 .50805 .37099 .49531 .35718 Metetra
.936 .261 0 r
.49531 .35718 .50805 .37099 .53117 .36432 .51855 .35036 Metetra
.94 .245 0 r
.51855 .35036 .53117 .36432 .5545 .35781 .54202 .34367 Metetra
.945 .226 0 r
.54202 .34367 .5545 .35781 .57806 .35146 .5657 .33713 Metetra
.951 .204 0 r
.5657 .33713 .57806 .35146 .60184 .34528 .58962 .33075 Metetra
.957 .178 0 r
.58962 .33075 .60184 .34528 .62586 .33929 .61377 .32453 Metetra
.964 .149 0 r
.61377 .32453 .62586 .33929 .65014 .33348 .63817 .31847 Metetra
.972 .118 0 r
.63817 .31847 .65014 .33348 .67465 .32753 .66282 .31221 Metetra
.973 .112 0 r
.66282 .31221 .67465 .32753 .69923 .31815 .68753 .30234 Metetra
.937 .255 0 r
.68753 .30234 .69923 .31815 .72286 .29066 .71132 .27385 Metetra
.793 .71 0 r
.71132 .27385 .72286 .29066 .74335 .22075 .73208 .20265 Metetra
.228 .623 0 r
.05279 .36803 .06575 .3908 .07341 .46625 .06046 .44057 Metetra
.85 .553 0 r
.06046 .44057 .07341 .46625 .08779 .4988 .07468 .47282 Metetra
.938 .253 0 r
.07468 .47282 .08779 .4988 .10667 .50036 .09339 .47528 Metetra
.953 .194 0 r
.09339 .47528 .10667 .50036 .12692 .49259 .11353 .46848 Metetra
.949 .209 0 r
.11353 .46848 .12692 .49259 .14745 .48359 .13398 .46032 Metetra
.943 .231 0 r
.13398 .46032 .14745 .48359 .1681 .47466 .15458 .45209 Metetra
.938 .252 0 r
.15458 .45209 .1681 .47466 .18887 .4659 .17532 .44389 Metetra
.933 .27 0 r
.17532 .44389 .18887 .4659 .20977 .45729 .19621 .43575 Metetra
.929 .286 0 r
.19621 .43575 .20977 .45729 .23079 .44883 .21724 .42765 Metetra
.925 .3 0 r
.21724 .42765 .23079 .44883 .25195 .4405 .23842 .41961 Metetra
.922 .312 0 r
.23842 .41961 .25195 .4405 .27325 .4323 .25975 .41161 Metetra
.919 .322 0 r
.25975 .41161 .27325 .4323 .2947 .42424 .28124 .40368 Metetra
.917 .329 0 r
.28124 .40368 .2947 .42424 .3163 .41631 .3029 .39581 Metetra
.916 .335 0 r
.3029 .39581 .3163 .41631 .33805 .4085 .32471 .388 Metetra
.915 .338 0 r
.32471 .388 .33805 .4085 .35998 .4008 .3467 .38026 Metetra
.914 .34 0 r
.3467 .38026 .35998 .4008 .38207 .39323 .36886 .37257 Metetra
.914 .339 0 r
.36886 .37257 .38207 .39323 .40434 .38578 .39121 .36494 Metetra
.915 .337 0 r
.39121 .36494 .40434 .38578 .4268 .37844 .41373 .35738 Metetra
.916 .332 0 r
.41373 .35738 .4268 .37844 .44944 .37123 .43645 .34988 Metetra
.918 .326 0 r
.43645 .34988 .44944 .37123 .47227 .36414 .45936 .34244 Metetra
.92 .318 0 r
.45936 .34244 .47227 .36414 .49531 .35718 .48247 .33505 Metetra
.923 .307 0 r
.48247 .33505 .49531 .35718 .51855 .35036 .50579 .32772 Metetra
.927 .294 0 r
.50579 .32772 .51855 .35036 .54202 .34367 .52931 .32045 Metetra
.931 .28 0 r
.52931 .32045 .54202 .34367 .5657 .33713 .55306 .31322 Metetra
.935 .262 0 r
.55306 .31322 .5657 .33713 .58962 .33075 .57703 .30604 Metetra
.94 .243 0 r
.57703 .30604 .58962 .33075 .61377 .32453 .60122 .2989 Metetra
.946 .221 0 r
.60122 .2989 .61377 .32453 .63817 .31847 .62565 .29177 Metetra
.952 .199 0 r
.62565 .29177 .63817 .31847 .66282 .31221 .6503 .28429 Metetra
.951 .203 0 r
.6503 .28429 .66282 .31221 .68753 .30234 .675 .27307 Metetra
.912 .348 0 r
.675 .27307 .68753 .30234 .71132 .27385 .69886 .24374 Metetra
.758 .767 0 r
.69886 .24374 .71132 .27385 .73208 .20265 .71996 .1738 Metetra
0 .53 .02 r
.04284 .32478 .05279 .36803 .06046 .44057 .05194 .38408 Metetra
.643 .739 0 r
.05194 .38408 .06046 .44057 .07468 .47282 .06649 .41135 Metetra
.826 .623 0 r
.06649 .41135 .07468 .47282 .09339 .47528 .08485 .41448 Metetra
.846 .564 0 r
.08485 .41448 .09339 .47528 .11353 .46848 .1045 .40981 Metetra
.848 .557 0 r
.1045 .40981 .11353 .46848 .13398 .46032 .12451 .40373 Metetra
.848 .558 0 r
.12451 .40373 .13398 .46032 .15458 .45209 .14472 .39733 Metetra
.847 .56 0 r
.14472 .39733 .15458 .45209 .17532 .44389 .16512 .39073 Metetra
.847 .563 0 r
.16512 .39073 .17532 .44389 .19621 .43575 .1857 .38393 Metetra
.846 .565 0 r
.1857 .38393 .19621 .43575 .21724 .42765 .20647 .37697 Metetra
.845 .567 0 r
.20647 .37697 .21724 .42765 .23842 .41961 .22742 .36986 Metetra
.844 .569 0 r
.22742 .36986 .23842 .41961 .25975 .41161 .24855 .3626 Metetra
.844 .571 0 r
.24855 .3626 .25975 .41161 .28124 .40368 .26987 .35523 Metetra
.843 .573 0 r
.26987 .35523 .28124 .40368 .3029 .39581 .29136 .34774 Metetra
.843 .574 0 r
.29136 .34774 .3029 .39581 .32471 .388 .31304 .34014 Metetra
.843 .575 0 r
.31304 .34014 .32471 .388 .3467 .38026 .3349 .33243 Metetra
.842 .575 0 r
.3349 .33243 .3467 .38026 .36886 .37257 .35695 .32461 Metetra
.842 .575 0 r
.35695 .32461 .36886 .37257 .39121 .36494 .37918 .31669 Metetra
.843 .575 0 r
.37918 .31669 .39121 .36494 .41373 .35738 .4016 .30866 Metetra
.843 .574 0 r
.4016 .30866 .41373 .35738 .43645 .34988 .42421 .30051 Metetra
.843 .572 0 r
.42421 .30051 .43645 .34988 .45936 .34244 .44701 .29225 Metetra
.844 .571 0 r
.44701 .29225 .45936 .34244 .48247 .33505 .47 .28385 Metetra
.845 .569 0 r
.47 .28385 .48247 .33505 .50579 .32772 .49318 .27532 Metetra
.845 .566 0 r
.49318 .27532 .50579 .32772 .52931 .32045 .51656 .26662 Metetra
.846 .564 0 r
.51656 .26662 .52931 .32045 .55306 .31322 .54013 .25775 Metetra
.847 .562 0 r
.54013 .25775 .55306 .31322 .57703 .30604 .5639 .24869 Metetra
.848 .559 0 r
.5639 .24869 .57703 .30604 .60122 .2989 .58786 .2394 Metetra
.848 .558 0 r
.58786 .2394 .60122 .2989 .62565 .29177 .61201 .22986 Metetra
.848 .558 0 r
.61201 .22986 .62565 .29177 .6503 .28429 .63633 .21972 Metetra
.841 .579 0 r
.63633 .21972 .6503 .28429 .675 .27307 .6607 .20622 Metetra
.799 .696 0 r
.6607 .20622 .675 .27307 .69886 .24374 .68442 .17785 Metetra
.353 .662 0 r
.68442 .17785 .69886 .24374 .71996 .1738 .70603 .11699 Metetra
0 .333 .297 r
.03634 .26033 .04284 .32478 .05194 .38408 .04859 .2952 Metetra
0 .496 .092 r
.04859 .2952 .05194 .38408 .06649 .41135 .06425 .31112 Metetra
.076 .569 0 r
.06425 .31112 .06649 .41135 .08485 .41448 .08236 .31262 Metetra
.142 .594 0 r
.08236 .31262 .08485 .41448 .1045 .40981 .10136 .30927 Metetra
.171 .604 0 r
.10136 .30927 .1045 .40981 .12451 .40373 .1207 .30485 Metetra
.192 .611 0 r
.1207 .30485 .12451 .40373 .14472 .39733 .14027 .3 Metetra
.211 .617 0 r
.14027 .3 .14472 .39733 .16512 .39073 .16007 .29479 Metetra
.227 .622 0 r
.16007 .29479 .16512 .39073 .1857 .38393 .18008 .28924 Metetra
.241 .627 0 r
.18008 .28924 .1857 .38393 .20647 .37697 .20031 .28336 Metetra
.253 .631 0 r
.20031 .28336 .20647 .37697 .22742 .36986 .22075 .27715 Metetra
.262 .634 0 r
.22075 .27715 .22742 .36986 .24855 .3626 .2414 .27062 Metetra
.27 .637 0 r
.2414 .27062 .24855 .3626 .26987 .35523 .26225 .2638 Metetra
.277 .638 0 r
.26225 .2638 .26987 .35523 .29136 .34774 .2833 .25667 Metetra
.281 .64 0 r
.2833 .25667 .29136 .34774 .31304 .34014 .30455 .24925 Metetra
.284 .641 0 r
.30455 .24925 .31304 .34014 .3349 .33243 .32599 .24154 Metetra
.285 .641 0 r
.32599 .24154 .3349 .33243 .35695 .32461 .34762 .23354 Metetra
.285 .641 0 r
.34762 .23354 .35695 .32461 .37918 .31669 .36945 .22524 Metetra
.283 .64 0 r
.36945 .22524 .37918 .31669 .4016 .30866 .39146 .21665 Metetra
.279 .639 0 r
.39146 .21665 .4016 .30866 .42421 .30051 .41365 .20775 Metetra
.274 .638 0 r
.41365 .20775 .42421 .30051 .44701 .29225 .43603 .19855 Metetra
.267 .635 0 r
.43603 .19855 .44701 .29225 .47 .28385 .45859 .18904 Metetra
.258 .633 0 r
.45859 .18904 .47 .28385 .49318 .27532 .48132 .17919 Metetra
.247 .629 0 r
.48132 .17919 .49318 .27532 .51656 .26662 .50423 .169 Metetra
.235 .625 0 r
.50423 .169 .51656 .26662 .54013 .25775 .5273 .15846 Metetra
.22 .62 0 r
.5273 .15846 .54013 .25775 .5639 .24869 .55053 .14755 Metetra
.203 .615 0 r
.55053 .14755 .5639 .24869 .58786 .2394 .57392 .13625 Metetra
.183 .608 0 r
.57392 .13625 .58786 .2394 .61201 .22986 .59747 .12454 Metetra
.16 .6 0 r
.59747 .12454 .61201 .22986 .63633 .21972 .62115 .11221 Metetra
.121 .586 0 r
.62115 .11221 .63633 .21972 .6607 .20622 .64488 .09765 Metetra
.016 .545 0 r
.64488 .09765 .6607 .20622 .68442 .17785 .6683 .07412 Metetra
0 .434 .196 r
.6683 .07412 .68442 .17785 .70603 .11699 .69056 .0314 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 233.562},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{145., 432.}, {528., 295.}} -> {-0.6542809413851561, \
1.1319388078367045, 0.00372925066927552, \
0.00372925066927552}},ExpressionUUID->"1ee85426-478a-4d6d-8c4c-9b9c5c3253c4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -111 0 ]
[.5 .82364 111 9 ]
[.08965 .22175 -18 -8.88375 ]
[.08965 .22175 0 .11625 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60423 .01939 -10.1877 -9 ]
[.60423 .01939 1.81231 0 ]
[.73698 .05037 0 -6.2075 ]
[.73698 .05037 18 2.7925 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95739 .38791 0 -5.88802 ]
[.95739 .38791 12 3.11198 ]
[.02412 .26509 -6 -2.7423 ]
[.02412 .26509 0 6.2577 ]
[.01077 .34875 -12 -2.8131 ]
[.01077 .34875 0 6.1869 ]
[-0.00332 .43708 -12 -2.88827 ]
[-0.00332 .43708 0 6.11173 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Difference \\(wavelengths\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72471 .05502 m
.71857 .05735 L
s
[(-10)] .73698 .05037 -1 .37944 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94486 .39177 m
.93859 .39371 L
s
[(10)] .95739 .38791 -1 .30845 Mshowa
.125 Mabswid
.75031 .09419 m
.74662 .09556 L
s
.775 .13196 m
.7713 .1333 L
s
.79883 .16841 m
.79512 .16972 L
s
.82184 .2036 m
.81812 .2049 L
s
.86557 .27049 m
.86184 .27174 L
s
.88636 .3023 m
.88262 .30352 L
s
.90649 .33308 m
.90274 .33428 L
s
.92597 .36289 m
.92222 .36407 L
s
.69814 .01439 m
.69447 .01581 L
s
.96316 .41977 m
.95939 .42091 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26032 m
.04245 .25793 L
s
[(0)] .02412 .26509 1 -0.3906 Mshowa
.02306 .34414 m
.0292 .34184 L
s
[(20)] .01077 .34875 1 -0.37487 Mshowa
.00903 .43265 m
.01521 .43044 L
s
[(40)] -0.00332 .43708 1 -0.35816 Mshowa
.125 Mabswid
.03308 .28085 m
.03676 .27943 L
s
.02979 .30167 m
.03346 .30026 L
s
.02644 .32276 m
.03013 .32137 L
s
.01962 .36581 m
.02331 .36445 L
s
.01614 .38779 m
.01984 .38643 L
s
.01261 .41006 m
.01631 .40872 L
s
.0054 .45556 m
.00911 .45425 L
s
.00172 .47879 m
.00543 .47749 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.976 .099 0 r
.38757 .79726 .39809 .8049 .41556 .80118 .40517 .79142 Metetra
.972 .117 0 r
.40517 .79142 .41556 .80118 .4332 .7955 .42294 .78377 Metetra
.961 .161 0 r
.42294 .78377 .4332 .7955 .45097 .78828 .44082 .77474 Metetra
.946 .223 0 r
.44082 .77474 .45097 .78828 .46885 .77987 .45879 .76468 Metetra
.926 .296 0 r
.45879 .76468 .46885 .77987 .48683 .77063 .47684 .75394 Metetra
.904 .374 0 r
.47684 .75394 .48683 .77063 .50488 .76084 .49496 .74281 Metetra
.882 .452 0 r
.49496 .74281 .50488 .76084 .523 .75079 .51312 .73155 Metetra
.859 .526 0 r
.51312 .73155 .523 .75079 .54118 .7407 .53135 .72041 Metetra
.836 .593 0 r
.53135 .72041 .54118 .7407 .55944 .7308 .54963 .70957 Metetra
.815 .652 0 r
.54963 .70957 .55944 .7308 .57776 .72124 .56798 .69922 Metetra
.797 .702 0 r
.56798 .69922 .57776 .72124 .59618 .71219 .58641 .68949 Metetra
.781 .742 0 r
.58641 .68949 .59618 .71219 .61469 .70376 .60493 .68051 Metetra
.763 .768 0 r
.60493 .68051 .61469 .70376 .63332 .69606 .62356 .67238 Metetra
.722 .758 0 r
.62356 .67238 .63332 .69606 .65207 .68916 .64232 .66515 Metetra
.698 .752 0 r
.64232 .66515 .65207 .68916 .67096 .6831 .66122 .65889 Metetra
.69 .75 0 r
.66122 .65889 .67096 .6831 .69002 .67792 .68028 .65362 Metetra
.698 .752 0 r
.68028 .65362 .69002 .67792 .70925 .67362 .69952 .64934 Metetra
.722 .758 0 r
.69952 .64934 .70925 .67362 .72868 .67019 .71897 .64604 Metetra
.763 .768 0 r
.71897 .64604 .72868 .67019 .74831 .66757 .73862 .64368 Metetra
.781 .742 0 r
.73862 .64368 .74831 .66757 .76816 .66571 .75851 .6422 Metetra
.797 .702 0 r
.75851 .6422 .76816 .66571 .78824 .66451 .77864 .64151 Metetra
.815 .652 0 r
.77864 .64151 .78824 .66451 .80856 .66386 .79902 .64149 Metetra
.836 .593 0 r
.79902 .64149 .80856 .66386 .8291 .66361 .81965 .64201 Metetra
.859 .526 0 r
.81965 .64201 .8291 .66361 .84987 .66357 .84053 .64289 Metetra
.882 .452 0 r
.84053 .64289 .84987 .66357 .87085 .66354 .86165 .64393 Metetra
.904 .374 0 r
.86165 .64393 .87085 .66354 .89202 .66327 .88299 .64489 Metetra
.926 .296 0 r
.88299 .64489 .89202 .66327 .91335 .66247 .90453 .64549 Metetra
.946 .223 0 r
.90453 .64549 .91335 .66247 .93478 .66082 .92621 .64541 Metetra
.961 .161 0 r
.92621 .64541 .93478 .66082 .95627 .65795 .948 .64429 Metetra
.972 .117 0 r
.948 .64429 .95627 .65795 .97774 .65345 .96982 .64173 Metetra
.976 .099 0 r
.96982 .64173 .97774 .65345 .99909 .64687 .99158 .63727 Metetra
.972 .117 0 r
.37699 .7876 .38757 .79726 .40517 .79142 .39474 .77978 Metetra
.96 .165 0 r
.39474 .77978 .40517 .79142 .42294 .78377 .41262 .77031 Metetra
.942 .235 0 r
.41262 .77031 .42294 .78377 .44082 .77474 .43061 .75961 Metetra
.92 .318 0 r
.43061 .75961 .44082 .77474 .45879 .76468 .44868 .74804 Metetra
.895 .406 0 r
.44868 .74804 .45879 .76468 .47684 .75394 .4668 .73593 Metetra
.868 .495 0 r
.4668 .73593 .47684 .75394 .49496 .74281 .48497 .72356 Metetra
.841 .58 0 r
.48497 .72356 .49496 .74281 .51312 .73155 .50319 .7112 Metetra
.814 .657 0 r
.50319 .7112 .51312 .73155 .53135 .72041 .52146 .69909 Metetra
.788 .724 0 r
.52146 .69909 .53135 .72041 .54963 .70957 .53977 .6874 Metetra
.746 .764 0 r
.53977 .6874 .54963 .70957 .56798 .69922 .55814 .67632 Metetra
.657 .743 0 r
.55814 .67632 .56798 .69922 .58641 .68949 .57659 .66597 Metetra
.584 .725 0 r
.57659 .66597 .58641 .68949 .60493 .68051 .59512 .65649 Metetra
.528 .71 0 r
.59512 .65649 .60493 .68051 .62356 .67238 .61375 .64795 Metetra
.488 .699 0 r
.61375 .64795 .62356 .67238 .64232 .66515 .63251 .64042 Metetra
.464 .693 0 r
.63251 .64042 .64232 .66515 .66122 .65889 .65141 .63397 Metetra
.456 .691 0 r
.65141 .63397 .66122 .65889 .68028 .65362 .67048 .6286 Metetra
.464 .693 0 r
.67048 .6286 .68028 .65362 .69952 .64934 .68973 .62433 Metetra
.488 .699 0 r
.68973 .62433 .69952 .64934 .71897 .64604 .70918 .62114 Metetra
.528 .71 0 r
.70918 .62114 .71897 .64604 .73862 .64368 .72885 .619 Metetra
.584 .725 0 r
.72885 .619 .73862 .64368 .75851 .6422 .74877 .61785 Metetra
.657 .743 0 r
.74877 .61785 .75851 .6422 .77864 .64151 .76893 .6176 Metetra
.746 .764 0 r
.76893 .6176 .77864 .64151 .79902 .64149 .78936 .61814 Metetra
.788 .724 0 r
.78936 .61814 .79902 .64149 .81965 .64201 .81007 .61935 Metetra
.814 .657 0 r
.81007 .61935 .81965 .64201 .84053 .64289 .83104 .62105 Metetra
.841 .58 0 r
.83104 .62105 .84053 .64289 .86165 .64393 .85228 .62304 Metetra
.868 .495 0 r
.85228 .62304 .86165 .64393 .88299 .64489 .87376 .62511 Metetra
.895 .406 0 r
.87376 .62511 .88299 .64489 .90453 .64549 .89548 .62697 Metetra
.92 .318 0 r
.89548 .62697 .90453 .64549 .92621 .64541 .91738 .62831 Metetra
.942 .235 0 r
.91738 .62831 .92621 .64541 .948 .64429 .93943 .62878 Metetra
.96 .165 0 r
.93943 .62878 .948 .64429 .96982 .64173 .96156 .62799 Metetra
.972 .117 0 r
.96156 .62799 .96982 .64173 .99158 .63727 .98368 .62548 Metetra
.961 .161 0 r
.36636 .77629 .37699 .7876 .39474 .77978 .38424 .76666 Metetra
.942 .235 0 r
.38424 .76666 .39474 .77978 .41262 .77031 .40225 .75553 Metetra
.918 .325 0 r
.40225 .75553 .41262 .77031 .43061 .75961 .42034 .7433 Metetra
.89 .423 0 r
.42034 .7433 .43061 .75961 .44868 .74804 .4385 .73034 Metetra
.86 .522 0 r
.4385 .73034 .44868 .74804 .4668 .73593 .4567 .71697 Metetra
.828 .616 0 r
.4567 .71697 .4668 .73593 .48497 .72356 .47494 .70347 Metetra
.797 .702 0 r
.47494 .70347 .48497 .72356 .50319 .7112 .49321 .69012 Metetra
.755 .766 0 r
.49321 .69012 .50319 .7112 .52146 .69909 .51151 .67711 Metetra
.633 .737 0 r
.51151 .67711 .52146 .69909 .53977 .6874 .52986 .66466 Metetra
.528 .71 0 r
.52986 .66466 .53977 .6874 .55814 .67632 .54826 .6529 Metetra
.44 .686 0 r
.54826 .6529 .55814 .67632 .57659 .66597 .56672 .642 Metetra
.369 .666 0 r
.56672 .642 .57659 .66597 .59512 .65649 .58526 .63204 Metetra
.315 .65 0 r
.58526 .63204 .59512 .65649 .61375 .64795 .6039 .62313 Metetra
.277 .639 0 r
.6039 .62313 .61375 .64795 .63251 .64042 .62266 .61533 Metetra
.255 .632 0 r
.62266 .61533 .63251 .64042 .65141 .63397 .64156 .60869 Metetra
.247 .629 0 r
.64156 .60869 .65141 .63397 .67048 .6286 .66063 .60323 Metetra
.255 .632 0 r
.66063 .60323 .67048 .6286 .68973 .62433 .67988 .59895 Metetra
.277 .639 0 r
.67988 .59895 .68973 .62433 .70918 .62114 .69934 .59585 Metetra
.315 .65 0 r
.69934 .59585 .70918 .62114 .72885 .619 .71902 .5939 Metetra
.369 .666 0 r
.71902 .5939 .72885 .619 .74877 .61785 .73895 .59302 Metetra
.44 .686 0 r
.73895 .59302 .74877 .61785 .76893 .6176 .75915 .59315 Metetra
.528 .71 0 r
.75915 .59315 .76893 .6176 .78936 .61814 .77962 .59419 Metetra
.633 .737 0 r
.77962 .59419 .78936 .61814 .81007 .61935 .80038 .596 Metetra
.755 .766 0 r
.80038 .596 .81007 .61935 .83104 .62105 .82143 .59842 Metetra
.797 .702 0 r
.82143 .59842 .83104 .62105 .85228 .62304 .84276 .60127 Metetra
.828 .616 0 r
.84276 .60127 .85228 .62304 .87376 .62511 .86438 .60432 Metetra
.86 .522 0 r
.86438 .60432 .87376 .62511 .89548 .62697 .88625 .60731 Metetra
.89 .423 0 r
.88625 .60731 .89548 .62697 .91738 .62831 .90834 .60994 Metetra
.918 .325 0 r
.90834 .60994 .91738 .62831 .93943 .62878 .93062 .61185 Metetra
.942 .235 0 r
.93062 .61185 .93943 .62878 .96156 .62799 .95302 .61265 Metetra
.961 .161 0 r
.95302 .61265 .96156 .62799 .98368 .62548 .97547 .61191 Metetra
.946 .223 0 r
.35566 .76372 .36636 .77629 .38424 .76666 .37369 .75242 Metetra
.92 .318 0 r
.37369 .75242 .38424 .76666 .40225 .75553 .39181 .73976 Metetra
.89 .423 0 r
.39181 .73976 .40225 .75553 .42034 .7433 .41001 .72614 Metetra
.857 .531 0 r
.41001 .72614 .42034 .7433 .4385 .73034 .42826 .71192 Metetra
.822 .634 0 r
.42826 .71192 .4385 .73034 .4567 .71697 .44654 .69741 Metetra
.786 .729 0 r
.44654 .69741 .4567 .71697 .47494 .70347 .46485 .6829 Metetra
.69 .751 0 r
.46485 .6829 .47494 .70347 .49321 .69012 .48317 .66863 Metetra
.552 .716 0 r
.48317 .66863 .49321 .69012 .51151 .67711 .50152 .65482 Metetra
.432 .684 0 r
.50152 .65482 .51151 .67711 .52986 .66466 .5199 .64166 Metetra
.331 .655 0 r
.5199 .64166 .52986 .66466 .54826 .6529 .53832 .62931 Metetra
.247 .629 0 r
.53832 .62931 .54826 .6529 .56672 .642 .5568 .61788 Metetra
.182 .607 0 r
.5568 .61788 .56672 .642 .58526 .63204 .57536 .6075 Metetra
.132 .59 0 r
.57536 .6075 .58526 .63204 .6039 .62313 .59401 .59825 Metetra
.098 .577 0 r
.59401 .59825 .6039 .62313 .62266 .61533 .61277 .5902 Metetra
.077 .57 0 r
.61277 .5902 .62266 .61533 .64156 .60869 .63168 .58337 Metetra
.071 .567 0 r
.63168 .58337 .64156 .60869 .66063 .60323 .65074 .57782 Metetra
.077 .57 0 r
.65074 .57782 .66063 .60323 .67988 .59895 .67 .57353 Metetra
.098 .577 0 r
.67 .57353 .67988 .59895 .69934 .59585 .68946 .5705 Metetra
.132 .59 0 r
.68946 .5705 .69934 .59585 .71902 .5939 .70915 .56869 Metetra
.182 .607 0 r
.70915 .56869 .71902 .5939 .73895 .59302 .7291 .56806 Metetra
.247 .629 0 r
.7291 .56806 .73895 .59302 .75915 .59315 .74932 .56852 Metetra
.331 .655 0 r
.74932 .56852 .75915 .59315 .77962 .59419 .76982 .56998 Metetra
.432 .684 0 r
.76982 .56998 .77962 .59419 .80038 .596 .79063 .57232 Metetra
.552 .716 0 r
.79063 .57232 .80038 .596 .82143 .59842 .81174 .57538 Metetra
.69 .751 0 r
.81174 .57538 .82143 .59842 .84276 .60127 .83316 .57898 Metetra
.786 .729 0 r
.83316 .57898 .84276 .60127 .86438 .60432 .85488 .5829 Metetra
.822 .634 0 r
.85488 .5829 .86438 .60432 .88625 .60731 .87688 .58689 Metetra
.857 .531 0 r
.87688 .58689 .88625 .60731 .90834 .60994 .89914 .59066 Metetra
.89 .423 0 r
.89914 .59066 .90834 .60994 .93062 .61185 .92162 .59386 Metetra
.92 .318 0 r
.92162 .59386 .93062 .61185 .95302 .61265 .94427 .59611 Metetra
.946 .223 0 r
.94427 .59611 .95302 .61265 .97547 .61191 .96701 .59697 Metetra
.926 .296 0 r
.3449 .75021 .35566 .76372 .37369 .75242 .36306 .7374 Metetra
.895 .406 0 r
.36306 .7374 .37369 .75242 .39181 .73976 .38131 .72336 Metetra
.86 .522 0 r
.38131 .72336 .39181 .73976 .41001 .72614 .39962 .70847 Metetra
.822 .634 0 r
.39962 .70847 .41001 .72614 .42826 .71192 .41796 .69311 Metetra
.782 .738 0 r
.41796 .69311 .42826 .71192 .44654 .69741 .43632 .67757 Metetra
.657 .743 0 r
.43632 .67757 .44654 .69741 .46485 .6829 .4547 .66213 Metetra
.504 .704 0 r
.4547 .66213 .46485 .6829 .48317 .66863 .47308 .64704 Metetra
.369 .666 0 r
.47308 .64704 .48317 .66863 .50152 .65482 .49148 .63251 Metetra
.255 .632 0 r
.49148 .63251 .50152 .65482 .5199 .64166 .5099 .61872 Metetra
.16 .6 0 r
.5099 .61872 .5199 .64166 .53832 .62931 .52835 .60581 Metetra
.084 .572 0 r
.52835 .60581 .53832 .62931 .5568 .61788 .54685 .59392 Metetra
.025 .549 0 r
.54685 .59392 .5568 .61788 .57536 .6075 .56542 .58316 Metetra
0 .53 .018 r
.56542 .58316 .57536 .6075 .59401 .59825 .58408 .57359 Metetra
0 .517 .048 r
.58408 .57359 .59401 .59825 .61277 .5902 .60286 .5653 Metetra
0 .509 .065 r
.60286 .5653 .61277 .5902 .63168 .58337 .62177 .55831 Metetra
0 .506 .071 r
.62177 .55831 .63168 .58337 .65074 .57782 .64084 .55265 Metetra
0 .509 .065 r
.64084 .55265 .65074 .57782 .67 .57353 .66009 .54834 Metetra
0 .517 .048 r
.66009 .54834 .67 .57353 .68946 .5705 .67956 .54536 Metetra
0 .53 .018 r
.67956 .54536 .68946 .5705 .70915 .56869 .69926 .54367 Metetra
.025 .549 0 r
.69926 .54367 .70915 .56869 .7291 .56806 .71921 .54324 Metetra
.084 .572 0 r
.71921 .54324 .7291 .56806 .74932 .56852 .73945 .54398 Metetra
.16 .6 0 r
.73945 .54398 .74932 .56852 .76982 .56998 .75998 .54581 Metetra
.255 .632 0 r
.75998 .54581 .76982 .56998 .79063 .57232 .78083 .5486 Metetra
.369 .666 0 r
.78083 .5486 .79063 .57232 .81174 .57538 .80199 .55222 Metetra
.504 .704 0 r
.80199 .55222 .81174 .57538 .83316 .57898 .82348 .55647 Metetra
.657 .743 0 r
.82348 .55647 .83316 .57898 .85488 .5829 .84529 .56116 Metetra
.782 .738 0 r
.84529 .56116 .85488 .5829 .87688 .58689 .86741 .56604 Metetra
.822 .634 0 r
.86741 .56604 .87688 .58689 .89914 .59066 .88982 .57082 Metetra
.86 .522 0 r
.88982 .57082 .89914 .59066 .92162 .59386 .91248 .57516 Metetra
.895 .406 0 r
.91248 .57516 .92162 .59386 .94427 .59611 .93534 .57869 Metetra
.926 .296 0 r
.93534 .57869 .94427 .59611 .96701 .59697 .95834 .58099 Metetra
.904 .374 0 r
.33406 .73606 .3449 .75021 .36306 .7374 .35236 .72188 Metetra
.868 .495 0 r
.35236 .72188 .36306 .7374 .38131 .72336 .37073 .70659 Metetra
.828 .616 0 r
.37073 .70659 .38131 .72336 .39962 .70847 .38915 .69058 Metetra
.786 .729 0 r
.38915 .69058 .39962 .70847 .41796 .69311 .40759 .67418 Metetra
.657 .743 0 r
.40759 .67418 .41796 .69311 .43632 .67757 .42604 .65771 Metetra
.488 .699 0 r
.42604 .65771 .43632 .67757 .4547 .66213 .44448 .64145 Metetra
.338 .657 0 r
.44448 .64145 .4547 .66213 .47308 .64704 .46293 .62562 Metetra
.211 .617 0 r
.46293 .62562 .47308 .64704 .49148 .63251 .48138 .61044 Metetra
.104 .58 0 r
.48138 .61044 .49148 .63251 .5099 .61872 .49984 .59607 Metetra
.019 .546 0 r
.49984 .59607 .5099 .61872 .52835 .60581 .51833 .58267 Metetra
0 .517 .048 r
.51833 .58267 .52835 .60581 .54685 .59392 .53686 .57036 Metetra
0 .492 .099 r
.53686 .57036 .54685 .59392 .56542 .58316 .55545 .55924 Metetra
0 .473 .135 r
.55545 .55924 .56542 .58316 .58408 .57359 .57413 .54939 Metetra
0 .458 .159 r
.57413 .54939 .58408 .57359 .60286 .5653 .59291 .54087 Metetra
0 .45 .173 r
.59291 .54087 .60286 .5653 .62177 .55831 .61183 .53373 Metetra
0 .447 .177 r
.61183 .53373 .62177 .55831 .64084 .55265 .63091 .52798 Metetra
0 .45 .173 r
.63091 .52798 .64084 .55265 .66009 .54834 .65017 .52363 Metetra
0 .458 .159 r
.65017 .52363 .66009 .54834 .67956 .54536 .66964 .52068 Metetra
0 .473 .135 r
.66964 .52068 .67956 .54536 .69926 .54367 .68935 .51909 Metetra
0 .492 .099 r
.68935 .51909 .69926 .54367 .71921 .54324 .70932 .51882 Metetra
0 .517 .048 r
.70932 .51882 .71921 .54324 .73945 .54398 .72957 .5198 Metetra
.019 .546 0 r
.72957 .5198 .73945 .54398 .75998 .54581 .75013 .52194 Metetra
.104 .58 0 r
.75013 .52194 .75998 .54581 .78083 .5486 .771 .52512 Metetra
.211 .617 0 r
.771 .52512 .78083 .5486 .80199 .55222 .79221 .52921 Metetra
.338 .657 0 r
.79221 .52921 .80199 .55222 .82348 .55647 .81377 .53404 Metetra
.488 .699 0 r
.81377 .53404 .82348 .55647 .84529 .56116 .83566 .5394 Metetra
.657 .743 0 r
.83566 .5394 .84529 .56116 .86741 .56604 .85788 .54505 Metetra
.786 .729 0 r
.85788 .54505 .86741 .56604 .88982 .57082 .88041 .55071 Metetra
.828 .616 0 r
.88041 .55071 .88982 .57082 .91248 .57516 .90323 .55607 Metetra
.868 .495 0 r
.90323 .55607 .91248 .57516 .93534 .57869 .92628 .56073 Metetra
.904 .374 0 r
.92628 .56073 .93534 .57869 .95834 .58099 .9495 .56429 Metetra
.882 .452 0 r
.32313 .72153 .33406 .73606 .35236 .72188 .34156 .70614 Metetra
.841 .58 0 r
.34156 .70614 .35236 .72188 .37073 .70659 .36006 .68973 Metetra
.797 .702 0 r
.36006 .68973 .37073 .70659 .38915 .69058 .37859 .6727 Metetra
.69 .751 0 r
.37859 .6727 .38915 .69058 .40759 .67418 .39713 .65538 Metetra
.504 .704 0 r
.39713 .65538 .40759 .67418 .42604 .65771 .41567 .63809 Metetra
.338 .657 0 r
.41567 .63809 .42604 .65771 .44448 .64145 .43419 .62108 Metetra
.196 .612 0 r
.43419 .62108 .44448 .64145 .46293 .62562 .45271 .6046 Metetra
.077 .57 0 r
.45271 .6046 .46293 .62562 .48138 .61044 .47122 .58883 Metetra
0 .531 .018 r
.47122 .58883 .48138 .61044 .49984 .59607 .48973 .57395 Metetra
0 .495 .093 r
.48973 .57395 .49984 .59607 .51833 .58267 .50826 .56011 Metetra
0 .464 .15 r
.50826 .56011 .51833 .58267 .53686 .57036 .52682 .54742 Metetra
0 .438 .191 r
.52682 .54742 .53686 .57036 .55545 .55924 .54544 .53598 Metetra
0 .417 .219 r
.54544 .53598 .55545 .55924 .57413 .54939 .56414 .52587 Metetra
0 .403 .237 r
.56414 .52587 .57413 .54939 .59291 .54087 .58294 .51715 Metetra
0 .393 .247 r
.58294 .51715 .59291 .54087 .61183 .53373 .60187 .50985 Metetra
0 .39 .25 r
.60187 .50985 .61183 .53373 .63091 .52798 .62096 .504 Metetra
0 .393 .247 r
.62096 .504 .63091 .52798 .65017 .52363 .64023 .49962 Metetra
0 .403 .237 r
.64023 .49962 .65017 .52363 .66964 .52068 .65971 .49668 Metetra
0 .417 .219 r
.65971 .49668 .66964 .52068 .68935 .51909 .67943 .49516 Metetra
0 .438 .191 r
.67943 .49516 .68935 .51909 .70932 .51882 .69941 .49502 Metetra
0 .464 .15 r
.69941 .49502 .70932 .51882 .72957 .5198 .71968 .4962 Metetra
0 .495 .093 r
.71968 .4962 .72957 .5198 .75013 .52194 .74026 .49859 Metetra
0 .531 .018 r
.74026 .49859 .75013 .52194 .771 .52512 .76117 .50211 Metetra
.077 .57 0 r
.76117 .50211 .771 .52512 .79221 .52921 .78242 .50661 Metetra
.196 .612 0 r
.78242 .50661 .79221 .52921 .81377 .53404 .80402 .51192 Metetra
.338 .657 0 r
.80402 .51192 .81377 .53404 .83566 .5394 .82598 .51785 Metetra
.504 .704 0 r
.82598 .51785 .83566 .5394 .85788 .54505 .8483 .52417 Metetra
.69 .751 0 r
.8483 .52417 .85788 .54505 .88041 .55071 .87094 .53061 Metetra
.797 .702 0 r
.87094 .53061 .88041 .55071 .90323 .55607 .89389 .53684 Metetra
.841 .58 0 r
.89389 .53684 .90323 .55607 .92628 .56073 .91711 .5425 Metetra
.882 .452 0 r
.91711 .5425 .92628 .56073 .9495 .56429 .94054 .54717 Metetra
.859 .526 0 r
.31209 .70688 .32313 .72153 .34156 .70614 .33066 .6904 Metetra
.814 .657 0 r
.33066 .6904 .34156 .70614 .36006 .68973 .34929 .67301 Metetra
.755 .766 0 r
.34929 .67301 .36006 .68973 .37859 .6727 .36794 .65507 Metetra
.552 .716 0 r
.36794 .65507 .37859 .6727 .39713 .65538 .38658 .63694 Metetra
.369 .666 0 r
.38658 .63694 .39713 .65538 .41567 .63809 .40521 .61891 Metetra
.211 .617 0 r
.40521 .61891 .41567 .63809 .43419 .62108 .42382 .60125 Metetra
.077 .57 0 r
.42382 .60125 .43419 .62108 .45271 .6046 .44241 .58417 Metetra
0 .525 .03 r
.44241 .58417 .45271 .6046 .47122 .58883 .46098 .56789 Metetra
0 .484 .114 r
.46098 .56789 .47122 .58883 .48973 .57395 .47955 .55255 Metetra
0 .447 .177 r
.47955 .55255 .48973 .57395 .50826 .56011 .49813 .53831 Metetra
0 .414 .223 r
.49813 .53831 .50826 .56011 .52682 .54742 .51673 .52528 Metetra
0 .387 .254 r
.51673 .52528 .52682 .54742 .54544 .53598 .53539 .51355 Metetra
0 .366 .274 r
.53539 .51355 .54544 .53598 .56414 .52587 .55412 .5032 Metetra
0 .35 .286 r
.55412 .5032 .56414 .52587 .58294 .51715 .57294 .49429 Metetra
0 .341 .292 r
.57294 .49429 .58294 .51715 .60187 .50985 .59189 .48685 Metetra
0 .338 .294 r
.59189 .48685 .60187 .50985 .62096 .504 .61099 .48091 Metetra
0 .341 .292 r
.61099 .48091 .62096 .504 .64023 .49962 .63028 .47648 Metetra
0 .35 .286 r
.63028 .47648 .64023 .49962 .65971 .49668 .64977 .47354 Metetra
0 .366 .274 r
.64977 .47354 .65971 .49668 .67943 .49516 .6695 .47207 Metetra
0 .387 .254 r
.6695 .47207 .67943 .49516 .69941 .49502 .6895 .47204 Metetra
0 .414 .223 r
.6895 .47204 .69941 .49502 .71968 .4962 .70978 .47336 Metetra
0 .447 .177 r
.70978 .47336 .71968 .4962 .74026 .49859 .73039 .47597 Metetra
0 .484 .114 r
.73039 .47597 .74026 .49859 .76117 .50211 .75132 .47976 Metetra
0 .525 .03 r
.75132 .47976 .76117 .50211 .78242 .50661 .77262 .4846 Metetra
.077 .57 0 r
.77262 .4846 .78242 .50661 .80402 .51192 .79427 .49033 Metetra
.211 .617 0 r
.79427 .49033 .80402 .51192 .82598 .51785 .81629 .49675 Metetra
.369 .666 0 r
.81629 .49675 .82598 .51785 .8483 .52417 .83869 .50364 Metetra
.552 .716 0 r
.83869 .50364 .8483 .52417 .87094 .53061 .86143 .51074 Metetra
.755 .766 0 r
.86143 .51074 .87094 .53061 .89389 .53684 .88451 .51772 Metetra
.814 .657 0 r
.88451 .51772 .89389 .53684 .91711 .5425 .90788 .52424 Metetra
.859 .526 0 r
.90788 .52424 .91711 .5425 .94054 .54717 .93149 .52988 Metetra
.836 .593 0 r
.30094 .69231 .31209 .70688 .33066 .6904 .31965 .67487 Metetra
.788 .724 0 r
.31965 .67487 .33066 .6904 .34929 .67301 .3384 .65661 Metetra
.633 .737 0 r
.3384 .65661 .34929 .67301 .36794 .65507 .35717 .63788 Metetra
.432 .684 0 r
.35717 .63788 .36794 .65507 .38658 .63694 .37592 .61903 Metetra
.255 .632 0 r
.37592 .61903 .38658 .63694 .40521 .61891 .39465 .60036 Metetra
.105 .58 0 r
.39465 .60036 .40521 .61891 .42382 .60125 .41335 .58211 Metetra
0 .531 .018 r
.41335 .58211 .42382 .60125 .44241 .58417 .43202 .56452 Metetra
0 .484 .114 r
.43202 .56452 .44241 .58417 .46098 .56789 .45066 .54777 Metetra
0 .441 .186 r
.45066 .54777 .46098 .56789 .47955 .55255 .46929 .53203 Metetra
0 .403 .237 r
.46929 .53203 .47955 .55255 .49813 .53831 .48793 .51744 Metetra
0 .369 .271 r
.48793 .51744 .49813 .53831 .51673 .52528 .50658 .5041 Metetra
0 .341 .292 r
.50658 .5041 .51673 .52528 .53539 .51355 .52528 .49211 Metetra
0 .319 .303 r
.52528 .49211 .53539 .51355 .55412 .5032 .54404 .48155 Metetra
0 .296 .303 r
.54404 .48155 .55412 .5032 .57294 .49429 .5629 .47246 Metetra
0 .274 .293 r
.5629 .47246 .57294 .49429 .59189 .48685 .58187 .46489 Metetra
0 .267 .29 r
.58187 .46489 .59189 .48685 .61099 .48091 .601 .45885 Metetra
0 .274 .293 r
.601 .45885 .61099 .48091 .63028 .47648 .6203 .45437 Metetra
0 .296 .303 r
.6203 .45437 .63028 .47648 .64977 .47354 .63982 .45142 Metetra
0 .319 .303 r
.63982 .45142 .64977 .47354 .6695 .47207 .65957 .44998 Metetra
0 .341 .292 r
.65957 .44998 .6695 .47207 .6895 .47204 .67958 .45002 Metetra
0 .369 .271 r
.67958 .45002 .6895 .47204 .70978 .47336 .69989 .45147 Metetra
0 .403 .237 r
.69989 .45147 .70978 .47336 .73039 .47597 .72052 .45425 Metetra
0 .441 .186 r
.72052 .45425 .73039 .47597 .75132 .47976 .74148 .45826 Metetra
0 .484 .114 r
.74148 .45826 .75132 .47976 .77262 .4846 .76281 .46338 Metetra
0 .531 .018 r
.76281 .46338 .77262 .4846 .79427 .49033 .78451 .46944 Metetra
.105 .58 0 r
.78451 .46944 .79427 .49033 .81629 .49675 .8066 .47627 Metetra
.255 .632 0 r
.8066 .47627 .81629 .49675 .83869 .50364 .82906 .48364 Metetra
.432 .684 0 r
.82906 .48364 .83869 .50364 .86143 .51074 .8519 .4913 Metetra
.633 .737 0 r
.8519 .4913 .86143 .51074 .88451 .51772 .87509 .49892 Metetra
.788 .724 0 r
.87509 .49892 .88451 .51772 .90788 .52424 .89859 .50617 Metetra
.836 .593 0 r
.89859 .50617 .90788 .52424 .93149 .52988 .92237 .51263 Metetra
.815 .652 0 r
.28965 .67799 .30094 .69231 .31965 .67487 .3085 .65973 Metetra
.747 .764 0 r
.3085 .65973 .31965 .67487 .3384 .65661 .32738 .64071 Metetra
.528 .71 0 r
.32738 .64071 .3384 .65661 .35717 .63788 .34627 .62129 Metetra
.331 .655 0 r
.34627 .62129 .35717 .63788 .37592 .61903 .36514 .60182 Metetra
.16 .6 0 r
.36514 .60182 .37592 .61903 .39465 .60036 .38397 .58258 Metetra
.019 .546 0 r
.38397 .58258 .39465 .60036 .41335 .58211 .40277 .56383 Metetra
0 .495 .093 r
.40277 .56383 .41335 .58211 .43202 .56452 .42152 .54579 Metetra
0 .447 .177 r
.42152 .54579 .43202 .56452 .45066 .54777 .44024 .52864 Metetra
0 .403 .237 r
.44024 .52864 .45066 .54777 .46929 .53203 .45895 .51254 Metetra
0 .363 .276 r
.45895 .51254 .46929 .53203 .48793 .51744 .47764 .49763 Metetra
0 .328 .299 r
.47764 .49763 .48793 .51744 .50658 .5041 .49635 .48402 Metetra
0 .289 .299 r
.49635 .48402 .50658 .5041 .52528 .49211 .5151 .4718 Metetra
0 .239 .277 r
.5151 .4718 .52528 .49211 .54404 .48155 .53391 .46104 Metetra
0 .206 .26 r
.53391 .46104 .54404 .48155 .5629 .47246 .5528 .45179 Metetra
0 .187 .25 r
.5528 .45179 .5629 .47246 .58187 .46489 .57182 .44409 Metetra
0 .181 .247 r
.57182 .44409 .58187 .46489 .601 .45885 .59097 .43796 Metetra
0 .187 .25 r
.59097 .43796 .601 .45885 .6203 .45437 .6103 .43342 Metetra
0 .206 .26 r
.6103 .43342 .6203 .45437 .63982 .45142 .62984 .43044 Metetra
0 .239 .277 r
.62984 .43044 .63982 .45142 .65957 .44998 .64962 .42902 Metetra
0 .289 .299 r
.64962 .42902 .65957 .44998 .67958 .45002 .66966 .42911 Metetra
0 .328 .299 r
.66966 .42911 .67958 .45002 .69989 .45147 .68999 .43064 Metetra
0 .363 .276 r
.68999 .43064 .69989 .45147 .72052 .45425 .71065 .43355 Metetra
0 .403 .237 r
.71065 .43355 .72052 .45425 .74148 .45826 .73165 .43774 Metetra
0 .447 .177 r
.73165 .43774 .74148 .45826 .76281 .46338 .75301 .44308 Metetra
0 .495 .093 r
.75301 .44308 .76281 .46338 .78451 .46944 .77476 .44942 Metetra
.019 .546 0 r
.77476 .44942 .78451 .46944 .8066 .47627 .7969 .45659 Metetra
.16 .6 0 r
.7969 .45659 .8066 .47627 .82906 .48364 .81943 .46435 Metetra
.331 .655 0 r
.81943 .46435 .82906 .48364 .8519 .4913 .84236 .47246 Metetra
.528 .71 0 r
.84236 .47246 .8519 .4913 .87509 .49892 .86565 .48062 Metetra
.747 .764 0 r
.86565 .48062 .87509 .49892 .89859 .50617 .88927 .48847 Metetra
.815 .652 0 r
.88927 .48847 .89859 .50617 .92237 .51263 .91319 .49562 Metetra
.797 .702 0 r
.27821 .66407 .28965 .67799 .3085 .65973 .2972 .64511 Metetra
.657 .743 0 r
.2972 .64511 .3085 .65973 .32738 .64071 .31622 .62545 Metetra
.44 .686 0 r
.31622 .62545 .32738 .64071 .34627 .62129 .33523 .60545 Metetra
.247 .629 0 r
.33523 .60545 .34627 .62129 .36514 .60182 .35422 .58544 Metetra
.084 .572 0 r
.35422 .58544 .36514 .60182 .38397 .58258 .37316 .56572 Metetra
0 .517 .048 r
.37316 .56572 .38397 .58258 .40277 .56383 .39205 .54653 Metetra
0 .464 .15 r
.39205 .54653 .40277 .56383 .42152 .54579 .4109 .52809 Metetra
0 .414 .223 r
.4109 .52809 .42152 .54579 .44024 .52864 .42971 .51059 Metetra
0 .369 .271 r
.42971 .51059 .44024 .52864 .45895 .51254 .44849 .49419 Metetra
0 .328 .299 r
.44849 .49419 .45895 .51254 .47764 .49763 .46726 .479 Metetra
0 .274 .293 r
.46726 .479 .47764 .49763 .49635 .48402 .48604 .46515 Metetra
0 .213 .263 r
.48604 .46515 .49635 .48402 .5151 .4718 .50484 .45272 Metetra
0 .169 .24 r
.50484 .45272 .5151 .4718 .53391 .46104 .52371 .44178 Metetra
0 .141 .223 r
.52371 .44178 .53391 .46104 .5528 .45179 .54265 .43238 Metetra
0 .125 .213 r
.54265 .43238 .5528 .45179 .57182 .44409 .5617 .42456 Metetra
0 .12 .209 r
.5617 .42456 .57182 .44409 .59097 .43796 .5809 .41834 Metetra
0 .125 .213 r
.5809 .41834 .59097 .43796 .6103 .43342 .60027 .41374 Metetra
0 .141 .223 r
.60027 .41374 .6103 .43342 .62984 .43044 .61984 .41073 Metetra
0 .169 .24 r
.61984 .41073 .62984 .43044 .64962 .42902 .63964 .4093 Metetra
0 .213 .263 r
.63964 .4093 .64962 .42902 .66966 .42911 .65972 .40941 Metetra
0 .274 .293 r
.65972 .40941 .66966 .42911 .68999 .43064 .68008 .41101 Metetra
0 .328 .299 r
.68008 .41101 .68999 .43064 .71065 .43355 .70077 .41401 Metetra
0 .369 .271 r
.70077 .41401 .71065 .43355 .73165 .43774 .72181 .41833 Metetra
0 .414 .223 r
.72181 .41833 .73165 .43774 .75301 .44308 .74322 .42384 Metetra
0 .464 .15 r
.74322 .42384 .75301 .44308 .77476 .44942 .76501 .4304 Metetra
0 .517 .048 r
.76501 .4304 .77476 .44942 .7969 .45659 .78721 .43782 Metetra
.084 .572 0 r
.78721 .43782 .7969 .45659 .81943 .46435 .80981 .44589 Metetra
.247 .629 0 r
.80981 .44589 .81943 .46435 .84236 .47246 .83281 .45437 Metetra
.44 .686 0 r
.83281 .45437 .84236 .47246 .86565 .48062 .85619 .46295 Metetra
.657 .743 0 r
.85619 .46295 .86565 .48062 .88927 .48847 .87993 .47129 Metetra
.797 .702 0 r
.87993 .47129 .88927 .48847 .91319 .49562 .90398 .479 Metetra
.781 .742 0 r
.2666 .6507 .27821 .66407 .2972 .64511 .28573 .63115 Metetra
.584 .725 0 r
.28573 .63115 .2972 .64511 .31622 .62545 .30488 .61095 Metetra
.369 .666 0 r
.30488 .61095 .31622 .62545 .33523 .60545 .32403 .59046 Metetra
.182 .607 0 r
.32403 .59046 .33523 .60545 .35422 .58544 .34313 .57 Metetra
.025 .549 0 r
.34313 .57 .35422 .58544 .37316 .56572 .36219 .54987 Metetra
0 .492 .099 r
.36219 .54987 .37316 .56572 .39205 .54653 .3812 .53032 Metetra
0 .438 .191 r
.3812 .53032 .39205 .54653 .4109 .52809 .40015 .51155 Metetra
0 .387 .254 r
.40015 .51155 .4109 .52809 .42971 .51059 .41905 .49375 Metetra
0 .341 .292 r
.41905 .49375 .42971 .51059 .44849 .49419 .43792 .47707 Metetra
0 .289 .299 r
.43792 .47707 .44849 .49419 .46726 .479 .45677 .46165 Metetra
0 .213 .263 r
.45677 .46165 .46726 .479 .48604 .46515 .47562 .44758 Metetra
0 .158 .233 r
.47562 .44758 .48604 .46515 .50484 .45272 .49449 .43497 Metetra
0 .12 .209 r
.49449 .43497 .50484 .45272 .52371 .44178 .51342 .42386 Metetra
0 .096 .192 r
.51342 .42386 .52371 .44178 .54265 .43238 .53242 .41433 Metetra
0 .082 .182 r
.53242 .41433 .54265 .43238 .5617 .42456 .55153 .4064 Metetra
0 .078 .178 r
.55153 .4064 .5617 .42456 .5809 .41834 .57077 .40009 Metetra
0 .082 .182 r
.57077 .40009 .5809 .41834 .60027 .41374 .59018 .39541 Metetra
0 .096 .192 r
.59018 .39541 .60027 .41374 .61984 .41073 .6098 .39236 Metetra
0 .12 .209 r
.6098 .39236 .61984 .41073 .63964 .4093 .62964 .39091 Metetra
0 .158 .233 r
.62964 .39091 .63964 .4093 .65972 .40941 .64975 .39103 Metetra
0 .213 .263 r
.64975 .39103 .65972 .40941 .68008 .41101 .67016 .39266 Metetra
0 .289 .299 r
.67016 .39266 .68008 .41101 .70077 .41401 .69088 .39572 Metetra
0 .341 .292 r
.69088 .39572 .70077 .41401 .72181 .41833 .71196 .40013 Metetra
0 .387 .254 r
.71196 .40013 .72181 .41833 .74322 .42384 .73342 .40576 Metetra
0 .438 .191 r
.73342 .40576 .74322 .42384 .76501 .4304 .75526 .41247 Metetra
0 .492 .099 r
.75526 .41247 .76501 .4304 .78721 .43782 .77752 .42008 Metetra
.025 .549 0 r
.77752 .42008 .78721 .43782 .80981 .44589 .80018 .42839 Metetra
.182 .607 0 r
.80018 .42839 .80981 .44589 .83281 .45437 .82326 .43715 Metetra
.369 .666 0 r
.82326 .43715 .83281 .45437 .85619 .46295 .84673 .44605 Metetra
.584 .725 0 r
.84673 .44605 .85619 .46295 .87993 .47129 .87057 .45477 Metetra
.781 .742 0 r
.87057 .45477 .87993 .47129 .90398 .479 .89475 .4629 Metetra
.763 .768 0 r
.2548 .63796 .2666 .6507 .28573 .63115 .27407 .61795 Metetra
.528 .71 0 r
.27407 .61795 .28573 .63115 .30488 .61095 .29337 .59731 Metetra
.315 .65 0 r
.29337 .59731 .30488 .61095 .32403 .59046 .31264 .57642 Metetra
.132 .59 0 r
.31264 .57642 .32403 .59046 .34313 .57 .33188 .5556 Metetra
0 .53 .018 r
.33188 .5556 .34313 .57 .36219 .54987 .35106 .53513 Metetra
0 .473 .135 r
.35106 .53513 .36219 .54987 .3812 .53032 .37018 .51527 Metetra
0 .417 .219 r
.37018 .51527 .3812 .53032 .40015 .51155 .38924 .49622 Metetra
0 .366 .274 r
.38924 .49622 .40015 .51155 .41905 .49375 .40824 .47817 Metetra
0 .319 .303 r
.40824 .47817 .41905 .49375 .43792 .47707 .42721 .46127 Metetra
0 .239 .277 r
.42721 .46127 .43792 .47707 .45677 .46165 .44615 .44564 Metetra
0 .169 .24 r
.44615 .44564 .45677 .46165 .47562 .44758 .46508 .43139 Metetra
0 .12 .209 r
.46508 .43139 .47562 .44758 .49449 .43497 .48403 .41861 Metetra
0 .087 .185 r
.48403 .41861 .49449 .43497 .51342 .42386 .50303 .40736 Metetra
0 .066 .168 r
.50303 .40736 .51342 .42386 .53242 .41433 .5221 .3977 Metetra
0 .055 .157 r
.5221 .3977 .53242 .41433 .55153 .4064 .54127 .38966 Metetra
0 .051 .154 r
.54127 .38966 .55153 .4064 .57077 .40009 .56057 .38327 Metetra
0 .055 .157 r
.56057 .38327 .57077 .40009 .59018 .39541 .58004 .37852 Metetra
0 .066 .168 r
.58004 .37852 .59018 .39541 .6098 .39236 .5997 .37542 Metetra
0 .087 .185 r
.5997 .37542 .6098 .39236 .62964 .39091 .6196 .37393 Metetra
0 .12 .209 r
.6196 .37393 .62964 .39091 .64975 .39103 .63975 .37403 Metetra
0 .169 .24 r
.63975 .37403 .64975 .39103 .67016 .39266 .6602 .37566 Metetra
0 .239 .277 r
.6602 .37566 .67016 .39266 .69088 .39572 .68098 .37875 Metetra
0 .319 .303 r
.68098 .37875 .69088 .39572 .71196 .40013 .70211 .38321 Metetra
0 .366 .274 r
.70211 .38321 .71196 .40013 .73342 .40576 .72361 .38891 Metetra
0 .417 .219 r
.72361 .38891 .73342 .40576 .75526 .41247 .74551 .39573 Metetra
0 .473 .135 r
.74551 .39573 .75526 .41247 .77752 .42008 .76782 .40347 Metetra
0 .53 .018 r
.76782 .40347 .77752 .42008 .80018 .42839 .79055 .41194 Metetra
.132 .59 0 r
.79055 .41194 .80018 .42839 .82326 .43715 .8137 .42089 Metetra
.315 .65 0 r
.8137 .42089 .82326 .43715 .84673 .44605 .83726 .43002 Metetra
.528 .71 0 r
.83726 .43002 .84673 .44605 .87057 .45477 .86121 .439 Metetra
.763 .768 0 r
.86121 .439 .87057 .45477 .89475 .4629 .88549 .44744 Metetra
.722 .758 0 r
.2428 .62593 .2548 .63796 .27407 .61795 .26222 .60556 Metetra
.488 .699 0 r
.26222 .60556 .27407 .61795 .29337 .59731 .28165 .5846 Metetra
.277 .639 0 r
.28165 .5846 .29337 .59731 .31264 .57642 .30106 .5634 Metetra
.098 .577 0 r
.30106 .5634 .31264 .57642 .33188 .5556 .32043 .5423 Metetra
0 .517 .048 r
.32043 .5423 .33188 .5556 .35106 .53513 .33973 .52157 Metetra
0 .458 .159 r
.33973 .52157 .35106 .53513 .37018 .51527 .35898 .50146 Metetra
0 .403 .237 r
.35898 .50146 .37018 .51527 .38924 .49622 .37815 .48219 Metetra
0 .35 .286 r
.37815 .48219 .38924 .49622 .40824 .47817 .39727 .46393 Metetra
0 .296 .303 r
.39727 .46393 .40824 .47817 .42721 .46127 .41634 .44684 Metetra
0 .206 .26 r
.41634 .44684 .42721 .46127 .44615 .44564 .43538 .43103 Metetra
0 .141 .223 r
.43538 .43103 .44615 .44564 .46508 .43139 .45441 .41663 Metetra
0 .096 .192 r
.45441 .41663 .46508 .43139 .48403 .41861 .47345 .40371 Metetra
0 .066 .168 r
.47345 .40371 .48403 .41861 .50303 .40736 .49252 .39233 Metetra
0 .048 .15 r
.49252 .39233 .50303 .40736 .5221 .3977 .51167 .38256 Metetra
0 .038 .139 r
.51167 .38256 .5221 .3977 .54127 .38966 .53091 .37442 Metetra
0 .035 .136 r
.53091 .37442 .54127 .38966 .56057 .38327 .55028 .36793 Metetra
0 .038 .139 r
.55028 .36793 .56057 .38327 .58004 .37852 .56981 .36311 Metetra
0 .048 .15 r
.56981 .36311 .58004 .37852 .5997 .37542 .58954 .35994 Metetra
0 .066 .168 r
.58954 .35994 .5997 .37542 .6196 .37393 .60949 .35841 Metetra
0 .096 .192 r
.60949 .35841 .6196 .37393 .63975 .37403 .62971 .35848 Metetra
0 .141 .223 r
.62971 .35848 .63975 .37403 .6602 .37566 .65021 .36009 Metetra
0 .206 .26 r
.65021 .36009 .6602 .37566 .68098 .37875 .67104 .36317 Metetra
0 .296 .303 r
.67104 .36317 .68098 .37875 .70211 .38321 .69222 .36764 Metetra
0 .35 .286 r
.69222 .36764 .70211 .38321 .72361 .38891 .71378 .37337 Metetra
0 .403 .237 r
.71378 .37337 .72361 .38891 .74551 .39573 .73574 .38023 Metetra
0 .458 .159 r
.73574 .38023 .74551 .39573 .76782 .40347 .75812 .38804 Metetra
0 .517 .048 r
.75812 .38804 .76782 .40347 .79055 .41194 .78092 .3966 Metetra
.098 .577 0 r
.78092 .3966 .79055 .41194 .8137 .42089 .80415 .40565 Metetra
.277 .639 0 r
.80415 .40565 .8137 .42089 .83726 .43002 .82779 .41492 Metetra
.488 .699 0 r
.82779 .41492 .83726 .43002 .86121 .439 .85183 .42406 Metetra
.722 .758 0 r
.85183 .42406 .86121 .439 .88549 .44744 .87622 .43269 Metetra
.698 .752 0 r
.23058 .61466 .2428 .62593 .26222 .60556 .25013 .59406 Metetra
.464 .693 0 r
.25013 .59406 .26222 .60556 .28165 .5846 .26971 .57287 Metetra
.255 .632 0 r
.26971 .57287 .28165 .5846 .30106 .5634 .28926 .55145 Metetra
.077 .57 0 r
.28926 .55145 .30106 .5634 .32043 .5423 .30876 .53014 Metetra
0 .509 .065 r
.30876 .53014 .32043 .5423 .33973 .52157 .3282 .50922 Metetra
0 .45 .173 r
.3282 .50922 .33973 .52157 .35898 .50146 .34757 .48893 Metetra
0 .393 .247 r
.34757 .48893 .35898 .50146 .37815 .48219 .36687 .46949 Metetra
0 .341 .292 r
.36687 .46949 .37815 .48219 .39727 .46393 .38611 .45107 Metetra
0 .274 .293 r
.38611 .45107 .39727 .46393 .41634 .44684 .40529 .43382 Metetra
0 .187 .25 r
.40529 .43382 .41634 .44684 .43538 .43103 .42444 .41788 Metetra
0 .125 .213 r
.42444 .41788 .43538 .43103 .45441 .41663 .44357 .40334 Metetra
0 .082 .182 r
.44357 .40334 .45441 .41663 .47345 .40371 .46271 .3903 Metetra
0 .055 .157 r
.46271 .3903 .47345 .40371 .49252 .39233 .48188 .37881 Metetra
0 .038 .139 r
.48188 .37881 .49252 .39233 .51167 .38256 .50112 .36893 Metetra
0 .029 .129 r
.50112 .36893 .51167 .38256 .53091 .37442 .52044 .3607 Metetra
0 .026 .125 r
.52044 .3607 .53091 .37442 .55028 .36793 .53989 .35412 Metetra
0 .029 .129 r
.53989 .35412 .55028 .36793 .56981 .36311 .5595 .34922 Metetra
0 .038 .139 r
.5595 .34922 .56981 .36311 .58954 .35994 .5793 .34599 Metetra
0 .055 .157 r
.5793 .34599 .58954 .35994 .60949 .35841 .59932 .34439 Metetra
0 .082 .182 r
.59932 .34439 .60949 .35841 .62971 .35848 .6196 .3444 Metetra
0 .125 .213 r
.6196 .3444 .62971 .35848 .65021 .36009 .64017 .34597 Metetra
0 .187 .25 r
.64017 .34597 .65021 .36009 .67104 .36317 .66106 .34902 Metetra
0 .274 .293 r
.66106 .34902 .67104 .36317 .69222 .36764 .68231 .35346 Metetra
0 .341 .292 r
.68231 .35346 .69222 .36764 .71378 .37337 .70393 .35918 Metetra
0 .393 .247 r
.70393 .35918 .71378 .37337 .73574 .38023 .72595 .36603 Metetra
0 .45 .173 r
.72595 .36603 .73574 .38023 .75812 .38804 .7484 .37385 Metetra
0 .509 .065 r
.7484 .37385 .75812 .38804 .78092 .3966 .77127 .38242 Metetra
.077 .57 0 r
.77127 .38242 .78092 .3966 .80415 .40565 .79457 .39151 Metetra
.255 .632 0 r
.79457 .39151 .80415 .40565 .82779 .41492 .8183 .40082 Metetra
.464 .693 0 r
.8183 .40082 .82779 .41492 .85183 .42406 .84243 .41001 Metetra
.698 .752 0 r
.84243 .41001 .85183 .42406 .87622 .43269 .86692 .4187 Metetra
.69 .751 0 r
.21812 .6042 .23058 .61466 .25013 .59406 .23781 .58347 Metetra
.456 .691 0 r
.23781 .58347 .25013 .59406 .26971 .57287 .25753 .56215 Metetra
.247 .629 0 r
.25753 .56215 .26971 .57287 .28926 .55145 .27722 .54061 Metetra
.071 .567 0 r
.27722 .54061 .28926 .55145 .30876 .53014 .29686 .51917 Metetra
0 .506 .071 r
.29686 .51917 .30876 .53014 .3282 .50922 .31644 .49812 Metetra
0 .447 .177 r
.31644 .49812 .3282 .50922 .34757 .48893 .33595 .47771 Metetra
0 .39 .25 r
.33595 .47771 .34757 .48893 .36687 .46949 .35538 .45815 Metetra
0 .338 .294 r
.35538 .45815 .36687 .46949 .38611 .45107 .37474 .43961 Metetra
0 .267 .29 r
.37474 .43961 .38611 .45107 .40529 .43382 .39405 .42225 Metetra
0 .181 .247 r
.39405 .42225 .40529 .43382 .42444 .41788 .41332 .4062 Metetra
0 .12 .209 r
.41332 .4062 .42444 .41788 .44357 .40334 .43256 .39156 Metetra
0 .078 .178 r
.43256 .39156 .44357 .40334 .46271 .3903 .45181 .37841 Metetra
0 .051 .154 r
.45181 .37841 .46271 .3903 .48188 .37881 .47108 .36683 Metetra
0 .035 .136 r
.47108 .36683 .48188 .37881 .50112 .36893 .49042 .35685 Metetra
0 .026 .125 r
.49042 .35685 .50112 .36893 .52044 .3607 .50984 .34853 Metetra
0 .023 .121 r
.50984 .34853 .52044 .3607 .53989 .35412 .52938 .34187 Metetra
0 .026 .125 r
.52938 .34187 .53989 .35412 .5595 .34922 .54907 .33688 Metetra
0 .035 .136 r
.54907 .33688 .5595 .34922 .5793 .34599 .56895 .33357 Metetra
0 .051 .154 r
.56895 .33357 .5793 .34599 .59932 .34439 .58905 .3319 Metetra
0 .078 .178 r
.58905 .3319 .59932 .34439 .6196 .3444 .60941 .33184 Metetra
0 .12 .209 r
.60941 .33184 .6196 .3444 .64017 .34597 .63005 .33333 Metetra
0 .181 .247 r
.63005 .33333 .64017 .34597 .66106 .34902 .65102 .33632 Metetra
0 .267 .29 r
.65102 .33632 .66106 .34902 .68231 .35346 .67233 .3407 Metetra
0 .338 .294 r
.67233 .3407 .68231 .35346 .70393 .35918 .69403 .34635 Metetra
0 .39 .25 r
.69403 .34635 .70393 .35918 .72595 .36603 .71613 .35315 Metetra
0 .447 .177 r
.71613 .35315 .72595 .36603 .7484 .37385 .73865 .36091 Metetra
0 .506 .071 r
.73865 .36091 .7484 .37385 .77127 .38242 .7616 .36943 Metetra
.071 .567 0 r
.7616 .36943 .77127 .38242 .79457 .39151 .78498 .37847 Metetra
.247 .629 0 r
.78498 .37847 .79457 .39151 .8183 .40082 .80879 .38773 Metetra
.456 .691 0 r
.80879 .38773 .8183 .40082 .84243 .41001 .83301 .39687 Metetra
.69 .751 0 r
.83301 .39687 .84243 .41001 .86692 .4187 .8576 .4055 Metetra
.698 .752 0 r
.20541 .59453 .21812 .6042 .23781 .58347 .22524 .57379 Metetra
.464 .693 0 r
.22524 .57379 .23781 .58347 .25753 .56215 .24509 .55245 Metetra
.255 .632 0 r
.24509 .55245 .25753 .56215 .27722 .54061 .26492 .53087 Metetra
.077 .57 0 r
.26492 .53087 .27722 .54061 .29686 .51917 .28471 .50938 Metetra
0 .509 .065 r
.28471 .50938 .29686 .51917 .31644 .49812 .30443 .48828 Metetra
0 .45 .173 r
.30443 .48828 .31644 .49812 .33595 .47771 .32408 .46781 Metetra
0 .393 .247 r
.32408 .46781 .33595 .47771 .35538 .45815 .34365 .44817 Metetra
0 .341 .292 r
.34365 .44817 .35538 .45815 .37474 .43961 .36315 .42957 Metetra
0 .274 .293 r
.36315 .42957 .37474 .43961 .39405 .42225 .38259 .41213 Metetra
0 .187 .25 r
.38259 .41213 .39405 .42225 .41332 .4062 .40198 .396 Metetra
0 .125 .213 r
.40198 .396 .41332 .4062 .43256 .39156 .42135 .38128 Metetra
0 .082 .182 r
.42135 .38128 .43256 .39156 .45181 .37841 .44072 .36805 Metetra
0 .055 .157 r
.44072 .36805 .45181 .37841 .47108 .36683 .46011 .35639 Metetra
0 .038 .139 r
.46011 .35639 .47108 .36683 .49042 .35685 .47955 .34633 Metetra
0 .029 .129 r
.47955 .34633 .49042 .35685 .50984 .34853 .49908 .33792 Metetra
0 .026 .125 r
.49908 .33792 .50984 .34853 .52938 .34187 .51872 .33117 Metetra
0 .029 .129 r
.51872 .33117 .52938 .34187 .54907 .33688 .53851 .3261 Metetra
0 .038 .139 r
.53851 .3261 .54907 .33688 .56895 .33357 .55848 .3227 Metetra
0 .055 .157 r
.55848 .3227 .56895 .33357 .58905 .3319 .57867 .32094 Metetra
0 .082 .182 r
.57867 .32094 .58905 .3319 .60941 .33184 .59912 .32079 Metetra
0 .125 .213 r
.59912 .32079 .60941 .33184 .63005 .33333 .61985 .32219 Metetra
0 .187 .25 r
.61985 .32219 .63005 .33333 .65102 .33632 .6409 .32508 Metetra
0 .274 .293 r
.6409 .32508 .65102 .33632 .67233 .3407 .6623 .32936 Metetra
0 .341 .292 r
.6623 .32936 .67233 .3407 .69403 .34635 .68407 .33491 Metetra
0 .393 .247 r
.68407 .33491 .69403 .34635 .71613 .35315 .70625 .3416 Metetra
0 .45 .173 r
.70625 .3416 .71613 .35315 .73865 .36091 .72885 .34925 Metetra
0 .509 .065 r
.72885 .34925 .73865 .36091 .7616 .36943 .75188 .35765 Metetra
.077 .57 0 r
.75188 .35765 .7616 .36943 .78498 .37847 .77535 .36655 Metetra
.255 .632 0 r
.77535 .36655 .78498 .37847 .80879 .38773 .79925 .37566 Metetra
.464 .693 0 r
.79925 .37566 .80879 .38773 .83301 .39687 .82355 .38465 Metetra
.698 .752 0 r
.82355 .38465 .83301 .39687 .8576 .4055 .84823 .39311 Metetra
.722 .758 0 r
.19243 .58565 .20541 .59453 .22524 .57379 .21239 .56502 Metetra
.488 .699 0 r
.21239 .56502 .22524 .57379 .24509 .55245 .23238 .54376 Metetra
.277 .639 0 r
.23238 .54376 .24509 .55245 .26492 .53087 .25236 .52223 Metetra
.098 .577 0 r
.25236 .52223 .26492 .53087 .28471 .50938 .27229 .50078 Metetra
0 .517 .048 r
.27229 .50078 .28471 .50938 .30443 .48828 .29216 .47969 Metetra
0 .458 .159 r
.29216 .47969 .30443 .48828 .32408 .46781 .31195 .45922 Metetra
0 .403 .237 r
.31195 .45922 .32408 .46781 .34365 .44817 .33167 .43957 Metetra
0 .35 .286 r
.33167 .43957 .34365 .44817 .36315 .42957 .35131 .42093 Metetra
0 .296 .303 r
.35131 .42093 .36315 .42957 .38259 .41213 .37089 .40347 Metetra
0 .206 .26 r
.37089 .40347 .38259 .41213 .40198 .396 .39042 .38729 Metetra
0 .141 .223 r
.39042 .38729 .40198 .396 .42135 .38128 .40993 .37251 Metetra
0 .096 .192 r
.40993 .37251 .42135 .38128 .44072 .36805 .42942 .35922 Metetra
0 .066 .168 r
.42942 .35922 .44072 .36805 .46011 .35639 .44894 .34749 Metetra
0 .048 .15 r
.44894 .34749 .46011 .35639 .47955 .34633 .4685 .33736 Metetra
0 .038 .139 r
.4685 .33736 .47955 .34633 .49908 .33792 .48815 .32887 Metetra
0 .035 .136 r
.48815 .32887 .49908 .33792 .51872 .33117 .5079 .32204 Metetra
0 .038 .139 r
.5079 .32204 .51872 .33117 .53851 .3261 .5278 .31687 Metetra
0 .048 .15 r
.5278 .31687 .53851 .3261 .55848 .3227 .54788 .31337 Metetra
0 .066 .168 r
.54788 .31337 .55848 .3227 .57867 .32094 .56817 .31151 Metetra
0 .096 .192 r
.56817 .31151 .57867 .32094 .59912 .32079 .58871 .31125 Metetra
0 .141 .223 r
.58871 .31125 .59912 .32079 .61985 .32219 .60954 .31254 Metetra
0 .206 .26 r
.60954 .31254 .61985 .32219 .6409 .32508 .63068 .3153 Metetra
0 .296 .303 r
.63068 .3153 .6409 .32508 .6623 .32936 .65217 .31944 Metetra
0 .35 .286 r
.65217 .31944 .6623 .32936 .68407 .33491 .67404 .32485 Metetra
0 .403 .237 r
.67404 .32485 .68407 .33491 .70625 .3416 .69631 .33137 Metetra
0 .458 .159 r
.69631 .33137 .70625 .3416 .72885 .34925 .71899 .33884 Metetra
0 .517 .048 r
.71899 .33884 .72885 .34925 .75188 .35765 .74211 .34705 Metetra
.098 .577 0 r
.74211 .34705 .75188 .35765 .77535 .36655 .76567 .35574 Metetra
.277 .639 0 r
.76567 .35574 .77535 .36655 .79925 .37566 .78965 .36461 Metetra
.488 .699 0 r
.78965 .36461 .79925 .37566 .82355 .38465 .81405 .37333 Metetra
.722 .758 0 r
.81405 .37333 .82355 .38465 .84823 .39311 .83882 .3815 Metetra
.763 .768 0 r
.17918 .57752 .19243 .58565 .21239 .56502 .19927 .55712 Metetra
.528 .71 0 r
.19927 .55712 .21239 .56502 .23238 .54376 .21939 .53603 Metetra
.315 .65 0 r
.21939 .53603 .23238 .54376 .25236 .52223 .23951 .51466 Metetra
.132 .59 0 r
.23951 .51466 .25236 .52223 .27229 .50078 .25958 .49332 Metetra
0 .53 .018 r
.25958 .49332 .27229 .50078 .29216 .47969 .2796 .47232 Metetra
0 .473 .135 r
.2796 .47232 .29216 .47969 .31195 .45922 .29954 .45191 Metetra
0 .417 .219 r
.29954 .45191 .31195 .45922 .33167 .43957 .31941 .43231 Metetra
0 .366 .274 r
.31941 .43231 .33167 .43957 .35131 .42093 .33921 .41369 Metetra
0 .319 .303 r
.33921 .41369 .35131 .42093 .37089 .40347 .35893 .39622 Metetra
0 .239 .277 r
.35893 .39622 .37089 .40347 .39042 .38729 .37861 .38004 Metetra
0 .169 .24 r
.37861 .38004 .39042 .38729 .40993 .37251 .39826 .36523 Metetra
0 .12 .209 r
.39826 .36523 .40993 .37251 .42942 .35922 .41789 .3519 Metetra
0 .087 .185 r
.41789 .3519 .42942 .35922 .44894 .34749 .43755 .34012 Metetra
0 .066 .168 r
.43755 .34012 .44894 .34749 .4685 .33736 .45724 .32992 Metetra
0 .055 .157 r
.45724 .32992 .4685 .33736 .48815 .32887 .47702 .32136 Metetra
0 .051 .154 r
.47702 .32136 .48815 .32887 .5079 .32204 .4969 .31444 Metetra
0 .055 .157 r
.4969 .31444 .5079 .32204 .5278 .31687 .51692 .30918 Metetra
0 .066 .168 r
.51692 .30918 .5278 .31687 .54788 .31337 .53711 .30558 Metetra
0 .087 .185 r
.53711 .30558 .54788 .31337 .56817 .31151 .55752 .3036 Metetra
0 .12 .209 r
.55752 .3036 .56817 .31151 .58871 .31125 .57817 .30321 Metetra
0 .169 .24 r
.57817 .30321 .58871 .31125 .60954 .31254 .59911 .30435 Metetra
0 .239 .277 r
.59911 .30435 .60954 .31254 .63068 .3153 .62035 .30695 Metetra
0 .319 .303 r
.62035 .30695 .63068 .3153 .65217 .31944 .64195 .31092 Metetra
0 .366 .274 r
.64195 .31092 .65217 .31944 .67404 .32485 .66391 .31613 Metetra
0 .417 .219 r
.66391 .31613 .67404 .32485 .69631 .33137 .68628 .32244 Metetra
0 .473 .135 r
.68628 .32244 .69631 .33137 .71899 .33884 .70906 .32967 Metetra
0 .53 .018 r
.70906 .32967 .71899 .33884 .74211 .34705 .73227 .33761 Metetra
.132 .59 0 r
.73227 .33761 .74211 .34705 .76567 .35574 .75592 .34599 Metetra
.315 .65 0 r
.75592 .34599 .76567 .35574 .78965 .36461 .78 .35453 Metetra
.528 .71 0 r
.78 .35453 .78965 .36461 .81405 .37333 .80448 .36288 Metetra
.763 .768 0 r
.80448 .36288 .81405 .37333 .83882 .3815 .82934 .37062 Metetra
.781 .742 0 r
.16565 .57007 .17918 .57752 .19927 .55712 .18585 .55001 Metetra
.584 .725 0 r
.18585 .55001 .19927 .55712 .21939 .53603 .2061 .52923 Metetra
.369 .666 0 r
.2061 .52923 .21939 .53603 .23951 .51466 .22635 .5081 Metetra
.182 .607 0 r
.22635 .5081 .23951 .51466 .25958 .49332 .24657 .48697 Metetra
.025 .549 0 r
.24657 .48697 .25958 .49332 .2796 .47232 .26674 .46613 Metetra
0 .492 .099 r
.26674 .46613 .2796 .47232 .29954 .45191 .28684 .44585 Metetra
0 .438 .191 r
.28684 .44585 .29954 .45191 .31941 .43231 .30686 .42634 Metetra
0 .387 .254 r
.30686 .42634 .31941 .43231 .33921 .41369 .32681 .4078 Metetra
0 .341 .292 r
.32681 .4078 .33921 .41369 .35893 .39622 .3467 .39037 Metetra
0 .289 .299 r
.3467 .39037 .35893 .39622 .37861 .38004 .36653 .37421 Metetra
0 .213 .263 r
.36653 .37421 .37861 .38004 .39826 .36523 .38633 .3594 Metetra
0 .158 .233 r
.38633 .3594 .39826 .36523 .41789 .3519 .40612 .34606 Metetra
0 .12 .209 r
.40612 .34606 .41789 .3519 .43755 .34012 .42592 .33423 Metetra
0 .096 .192 r
.42592 .33423 .43755 .34012 .45724 .32992 .44576 .32399 Metetra
0 .082 .182 r
.44576 .32399 .45724 .32992 .47702 .32136 .46567 .31535 Metetra
0 .078 .178 r
.46567 .31535 .47702 .32136 .4969 .31444 .48568 .30835 Metetra
0 .082 .182 r
.48568 .30835 .4969 .31444 .51692 .30918 .50584 .303 Metetra
0 .096 .192 r
.50584 .303 .51692 .30918 .53711 .30558 .52616 .29927 Metetra
0 .12 .209 r
.52616 .29927 .53711 .30558 .55752 .3036 .5467 .29716 Metetra
0 .158 .233 r
.5467 .29716 .55752 .3036 .57817 .30321 .56747 .29662 Metetra
0 .213 .263 r
.56747 .29662 .57817 .30321 .59911 .30435 .58852 .29759 Metetra
0 .289 .299 r
.58852 .29759 .59911 .30435 .62035 .30695 .60989 .3 Metetra
0 .341 .292 r
.60989 .3 .62035 .30695 .64195 .31092 .63159 .30375 Metetra
0 .387 .254 r
.63159 .30375 .64195 .31092 .66391 .31613 .65367 .30872 Metetra
0 .438 .191 r
.65367 .30872 .66391 .31613 .68628 .32244 .67614 .31475 Metetra
0 .492 .099 r
.67614 .31475 .68628 .32244 .70906 .32967 .69903 .32168 Metetra
.025 .549 0 r
.69903 .32168 .70906 .32967 .73227 .33761 .72234 .32927 Metetra
.182 .607 0 r
.72234 .32927 .73227 .33761 .75592 .34599 .74609 .33726 Metetra
.369 .666 0 r
.74609 .33726 .75592 .34599 .78 .35453 .77026 .34537 Metetra
.584 .725 0 r
.77026 .34537 .78 .35453 .80448 .36288 .79484 .35322 Metetra
.781 .742 0 r
.79484 .35322 .80448 .36288 .82934 .37062 .81978 .36041 Metetra
.797 .702 0 r
.15182 .56321 .16565 .57007 .18585 .55001 .17212 .54363 Metetra
.657 .743 0 r
.17212 .54363 .18585 .55001 .2061 .52923 .19249 .52325 Metetra
.44 .686 0 r
.19249 .52325 .2061 .52923 .22635 .5081 .21288 .50247 Metetra
.247 .629 0 r
.21288 .50247 .22635 .5081 .24657 .48697 .23324 .48164 Metetra
.084 .572 0 r
.23324 .48164 .24657 .48697 .26674 .46613 .25356 .46105 Metetra
0 .517 .048 r
.25356 .46105 .26674 .46613 .28684 .44585 .27382 .44096 Metetra
0 .464 .15 r
.27382 .44096 .28684 .44585 .30686 .42634 .294 .42161 Metetra
0 .414 .223 r
.294 .42161 .30686 .42634 .32681 .4078 .31411 .40319 Metetra
0 .369 .271 r
.31411 .40319 .32681 .4078 .3467 .39037 .33416 .38586 Metetra
0 .328 .299 r
.33416 .38586 .3467 .39037 .36653 .37421 .35416 .36975 Metetra
0 .274 .293 r
.35416 .36975 .36653 .37421 .38633 .3594 .37412 .35497 Metetra
0 .213 .263 r
.37412 .35497 .38633 .3594 .40612 .34606 .39406 .34163 Metetra
0 .169 .24 r
.39406 .34163 .40612 .34606 .42592 .33423 .41402 .32979 Metetra
0 .141 .223 r
.41402 .32979 .42592 .33423 .44576 .32399 .43402 .3195 Metetra
0 .125 .213 r
.43402 .3195 .44576 .32399 .46567 .31535 .45408 .31081 Metetra
0 .12 .209 r
.45408 .31081 .46567 .31535 .48568 .30835 .47424 .30372 Metetra
0 .125 .213 r
.47424 .30372 .48568 .30835 .50584 .303 .49454 .29826 Metetra
0 .141 .223 r
.49454 .29826 .50584 .303 .52616 .29927 .51501 .29441 Metetra
0 .169 .24 r
.51501 .29441 .52616 .29927 .5467 .29716 .53568 .29215 Metetra
0 .213 .263 r
.53568 .29215 .5467 .29716 .56747 .29662 .55659 .29143 Metetra
0 .274 .293 r
.55659 .29143 .56747 .29662 .58852 .29759 .57777 .2922 Metetra
0 .328 .299 r
.57777 .2922 .58852 .29759 .60989 .3 .59926 .29438 Metetra
0 .369 .271 r
.59926 .29438 .60989 .3 .63159 .30375 .62109 .29787 Metetra
0 .414 .223 r
.62109 .29787 .63159 .30375 .65367 .30872 .64329 .30255 Metetra
0 .464 .15 r
.64329 .30255 .65367 .30872 .67614 .31475 .66588 .30825 Metetra
0 .517 .048 r
.66588 .30825 .67614 .31475 .69903 .32168 .68888 .31479 Metetra
.084 .572 0 r
.68888 .31479 .69903 .32168 .72234 .32927 .7123 .32195 Metetra
.247 .629 0 r
.7123 .32195 .72234 .32927 .74609 .33726 .73615 .32946 Metetra
.44 .686 0 r
.73615 .32946 .74609 .33726 .77026 .34537 .76042 .33702 Metetra
.657 .743 0 r
.76042 .33702 .77026 .34537 .79484 .35322 .78509 .34426 Metetra
.797 .702 0 r
.78509 .34426 .79484 .35322 .81978 .36041 .81012 .35076 Metetra
.815 .652 0 r
.13771 .55681 .15182 .56321 .17212 .54363 .1581 .53784 Metetra
.747 .764 0 r
.1581 .53784 .17212 .54363 .19249 .52325 .17857 .518 Metetra
.528 .71 0 r
.17857 .518 .19249 .52325 .21288 .50247 .19908 .49768 Metetra
.331 .655 0 r
.19908 .49768 .21288 .50247 .23324 .48164 .21959 .47724 Metetra
.16 .6 0 r
.21959 .47724 .23324 .48164 .25356 .46105 .24005 .45698 Metetra
.019 .546 0 r
.24005 .45698 .25356 .46105 .27382 .44096 .26047 .43717 Metetra
0 .495 .093 r
.26047 .43717 .27382 .44096 .294 .42161 .28081 .41804 Metetra
0 .447 .177 r
.28081 .41804 .294 .42161 .31411 .40319 .30109 .39979 Metetra
0 .403 .237 r
.30109 .39979 .31411 .40319 .33416 .38586 .32131 .38259 Metetra
0 .363 .276 r
.32131 .38259 .33416 .38586 .35416 .36975 .34147 .36658 Metetra
0 .328 .299 r
.34147 .36658 .35416 .36975 .37412 .35497 .3616 .35187 Metetra
0 .289 .299 r
.3616 .35187 .37412 .35497 .39406 .34163 .38172 .33856 Metetra
0 .239 .277 r
.38172 .33856 .39406 .34163 .41402 .32979 .40184 .32672 Metetra
0 .206 .26 r
.40184 .32672 .41402 .32979 .43402 .3195 .422 .3164 Metetra
0 .187 .25 r
.422 .3164 .43402 .3195 .45408 .31081 .44223 .30765 Metetra
0 .181 .247 r
.44223 .30765 .45408 .31081 .47424 .30372 .46255 .30048 Metetra
0 .187 .25 r
.46255 .30048 .47424 .30372 .49454 .29826 .48301 .29491 Metetra
0 .206 .26 r
.48301 .29491 .49454 .29826 .51501 .29441 .50363 .29092 Metetra
0 .239 .277 r
.50363 .29092 .51501 .29441 .53568 .29215 .52445 .28849 Metetra
0 .289 .299 r
.52445 .28849 .53568 .29215 .55659 .29143 .54551 .28757 Metetra
0 .328 .299 r
.54551 .28757 .55659 .29143 .57777 .2922 .56683 .28811 Metetra
0 .363 .276 r
.56683 .28811 .57777 .2922 .59926 .29438 .58846 .29003 Metetra
0 .403 .237 r
.58846 .29003 .59926 .29438 .62109 .29787 .61043 .29321 Metetra
0 .447 .177 r
.61043 .29321 .62109 .29787 .64329 .30255 .63276 .29753 Metetra
0 .495 .093 r
.63276 .29753 .64329 .30255 .66588 .30825 .65547 .30283 Metetra
.019 .546 0 r
.65547 .30283 .66588 .30825 .68888 .31479 .67859 .30891 Metetra
.16 .6 0 r
.67859 .30891 .68888 .31479 .7123 .32195 .70213 .31555 Metetra
.331 .655 0 r
.70213 .31555 .7123 .32195 .73615 .32946 .72609 .32248 Metetra
.528 .71 0 r
.72609 .32248 .73615 .32946 .76042 .33702 .75046 .32938 Metetra
.747 .764 0 r
.75046 .32938 .76042 .33702 .78509 .34426 .77522 .33588 Metetra
.815 .652 0 r
.77522 .33588 .78509 .34426 .81012 .35076 .80033 .34154 Metetra
.836 .593 0 r
.12331 .55072 .13771 .55681 .1581 .53784 .14377 .53251 Metetra
.788 .724 0 r
.14377 .53251 .1581 .53784 .17857 .518 .16434 .51333 Metetra
.633 .737 0 r
.16434 .51333 .17857 .518 .19908 .49768 .18496 .49359 Metetra
.432 .684 0 r
.18496 .49359 .19908 .49768 .21959 .47724 .2056 .47364 Metetra
.255 .632 0 r
.2056 .47364 .21959 .47724 .24005 .45698 .22621 .4538 Metetra
.105 .58 0 r
.22621 .4538 .24005 .45698 .26047 .43717 .24677 .43434 Metetra
0 .531 .018 r
.24677 .43434 .26047 .43717 .28081 .41804 .26728 .41551 Metetra
0 .484 .114 r
.26728 .41551 .28081 .41804 .30109 .39979 .28773 .3975 Metetra
0 .441 .186 r
.28773 .3975 .30109 .39979 .32131 .38259 .30812 .38049 Metetra
0 .403 .237 r
.30812 .38049 .32131 .38259 .34147 .36658 .32846 .36461 Metetra
0 .369 .271 r
.32846 .36461 .34147 .36658 .3616 .35187 .34877 .35 Metetra
0 .341 .292 r
.34877 .35 .3616 .35187 .38172 .33856 .36906 .33675 Metetra
0 .319 .303 r
.36906 .33675 .38172 .33856 .40184 .32672 .38936 .32492 Metetra
0 .296 .303 r
.38936 .32492 .40184 .32672 .422 .3164 .4097 .31459 Metetra
0 .274 .293 r
.4097 .31459 .422 .3164 .44223 .30765 .4301 .30579 Metetra
0 .267 .29 r
.4301 .30579 .44223 .30765 .46255 .30048 .45059 .29854 Metetra
0 .274 .293 r
.45059 .29854 .46255 .30048 .48301 .29491 .47122 .29285 Metetra
0 .296 .303 r
.47122 .29285 .48301 .29491 .50363 .29092 .492 .28871 Metetra
0 .319 .303 r
.492 .28871 .50363 .29092 .52445 .28849 .51298 .28609 Metetra
0 .341 .292 r
.51298 .28609 .52445 .28849 .54551 .28757 .5342 .28495 Metetra
0 .369 .271 r
.5342 .28495 .54551 .28757 .56683 .28811 .55568 .28522 Metetra
0 .403 .237 r
.55568 .28522 .56683 .28811 .58846 .29003 .57746 .28682 Metetra
0 .441 .186 r
.57746 .28682 .58846 .29003 .61043 .29321 .59957 .28964 Metetra
0 .484 .114 r
.59957 .28964 .61043 .29321 .63276 .29753 .62204 .29355 Metetra
0 .531 .018 r
.62204 .29355 .63276 .29753 .65547 .30283 .64489 .29837 Metetra
.105 .58 0 r
.64489 .29837 .65547 .30283 .67859 .30891 .66814 .30392 Metetra
.255 .632 0 r
.66814 .30392 .67859 .30891 .70213 .31555 .6918 .30995 Metetra
.432 .684 0 r
.6918 .30995 .70213 .31555 .72609 .32248 .71587 .31619 Metetra
.633 .737 0 r
.71587 .31619 .72609 .32248 .75046 .32938 .74035 .3223 Metetra
.788 .724 0 r
.74035 .3223 .75046 .32938 .77522 .33588 .7652 .32791 Metetra
.836 .593 0 r
.7652 .32791 .77522 .33588 .80033 .34154 .7904 .3326 Metetra
.859 .526 0 r
.10863 .54476 .12331 .55072 .14377 .53251 .12914 .52745 Metetra
.814 .657 0 r
.12914 .52745 .14377 .53251 .16434 .51333 .14978 .50908 Metetra
.755 .766 0 r
.14978 .50908 .16434 .51333 .18496 .49359 .17051 .49003 Metetra
.552 .716 0 r
.17051 .49003 .18496 .49359 .2056 .47364 .19126 .47069 Metetra
.369 .666 0 r
.19126 .47069 .2056 .47364 .22621 .4538 .21201 .45137 Metetra
.211 .617 0 r
.21201 .45137 .22621 .4538 .24677 .43434 .23273 .43235 Metetra
.077 .57 0 r
.23273 .43235 .24677 .43434 .26728 .41551 .2534 .41389 Metetra
0 .525 .03 r
.2534 .41389 .26728 .41551 .28773 .3975 .27402 .39618 Metetra
0 .484 .114 r
.27402 .39618 .28773 .3975 .30812 .38049 .29458 .37941 Metetra
0 .447 .177 r
.29458 .37941 .30812 .38049 .32846 .36461 .31511 .36372 Metetra
0 .414 .223 r
.31511 .36372 .32846 .36461 .34877 .35 .3356 .34924 Metetra
0 .387 .254 r
.3356 .34924 .34877 .35 .36906 .33675 .35607 .33607 Metetra
0 .366 .274 r
.35607 .33607 .36906 .33675 .38936 .32492 .37656 .32429 Metetra
0 .35 .286 r
.37656 .32429 .38936 .32492 .4097 .31459 .39708 .31396 Metetra
0 .341 .292 r
.39708 .31396 .4097 .31459 .4301 .30579 .41766 .30511 Metetra
0 .338 .294 r
.41766 .30511 .4301 .30579 .45059 .29854 .43834 .29778 Metetra
0 .341 .292 r
.43834 .29778 .45059 .29854 .47122 .29285 .45914 .29197 Metetra
0 .35 .286 r
.45914 .29197 .47122 .29285 .492 .28871 .4801 .28766 Metetra
0 .366 .274 r
.4801 .28766 .492 .28871 .51298 .28609 .50126 .28483 Metetra
0 .387 .254 r
.50126 .28483 .51298 .28609 .5342 .28495 .52264 .28343 Metetra
0 .414 .223 r
.52264 .28343 .5342 .28495 .55568 .28522 .54429 .2834 Metetra
0 .447 .177 r
.54429 .2834 .55568 .28522 .57746 .28682 .56623 .28464 Metetra
0 .484 .114 r
.56623 .28464 .57746 .28682 .59957 .28964 .5885 .28704 Metetra
0 .525 .03 r
.5885 .28704 .59957 .28964 .62204 .29355 .61112 .29047 Metetra
.077 .57 0 r
.61112 .29047 .62204 .29355 .64489 .29837 .63412 .29474 Metetra
.211 .617 0 r
.63412 .29474 .64489 .29837 .66814 .30392 .6575 .29966 Metetra
.369 .666 0 r
.6575 .29966 .66814 .30392 .6918 .30995 .6813 .30498 Metetra
.552 .716 0 r
.6813 .30498 .6918 .30995 .71587 .31619 .70549 .3104 Metetra
.755 .766 0 r
.70549 .3104 .71587 .31619 .74035 .3223 .73007 .3156 Metetra
.814 .657 0 r
.73007 .3156 .74035 .3223 .7652 .32791 .75502 .32019 Metetra
.859 .526 0 r
.75502 .32019 .7652 .32791 .7904 .3326 .78029 .32372 Metetra
.882 .452 0 r
.0937 .5387 .10863 .54476 .12914 .52745 .11423 .52246 Metetra
.841 .58 0 r
.11423 .52246 .12914 .52745 .14978 .50908 .13493 .50503 Metetra
.797 .702 0 r
.13493 .50503 .14978 .50908 .17051 .49003 .15574 .48682 Metetra
.69 .751 0 r
.15574 .48682 .17051 .49003 .19126 .47069 .1766 .4682 Metetra
.504 .704 0 r
.1766 .4682 .19126 .47069 .21201 .45137 .19747 .4495 Metetra
.338 .657 0 r
.19747 .4495 .21201 .45137 .23273 .43235 .21833 .43102 Metetra
.196 .612 0 r
.21833 .43102 .23273 .43235 .2534 .41389 .23916 .41301 Metetra
.077 .57 0 r
.23916 .41301 .2534 .41389 .27402 .39618 .25995 .39567 Metetra
0 .531 .018 r
.25995 .39567 .27402 .39618 .29458 .37941 .28069 .3792 Metetra
0 .495 .093 r
.28069 .3792 .29458 .37941 .31511 .36372 .30139 .36375 Metetra
0 .464 .15 r
.30139 .36375 .31511 .36372 .3356 .34924 .32207 .34945 Metetra
0 .438 .191 r
.32207 .34945 .3356 .34924 .35607 .33607 .34274 .3364 Metetra
0 .417 .219 r
.34274 .3364 .35607 .33607 .37656 .32429 .36342 .32469 Metetra
0 .403 .237 r
.36342 .32469 .37656 .32429 .39708 .31396 .38413 .31437 Metetra
0 .393 .247 r
.38413 .31437 .39708 .31396 .41766 .30511 .40491 .30549 Metetra
0 .39 .25 r
.40491 .30549 .41766 .30511 .43834 .29778 .42577 .29807 Metetra
0 .393 .247 r
.42577 .29807 .43834 .29778 .45914 .29197 .44677 .29212 Metetra
0 .403 .237 r
.44677 .29212 .45914 .29197 .4801 .28766 .46792 .28763 Metetra
0 .417 .219 r
.46792 .28763 .4801 .28766 .50126 .28483 .48926 .28456 Metetra
0 .438 .191 r
.48926 .28456 .50126 .28483 .52264 .28343 .51082 .28288 Metetra
0 .464 .15 r
.51082 .28288 .52264 .28343 .54429 .2834 .53265 .2825 Metetra
0 .495 .093 r
.53265 .2825 .54429 .2834 .56623 .28464 .55476 .28333 Metetra
0 .531 .018 r
.55476 .28333 .56623 .28464 .5885 .28704 .5772 .28525 Metetra
.077 .57 0 r
.5772 .28525 .5885 .28704 .61112 .29047 .59998 .28812 Metetra
.196 .612 0 r
.59998 .28812 .61112 .29047 .63412 .29474 .62313 .29176 Metetra
.338 .657 0 r
.62313 .29176 .63412 .29474 .6575 .29966 .64666 .29595 Metetra
.504 .704 0 r
.64666 .29595 .6575 .29966 .6813 .30498 .67059 .30043 Metetra
.69 .751 0 r
.67059 .30043 .6813 .30498 .70549 .3104 .6949 .30492 Metetra
.797 .702 0 r
.6949 .30492 .70549 .3104 .73007 .3156 .7196 .30906 Metetra
.841 .58 0 r
.7196 .30906 .73007 .3156 .75502 .32019 .74464 .31246 Metetra
.882 .452 0 r
.74464 .31246 .75502 .32019 .78029 .32372 .76999 .31467 Metetra
.904 .374 0 r
.07854 .53228 .0937 .5387 .11423 .52246 .09906 .51728 Metetra
.868 .495 0 r
.09906 .51728 .11423 .52246 .13493 .50503 .11978 .50095 Metetra
.828 .616 0 r
.11978 .50095 .13493 .50503 .15574 .48682 .14065 .48371 Metetra
.786 .729 0 r
.14065 .48371 .15574 .48682 .1766 .4682 .1616 .46595 Metetra
.657 .743 0 r
.1616 .46595 .1766 .4682 .19747 .4495 .18259 .44799 Metetra
.488 .699 0 r
.18259 .44799 .19747 .4495 .21833 .43102 .20358 .43014 Metetra
.338 .657 0 r
.20358 .43014 .21833 .43102 .23916 .41301 .22456 .41267 Metetra
.211 .617 0 r
.22456 .41267 .23916 .41301 .25995 .39567 .24551 .39578 Metetra
.104 .58 0 r
.24551 .39578 .25995 .39567 .28069 .3792 .26643 .37968 Metetra
.019 .546 0 r
.26643 .37968 .28069 .3792 .30139 .36375 .28732 .36452 Metetra
0 .517 .048 r
.28732 .36452 .30139 .36375 .32207 .34945 .30819 .35044 Metetra
0 .492 .099 r
.30819 .35044 .32207 .34945 .34274 .3364 .32905 .33755 Metetra
0 .473 .135 r
.32905 .33755 .34274 .3364 .36342 .32469 .34992 .32593 Metetra
0 .458 .159 r
.34992 .32593 .36342 .32469 .38413 .31437 .37084 .31564 Metetra
0 .45 .173 r
.37084 .31564 .38413 .31437 .40491 .30549 .39181 .30673 Metetra
0 .447 .177 r
.39181 .30673 .40491 .30549 .42577 .29807 .41288 .29923 Metetra
0 .45 .173 r
.41288 .29923 .42577 .29807 .44677 .29212 .43407 .29314 Metetra
0 .458 .159 r
.43407 .29314 .44677 .29212 .46792 .28763 .45542 .28844 Metetra
0 .473 .135 r
.45542 .28844 .46792 .28763 .48926 .28456 .47696 .28512 Metetra
0 .492 .099 r
.47696 .28512 .48926 .28456 .51082 .28288 .49872 .2831 Metetra
0 .517 .048 r
.49872 .2831 .51082 .28288 .53265 .2825 .52073 .28232 Metetra
.019 .546 0 r
.52073 .28232 .53265 .2825 .55476 .28333 .54303 .28268 Metetra
.104 .58 0 r
.54303 .28268 .55476 .28333 .5772 .28525 .56564 .28406 Metetra
.211 .617 0 r
.56564 .28406 .5772 .28525 .59998 .28812 .58859 .28629 Metetra
.338 .657 0 r
.58859 .28629 .59998 .28812 .62313 .29176 .6119 .2892 Metetra
.488 .699 0 r
.6119 .2892 .62313 .29176 .64666 .29595 .63559 .29255 Metetra
.657 .743 0 r
.63559 .29255 .64666 .29595 .67059 .30043 .65966 .29609 Metetra
.786 .729 0 r
.65966 .29609 .67059 .30043 .6949 .30492 .6841 .2995 Metetra
.828 .616 0 r
.6841 .2995 .6949 .30492 .7196 .30906 .7089 .30244 Metetra
.868 .495 0 r
.7089 .30244 .7196 .30906 .74464 .31246 .73404 .30448 Metetra
.904 .374 0 r
.73404 .30448 .74464 .31246 .76999 .31467 .75946 .30518 Metetra
.926 .296 0 r
.06319 .5252 .07854 .53228 .09906 .51728 .08366 .51162 Metetra
.895 .406 0 r
.08366 .51162 .09906 .51728 .11978 .50095 .10438 .49656 Metetra
.86 .522 0 r
.10438 .49656 .11978 .50095 .14065 .48371 .12528 .48044 Metetra
.822 .634 0 r
.12528 .48044 .14065 .48371 .1616 .46595 .1463 .46366 Metetra
.782 .738 0 r
.1463 .46366 .1616 .46595 .18259 .44799 .16738 .44657 Metetra
.657 .743 0 r
.16738 .44657 .18259 .44799 .20358 .43014 .18849 .42947 Metetra
.504 .704 0 r
.18849 .42947 .20358 .43014 .22456 .41267 .20961 .41263 Metetra
.369 .666 0 r
.20961 .41263 .22456 .41267 .24551 .39578 .23072 .39628 Metetra
.255 .632 0 r
.23072 .39628 .24551 .39578 .26643 .37968 .2518 .38062 Metetra
.16 .6 0 r
.2518 .38062 .26643 .37968 .28732 .36452 .27287 .36581 Metetra
.084 .572 0 r
.27287 .36581 .28732 .36452 .30819 .35044 .29393 .352 Metetra
.025 .549 0 r
.29393 .352 .30819 .35044 .32905 .33755 .31499 .3393 Metetra
0 .53 .018 r
.31499 .3393 .32905 .33755 .34992 .32593 .33607 .3278 Metetra
0 .517 .048 r
.33607 .3278 .34992 .32593 .37084 .31564 .35719 .31757 Metetra
0 .509 .065 r
.35719 .31757 .37084 .31564 .39181 .30673 .37837 .30864 Metetra
0 .506 .071 r
.37837 .30864 .39181 .30673 .41288 .29923 .39965 .30105 Metetra
0 .509 .065 r
.39965 .30105 .41288 .29923 .43407 .29314 .42105 .29481 Metetra
0 .517 .048 r
.42105 .29481 .43407 .29314 .45542 .28844 .4426 .28989 Metetra
0 .53 .018 r
.4426 .28989 .45542 .28844 .47696 .28512 .46435 .28627 Metetra
.025 .549 0 r
.46435 .28627 .47696 .28512 .49872 .2831 .48631 .28388 Metetra
.084 .572 0 r
.48631 .28388 .49872 .2831 .52073 .28232 .50852 .28266 Metetra
.16 .6 0 r
.50852 .28266 .52073 .28232 .54303 .28268 .53101 .28248 Metetra
.255 .632 0 r
.53101 .28248 .54303 .28268 .56564 .28406 .55381 .28323 Metetra
.369 .666 0 r
.55381 .28323 .56564 .28406 .58859 .28629 .57694 .28474 Metetra
.504 .704 0 r
.57694 .28474 .58859 .28629 .6119 .2892 .60042 .28681 Metetra
.657 .743 0 r
.60042 .28681 .6119 .2892 .63559 .29255 .62427 .28921 Metetra
.782 .738 0 r
.62427 .28921 .63559 .29255 .65966 .29609 .64848 .29166 Metetra
.822 .634 0 r
.64848 .29166 .65966 .29609 .6841 .2995 .67305 .29386 Metetra
.86 .522 0 r
.67305 .29386 .6841 .2995 .7089 .30244 .69797 .29542 Metetra
.895 .406 0 r
.69797 .29542 .7089 .30244 .73404 .30448 .72319 .29593 Metetra
.926 .296 0 r
.72319 .29593 .73404 .30448 .75946 .30518 .74867 .29491 Metetra
.946 .223 0 r
.0477 .51711 .06319 .5252 .08366 .51162 .06807 .50514 Metetra
.92 .318 0 r
.06807 .50514 .08366 .51162 .10438 .49656 .08875 .49152 Metetra
.89 .423 0 r
.08875 .49152 .10438 .49656 .12528 .48044 .10965 .47669 Metetra
.857 .531 0 r
.10965 .47669 .12528 .48044 .1463 .46366 .13071 .46105 Metetra
.822 .634 0 r
.13071 .46105 .1463 .46366 .16738 .44657 .15186 .44495 Metetra
.786 .729 0 r
.15186 .44495 .16738 .44657 .18849 .42947 .17307 .42871 Metetra
.69 .751 0 r
.17307 .42871 .18849 .42947 .20961 .41263 .19432 .41261 Metetra
.552 .716 0 r
.19432 .41261 .20961 .41263 .23072 .39628 .21557 .39689 Metetra
.432 .684 0 r
.21557 .39689 .23072 .39628 .2518 .38062 .23682 .38175 Metetra
.331 .655 0 r
.23682 .38175 .2518 .38062 .27287 .36581 .25807 .36736 Metetra
.247 .629 0 r
.25807 .36736 .27287 .36581 .29393 .352 .27931 .35388 Metetra
.182 .607 0 r
.27931 .35388 .29393 .352 .31499 .3393 .30057 .34142 Metetra
.132 .59 0 r
.30057 .34142 .31499 .3393 .33607 .3278 .32185 .33007 Metetra
.098 .577 0 r
.32185 .33007 .33607 .3278 .35719 .31757 .34318 .3199 Metetra
.077 .57 0 r
.34318 .3199 .35719 .31757 .37837 .30864 .36457 .31097 Metetra
.071 .567 0 r
.36457 .31097 .37837 .30864 .39965 .30105 .38607 .30329 Metetra
.077 .57 0 r
.38607 .30329 .39965 .30105 .42105 .29481 .40768 .29688 Metetra
.098 .577 0 r
.40768 .29688 .42105 .29481 .4426 .28989 .42945 .29172 Metetra
.132 .59 0 r
.42945 .29172 .4426 .28989 .46435 .28627 .45141 .28777 Metetra
.182 .607 0 r
.45141 .28777 .46435 .28627 .48631 .28388 .47358 .28497 Metetra
.247 .629 0 r
.47358 .28497 .48631 .28388 .50852 .28266 .496 .28323 Metetra
.331 .655 0 r
.496 .28323 .50852 .28266 .53101 .28248 .51869 .28245 Metetra
.432 .684 0 r
.51869 .28245 .53101 .28248 .55381 .28323 .54168 .28249 Metetra
.552 .716 0 r
.54168 .28249 .55381 .28323 .57694 .28474 .565 .28317 Metetra
.69 .751 0 r
.565 .28317 .57694 .28474 .60042 .28681 .58866 .28429 Metetra
.786 .729 0 r
.58866 .28429 .60042 .28681 .62427 .28921 .61267 .28561 Metetra
.822 .634 0 r
.61267 .28561 .62427 .28921 .64848 .29166 .63703 .28684 Metetra
.857 .531 0 r
.63703 .28684 .64848 .29166 .67305 .29386 .66174 .28765 Metetra
.89 .423 0 r
.66174 .28765 .67305 .29386 .69797 .29542 .68677 .28766 Metetra
.92 .318 0 r
.68677 .28766 .69797 .29542 .72319 .29593 .71208 .28644 Metetra
.946 .223 0 r
.71208 .28644 .72319 .29593 .74867 .29491 .73762 .28351 Metetra
.961 .161 0 r
.03213 .50762 .0477 .51711 .06807 .50514 .05236 .49745 Metetra
.942 .235 0 r
.05236 .49745 .06807 .50514 .08875 .49152 .07295 .48546 Metetra
.918 .325 0 r
.07295 .48546 .08875 .49152 .10965 .47669 .09381 .47208 Metetra
.89 .423 0 r
.09381 .47208 .10965 .47669 .13071 .46105 .11487 .45773 Metetra
.86 .522 0 r
.11487 .45773 .13071 .46105 .15186 .44495 .13607 .44277 Metetra
.828 .616 0 r
.13607 .44277 .15186 .44495 .17307 .42871 .15736 .42753 Metetra
.797 .702 0 r
.15736 .42753 .17307 .42871 .19432 .41261 .17871 .41228 Metetra
.755 .766 0 r
.17871 .41228 .19432 .41261 .21557 .39689 .20009 .39729 Metetra
.633 .737 0 r
.20009 .39729 .21557 .39689 .23682 .38175 .22149 .38275 Metetra
.528 .71 0 r
.22149 .38275 .23682 .38175 .25807 .36736 .2429 .36886 Metetra
.44 .686 0 r
.2429 .36886 .25807 .36736 .27931 .35388 .26433 .35576 Metetra
.369 .666 0 r
.26433 .35576 .27931 .35388 .30057 .34142 .28578 .34358 Metetra
.315 .65 0 r
.28578 .34358 .30057 .34142 .32185 .33007 .30727 .33242 Metetra
.277 .639 0 r
.30727 .33242 .32185 .33007 .34318 .3199 .32881 .32235 Metetra
.255 .632 0 r
.32881 .32235 .34318 .3199 .36457 .31097 .35042 .31342 Metetra
.247 .629 0 r
.35042 .31342 .36457 .31097 .38607 .30329 .37213 .30565 Metetra
.255 .632 0 r
.37213 .30565 .38607 .30329 .40768 .29688 .39397 .29906 Metetra
.277 .639 0 r
.39397 .29906 .40768 .29688 .42945 .29172 .41596 .29363 Metetra
.315 .65 0 r
.41596 .29363 .42945 .29172 .45141 .28777 .43814 .28931 Metetra
.369 .666 0 r
.43814 .28931 .45141 .28777 .47358 .28497 .46053 .28604 Metetra
.44 .686 0 r
.46053 .28604 .47358 .28497 .496 .28323 .48316 .28373 Metetra
.528 .71 0 r
.48316 .28373 .496 .28323 .51869 .28245 .50606 .28226 Metetra
.633 .737 0 r
.50606 .28226 .51869 .28245 .54168 .28249 .52926 .28149 Metetra
.755 .766 0 r
.52926 .28149 .54168 .28249 .565 .28317 .55277 .28124 Metetra
.797 .702 0 r
.55277 .28124 .565 .28317 .58866 .28429 .57661 .28129 Metetra
.828 .616 0 r
.57661 .28129 .58866 .28429 .61267 .28561 .60079 .28138 Metetra
.86 .522 0 r
.60079 .28138 .61267 .28561 .63703 .28684 .62531 .28123 Metetra
.89 .423 0 r
.62531 .28123 .63703 .28684 .66174 .28765 .65014 .28049 Metetra
.918 .325 0 r
.65014 .28049 .66174 .28765 .68677 .28766 .67528 .27876 Metetra
.942 .235 0 r
.67528 .27876 .68677 .28766 .71208 .28644 .70067 .27561 Metetra
.961 .161 0 r
.70067 .27561 .71208 .28644 .73762 .28351 .72626 .27056 Metetra
.972 .117 0 r
.01657 .4963 .03213 .50762 .05236 .49745 .0366 .48813 Metetra
.96 .165 0 r
.0366 .48813 .05236 .49745 .07295 .48546 .05705 .47795 Metetra
.942 .235 0 r
.05705 .47795 .07295 .48546 .09381 .47208 .07782 .46621 Metetra
.92 .318 0 r
.07782 .46621 .09381 .47208 .11487 .45773 .09884 .45332 Metetra
.895 .406 0 r
.09884 .45332 .11487 .45773 .13607 .44277 .12005 .43964 Metetra
.868 .495 0 r
.12005 .43964 .13607 .44277 .15736 .42753 .14139 .42553 Metetra
.841 .58 0 r
.14139 .42553 .15736 .42753 .17871 .41228 .16282 .41126 Metetra
.814 .657 0 r
.16282 .41126 .17871 .41228 .20009 .39729 .18431 .3971 Metetra
.788 .724 0 r
.18431 .3971 .20009 .39729 .22149 .38275 .20584 .38326 Metetra
.746 .764 0 r
.20584 .38326 .22149 .38275 .2429 .36886 .22741 .36994 Metetra
.657 .743 0 r
.22741 .36994 .2429 .36886 .26433 .35576 .24901 .35729 Metetra
.584 .725 0 r
.24901 .35729 .26433 .35576 .28578 .34358 .27065 .34545 Metetra
.528 .71 0 r
.27065 .34545 .28578 .34358 .30727 .33242 .29234 .33451 Metetra
.488 .699 0 r
.29234 .33451 .30727 .33242 .32881 .32235 .31409 .32456 Metetra
.464 .693 0 r
.31409 .32456 .32881 .32235 .35042 .31342 .33591 .31564 Metetra
.456 .691 0 r
.33591 .31564 .35042 .31342 .37213 .30565 .35785 .30778 Metetra
.464 .693 0 r
.35785 .30778 .37213 .30565 .39397 .29906 .37991 .301 Metetra
.488 .699 0 r
.37991 .301 .39397 .29906 .41596 .29363 .40213 .29526 Metetra
.528 .71 0 r
.40213 .29526 .41596 .29363 .43814 .28931 .42453 .29053 Metetra
.584 .725 0 r
.42453 .29053 .43814 .28931 .46053 .28604 .44715 .28673 Metetra
.657 .743 0 r
.44715 .28673 .46053 .28604 .48316 .28373 .47 .28377 Metetra
.746 .764 0 r
.47 .28377 .48316 .28373 .50606 .28226 .49312 .28154 Metetra
.788 .724 0 r
.49312 .28154 .50606 .28226 .52926 .28149 .51653 .27986 Metetra
.814 .657 0 r
.51653 .27986 .52926 .28149 .55277 .28124 .54024 .27856 Metetra
.841 .58 0 r
.54024 .27856 .55277 .28124 .57661 .28129 .56426 .2774 Metetra
.868 .495 0 r
.56426 .2774 .57661 .28129 .60079 .28138 .58861 .27612 Metetra
.895 .406 0 r
.58861 .27612 .60079 .28138 .62531 .28123 .61328 .27442 Metetra
.92 .318 0 r
.61328 .27442 .62531 .28123 .65014 .28049 .63825 .27194 Metetra
.942 .235 0 r
.63825 .27194 .65014 .28049 .67528 .27876 .66349 .26828 Metetra
.96 .165 0 r
.66349 .26828 .67528 .27876 .70067 .27561 .68895 .26299 Metetra
.972 .117 0 r
.68895 .26299 .70067 .27561 .72626 .27056 .71457 .25558 Metetra
.976 .099 0 r
.00111 .48265 .01657 .4963 .0366 .48813 .02087 .47669 Metetra
.972 .117 0 r
.02087 .47669 .0366 .48813 .05705 .47795 .04112 .46852 Metetra
.961 .161 0 r
.04112 .46852 .05705 .47795 .07782 .46621 .06175 .4586 Metetra
.946 .223 0 r
.06175 .4586 .07782 .46621 .09884 .45332 .08269 .44733 Metetra
.926 .296 0 r
.08269 .44733 .09884 .45332 .12005 .43964 .10387 .43511 Metetra
.904 .374 0 r
.10387 .43511 .12005 .43964 .14139 .42553 .12521 .42226 Metetra
.882 .452 0 r
.12521 .42226 .14139 .42553 .16282 .41126 .14669 .4091 Metetra
.859 .526 0 r
.14669 .4091 .16282 .41126 .18431 .3971 .16827 .39589 Metetra
.836 .593 0 r
.16827 .39589 .18431 .3971 .20584 .38326 .18992 .38285 Metetra
.815 .652 0 r
.18992 .38285 .20584 .38326 .22741 .36994 .21162 .37018 Metetra
.797 .702 0 r
.21162 .37018 .22741 .36994 .24901 .35729 .23339 .35806 Metetra
.781 .742 0 r
.23339 .35806 .24901 .35729 .27065 .34545 .2552 .34661 Metetra
.763 .768 0 r
.2552 .34661 .27065 .34545 .29234 .33451 .27708 .33594 Metetra
.722 .758 0 r
.27708 .33594 .29234 .33451 .31409 .32456 .29903 .32613 Metetra
.698 .752 0 r
.29903 .32613 .31409 .32456 .33591 .31564 .32107 .31723 Metetra
.69 .75 0 r
.32107 .31723 .33591 .31564 .35785 .30778 .34323 .30928 Metetra
.698 .752 0 r
.34323 .30928 .35785 .30778 .37991 .301 .36552 .30228 Metetra
.722 .758 0 r
.36552 .30228 .37991 .301 .40213 .29526 .38797 .29621 Metetra
.763 .768 0 r
.38797 .29621 .40213 .29526 .42453 .29053 .4106 .29101 Metetra
.781 .742 0 r
.4106 .29101 .42453 .29053 .44715 .28673 .43344 .28663 Metetra
.797 .702 0 r
.43344 .28663 .44715 .28673 .47 .28377 .45652 .28295 Metetra
.815 .652 0 r
.45652 .28295 .47 .28377 .49312 .28154 .47986 .27984 Metetra
.836 .593 0 r
.47986 .27984 .49312 .28154 .51653 .27986 .50348 .27715 Metetra
.859 .526 0 r
.50348 .27715 .51653 .27986 .54024 .27856 .52739 .27466 Metetra
.882 .452 0 r
.52739 .27466 .54024 .27856 .56426 .2774 .55161 .27216 Metetra
.904 .374 0 r
.55161 .27216 .56426 .2774 .58861 .27612 .57613 .26935 Metetra
.926 .296 0 r
.57613 .26935 .58861 .27612 .61328 .27442 .60095 .26592 Metetra
.946 .223 0 r
.60095 .26592 .61328 .27442 .63825 .27194 .62604 .26151 Metetra
.961 .161 0 r
.62604 .26151 .63825 .27194 .66349 .26828 .65138 .25571 Metetra
.972 .117 0 r
.65138 .25571 .66349 .26828 .68895 .26299 .67691 .24806 Metetra
.976 .099 0 r
.67691 .24806 .68895 .26299 .71457 .25558 .70256 .23806 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 233.562},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{145., 432.}, {288., 56.}} -> {-0.5784220080805097, \
0.2514653599029323, 0.0035800367244681977, \
0.0035800367244681977}},ExpressionUUID->"38662434-5d71-400a-adcf-\
6e4c8d065159"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"10.529999999999973`", " ", "Second"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ComponentNumber", "\[Rule]", "2"}], ",", 
      RowBox[{"Energy", "\[Rule]", "100.`"}], ",", 
      RowBox[{"Offset", "\[Rule]", "155.23250625987404`"}], ",", 
      RowBox[{"OpticalLengthFunction", "\[Rule]", 
       TagBox[
        RowBox[{"CompiledFunction", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#1", "\[Equal]", "0"}], "&&", 
             RowBox[{"#2", "\[Equal]", "0"}]}], ",", "155.23245157878875`", 
            ",", 
            RowBox[{
             RowBox[{"155.25089886845007`", "\[InvisibleSpace]"}], "-", 
             RowBox[{"2.8838985855792276`*^-9", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["#1", "2"], "+", 
                SuperscriptBox["#2", "2"]}], ")"}]}], "+", 
             RowBox[{"0.013712112400497804`", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"0.006209067528539418`", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{"8.658162146957153`*^-7", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "0.009313601292809127`"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "+", 
                RowBox[{"0.0000385525195739626`", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}]}], ")"}]}], 
             "-", 
             RowBox[{"0.004893482322796429`", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"0.018627202585618254`", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "+", 
                RowBox[{"0.00005782877936094391`", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}]}], ")"}]}], 
             "+", 
             RowBox[{"6.378518354310161`*^-6", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"4", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "0.00004819064946745325`"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}], "+", 
                RowBox[{"1.7953139807255362`*^-7", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "3"]}]}], ")"}]}], 
             "-", 
             RowBox[{"4.3494383308015985`*^-7", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"0.018627202585618254`", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "-", 
                RowBox[{"0.000192762597869813`", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}], "+", 
                RowBox[{"4.488284951813841`*^-7", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "3"]}]}], ")"}]}], 
             "-", 
             RowBox[{"0.00015830506196050484`", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"0.03725440517123651`", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "-", 
                RowBox[{"0.0002891438968047195`", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}], "+", 
                RowBox[{"5.984379935751788`*^-7", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "3"]}]}], ")"}]}]}]}],
            "]"}], ",", "\<\"-CompiledCode-\"\>"}], "]"}],
        False,
        Editable->False]}], ",", 
      RowBox[{"OpticalPathDifference", "\[Rule]", 
       TagBox[
        RowBox[{"CompiledFunction", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#1", "\[Equal]", "0"}], "&&", 
             RowBox[{"#2", "\[Equal]", "0"}]}], ",", 
            RowBox[{"-", "0.10278399575815439`"}], ",", 
            RowBox[{
             RowBox[{"34.57257251087704`", "\[InvisibleSpace]"}], "-", 
             RowBox[{"5.420859346745704`*^-6", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["#1", "2"], "+", 
                SuperscriptBox["#2", "2"]}], ")"}]}], "+", 
             RowBox[{"1.5341525684545546`*^-7", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"4", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["#1", "2"], "+", 
                 SuperscriptBox["#2", "2"]}], ")"}], "2"]}], "+", 
             RowBox[{"25.774647368542087`", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"0.006209067528539418`", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{"0.0016274736098964187`", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "0.009313601292809127`"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "+", 
                RowBox[{"0.0000385525195739626`", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}]}], ")"}]}], 
             "-", 
             RowBox[{"9.198275043751126`", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"0.018627202585618254`", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "+", 
                RowBox[{"0.00005782877936094391`", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}]}], ")"}]}], 
             "+", 
             RowBox[{"0.011989695850228327`", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"4", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "0.00004819064946745325`"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}], "+", 
                RowBox[{"1.7953139807255362`*^-7", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "3"]}]}], ")"}]}], 
             "-", 
             RowBox[{"0.0008175630752928467`", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"0.018627202585618254`", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "-", 
                RowBox[{"0.000192762597869813`", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}], "+", 
                RowBox[{"4.488284951813841`*^-7", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "3"]}]}], ")"}]}], 
             "-", 
             RowBox[{"0.2975659056580214`", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"0.03725440517123651`", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "-", 
                RowBox[{"0.0002891438968047195`", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}], "+", 
                RowBox[{"5.984379935751788`*^-7", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "3"]}]}], ")"}]}]}]}],
            "]"}], ",", "\<\"-CompiledCode-\"\>"}], "]"}],
        False,
        Editable->False]}], ",", 
      RowBox[{"OpticalPathRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"155.23250625987404`", ",", "155.25963194161014`"}], "}"}]}], 
      ",", 
      RowBox[{"OutputGraphics", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"OpticalLengthFunction", "\[Rule]", 
          RowBox[{"(", 
           TagBox[
            RowBox[{
            "\[SkeletonIndicator]", "SurfaceGraphics", 
             "\[SkeletonIndicator]"}],
            False,
            Editable->False], ")"}]}], ",", 
         RowBox[{"WaveFrontIntensity", "\[Rule]", 
          RowBox[{"(", 
           TagBox[
            RowBox[{
            "\[SkeletonIndicator]", "SurfaceGraphics", 
             "\[SkeletonIndicator]"}],
            False,
            Editable->False], ")"}]}], ",", 
         RowBox[{"OpticalPathDifference", "\[Rule]", 
          RowBox[{"(", 
           TagBox[
            RowBox[{
            "\[SkeletonIndicator]", "SurfaceGraphics", 
             "\[SkeletonIndicator]"}],
            False,
            Editable->False], ")"}]}]}], "}"}]}], ",", 
      RowBox[{"RayBoundary", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "12.690848135359127`"}], ",", "12.690848135359127`"}],
           "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "12.69062378508626`"}], ",", "12.69062378508626`"}], 
          "}"}]}], "}"}]}], ",", 
      RowBox[{"RefractiveIndex", "\[Rule]", "1.0002694514570802`"}], ",", 
      RowBox[{"ResidualFitError", "\[Rule]", "0.003354510990161439`"}], ",", 
      RowBox[{"Source", "\[Rule]", "1"}], ",", 
      RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
      RowBox[{"SurfaceNumber", "\[Rule]", "1"}], ",", 
      RowBox[{"WaveFrontID", "\[Rule]", "1"}], ",", 
      RowBox[{"WaveFrontIntensity", "\[Rule]", 
       TagBox[
        RowBox[{"InterpolatingFunction", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "17.00773585640436`"}], ",", 
              "17.00773585640436`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "17.007511506131493`"}], ",", 
              "17.007511506131493`"}], "}"}]}], "}"}], ",", "\<\"<>\"\>"}], 
         "]"}],
        False,
        Editable->False]}], ",", 
      RowBox[{"WaveLength", "\[Rule]", "0.532`"}], ",", 
      RowBox[{"WaveTilt", "\[Rule]", "WaveTilt"}]}], "}"}], "}"}]}], 
  "}"}]], "Output",ExpressionUUID->"0fa3aee2-16aa-46d3-b6d5-723ca666fcfc"]
}, Open  ]],

Cell[TextData[{
 "Next we use ",
 StyleBox["RayTracePrecision->100", "Input"],
 " with ",
 StyleBox["FindWaveFronts", "Input"],
 " to increase the precision of the result to 100 decimal places."
}], "Text",ExpressionUUID->"3076462c-e28c-49c0-80b9-8eb6f3245d77"],

Cell[CellGroupData[{

Cell["Timing[wav = FindWaveFronts[sys2D,RayTracePrecision->100]]", "Input",ExpressionUUID->"713d1d20-fff2-46a5-9251-480d37633767"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface Location : \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ComponentNumber", "\[Rule]", "2"}], ",", 
     RowBox[{"SurfaceNumber", "\[Rule]", "1"}], ",", 
     RowBox[{"WaveFrontID", "\[Rule]", "1"}], ",", 
     RowBox[{"Source", "\[Rule]", "1"}]}], "}"}]}],
  SequenceForm[
  "Surface Location : ", {
   ComponentNumber -> 2, SurfaceNumber -> 1, WaveFrontID -> 1, Source -> 1}],
  Editable->False]], "Print",ExpressionUUID->"5bd116b9-0725-4057-a301-\
4bc78c856a8a"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.24573e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -117 0 ]
[.5 .82364 117 9 ]
[.08965 .22175 -18 -8.88375 ]
[.08965 .22175 0 .11625 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60423 .01939 -10.1877 -9 ]
[.60423 .01939 1.81231 0 ]
[.73698 .05037 0 -6.2075 ]
[.73698 .05037 18 2.7925 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95739 .38791 0 -5.88802 ]
[.95739 .38791 12 3.11198 ]
[.01479 .32352 -36 -2.79172 ]
[.01479 .32352 0 6.20828 ]
[.00179 .40505 -36 -2.86096 ]
[.00179 .40505 0 6.13904 ]
[-0.01191 .49092 -36 -2.9343 ]
[-0.01191 .49092 0 6.0657 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Length \\(absolute distance\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72471 .05502 m
.71857 .05735 L
s
[(-10)] .73698 .05037 -1 .37944 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94486 .39177 m
.93859 .39371 L
s
[(10)] .95739 .38791 -1 .30845 Mshowa
.125 Mabswid
.75031 .09419 m
.74662 .09556 L
s
.775 .13196 m
.7713 .1333 L
s
.79883 .16841 m
.79512 .16972 L
s
.82184 .2036 m
.81812 .2049 L
s
.86557 .27049 m
.86184 .27174 L
s
.88636 .3023 m
.88262 .30352 L
s
.90649 .33308 m
.90274 .33428 L
s
.92597 .36289 m
.92222 .36407 L
s
.69814 .01439 m
.69447 .01581 L
s
.96316 .41977 m
.95939 .42091 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02706 .31887 m
.03319 .31654 L
s
[(155.24)] .01479 .32352 1 -0.37962 Mshowa
.01412 .40055 m
.02028 .39831 L
s
[(155.25)] .00179 .40505 1 -0.36423 Mshowa
.00048 .4866 m
.00668 .48445 L
s
[(155.26)] -0.01191 .49092 1 -0.34793 Mshowa
.125 Mabswid
.02452 .33487 m
.02821 .33348 L
s
.02196 .35104 m
.02565 .34966 L
s
.01937 .36737 m
.02307 .36601 L
s
.01676 .38388 m
.02045 .38252 L
s
.01145 .4174 m
.01515 .41607 L
s
.00875 .43443 m
.01245 .43311 L
s
.00602 .45164 m
.00973 .45032 L
s
.00326 .46903 m
.00698 .46772 L
s
.02957 .30302 m
.03325 .30162 L
s
.03206 .28734 m
.03573 .28592 L
s
.03452 .27181 m
.03819 .27039 L
s
.03695 .25644 m
.04062 .255 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.977 .099 0 r
.38757 .79726 .39809 .80491 .41556 .80118 .40517 .79141 Metetra
.972 .117 0 r
.40517 .79141 .41556 .80118 .4332 .7955 .42294 .78376 Metetra
.961 .161 0 r
.42294 .78376 .4332 .7955 .45097 .78826 .44082 .77472 Metetra
.945 .223 0 r
.44082 .77472 .45097 .78826 .46885 .77985 .45879 .76466 Metetra
.926 .297 0 r
.45879 .76466 .46885 .77985 .48683 .7706 .47684 .75391 Metetra
.904 .375 0 r
.47684 .75391 .48683 .7706 .50488 .76081 .49496 .74278 Metetra
.881 .453 0 r
.49496 .74278 .50488 .76081 .523 .75075 .51312 .73152 Metetra
.858 .527 0 r
.51312 .73152 .523 .75075 .54118 .74066 .53135 .72037 Metetra
.836 .594 0 r
.53135 .72037 .54118 .74066 .55943 .73075 .54963 .70953 Metetra
.815 .653 0 r
.54963 .70953 .55943 .73075 .57776 .72119 .56798 .69917 Metetra
.796 .702 0 r
.56798 .69917 .57776 .72119 .59618 .71213 .58641 .68944 Metetra
.78 .743 0 r
.58641 .68944 .59618 .71213 .61469 .7037 .60493 .68046 Metetra
.762 .767 0 r
.60493 .68046 .61469 .7037 .63331 .696 .62356 .67232 Metetra
.721 .758 0 r
.62356 .67232 .63331 .696 .65207 .6891 .64232 .6651 Metetra
.697 .752 0 r
.64232 .6651 .65207 .6891 .67096 .68304 .66122 .65884 Metetra
.689 .75 0 r
.66122 .65884 .67096 .68304 .69002 .67786 .68028 .65356 Metetra
.697 .752 0 r
.68028 .65356 .69002 .67786 .70925 .67356 .69952 .64929 Metetra
.721 .758 0 r
.69952 .64929 .70925 .67356 .72867 .67013 .71896 .64599 Metetra
.762 .767 0 r
.71896 .64599 .72867 .67013 .74831 .66751 .73862 .64363 Metetra
.78 .743 0 r
.73862 .64363 .74831 .66751 .76816 .66565 .75851 .64215 Metetra
.796 .702 0 r
.75851 .64215 .76816 .66565 .78824 .66446 .77864 .64146 Metetra
.815 .653 0 r
.77864 .64146 .78824 .66446 .80855 .66381 .79902 .64145 Metetra
.836 .594 0 r
.79902 .64145 .80855 .66381 .8291 .66356 .81965 .64197 Metetra
.858 .527 0 r
.81965 .64197 .8291 .66356 .84987 .66353 .84053 .64285 Metetra
.881 .453 0 r
.84053 .64285 .84987 .66353 .87085 .66351 .86165 .6439 Metetra
.904 .375 0 r
.86165 .6439 .87085 .66351 .89202 .66324 .88299 .64486 Metetra
.926 .297 0 r
.88299 .64486 .89202 .66324 .91334 .66245 .90452 .64546 Metetra
.945 .223 0 r
.90452 .64546 .91334 .66245 .93478 .6608 .92621 .64539 Metetra
.961 .161 0 r
.92621 .64539 .93478 .6608 .95627 .65794 .948 .64428 Metetra
.972 .117 0 r
.948 .64428 .95627 .65794 .97774 .65345 .96981 .64172 Metetra
.977 .099 0 r
.96981 .64172 .97774 .65345 .99909 .64688 .99158 .63727 Metetra
.972 .117 0 r
.37699 .78759 .38757 .79726 .40517 .79141 .39474 .77976 Metetra
.96 .165 0 r
.39474 .77976 .40517 .79141 .42294 .78376 .41262 .7703 Metetra
.942 .235 0 r
.41262 .7703 .42294 .78376 .44082 .77472 .43061 .75959 Metetra
.92 .318 0 r
.43061 .75959 .44082 .77472 .45879 .76466 .44868 .74802 Metetra
.895 .407 0 r
.44868 .74802 .45879 .76466 .47684 .75391 .4668 .7359 Metetra
.868 .496 0 r
.4668 .7359 .47684 .75391 .49496 .74278 .48498 .72353 Metetra
.841 .58 0 r
.48498 .72353 .49496 .74278 .51312 .73152 .50319 .71117 Metetra
.814 .657 0 r
.50319 .71117 .51312 .73152 .53135 .72037 .52146 .69905 Metetra
.788 .725 0 r
.52146 .69905 .53135 .72037 .54963 .70953 .53977 .68736 Metetra
.746 .764 0 r
.53977 .68736 .54963 .70953 .56798 .69917 .55814 .67628 Metetra
.656 .742 0 r
.55814 .67628 .56798 .69917 .58641 .68944 .57659 .66593 Metetra
.583 .724 0 r
.57659 .66593 .58641 .68944 .60493 .68046 .59512 .65644 Metetra
.527 .71 0 r
.59512 .65644 .60493 .68046 .62356 .67232 .61375 .6479 Metetra
.487 .699 0 r
.61375 .6479 .62356 .67232 .64232 .6651 .63251 .64038 Metetra
.463 .693 0 r
.63251 .64038 .64232 .6651 .66122 .65884 .65141 .63392 Metetra
.455 .691 0 r
.65141 .63392 .66122 .65884 .68028 .65356 .67048 .62855 Metetra
.463 .693 0 r
.67048 .62855 .68028 .65356 .69952 .64929 .68972 .62428 Metetra
.487 .699 0 r
.68972 .62428 .69952 .64929 .71896 .64599 .70918 .6211 Metetra
.527 .71 0 r
.70918 .6211 .71896 .64599 .73862 .64363 .72885 .61896 Metetra
.583 .724 0 r
.72885 .61896 .73862 .64363 .75851 .64215 .74876 .6178 Metetra
.656 .742 0 r
.74876 .6178 .75851 .64215 .77864 .64146 .76893 .61755 Metetra
.746 .764 0 r
.76893 .61755 .77864 .64146 .79902 .64145 .78936 .6181 Metetra
.788 .725 0 r
.78936 .6181 .79902 .64145 .81965 .64197 .81006 .61931 Metetra
.814 .657 0 r
.81006 .61931 .81965 .64197 .84053 .64285 .83103 .62101 Metetra
.841 .58 0 r
.83103 .62101 .84053 .64285 .86165 .6439 .85227 .62301 Metetra
.868 .496 0 r
.85227 .62301 .86165 .6439 .88299 .64486 .87376 .62508 Metetra
.895 .407 0 r
.87376 .62508 .88299 .64486 .90452 .64546 .89547 .62694 Metetra
.92 .318 0 r
.89547 .62694 .90452 .64546 .92621 .64539 .91738 .62829 Metetra
.942 .235 0 r
.91738 .62829 .92621 .64539 .948 .64428 .93943 .62877 Metetra
.96 .165 0 r
.93943 .62877 .948 .64428 .96981 .64172 .96156 .62797 Metetra
.972 .117 0 r
.96156 .62797 .96981 .64172 .99158 .63727 .98368 .62547 Metetra
.961 .161 0 r
.36636 .77628 .37699 .78759 .39474 .77976 .38424 .76664 Metetra
.942 .235 0 r
.38424 .76664 .39474 .77976 .41262 .7703 .40225 .7555 Metetra
.918 .325 0 r
.40225 .7555 .41262 .7703 .43061 .75959 .42034 .74327 Metetra
.89 .423 0 r
.42034 .74327 .43061 .75959 .44868 .74802 .4385 .73031 Metetra
.86 .522 0 r
.4385 .73031 .44868 .74802 .4668 .7359 .4567 .71694 Metetra
.828 .616 0 r
.4567 .71694 .4668 .7359 .48498 .72353 .47494 .70344 Metetra
.797 .702 0 r
.47494 .70344 .48498 .72353 .50319 .71117 .49321 .69009 Metetra
.754 .766 0 r
.49321 .69009 .50319 .71117 .52146 .69905 .51151 .67708 Metetra
.632 .737 0 r
.51151 .67708 .52146 .69905 .53977 .68736 .52986 .66462 Metetra
.527 .71 0 r
.52986 .66462 .53977 .68736 .55814 .67628 .54826 .65287 Metetra
.439 .686 0 r
.54826 .65287 .55814 .67628 .57659 .66593 .56672 .64196 Metetra
.369 .666 0 r
.56672 .64196 .57659 .66593 .59512 .65644 .58526 .632 Metetra
.315 .65 0 r
.58526 .632 .59512 .65644 .61375 .6479 .6039 .62309 Metetra
.277 .638 0 r
.6039 .62309 .61375 .6479 .63251 .64038 .62266 .61529 Metetra
.254 .631 0 r
.62266 .61529 .63251 .64038 .65141 .63392 .64156 .60865 Metetra
.247 .629 0 r
.64156 .60865 .65141 .63392 .67048 .62855 .66063 .60319 Metetra
.254 .631 0 r
.66063 .60319 .67048 .62855 .68972 .62428 .67988 .59891 Metetra
.277 .638 0 r
.67988 .59891 .68972 .62428 .70918 .6211 .69933 .59581 Metetra
.315 .65 0 r
.69933 .59581 .70918 .6211 .72885 .61896 .71902 .59386 Metetra
.369 .666 0 r
.71902 .59386 .72885 .61896 .74876 .6178 .73895 .59298 Metetra
.439 .686 0 r
.73895 .59298 .74876 .6178 .76893 .61755 .75915 .59312 Metetra
.527 .71 0 r
.75915 .59312 .76893 .61755 .78936 .6181 .77962 .59415 Metetra
.632 .737 0 r
.77962 .59415 .78936 .6181 .81006 .61931 .80038 .59597 Metetra
.754 .766 0 r
.80038 .59597 .81006 .61931 .83103 .62101 .82143 .59839 Metetra
.797 .702 0 r
.82143 .59839 .83103 .62101 .85227 .62301 .84276 .60124 Metetra
.828 .616 0 r
.84276 .60124 .85227 .62301 .87376 .62508 .86437 .6043 Metetra
.86 .522 0 r
.86437 .6043 .87376 .62508 .89547 .62694 .88624 .60729 Metetra
.89 .423 0 r
.88624 .60729 .89547 .62694 .91738 .62829 .90834 .60991 Metetra
.918 .325 0 r
.90834 .60991 .91738 .62829 .93943 .62877 .93062 .61182 Metetra
.942 .235 0 r
.93062 .61182 .93943 .62877 .96156 .62797 .95302 .61263 Metetra
.961 .161 0 r
.95302 .61263 .96156 .62797 .98368 .62547 .97547 .6119 Metetra
.945 .223 0 r
.35566 .7637 .36636 .77628 .38424 .76664 .37369 .7524 Metetra
.92 .318 0 r
.37369 .7524 .38424 .76664 .40225 .7555 .39181 .73974 Metetra
.89 .423 0 r
.39181 .73974 .40225 .7555 .42034 .74327 .41001 .72612 Metetra
.857 .531 0 r
.41001 .72612 .42034 .74327 .4385 .73031 .42826 .71189 Metetra
.822 .634 0 r
.42826 .71189 .4385 .73031 .4567 .71694 .44654 .69738 Metetra
.786 .729 0 r
.44654 .69738 .4567 .71694 .47494 .70344 .46485 .68287 Metetra
.689 .75 0 r
.46485 .68287 .47494 .70344 .49321 .69009 .48317 .6686 Metetra
.552 .716 0 r
.48317 .6686 .49321 .69009 .51151 .67708 .50152 .65479 Metetra
.432 .684 0 r
.50152 .65479 .51151 .67708 .52986 .66462 .5199 .64163 Metetra
.33 .655 0 r
.5199 .64163 .52986 .66462 .54826 .65287 .53832 .62927 Metetra
.247 .629 0 r
.53832 .62927 .54826 .65287 .56672 .64196 .5568 .61785 Metetra
.181 .607 0 r
.5568 .61785 .56672 .64196 .58526 .632 .57536 .60747 Metetra
.132 .59 0 r
.57536 .60747 .58526 .632 .6039 .62309 .59401 .59822 Metetra
.097 .577 0 r
.59401 .59822 .6039 .62309 .62266 .61529 .61277 .59016 Metetra
.077 .57 0 r
.61277 .59016 .62266 .61529 .64156 .60865 .63168 .58334 Metetra
.07 .567 0 r
.63168 .58334 .64156 .60865 .66063 .60319 .65074 .57778 Metetra
.077 .57 0 r
.65074 .57778 .66063 .60319 .67988 .59891 .66999 .5735 Metetra
.097 .577 0 r
.66999 .5735 .67988 .59891 .69933 .59581 .68946 .57046 Metetra
.132 .59 0 r
.68946 .57046 .69933 .59581 .71902 .59386 .70915 .56866 Metetra
.181 .607 0 r
.70915 .56866 .71902 .59386 .73895 .59298 .7291 .56802 Metetra
.247 .629 0 r
.7291 .56802 .73895 .59298 .75915 .59312 .74931 .56849 Metetra
.33 .655 0 r
.74931 .56849 .75915 .59312 .77962 .59415 .76982 .56995 Metetra
.432 .684 0 r
.76982 .56995 .77962 .59415 .80038 .59597 .79062 .57229 Metetra
.552 .716 0 r
.79062 .57229 .80038 .59597 .82143 .59839 .81174 .57535 Metetra
.689 .75 0 r
.81174 .57535 .82143 .59839 .84276 .60124 .83315 .57895 Metetra
.786 .729 0 r
.83315 .57895 .84276 .60124 .86437 .6043 .85487 .58287 Metetra
.822 .634 0 r
.85487 .58287 .86437 .6043 .88624 .60729 .87688 .58687 Metetra
.857 .531 0 r
.87688 .58687 .88624 .60729 .90834 .60991 .89914 .59063 Metetra
.89 .423 0 r
.89914 .59063 .90834 .60991 .93062 .61182 .92162 .59383 Metetra
.92 .318 0 r
.92162 .59383 .93062 .61182 .95302 .61263 .94427 .59608 Metetra
.945 .223 0 r
.94427 .59608 .95302 .61263 .97547 .6119 .96701 .59694 Metetra
.926 .297 0 r
.3449 .75018 .35566 .7637 .37369 .7524 .36306 .73737 Metetra
.895 .407 0 r
.36306 .73737 .37369 .7524 .39181 .73974 .38131 .72333 Metetra
.86 .522 0 r
.38131 .72333 .39181 .73974 .41001 .72612 .39962 .70845 Metetra
.822 .634 0 r
.39962 .70845 .41001 .72612 .42826 .71189 .41796 .69308 Metetra
.782 .738 0 r
.41796 .69308 .42826 .71189 .44654 .69738 .43632 .67754 Metetra
.657 .743 0 r
.43632 .67754 .44654 .69738 .46485 .68287 .4547 .6621 Metetra
.503 .704 0 r
.4547 .6621 .46485 .68287 .48317 .6686 .47308 .64701 Metetra
.369 .666 0 r
.47308 .64701 .48317 .6686 .50152 .65479 .49148 .63248 Metetra
.255 .631 0 r
.49148 .63248 .50152 .65479 .5199 .64163 .5099 .61869 Metetra
.16 .6 0 r
.5099 .61869 .5199 .64163 .53832 .62927 .52835 .60578 Metetra
.084 .572 0 r
.52835 .60578 .53832 .62927 .5568 .61785 .54685 .5939 Metetra
.025 .549 0 r
.54685 .5939 .5568 .61785 .57536 .60747 .56542 .58313 Metetra
0 .53 .019 r
.56542 .58313 .57536 .60747 .59401 .59822 .58408 .57357 Metetra
0 .517 .048 r
.58408 .57357 .59401 .59822 .61277 .59016 .60286 .56527 Metetra
0 .509 .066 r
.60286 .56527 .61277 .59016 .63168 .58334 .62177 .55828 Metetra
0 .506 .071 r
.62177 .55828 .63168 .58334 .65074 .57778 .64083 .55263 Metetra
0 .509 .066 r
.64083 .55263 .65074 .57778 .66999 .5735 .66009 .54831 Metetra
0 .517 .048 r
.66009 .54831 .66999 .5735 .68946 .57046 .67955 .54533 Metetra
0 .53 .019 r
.67955 .54533 .68946 .57046 .70915 .56866 .69925 .54364 Metetra
.025 .549 0 r
.69925 .54364 .70915 .56866 .7291 .56802 .71921 .54321 Metetra
.084 .572 0 r
.71921 .54321 .7291 .56802 .74931 .56849 .73945 .54395 Metetra
.16 .6 0 r
.73945 .54395 .74931 .56849 .76982 .56995 .75998 .54578 Metetra
.255 .631 0 r
.75998 .54578 .76982 .56995 .79062 .57229 .78083 .54857 Metetra
.369 .666 0 r
.78083 .54857 .79062 .57229 .81174 .57535 .80199 .55219 Metetra
.503 .704 0 r
.80199 .55219 .81174 .57535 .83315 .57895 .82348 .55645 Metetra
.657 .743 0 r
.82348 .55645 .83315 .57895 .85487 .58287 .84529 .56114 Metetra
.782 .738 0 r
.84529 .56114 .85487 .58287 .87688 .58687 .86741 .56601 Metetra
.822 .634 0 r
.86741 .56601 .87688 .58687 .89914 .59063 .88982 .57079 Metetra
.86 .522 0 r
.88982 .57079 .89914 .59063 .92162 .59383 .91248 .57513 Metetra
.895 .407 0 r
.91248 .57513 .92162 .59383 .94427 .59608 .93534 .57866 Metetra
.926 .297 0 r
.93534 .57866 .94427 .59608 .96701 .59694 .95833 .58095 Metetra
.904 .375 0 r
.33406 .73602 .3449 .75018 .36306 .73737 .35236 .72185 Metetra
.868 .496 0 r
.35236 .72185 .36306 .73737 .38131 .72333 .37073 .70656 Metetra
.828 .616 0 r
.37073 .70656 .38131 .72333 .39962 .70845 .38915 .69055 Metetra
.786 .729 0 r
.38915 .69055 .39962 .70845 .41796 .69308 .40759 .67415 Metetra
.657 .743 0 r
.40759 .67415 .41796 .69308 .43632 .67754 .42604 .65768 Metetra
.487 .699 0 r
.42604 .65768 .43632 .67754 .4547 .6621 .44448 .64142 Metetra
.338 .657 0 r
.44448 .64142 .4547 .6621 .47308 .64701 .46293 .6256 Metetra
.21 .617 0 r
.46293 .6256 .47308 .64701 .49148 .63248 .48138 .61041 Metetra
.104 .58 0 r
.48138 .61041 .49148 .63248 .5099 .61869 .49984 .59605 Metetra
.019 .546 0 r
.49984 .59605 .5099 .61869 .52835 .60578 .51833 .58265 Metetra
0 .517 .048 r
.51833 .58265 .52835 .60578 .54685 .5939 .53686 .57034 Metetra
0 .492 .099 r
.53686 .57034 .54685 .5939 .56542 .58313 .55545 .55922 Metetra
0 .472 .135 r
.55545 .55922 .56542 .58313 .58408 .57357 .57413 .54937 Metetra
0 .458 .159 r
.57413 .54937 .58408 .57357 .60286 .56527 .59291 .54085 Metetra
0 .45 .173 r
.59291 .54085 .60286 .56527 .62177 .55828 .61183 .53371 Metetra
0 .447 .178 r
.61183 .53371 .62177 .55828 .64083 .55263 .63091 .52796 Metetra
0 .45 .173 r
.63091 .52796 .64083 .55263 .66009 .54831 .65017 .52361 Metetra
0 .458 .159 r
.65017 .52361 .66009 .54831 .67955 .54533 .66964 .52066 Metetra
0 .472 .135 r
.66964 .52066 .67955 .54533 .69925 .54364 .68935 .51907 Metetra
0 .492 .099 r
.68935 .51907 .69925 .54364 .71921 .54321 .70931 .5188 Metetra
0 .517 .048 r
.70931 .5188 .71921 .54321 .73945 .54395 .72957 .51977 Metetra
.019 .546 0 r
.72957 .51977 .73945 .54395 .75998 .54578 .75012 .52191 Metetra
.104 .58 0 r
.75012 .52191 .75998 .54578 .78083 .54857 .771 .5251 Metetra
.21 .617 0 r
.771 .5251 .78083 .54857 .80199 .55219 .79221 .52919 Metetra
.338 .657 0 r
.79221 .52919 .80199 .55219 .82348 .55645 .81376 .53401 Metetra
.487 .699 0 r
.81376 .53401 .82348 .55645 .84529 .56114 .83565 .53937 Metetra
.657 .743 0 r
.83565 .53937 .84529 .56114 .86741 .56601 .85787 .54502 Metetra
.786 .729 0 r
.85787 .54502 .86741 .56601 .88982 .57079 .88041 .55068 Metetra
.828 .616 0 r
.88041 .55068 .88982 .57079 .91248 .57513 .90322 .55603 Metetra
.868 .496 0 r
.90322 .55603 .91248 .57513 .93534 .57866 .92627 .5607 Metetra
.904 .375 0 r
.92627 .5607 .93534 .57866 .95833 .58095 .9495 .56426 Metetra
.881 .453 0 r
.32313 .72149 .33406 .73602 .35236 .72185 .34156 .7061 Metetra
.841 .58 0 r
.34156 .7061 .35236 .72185 .37073 .70656 .36006 .6897 Metetra
.797 .702 0 r
.36006 .6897 .37073 .70656 .38915 .69055 .37859 .67267 Metetra
.689 .75 0 r
.37859 .67267 .38915 .69055 .40759 .67415 .39713 .65535 Metetra
.503 .704 0 r
.39713 .65535 .40759 .67415 .42604 .65768 .41567 .63806 Metetra
.338 .657 0 r
.41567 .63806 .42604 .65768 .44448 .64142 .43419 .62106 Metetra
.196 .612 0 r
.43419 .62106 .44448 .64142 .46293 .6256 .45271 .60457 Metetra
.077 .57 0 r
.45271 .60457 .46293 .6256 .48138 .61041 .47122 .58881 Metetra
0 .53 .019 r
.47122 .58881 .48138 .61041 .49984 .59605 .48973 .57393 Metetra
0 .495 .093 r
.48973 .57393 .49984 .59605 .51833 .58265 .50826 .56009 Metetra
0 .464 .15 r
.50826 .56009 .51833 .58265 .53686 .57034 .52682 .5474 Metetra
0 .438 .191 r
.52682 .5474 .53686 .57034 .55545 .55922 .54544 .53596 Metetra
0 .417 .219 r
.54544 .53596 .55545 .55922 .57413 .54937 .56414 .52585 Metetra
0 .402 .237 r
.56414 .52585 .57413 .54937 .59291 .54085 .58294 .51713 Metetra
0 .393 .247 r
.58294 .51713 .59291 .54085 .61183 .53371 .60187 .50983 Metetra
0 .39 .251 r
.60187 .50983 .61183 .53371 .63091 .52796 .62096 .50399 Metetra
0 .393 .247 r
.62096 .50399 .63091 .52796 .65017 .52361 .64023 .4996 Metetra
0 .402 .237 r
.64023 .4996 .65017 .52361 .66964 .52066 .65971 .49666 Metetra
0 .417 .219 r
.65971 .49666 .66964 .52066 .68935 .51907 .67943 .49514 Metetra
0 .438 .191 r
.67943 .49514 .68935 .51907 .70931 .5188 .69941 .495 Metetra
0 .464 .15 r
.69941 .495 .70931 .5188 .72957 .51977 .71968 .49617 Metetra
0 .495 .093 r
.71968 .49617 .72957 .51977 .75012 .52191 .74026 .49857 Metetra
0 .53 .019 r
.74026 .49857 .75012 .52191 .771 .5251 .76116 .50209 Metetra
.077 .57 0 r
.76116 .50209 .771 .5251 .79221 .52919 .78242 .50658 Metetra
.196 .612 0 r
.78242 .50658 .79221 .52919 .81376 .53401 .80402 .51189 Metetra
.338 .657 0 r
.80402 .51189 .81376 .53401 .83565 .53937 .82598 .51783 Metetra
.503 .704 0 r
.82598 .51783 .83565 .53937 .85787 .54502 .84829 .52414 Metetra
.689 .75 0 r
.84829 .52414 .85787 .54502 .88041 .55068 .87094 .53058 Metetra
.797 .702 0 r
.87094 .53058 .88041 .55068 .90322 .55603 .89389 .5368 Metetra
.841 .58 0 r
.89389 .5368 .90322 .55603 .92627 .5607 .91711 .54246 Metetra
.881 .453 0 r
.91711 .54246 .92627 .5607 .9495 .56426 .94054 .54713 Metetra
.858 .527 0 r
.31209 .70684 .32313 .72149 .34156 .7061 .33067 .69036 Metetra
.814 .657 0 r
.33067 .69036 .34156 .7061 .36006 .6897 .34929 .67297 Metetra
.754 .766 0 r
.34929 .67297 .36006 .6897 .37859 .67267 .36794 .65504 Metetra
.552 .716 0 r
.36794 .65504 .37859 .67267 .39713 .65535 .38658 .63691 Metetra
.369 .666 0 r
.38658 .63691 .39713 .65535 .41567 .63806 .40521 .61888 Metetra
.21 .617 0 r
.40521 .61888 .41567 .63806 .43419 .62106 .42382 .60122 Metetra
.077 .57 0 r
.42382 .60122 .43419 .62106 .45271 .60457 .44241 .58415 Metetra
0 .525 .031 r
.44241 .58415 .45271 .60457 .47122 .58881 .46098 .56787 Metetra
0 .484 .115 r
.46098 .56787 .47122 .58881 .48973 .57393 .47955 .55253 Metetra
0 .447 .178 r
.47955 .55253 .48973 .57393 .50826 .56009 .49813 .53829 Metetra
0 .414 .223 r
.49813 .53829 .50826 .56009 .52682 .5474 .51673 .52526 Metetra
0 .387 .254 r
.51673 .52526 .52682 .5474 .54544 .53596 .53539 .51354 Metetra
0 .366 .274 r
.53539 .51354 .54544 .53596 .56414 .52585 .55412 .50319 Metetra
0 .35 .286 r
.55412 .50319 .56414 .52585 .58294 .51713 .57294 .49427 Metetra
0 .341 .292 r
.57294 .49427 .58294 .51713 .60187 .50983 .59189 .48684 Metetra
0 .338 .294 r
.59189 .48684 .60187 .50983 .62096 .50399 .61099 .4809 Metetra
0 .341 .292 r
.61099 .4809 .62096 .50399 .64023 .4996 .63028 .47646 Metetra
0 .35 .286 r
.63028 .47646 .64023 .4996 .65971 .49666 .64977 .47353 Metetra
0 .366 .274 r
.64977 .47353 .65971 .49666 .67943 .49514 .6695 .47206 Metetra
0 .387 .254 r
.6695 .47206 .67943 .49514 .69941 .495 .6895 .47202 Metetra
0 .414 .223 r
.6895 .47202 .69941 .495 .71968 .49617 .70978 .47335 Metetra
0 .447 .178 r
.70978 .47335 .71968 .49617 .74026 .49857 .73039 .47596 Metetra
0 .484 .115 r
.73039 .47596 .74026 .49857 .76116 .50209 .75132 .47974 Metetra
0 .525 .031 r
.75132 .47974 .76116 .50209 .78242 .50658 .77261 .48458 Metetra
.077 .57 0 r
.77261 .48458 .78242 .50658 .80402 .51189 .79427 .4903 Metetra
.21 .617 0 r
.79427 .4903 .80402 .51189 .82598 .51783 .81629 .49672 Metetra
.369 .666 0 r
.81629 .49672 .82598 .51783 .84829 .52414 .83868 .50361 Metetra
.552 .716 0 r
.83868 .50361 .84829 .52414 .87094 .53058 .86143 .5107 Metetra
.754 .766 0 r
.86143 .5107 .87094 .53058 .89389 .5368 .8845 .51768 Metetra
.814 .657 0 r
.8845 .51768 .89389 .5368 .91711 .54246 .90787 .5242 Metetra
.858 .527 0 r
.90787 .5242 .91711 .54246 .94054 .54713 .93148 .52983 Metetra
.836 .594 0 r
.30094 .69226 .31209 .70684 .33067 .69036 .31965 .67483 Metetra
.788 .725 0 r
.31965 .67483 .33067 .69036 .34929 .67297 .33841 .65657 Metetra
.632 .737 0 r
.33841 .65657 .34929 .67297 .36794 .65504 .35717 .63784 Metetra
.432 .684 0 r
.35717 .63784 .36794 .65504 .38658 .63691 .37592 .619 Metetra
.255 .631 0 r
.37592 .619 .38658 .63691 .40521 .61888 .39465 .60033 Metetra
.104 .58 0 r
.39465 .60033 .40521 .61888 .42382 .60122 .41335 .58209 Metetra
0 .53 .019 r
.41335 .58209 .42382 .60122 .44241 .58415 .43202 .5645 Metetra
0 .484 .115 r
.43202 .5645 .44241 .58415 .46098 .56787 .45066 .54775 Metetra
0 .441 .186 r
.45066 .54775 .46098 .56787 .47955 .55253 .46929 .53202 Metetra
0 .402 .237 r
.46929 .53202 .47955 .55253 .49813 .53829 .48793 .51742 Metetra
0 .369 .271 r
.48793 .51742 .49813 .53829 .51673 .52526 .50658 .50409 Metetra
0 .341 .292 r
.50658 .50409 .51673 .52526 .53539 .51354 .52528 .4921 Metetra
0 .319 .304 r
.52528 .4921 .53539 .51354 .55412 .50319 .54404 .48154 Metetra
0 .296 .303 r
.54404 .48154 .55412 .50319 .57294 .49427 .5629 .47245 Metetra
0 .274 .293 r
.5629 .47245 .57294 .49427 .59189 .48684 .58187 .46488 Metetra
0 .267 .29 r
.58187 .46488 .59189 .48684 .61099 .4809 .601 .45884 Metetra
0 .274 .293 r
.601 .45884 .61099 .4809 .63028 .47646 .6203 .45436 Metetra
0 .296 .303 r
.6203 .45436 .63028 .47646 .64977 .47353 .63982 .45141 Metetra
0 .319 .304 r
.63982 .45141 .64977 .47353 .6695 .47206 .65956 .44997 Metetra
0 .341 .292 r
.65956 .44997 .6695 .47206 .6895 .47202 .67958 .45 Metetra
0 .369 .271 r
.67958 .45 .6895 .47202 .70978 .47335 .69989 .45145 Metetra
0 .402 .237 r
.69989 .45145 .70978 .47335 .73039 .47596 .72052 .45423 Metetra
0 .441 .186 r
.72052 .45423 .73039 .47596 .75132 .47974 .74148 .45824 Metetra
0 .484 .115 r
.74148 .45824 .75132 .47974 .77261 .48458 .76281 .46336 Metetra
0 .53 .019 r
.76281 .46336 .77261 .48458 .79427 .4903 .78451 .46942 Metetra
.104 .58 0 r
.78451 .46942 .79427 .4903 .81629 .49672 .8066 .47624 Metetra
.255 .631 0 r
.8066 .47624 .81629 .49672 .83868 .50361 .82906 .48361 Metetra
.432 .684 0 r
.82906 .48361 .83868 .50361 .86143 .5107 .8519 .49126 Metetra
.632 .737 0 r
.8519 .49126 .86143 .5107 .8845 .51768 .87508 .49888 Metetra
.788 .725 0 r
.87508 .49888 .8845 .51768 .90787 .5242 .89859 .50612 Metetra
.836 .594 0 r
.89859 .50612 .90787 .5242 .93148 .52983 .92236 .51258 Metetra
.815 .653 0 r
.28965 .67793 .30094 .69226 .31965 .67483 .3085 .65968 Metetra
.746 .764 0 r
.3085 .65968 .31965 .67483 .33841 .65657 .32739 .64066 Metetra
.527 .71 0 r
.32739 .64066 .33841 .65657 .35717 .63784 .34627 .62125 Metetra
.33 .655 0 r
.34627 .62125 .35717 .63784 .37592 .619 .36514 .60179 Metetra
.16 .6 0 r
.36514 .60179 .37592 .619 .39465 .60033 .38397 .58255 Metetra
.019 .546 0 r
.38397 .58255 .39465 .60033 .41335 .58209 .40277 .56381 Metetra
0 .495 .093 r
.40277 .56381 .41335 .58209 .43202 .5645 .42152 .54577 Metetra
0 .447 .178 r
.42152 .54577 .43202 .5645 .45066 .54775 .44024 .52862 Metetra
0 .402 .237 r
.44024 .52862 .45066 .54775 .46929 .53202 .45895 .51253 Metetra
0 .363 .276 r
.45895 .51253 .46929 .53202 .48793 .51742 .47764 .49762 Metetra
0 .328 .299 r
.47764 .49762 .48793 .51742 .50658 .50409 .49635 .48401 Metetra
0 .289 .299 r
.49635 .48401 .50658 .50409 .52528 .4921 .5151 .47179 Metetra
0 .239 .276 r
.5151 .47179 .52528 .4921 .54404 .48154 .53391 .46103 Metetra
0 .206 .26 r
.53391 .46103 .54404 .48154 .5629 .47245 .5528 .45178 Metetra
0 .187 .25 r
.5528 .45178 .5629 .47245 .58187 .46488 .57182 .44408 Metetra
0 .181 .247 r
.57182 .44408 .58187 .46488 .601 .45884 .59097 .43796 Metetra
0 .187 .25 r
.59097 .43796 .601 .45884 .6203 .45436 .6103 .43341 Metetra
0 .206 .26 r
.6103 .43341 .6203 .45436 .63982 .45141 .62984 .43044 Metetra
0 .239 .276 r
.62984 .43044 .63982 .45141 .65956 .44997 .64962 .42901 Metetra
0 .289 .299 r
.64962 .42901 .65956 .44997 .67958 .45 .66965 .4291 Metetra
0 .328 .299 r
.66965 .4291 .67958 .45 .69989 .45145 .68999 .43063 Metetra
0 .363 .276 r
.68999 .43063 .69989 .45145 .72052 .45423 .71064 .43354 Metetra
0 .402 .237 r
.71064 .43354 .72052 .45423 .74148 .45824 .73165 .43772 Metetra
0 .447 .178 r
.73165 .43772 .74148 .45824 .76281 .46336 .75301 .44306 Metetra
0 .495 .093 r
.75301 .44306 .76281 .46336 .78451 .46942 .77476 .4494 Metetra
.019 .546 0 r
.77476 .4494 .78451 .46942 .8066 .47624 .7969 .45656 Metetra
.16 .6 0 r
.7969 .45656 .8066 .47624 .82906 .48361 .81943 .46432 Metetra
.33 .655 0 r
.81943 .46432 .82906 .48361 .8519 .49126 .84235 .47242 Metetra
.527 .71 0 r
.84235 .47242 .8519 .49126 .87508 .49888 .86564 .48057 Metetra
.746 .764 0 r
.86564 .48057 .87508 .49888 .89859 .50612 .88927 .48842 Metetra
.815 .653 0 r
.88927 .48842 .89859 .50612 .92236 .51258 .91319 .49556 Metetra
.796 .702 0 r
.27821 .66402 .28965 .67793 .3085 .65968 .2972 .64507 Metetra
.656 .742 0 r
.2972 .64507 .3085 .65968 .32739 .64066 .31622 .6254 Metetra
.439 .686 0 r
.31622 .6254 .32739 .64066 .34627 .62125 .33523 .60541 Metetra
.247 .629 0 r
.33523 .60541 .34627 .62125 .36514 .60179 .35422 .58541 Metetra
.084 .572 0 r
.35422 .58541 .36514 .60179 .38397 .58255 .37316 .56569 Metetra
0 .517 .048 r
.37316 .56569 .38397 .58255 .40277 .56381 .39205 .54651 Metetra
0 .464 .15 r
.39205 .54651 .40277 .56381 .42152 .54577 .4109 .52807 Metetra
0 .414 .223 r
.4109 .52807 .42152 .54577 .44024 .52862 .42971 .51058 Metetra
0 .369 .271 r
.42971 .51058 .44024 .52862 .45895 .51253 .44849 .49417 Metetra
0 .328 .299 r
.44849 .49417 .45895 .51253 .47764 .49762 .46726 .47899 Metetra
0 .274 .293 r
.46726 .47899 .47764 .49762 .49635 .48401 .48604 .46514 Metetra
0 .213 .263 r
.48604 .46514 .49635 .48401 .5151 .47179 .50484 .45271 Metetra
0 .169 .24 r
.50484 .45271 .5151 .47179 .53391 .46103 .52371 .44177 Metetra
0 .141 .223 r
.52371 .44177 .53391 .46103 .5528 .45178 .54265 .43238 Metetra
0 .125 .213 r
.54265 .43238 .5528 .45178 .57182 .44408 .5617 .42456 Metetra
0 .12 .209 r
.5617 .42456 .57182 .44408 .59097 .43796 .5809 .41834 Metetra
0 .125 .213 r
.5809 .41834 .59097 .43796 .6103 .43341 .60027 .41373 Metetra
0 .141 .223 r
.60027 .41373 .6103 .43341 .62984 .43044 .61984 .41072 Metetra
0 .169 .24 r
.61984 .41072 .62984 .43044 .64962 .42901 .63964 .40929 Metetra
0 .213 .263 r
.63964 .40929 .64962 .42901 .66965 .4291 .65972 .4094 Metetra
0 .274 .293 r
.65972 .4094 .66965 .4291 .68999 .43063 .68008 .411 Metetra
0 .328 .299 r
.68008 .411 .68999 .43063 .71064 .43354 .70077 .414 Metetra
0 .369 .271 r
.70077 .414 .71064 .43354 .73165 .43772 .72181 .41832 Metetra
0 .414 .223 r
.72181 .41832 .73165 .43772 .75301 .44306 .74321 .42382 Metetra
0 .464 .15 r
.74321 .42382 .75301 .44306 .77476 .4494 .76501 .43037 Metetra
0 .517 .048 r
.76501 .43037 .77476 .4494 .7969 .45656 .78721 .43779 Metetra
.084 .572 0 r
.78721 .43779 .7969 .45656 .81943 .46432 .8098 .44586 Metetra
.247 .629 0 r
.8098 .44586 .81943 .46432 .84235 .47242 .8328 .45433 Metetra
.439 .686 0 r
.8328 .45433 .84235 .47242 .86564 .48057 .85619 .46291 Metetra
.656 .742 0 r
.85619 .46291 .86564 .48057 .88927 .48842 .87993 .47124 Metetra
.796 .702 0 r
.87993 .47124 .88927 .48842 .91319 .49556 .90398 .47894 Metetra
.78 .743 0 r
.2666 .65064 .27821 .66402 .2972 .64507 .28573 .6311 Metetra
.584 .724 0 r
.28573 .6311 .2972 .64507 .31622 .6254 .30489 .61091 Metetra
.369 .666 0 r
.30489 .61091 .31622 .6254 .33523 .60541 .32403 .59042 Metetra
.181 .607 0 r
.32403 .59042 .33523 .60541 .35422 .58541 .34314 .56997 Metetra
.025 .549 0 r
.34314 .56997 .35422 .58541 .37316 .56569 .36219 .54985 Metetra
0 .492 .099 r
.36219 .54985 .37316 .56569 .39205 .54651 .3812 .53029 Metetra
0 .438 .191 r
.3812 .53029 .39205 .54651 .4109 .52807 .40015 .51153 Metetra
0 .387 .254 r
.40015 .51153 .4109 .52807 .42971 .51058 .41905 .49373 Metetra
0 .341 .292 r
.41905 .49373 .42971 .51058 .44849 .49417 .43792 .47706 Metetra
0 .289 .299 r
.43792 .47706 .44849 .49417 .46726 .47899 .45677 .46164 Metetra
0 .213 .263 r
.45677 .46164 .46726 .47899 .48604 .46514 .47562 .44758 Metetra
0 .158 .233 r
.47562 .44758 .48604 .46514 .50484 .45271 .49449 .43496 Metetra
0 .12 .209 r
.49449 .43496 .50484 .45271 .52371 .44177 .51342 .42386 Metetra
0 .096 .192 r
.51342 .42386 .52371 .44177 .54265 .43238 .53242 .41433 Metetra
0 .082 .182 r
.53242 .41433 .54265 .43238 .5617 .42456 .55153 .40639 Metetra
0 .078 .178 r
.55153 .40639 .5617 .42456 .5809 .41834 .57077 .40009 Metetra
0 .082 .182 r
.57077 .40009 .5809 .41834 .60027 .41373 .59018 .39541 Metetra
0 .096 .192 r
.59018 .39541 .60027 .41373 .61984 .41072 .6098 .39236 Metetra
0 .12 .209 r
.6098 .39236 .61984 .41072 .63964 .40929 .62964 .39091 Metetra
0 .158 .233 r
.62964 .39091 .63964 .40929 .65972 .4094 .64975 .39102 Metetra
0 .213 .263 r
.64975 .39102 .65972 .4094 .68008 .411 .67016 .39265 Metetra
0 .289 .299 r
.67016 .39265 .68008 .411 .70077 .414 .69088 .39571 Metetra
0 .341 .292 r
.69088 .39571 .70077 .414 .72181 .41832 .71196 .40011 Metetra
0 .387 .254 r
.71196 .40011 .72181 .41832 .74321 .42382 .73342 .40574 Metetra
0 .438 .191 r
.73342 .40574 .74321 .42382 .76501 .43037 .75526 .41245 Metetra
0 .492 .099 r
.75526 .41245 .76501 .43037 .78721 .43779 .77751 .42006 Metetra
.025 .549 0 r
.77751 .42006 .78721 .43779 .8098 .44586 .80018 .42836 Metetra
.181 .607 0 r
.80018 .42836 .8098 .44586 .8328 .45433 .82325 .43711 Metetra
.369 .666 0 r
.82325 .43711 .8328 .45433 .85619 .46291 .84673 .44601 Metetra
.584 .724 0 r
.84673 .44601 .85619 .46291 .87993 .47124 .87057 .45472 Metetra
.78 .743 0 r
.87057 .45472 .87993 .47124 .90398 .47894 .89474 .46284 Metetra
.762 .767 0 r
.2548 .63789 .2666 .65064 .28573 .6311 .27408 .61789 Metetra
.527 .71 0 r
.27408 .61789 .28573 .6311 .30489 .61091 .29337 .59726 Metetra
.315 .65 0 r
.29337 .59726 .30489 .61091 .32403 .59042 .31264 .57638 Metetra
.132 .59 0 r
.31264 .57638 .32403 .59042 .34314 .56997 .33188 .55557 Metetra
0 .53 .019 r
.33188 .55557 .34314 .56997 .36219 .54985 .35106 .53511 Metetra
0 .472 .135 r
.35106 .53511 .36219 .54985 .3812 .53029 .37018 .51525 Metetra
0 .417 .219 r
.37018 .51525 .3812 .53029 .40015 .51153 .38924 .49621 Metetra
0 .366 .274 r
.38924 .49621 .40015 .51153 .41905 .49373 .40824 .47816 Metetra
0 .319 .304 r
.40824 .47816 .41905 .49373 .43792 .47706 .42721 .46125 Metetra
0 .239 .276 r
.42721 .46125 .43792 .47706 .45677 .46164 .44615 .44563 Metetra
0 .169 .24 r
.44615 .44563 .45677 .46164 .47562 .44758 .46508 .43138 Metetra
0 .12 .209 r
.46508 .43138 .47562 .44758 .49449 .43496 .48403 .41861 Metetra
0 .087 .185 r
.48403 .41861 .49449 .43496 .51342 .42386 .50303 .40736 Metetra
0 .066 .168 r
.50303 .40736 .51342 .42386 .53242 .41433 .5221 .3977 Metetra
0 .055 .157 r
.5221 .3977 .53242 .41433 .55153 .40639 .54127 .38966 Metetra
0 .051 .154 r
.54127 .38966 .55153 .40639 .57077 .40009 .56057 .38327 Metetra
0 .055 .157 r
.56057 .38327 .57077 .40009 .59018 .39541 .58004 .37852 Metetra
0 .066 .168 r
.58004 .37852 .59018 .39541 .6098 .39236 .5997 .37541 Metetra
0 .087 .185 r
.5997 .37541 .6098 .39236 .62964 .39091 .6196 .37393 Metetra
0 .12 .209 r
.6196 .37393 .62964 .39091 .64975 .39102 .63975 .37403 Metetra
0 .169 .24 r
.63975 .37403 .64975 .39102 .67016 .39265 .6602 .37566 Metetra
0 .239 .276 r
.6602 .37566 .67016 .39265 .69088 .39571 .68098 .37874 Metetra
0 .319 .304 r
.68098 .37874 .69088 .39571 .71196 .40011 .70211 .3832 Metetra
0 .366 .274 r
.70211 .3832 .71196 .40011 .73342 .40574 .72361 .3889 Metetra
0 .417 .219 r
.72361 .3889 .73342 .40574 .75526 .41245 .74551 .3957 Metetra
0 .472 .135 r
.74551 .3957 .75526 .41245 .77751 .42006 .76782 .40344 Metetra
0 .53 .019 r
.76782 .40344 .77751 .42006 .80018 .42836 .79055 .4119 Metetra
.132 .59 0 r
.79055 .4119 .80018 .42836 .82325 .43711 .8137 .42084 Metetra
.315 .65 0 r
.8137 .42084 .82325 .43711 .84673 .44601 .83726 .42997 Metetra
.527 .71 0 r
.83726 .42997 .84673 .44601 .87057 .45472 .8612 .43895 Metetra
.762 .767 0 r
.8612 .43895 .87057 .45472 .89474 .46284 .88549 .44737 Metetra
.721 .758 0 r
.2428 .62586 .2548 .63789 .27408 .61789 .26222 .60551 Metetra
.487 .699 0 r
.26222 .60551 .27408 .61789 .29337 .59726 .28165 .58455 Metetra
.277 .638 0 r
.28165 .58455 .29337 .59726 .31264 .57638 .30106 .56336 Metetra
.097 .577 0 r
.30106 .56336 .31264 .57638 .33188 .55557 .32043 .54226 Metetra
0 .517 .048 r
.32043 .54226 .33188 .55557 .35106 .53511 .33973 .52154 Metetra
0 .458 .159 r
.33973 .52154 .35106 .53511 .37018 .51525 .35898 .50144 Metetra
0 .402 .237 r
.35898 .50144 .37018 .51525 .38924 .49621 .37815 .48217 Metetra
0 .35 .286 r
.37815 .48217 .38924 .49621 .40824 .47816 .39727 .46392 Metetra
0 .296 .303 r
.39727 .46392 .40824 .47816 .42721 .46125 .41634 .44683 Metetra
0 .206 .26 r
.41634 .44683 .42721 .46125 .44615 .44563 .43538 .43103 Metetra
0 .141 .223 r
.43538 .43103 .44615 .44563 .46508 .43138 .45441 .41662 Metetra
0 .096 .192 r
.45441 .41662 .46508 .43138 .48403 .41861 .47345 .4037 Metetra
0 .066 .168 r
.47345 .4037 .48403 .41861 .50303 .40736 .49252 .39233 Metetra
0 .048 .15 r
.49252 .39233 .50303 .40736 .5221 .3977 .51167 .38256 Metetra
0 .038 .139 r
.51167 .38256 .5221 .3977 .54127 .38966 .53091 .37442 Metetra
0 .035 .136 r
.53091 .37442 .54127 .38966 .56057 .38327 .55028 .36793 Metetra
0 .038 .139 r
.55028 .36793 .56057 .38327 .58004 .37852 .56981 .36311 Metetra
0 .048 .15 r
.56981 .36311 .58004 .37852 .5997 .37541 .58954 .35994 Metetra
0 .066 .168 r
.58954 .35994 .5997 .37541 .6196 .37393 .60949 .35841 Metetra
0 .096 .192 r
.60949 .35841 .6196 .37393 .63975 .37403 .62971 .35847 Metetra
0 .141 .223 r
.62971 .35847 .63975 .37403 .6602 .37566 .65021 .36008 Metetra
0 .206 .26 r
.65021 .36008 .6602 .37566 .68098 .37874 .67104 .36316 Metetra
0 .296 .303 r
.67104 .36316 .68098 .37874 .70211 .3832 .69222 .36763 Metetra
0 .35 .286 r
.69222 .36763 .70211 .3832 .72361 .3889 .71378 .37335 Metetra
0 .402 .237 r
.71378 .37335 .72361 .3889 .74551 .3957 .73574 .38021 Metetra
0 .458 .159 r
.73574 .38021 .74551 .3957 .76782 .40344 .75812 .38801 Metetra
0 .517 .048 r
.75812 .38801 .76782 .40344 .79055 .4119 .78092 .39656 Metetra
.097 .577 0 r
.78092 .39656 .79055 .4119 .8137 .42084 .80414 .40561 Metetra
.277 .638 0 r
.80414 .40561 .8137 .42084 .83726 .42997 .82778 .41487 Metetra
.487 .699 0 r
.82778 .41487 .83726 .42997 .8612 .43895 .85182 .42401 Metetra
.721 .758 0 r
.85182 .42401 .8612 .43895 .88549 .44737 .87621 .43262 Metetra
.697 .752 0 r
.23058 .6146 .2428 .62586 .26222 .60551 .25014 .59401 Metetra
.463 .693 0 r
.25014 .59401 .26222 .60551 .28165 .58455 .26971 .57282 Metetra
.254 .631 0 r
.26971 .57282 .28165 .58455 .30106 .56336 .28926 .55141 Metetra
.077 .57 0 r
.28926 .55141 .30106 .56336 .32043 .54226 .30876 .53011 Metetra
0 .509 .066 r
.30876 .53011 .32043 .54226 .33973 .52154 .3282 .50919 Metetra
0 .45 .173 r
.3282 .50919 .33973 .52154 .35898 .50144 .34757 .48891 Metetra
0 .393 .247 r
.34757 .48891 .35898 .50144 .37815 .48217 .36687 .46947 Metetra
0 .341 .292 r
.36687 .46947 .37815 .48217 .39727 .46392 .38611 .45105 Metetra
0 .274 .293 r
.38611 .45105 .39727 .46392 .41634 .44683 .40529 .43381 Metetra
0 .187 .25 r
.40529 .43381 .41634 .44683 .43538 .43103 .42444 .41787 Metetra
0 .125 .213 r
.42444 .41787 .43538 .43103 .45441 .41662 .44357 .40334 Metetra
0 .082 .182 r
.44357 .40334 .45441 .41662 .47345 .4037 .46271 .3903 Metetra
0 .055 .157 r
.46271 .3903 .47345 .4037 .49252 .39233 .48188 .37881 Metetra
0 .038 .139 r
.48188 .37881 .49252 .39233 .51167 .38256 .50112 .36893 Metetra
0 .029 .129 r
.50112 .36893 .51167 .38256 .53091 .37442 .52044 .3607 Metetra
0 .026 .125 r
.52044 .3607 .53091 .37442 .55028 .36793 .53989 .35412 Metetra
0 .029 .129 r
.53989 .35412 .55028 .36793 .56981 .36311 .5595 .34922 Metetra
0 .038 .139 r
.5595 .34922 .56981 .36311 .58954 .35994 .57929 .34598 Metetra
0 .055 .157 r
.57929 .34598 .58954 .35994 .60949 .35841 .59932 .34439 Metetra
0 .082 .182 r
.59932 .34439 .60949 .35841 .62971 .35847 .6196 .3444 Metetra
0 .125 .213 r
.6196 .3444 .62971 .35847 .65021 .36008 .64017 .34596 Metetra
0 .187 .25 r
.64017 .34596 .65021 .36008 .67104 .36316 .66106 .34901 Metetra
0 .274 .293 r
.66106 .34901 .67104 .36316 .69222 .36763 .6823 .35345 Metetra
0 .341 .292 r
.6823 .35345 .69222 .36763 .71378 .37335 .70393 .35916 Metetra
0 .393 .247 r
.70393 .35916 .71378 .37335 .73574 .38021 .72595 .36601 Metetra
0 .45 .173 r
.72595 .36601 .73574 .38021 .75812 .38801 .7484 .37382 Metetra
0 .509 .066 r
.7484 .37382 .75812 .38801 .78092 .39656 .77127 .38239 Metetra
.077 .57 0 r
.77127 .38239 .78092 .39656 .80414 .40561 .79457 .39146 Metetra
.254 .631 0 r
.79457 .39146 .80414 .40561 .82778 .41487 .8183 .40077 Metetra
.463 .693 0 r
.8183 .40077 .82778 .41487 .85182 .42401 .84242 .40995 Metetra
.697 .752 0 r
.84242 .40995 .85182 .42401 .87621 .43262 .86692 .41863 Metetra
.689 .75 0 r
.21812 .60413 .23058 .6146 .25014 .59401 .23782 .58341 Metetra
.455 .691 0 r
.23782 .58341 .25014 .59401 .26971 .57282 .25753 .5621 Metetra
.247 .629 0 r
.25753 .5621 .26971 .57282 .28926 .55141 .27722 .54057 Metetra
.07 .567 0 r
.27722 .54057 .28926 .55141 .30876 .53011 .29686 .51914 Metetra
0 .506 .071 r
.29686 .51914 .30876 .53011 .3282 .50919 .31644 .49809 Metetra
0 .447 .178 r
.31644 .49809 .3282 .50919 .34757 .48891 .33595 .47769 Metetra
0 .39 .251 r
.33595 .47769 .34757 .48891 .36687 .46947 .35538 .45813 Metetra
0 .338 .294 r
.35538 .45813 .36687 .46947 .38611 .45105 .37474 .43959 Metetra
0 .267 .29 r
.37474 .43959 .38611 .45105 .40529 .43381 .39405 .42224 Metetra
0 .181 .247 r
.39405 .42224 .40529 .43381 .42444 .41787 .41332 .40619 Metetra
0 .12 .209 r
.41332 .40619 .42444 .41787 .44357 .40334 .43256 .39155 Metetra
0 .078 .178 r
.43256 .39155 .44357 .40334 .46271 .3903 .45181 .37841 Metetra
0 .051 .154 r
.45181 .37841 .46271 .3903 .48188 .37881 .47108 .36683 Metetra
0 .035 .136 r
.47108 .36683 .48188 .37881 .50112 .36893 .49042 .35685 Metetra
0 .026 .125 r
.49042 .35685 .50112 .36893 .52044 .3607 .50984 .34853 Metetra
0 .023 .121 r
.50984 .34853 .52044 .3607 .53989 .35412 .52938 .34187 Metetra
0 .026 .125 r
.52938 .34187 .53989 .35412 .5595 .34922 .54907 .33688 Metetra
0 .035 .136 r
.54907 .33688 .5595 .34922 .57929 .34598 .56895 .33356 Metetra
0 .051 .154 r
.56895 .33356 .57929 .34598 .59932 .34439 .58905 .33189 Metetra
0 .078 .178 r
.58905 .33189 .59932 .34439 .6196 .3444 .60941 .33183 Metetra
0 .12 .209 r
.60941 .33183 .6196 .3444 .64017 .34596 .63005 .33333 Metetra
0 .181 .247 r
.63005 .33333 .64017 .34596 .66106 .34901 .65102 .33631 Metetra
0 .267 .29 r
.65102 .33631 .66106 .34901 .6823 .35345 .67233 .34068 Metetra
0 .338 .294 r
.67233 .34068 .6823 .35345 .70393 .35916 .69403 .34634 Metetra
0 .39 .251 r
.69403 .34634 .70393 .35916 .72595 .36601 .71613 .35313 Metetra
0 .447 .178 r
.71613 .35313 .72595 .36601 .7484 .37382 .73864 .36088 Metetra
0 .506 .071 r
.73864 .36088 .7484 .37382 .77127 .38239 .76159 .3694 Metetra
.07 .567 0 r
.76159 .3694 .77127 .38239 .79457 .39146 .78498 .37843 Metetra
.247 .629 0 r
.78498 .37843 .79457 .39146 .8183 .40077 .80879 .38768 Metetra
.455 .691 0 r
.80879 .38768 .8183 .40077 .84242 .40995 .833 .39681 Metetra
.689 .75 0 r
.833 .39681 .84242 .40995 .86692 .41863 .85759 .40544 Metetra
.697 .752 0 r
.20541 .59447 .21812 .60413 .23782 .58341 .22524 .57374 Metetra
.463 .693 0 r
.22524 .57374 .23782 .58341 .25753 .5621 .2451 .5524 Metetra
.254 .631 0 r
.2451 .5524 .25753 .5621 .27722 .54057 .26493 .53083 Metetra
.077 .57 0 r
.26493 .53083 .27722 .54057 .29686 .51914 .28471 .50935 Metetra
0 .509 .066 r
.28471 .50935 .29686 .51914 .31644 .49809 .30443 .48825 Metetra
0 .45 .173 r
.30443 .48825 .31644 .49809 .33595 .47769 .32408 .46778 Metetra
0 .393 .247 r
.32408 .46778 .33595 .47769 .35538 .45813 .34365 .44816 Metetra
0 .341 .292 r
.34365 .44816 .35538 .45813 .37474 .43959 .36315 .42955 Metetra
0 .274 .293 r
.36315 .42955 .37474 .43959 .39405 .42224 .38259 .41212 Metetra
0 .187 .25 r
.38259 .41212 .39405 .42224 .41332 .40619 .40198 .396 Metetra
0 .125 .213 r
.40198 .396 .41332 .40619 .43256 .39155 .42135 .38128 Metetra
0 .082 .182 r
.42135 .38128 .43256 .39155 .45181 .37841 .44072 .36805 Metetra
0 .055 .157 r
.44072 .36805 .45181 .37841 .47108 .36683 .46011 .35638 Metetra
0 .038 .139 r
.46011 .35638 .47108 .36683 .49042 .35685 .47955 .34633 Metetra
0 .029 .129 r
.47955 .34633 .49042 .35685 .50984 .34853 .49908 .33792 Metetra
0 .026 .125 r
.49908 .33792 .50984 .34853 .52938 .34187 .51872 .33117 Metetra
0 .029 .129 r
.51872 .33117 .52938 .34187 .54907 .33688 .53851 .3261 Metetra
0 .038 .139 r
.53851 .3261 .54907 .33688 .56895 .33356 .55848 .32269 Metetra
0 .055 .157 r
.55848 .32269 .56895 .33356 .58905 .33189 .57867 .32093 Metetra
0 .082 .182 r
.57867 .32093 .58905 .33189 .60941 .33183 .59912 .32078 Metetra
0 .125 .213 r
.59912 .32078 .60941 .33183 .63005 .33333 .61985 .32218 Metetra
0 .187 .25 r
.61985 .32218 .63005 .33333 .65102 .33631 .6409 .32507 Metetra
0 .274 .293 r
.6409 .32507 .65102 .33631 .67233 .34068 .6623 .32934 Metetra
0 .341 .292 r
.6623 .32934 .67233 .34068 .69403 .34634 .68407 .33489 Metetra
0 .393 .247 r
.68407 .33489 .69403 .34634 .71613 .35313 .70625 .34158 Metetra
0 .45 .173 r
.70625 .34158 .71613 .35313 .73864 .36088 .72885 .34922 Metetra
0 .509 .066 r
.72885 .34922 .73864 .36088 .76159 .3694 .75188 .35761 Metetra
.077 .57 0 r
.75188 .35761 .76159 .3694 .78498 .37843 .77535 .36651 Metetra
.254 .631 0 r
.77535 .36651 .78498 .37843 .80879 .38768 .79924 .37562 Metetra
.463 .693 0 r
.79924 .37562 .80879 .38768 .833 .39681 .82355 .38459 Metetra
.697 .752 0 r
.82355 .38459 .833 .39681 .85759 .40544 .84823 .39305 Metetra
.721 .758 0 r
.19244 .58559 .20541 .59447 .22524 .57374 .2124 .56497 Metetra
.487 .699 0 r
.2124 .56497 .22524 .57374 .2451 .5524 .23239 .54371 Metetra
.277 .638 0 r
.23239 .54371 .2451 .5524 .26493 .53083 .25236 .52219 Metetra
.097 .577 0 r
.25236 .52219 .26493 .53083 .28471 .50935 .27229 .50075 Metetra
0 .517 .048 r
.27229 .50075 .28471 .50935 .30443 .48825 .29216 .47966 Metetra
0 .458 .159 r
.29216 .47966 .30443 .48825 .32408 .46778 .31195 .45919 Metetra
0 .402 .237 r
.31195 .45919 .32408 .46778 .34365 .44816 .33167 .43955 Metetra
0 .35 .286 r
.33167 .43955 .34365 .44816 .36315 .42955 .35131 .42092 Metetra
0 .296 .303 r
.35131 .42092 .36315 .42955 .38259 .41212 .37089 .40345 Metetra
0 .206 .26 r
.37089 .40345 .38259 .41212 .40198 .396 .39042 .38728 Metetra
0 .141 .223 r
.39042 .38728 .40198 .396 .42135 .38128 .40993 .37251 Metetra
0 .096 .192 r
.40993 .37251 .42135 .38128 .44072 .36805 .42942 .35922 Metetra
0 .066 .168 r
.42942 .35922 .44072 .36805 .46011 .35638 .44894 .34749 Metetra
0 .048 .15 r
.44894 .34749 .46011 .35638 .47955 .34633 .4685 .33736 Metetra
0 .038 .139 r
.4685 .33736 .47955 .34633 .49908 .33792 .48815 .32887 Metetra
0 .035 .136 r
.48815 .32887 .49908 .33792 .51872 .33117 .5079 .32203 Metetra
0 .038 .139 r
.5079 .32203 .51872 .33117 .53851 .3261 .5278 .31687 Metetra
0 .048 .15 r
.5278 .31687 .53851 .3261 .55848 .32269 .54788 .31337 Metetra
0 .066 .168 r
.54788 .31337 .55848 .32269 .57867 .32093 .56817 .31151 Metetra
0 .096 .192 r
.56817 .31151 .57867 .32093 .59912 .32078 .58871 .31124 Metetra
0 .141 .223 r
.58871 .31124 .59912 .32078 .61985 .32218 .60954 .31253 Metetra
0 .206 .26 r
.60954 .31253 .61985 .32218 .6409 .32507 .63068 .31529 Metetra
0 .296 .303 r
.63068 .31529 .6409 .32507 .6623 .32934 .65217 .31943 Metetra
0 .35 .286 r
.65217 .31943 .6623 .32934 .68407 .33489 .67404 .32483 Metetra
0 .402 .237 r
.67404 .32483 .68407 .33489 .70625 .34158 .69631 .33135 Metetra
0 .458 .159 r
.69631 .33135 .70625 .34158 .72885 .34922 .71899 .33882 Metetra
0 .517 .048 r
.71899 .33882 .72885 .34922 .75188 .35761 .74211 .34701 Metetra
.097 .577 0 r
.74211 .34701 .75188 .35761 .77535 .36651 .76567 .3557 Metetra
.277 .638 0 r
.76567 .3557 .77535 .36651 .79924 .37562 .78965 .36456 Metetra
.487 .699 0 r
.78965 .36456 .79924 .37562 .82355 .38459 .81404 .37328 Metetra
.721 .758 0 r
.81404 .37328 .82355 .38459 .84823 .39305 .83881 .38143 Metetra
.762 .767 0 r
.17919 .57746 .19244 .58559 .2124 .56497 .19927 .55706 Metetra
.527 .71 0 r
.19927 .55706 .2124 .56497 .23239 .54371 .21939 .53599 Metetra
.315 .65 0 r
.21939 .53599 .23239 .54371 .25236 .52219 .23951 .51462 Metetra
.132 .59 0 r
.23951 .51462 .25236 .52219 .27229 .50075 .25959 .49329 Metetra
0 .53 .019 r
.25959 .49329 .27229 .50075 .29216 .47966 .2796 .4723 Metetra
0 .472 .135 r
.2796 .4723 .29216 .47966 .31195 .45919 .29955 .45189 Metetra
0 .417 .219 r
.29955 .45189 .31195 .45919 .33167 .43955 .31941 .43229 Metetra
0 .366 .274 r
.31941 .43229 .33167 .43955 .35131 .42092 .33921 .41368 Metetra
0 .319 .304 r
.33921 .41368 .35131 .42092 .37089 .40345 .35894 .39621 Metetra
0 .239 .276 r
.35894 .39621 .37089 .40345 .39042 .38728 .37861 .38003 Metetra
0 .169 .24 r
.37861 .38003 .39042 .38728 .40993 .37251 .39826 .36523 Metetra
0 .12 .209 r
.39826 .36523 .40993 .37251 .42942 .35922 .4179 .3519 Metetra
0 .087 .185 r
.4179 .3519 .42942 .35922 .44894 .34749 .43755 .34011 Metetra
0 .066 .168 r
.43755 .34011 .44894 .34749 .4685 .33736 .45724 .32992 Metetra
0 .055 .157 r
.45724 .32992 .4685 .33736 .48815 .32887 .47702 .32135 Metetra
0 .051 .154 r
.47702 .32135 .48815 .32887 .5079 .32203 .4969 .31444 Metetra
0 .055 .157 r
.4969 .31444 .5079 .32203 .5278 .31687 .51692 .30918 Metetra
0 .066 .168 r
.51692 .30918 .5278 .31687 .54788 .31337 .53711 .30557 Metetra
0 .087 .185 r
.53711 .30557 .54788 .31337 .56817 .31151 .55752 .30359 Metetra
0 .12 .209 r
.55752 .30359 .56817 .31151 .58871 .31124 .57817 .3032 Metetra
0 .169 .24 r
.57817 .3032 .58871 .31124 .60954 .31253 .59911 .30434 Metetra
0 .239 .276 r
.59911 .30434 .60954 .31253 .63068 .31529 .62035 .30694 Metetra
0 .319 .304 r
.62035 .30694 .63068 .31529 .65217 .31943 .64195 .3109 Metetra
0 .366 .274 r
.64195 .3109 .65217 .31943 .67404 .32483 .66391 .31611 Metetra
0 .417 .219 r
.66391 .31611 .67404 .32483 .69631 .33135 .68628 .32242 Metetra
0 .472 .135 r
.68628 .32242 .69631 .33135 .71899 .33882 .70906 .32964 Metetra
0 .53 .019 r
.70906 .32964 .71899 .33882 .74211 .34701 .73227 .33757 Metetra
.132 .59 0 r
.73227 .33757 .74211 .34701 .76567 .3557 .75592 .34595 Metetra
.315 .65 0 r
.75592 .34595 .76567 .3557 .78965 .36456 .77999 .35449 Metetra
.527 .71 0 r
.77999 .35449 .78965 .36456 .81404 .37328 .80448 .36282 Metetra
.762 .767 0 r
.80448 .36282 .81404 .37328 .83881 .38143 .82934 .37056 Metetra
.78 .743 0 r
.16565 .57001 .17919 .57746 .19927 .55706 .18585 .54996 Metetra
.584 .724 0 r
.18585 .54996 .19927 .55706 .21939 .53599 .2061 .52918 Metetra
.369 .666 0 r
.2061 .52918 .21939 .53599 .23951 .51462 .22635 .50806 Metetra
.181 .607 0 r
.22635 .50806 .23951 .51462 .25959 .49329 .24657 .48693 Metetra
.025 .549 0 r
.24657 .48693 .25959 .49329 .2796 .4723 .26674 .4661 Metetra
0 .492 .099 r
.26674 .4661 .2796 .4723 .29955 .45189 .28684 .44583 Metetra
0 .438 .191 r
.28684 .44583 .29955 .45189 .31941 .43229 .30686 .42632 Metetra
0 .387 .254 r
.30686 .42632 .31941 .43229 .33921 .41368 .32681 .40778 Metetra
0 .341 .292 r
.32681 .40778 .33921 .41368 .35894 .39621 .3467 .39036 Metetra
0 .289 .299 r
.3467 .39036 .35894 .39621 .37861 .38003 .36653 .3742 Metetra
0 .213 .263 r
.36653 .3742 .37861 .38003 .39826 .36523 .38633 .3594 Metetra
0 .158 .233 r
.38633 .3594 .39826 .36523 .4179 .3519 .40612 .34605 Metetra
0 .12 .209 r
.40612 .34605 .4179 .3519 .43755 .34011 .42592 .33423 Metetra
0 .096 .192 r
.42592 .33423 .43755 .34011 .45724 .32992 .44576 .32398 Metetra
0 .082 .182 r
.44576 .32398 .45724 .32992 .47702 .32135 .46567 .31535 Metetra
0 .078 .178 r
.46567 .31535 .47702 .32135 .4969 .31444 .48568 .30835 Metetra
0 .082 .182 r
.48568 .30835 .4969 .31444 .51692 .30918 .50584 .30299 Metetra
0 .096 .192 r
.50584 .30299 .51692 .30918 .53711 .30557 .52616 .29927 Metetra
0 .12 .209 r
.52616 .29927 .53711 .30557 .55752 .30359 .5467 .29715 Metetra
0 .158 .233 r
.5467 .29715 .55752 .30359 .57817 .3032 .56747 .29661 Metetra
0 .213 .263 r
.56747 .29661 .57817 .3032 .59911 .30434 .58852 .29758 Metetra
0 .289 .299 r
.58852 .29758 .59911 .30434 .62035 .30694 .60989 .29999 Metetra
0 .341 .292 r
.60989 .29999 .62035 .30694 .64195 .3109 .63159 .30373 Metetra
0 .387 .254 r
.63159 .30373 .64195 .3109 .66391 .31611 .65367 .3087 Metetra
0 .438 .191 r
.65367 .3087 .66391 .31611 .68628 .32242 .67614 .31473 Metetra
0 .492 .099 r
.67614 .31473 .68628 .32242 .70906 .32964 .69903 .32165 Metetra
.025 .549 0 r
.69903 .32165 .70906 .32964 .73227 .33757 .72234 .32923 Metetra
.181 .607 0 r
.72234 .32923 .73227 .33757 .75592 .34595 .74609 .33722 Metetra
.369 .666 0 r
.74609 .33722 .75592 .34595 .77999 .35449 .77026 .34532 Metetra
.584 .724 0 r
.77026 .34532 .77999 .35449 .80448 .36282 .79483 .35317 Metetra
.78 .743 0 r
.79483 .35317 .80448 .36282 .82934 .37056 .81978 .36035 Metetra
.796 .702 0 r
.15183 .56315 .16565 .57001 .18585 .54996 .17213 .54358 Metetra
.656 .742 0 r
.17213 .54358 .18585 .54996 .2061 .52918 .1925 .52321 Metetra
.439 .686 0 r
.1925 .52321 .2061 .52918 .22635 .50806 .21288 .50244 Metetra
.247 .629 0 r
.21288 .50244 .22635 .50806 .24657 .48693 .23325 .48161 Metetra
.084 .572 0 r
.23325 .48161 .24657 .48693 .26674 .4661 .25356 .46102 Metetra
0 .517 .048 r
.25356 .46102 .26674 .4661 .28684 .44583 .27382 .44094 Metetra
0 .464 .15 r
.27382 .44094 .28684 .44583 .30686 .42632 .294 .42159 Metetra
0 .414 .223 r
.294 .42159 .30686 .42632 .32681 .40778 .31411 .40317 Metetra
0 .369 .271 r
.31411 .40317 .32681 .40778 .3467 .39036 .33416 .38584 Metetra
0 .328 .299 r
.33416 .38584 .3467 .39036 .36653 .3742 .35416 .36973 Metetra
0 .274 .293 r
.35416 .36973 .36653 .3742 .38633 .3594 .37412 .35496 Metetra
0 .213 .263 r
.37412 .35496 .38633 .3594 .40612 .34605 .39406 .34162 Metetra
0 .169 .24 r
.39406 .34162 .40612 .34605 .42592 .33423 .41402 .32978 Metetra
0 .141 .223 r
.41402 .32978 .42592 .33423 .44576 .32398 .43402 .31949 Metetra
0 .125 .213 r
.43402 .31949 .44576 .32398 .46567 .31535 .45408 .3108 Metetra
0 .12 .209 r
.45408 .3108 .46567 .31535 .48568 .30835 .47424 .30372 Metetra
0 .125 .213 r
.47424 .30372 .48568 .30835 .50584 .30299 .49454 .29825 Metetra
0 .141 .223 r
.49454 .29825 .50584 .30299 .52616 .29927 .51501 .2944 Metetra
0 .169 .24 r
.51501 .2944 .52616 .29927 .5467 .29715 .53568 .29214 Metetra
0 .213 .263 r
.53568 .29214 .5467 .29715 .56747 .29661 .55659 .29142 Metetra
0 .274 .293 r
.55659 .29142 .56747 .29661 .58852 .29758 .57777 .29219 Metetra
0 .328 .299 r
.57777 .29219 .58852 .29758 .60989 .29999 .59926 .29437 Metetra
0 .369 .271 r
.59926 .29437 .60989 .29999 .63159 .30373 .62109 .29786 Metetra
0 .414 .223 r
.62109 .29786 .63159 .30373 .65367 .3087 .64329 .30253 Metetra
0 .464 .15 r
.64329 .30253 .65367 .3087 .67614 .31473 .66588 .30822 Metetra
0 .517 .048 r
.66588 .30822 .67614 .31473 .69903 .32165 .68888 .31476 Metetra
.084 .572 0 r
.68888 .31476 .69903 .32165 .72234 .32923 .7123 .32192 Metetra
.247 .629 0 r
.7123 .32192 .72234 .32923 .74609 .33722 .73615 .32942 Metetra
.439 .686 0 r
.73615 .32942 .74609 .33722 .77026 .34532 .76042 .33698 Metetra
.656 .742 0 r
.76042 .33698 .77026 .34532 .79483 .35317 .78509 .34421 Metetra
.796 .702 0 r
.78509 .34421 .79483 .35317 .81978 .36035 .81011 .3507 Metetra
.815 .653 0 r
.13771 .55676 .15183 .56315 .17213 .54358 .1581 .53779 Metetra
.746 .764 0 r
.1581 .53779 .17213 .54358 .1925 .52321 .17858 .51796 Metetra
.527 .71 0 r
.17858 .51796 .1925 .52321 .21288 .50244 .19909 .49764 Metetra
.33 .655 0 r
.19909 .49764 .21288 .50244 .23325 .48161 .21959 .4772 Metetra
.16 .6 0 r
.21959 .4772 .23325 .48161 .25356 .46102 .24006 .45695 Metetra
.019 .546 0 r
.24006 .45695 .25356 .46102 .27382 .44094 .26047 .43714 Metetra
0 .495 .093 r
.26047 .43714 .27382 .44094 .294 .42159 .28081 .41802 Metetra
0 .447 .178 r
.28081 .41802 .294 .42159 .31411 .40317 .30109 .39977 Metetra
0 .402 .237 r
.30109 .39977 .31411 .40317 .33416 .38584 .32131 .38258 Metetra
0 .363 .276 r
.32131 .38258 .33416 .38584 .35416 .36973 .34147 .36657 Metetra
0 .328 .299 r
.34147 .36657 .35416 .36973 .37412 .35496 .36161 .35186 Metetra
0 .289 .299 r
.36161 .35186 .37412 .35496 .39406 .34162 .38172 .33855 Metetra
0 .239 .276 r
.38172 .33855 .39406 .34162 .41402 .32978 .40184 .32671 Metetra
0 .206 .26 r
.40184 .32671 .41402 .32978 .43402 .31949 .422 .31639 Metetra
0 .187 .25 r
.422 .31639 .43402 .31949 .45408 .3108 .44223 .30764 Metetra
0 .181 .247 r
.44223 .30764 .45408 .3108 .47424 .30372 .46255 .30047 Metetra
0 .187 .25 r
.46255 .30047 .47424 .30372 .49454 .29825 .48301 .2949 Metetra
0 .206 .26 r
.48301 .2949 .49454 .29825 .51501 .2944 .50363 .29091 Metetra
0 .239 .276 r
.50363 .29091 .51501 .2944 .53568 .29214 .52445 .28848 Metetra
0 .289 .299 r
.52445 .28848 .53568 .29214 .55659 .29142 .54551 .28756 Metetra
0 .328 .299 r
.54551 .28756 .55659 .29142 .57777 .29219 .56683 .2881 Metetra
0 .363 .276 r
.56683 .2881 .57777 .29219 .59926 .29437 .58846 .29001 Metetra
0 .402 .237 r
.58846 .29001 .59926 .29437 .62109 .29786 .61043 .29319 Metetra
0 .447 .178 r
.61043 .29319 .62109 .29786 .64329 .30253 .63275 .2975 Metetra
0 .495 .093 r
.63275 .2975 .64329 .30253 .66588 .30822 .65547 .3028 Metetra
.019 .546 0 r
.65547 .3028 .66588 .30822 .68888 .31476 .67859 .30888 Metetra
.16 .6 0 r
.67859 .30888 .68888 .31476 .7123 .32192 .70213 .31552 Metetra
.33 .655 0 r
.70213 .31552 .7123 .32192 .73615 .32942 .72609 .32245 Metetra
.527 .71 0 r
.72609 .32245 .73615 .32942 .76042 .33698 .75046 .32934 Metetra
.746 .764 0 r
.75046 .32934 .76042 .33698 .78509 .34421 .77522 .33583 Metetra
.815 .653 0 r
.77522 .33583 .78509 .34421 .81011 .3507 .80033 .34149 Metetra
.836 .594 0 r
.12331 .55067 .13771 .55676 .1581 .53779 .14377 .53247 Metetra
.788 .725 0 r
.14377 .53247 .1581 .53779 .17858 .51796 .16434 .51329 Metetra
.632 .737 0 r
.16434 .51329 .17858 .51796 .19909 .49764 .18496 .49355 Metetra
.432 .684 0 r
.18496 .49355 .19909 .49764 .21959 .4772 .2056 .47361 Metetra
.255 .631 0 r
.2056 .47361 .21959 .4772 .24006 .45695 .22621 .45377 Metetra
.104 .58 0 r
.22621 .45377 .24006 .45695 .26047 .43714 .24678 .43432 Metetra
0 .53 .019 r
.24678 .43432 .26047 .43714 .28081 .41802 .26728 .41549 Metetra
0 .484 .115 r
.26728 .41549 .28081 .41802 .30109 .39977 .28773 .39748 Metetra
0 .441 .186 r
.28773 .39748 .30109 .39977 .32131 .38258 .30812 .38047 Metetra
0 .402 .237 r
.30812 .38047 .32131 .38258 .34147 .36657 .32846 .3646 Metetra
0 .369 .271 r
.32846 .3646 .34147 .36657 .36161 .35186 .34877 .34998 Metetra
0 .341 .292 r
.34877 .34998 .36161 .35186 .38172 .33855 .36906 .33673 Metetra
0 .319 .304 r
.36906 .33673 .38172 .33855 .40184 .32671 .38936 .32491 Metetra
0 .296 .303 r
.38936 .32491 .40184 .32671 .422 .31639 .4097 .31458 Metetra
0 .274 .293 r
.4097 .31458 .422 .31639 .44223 .30764 .4301 .30577 Metetra
0 .267 .29 r
.4301 .30577 .44223 .30764 .46255 .30047 .45059 .29852 Metetra
0 .274 .293 r
.45059 .29852 .46255 .30047 .48301 .2949 .47122 .29283 Metetra
0 .296 .303 r
.47122 .29283 .48301 .2949 .50363 .29091 .492 .28869 Metetra
0 .319 .304 r
.492 .28869 .50363 .29091 .52445 .28848 .51298 .28607 Metetra
0 .341 .292 r
.51298 .28607 .52445 .28848 .54551 .28756 .5342 .28493 Metetra
0 .369 .271 r
.5342 .28493 .54551 .28756 .56683 .2881 .55568 .2852 Metetra
0 .402 .237 r
.55568 .2852 .56683 .2881 .58846 .29001 .57746 .2868 Metetra
0 .441 .186 r
.57746 .2868 .58846 .29001 .61043 .29319 .59957 .28962 Metetra
0 .484 .115 r
.59957 .28962 .61043 .29319 .63275 .2975 .62204 .29352 Metetra
0 .53 .019 r
.62204 .29352 .63275 .2975 .65547 .3028 .64489 .29835 Metetra
.104 .58 0 r
.64489 .29835 .65547 .3028 .67859 .30888 .66814 .30389 Metetra
.255 .631 0 r
.66814 .30389 .67859 .30888 .70213 .31552 .6918 .30992 Metetra
.432 .684 0 r
.6918 .30992 .70213 .31552 .72609 .32245 .71587 .31615 Metetra
.632 .737 0 r
.71587 .31615 .72609 .32245 .75046 .32934 .74035 .32226 Metetra
.788 .725 0 r
.74035 .32226 .75046 .32934 .77522 .33583 .7652 .32787 Metetra
.836 .594 0 r
.7652 .32787 .77522 .33583 .80033 .34149 .79039 .33254 Metetra
.858 .527 0 r
.10864 .54471 .12331 .55067 .14377 .53247 .12914 .52741 Metetra
.814 .657 0 r
.12914 .52741 .14377 .53247 .16434 .51329 .14979 .50904 Metetra
.754 .766 0 r
.14979 .50904 .16434 .51329 .18496 .49355 .17051 .49 Metetra
.552 .716 0 r
.17051 .49 .18496 .49355 .2056 .47361 .19127 .47066 Metetra
.369 .666 0 r
.19127 .47066 .2056 .47361 .22621 .45377 .21202 .45134 Metetra
.21 .617 0 r
.21202 .45134 .22621 .45377 .24678 .43432 .23273 .43233 Metetra
.077 .57 0 r
.23273 .43233 .24678 .43432 .26728 .41549 .2534 .41386 Metetra
0 .525 .031 r
.2534 .41386 .26728 .41549 .28773 .39748 .27402 .39616 Metetra
0 .484 .115 r
.27402 .39616 .28773 .39748 .30812 .38047 .29459 .37939 Metetra
0 .447 .178 r
.29459 .37939 .30812 .38047 .32846 .3646 .31511 .3637 Metetra
0 .414 .223 r
.31511 .3637 .32846 .3646 .34877 .34998 .3356 .34922 Metetra
0 .387 .254 r
.3356 .34922 .34877 .34998 .36906 .33673 .35607 .33605 Metetra
0 .366 .274 r
.35607 .33605 .36906 .33673 .38936 .32491 .37656 .32427 Metetra
0 .35 .286 r
.37656 .32427 .38936 .32491 .4097 .31458 .39708 .31394 Metetra
0 .341 .292 r
.39708 .31394 .4097 .31458 .4301 .30577 .41766 .3051 Metetra
0 .338 .294 r
.41766 .3051 .4301 .30577 .45059 .29852 .43834 .29776 Metetra
0 .341 .292 r
.43834 .29776 .45059 .29852 .47122 .29283 .45914 .29195 Metetra
0 .35 .286 r
.45914 .29195 .47122 .29283 .492 .28869 .4801 .28764 Metetra
0 .366 .274 r
.4801 .28764 .492 .28869 .51298 .28607 .50126 .28481 Metetra
0 .387 .254 r
.50126 .28481 .51298 .28607 .5342 .28493 .52264 .28341 Metetra
0 .414 .223 r
.52264 .28341 .5342 .28493 .55568 .2852 .54429 .28338 Metetra
0 .447 .178 r
.54429 .28338 .55568 .2852 .57746 .2868 .56623 .28462 Metetra
0 .484 .115 r
.56623 .28462 .57746 .2868 .59957 .28962 .5885 .28702 Metetra
0 .525 .031 r
.5885 .28702 .59957 .28962 .62204 .29352 .61112 .29044 Metetra
.077 .57 0 r
.61112 .29044 .62204 .29352 .64489 .29835 .63412 .29472 Metetra
.21 .617 0 r
.63412 .29472 .64489 .29835 .66814 .30389 .6575 .29963 Metetra
.369 .666 0 r
.6575 .29963 .66814 .30389 .6918 .30992 .68129 .30494 Metetra
.552 .716 0 r
.68129 .30494 .6918 .30992 .71587 .31615 .70549 .31037 Metetra
.754 .766 0 r
.70549 .31037 .71587 .31615 .74035 .32226 .73007 .31556 Metetra
.814 .657 0 r
.73007 .31556 .74035 .32226 .7652 .32787 .75502 .32014 Metetra
.858 .527 0 r
.75502 .32014 .7652 .32787 .79039 .33254 .78029 .32367 Metetra
.881 .453 0 r
.0937 .53866 .10864 .54471 .12914 .52741 .11423 .52243 Metetra
.841 .58 0 r
.11423 .52243 .12914 .52741 .14979 .50904 .13493 .505 Metetra
.797 .702 0 r
.13493 .505 .14979 .50904 .17051 .49 .15574 .48678 Metetra
.689 .75 0 r
.15574 .48678 .17051 .49 .19127 .47066 .1766 .46817 Metetra
.503 .704 0 r
.1766 .46817 .19127 .47066 .21202 .45134 .19748 .44947 Metetra
.338 .657 0 r
.19748 .44947 .21202 .45134 .23273 .43233 .21834 .43099 Metetra
.196 .612 0 r
.21834 .43099 .23273 .43233 .2534 .41386 .23916 .41298 Metetra
.077 .57 0 r
.23916 .41298 .2534 .41386 .27402 .39616 .25995 .39565 Metetra
0 .53 .019 r
.25995 .39565 .27402 .39616 .29459 .37939 .28069 .37918 Metetra
0 .495 .093 r
.28069 .37918 .29459 .37939 .31511 .3637 .3014 .36373 Metetra
0 .464 .15 r
.3014 .36373 .31511 .3637 .3356 .34922 .32207 .34943 Metetra
0 .438 .191 r
.32207 .34943 .3356 .34922 .35607 .33605 .34274 .33638 Metetra
0 .417 .219 r
.34274 .33638 .35607 .33605 .37656 .32427 .36342 .32466 Metetra
0 .402 .237 r
.36342 .32466 .37656 .32427 .39708 .31394 .38413 .31434 Metetra
0 .393 .247 r
.38413 .31434 .39708 .31394 .41766 .3051 .40491 .30546 Metetra
0 .39 .251 r
.40491 .30546 .41766 .3051 .43834 .29776 .42578 .29805 Metetra
0 .393 .247 r
.42578 .29805 .43834 .29776 .45914 .29195 .44677 .2921 Metetra
0 .402 .237 r
.44677 .2921 .45914 .29195 .4801 .28764 .46792 .28761 Metetra
0 .417 .219 r
.46792 .28761 .4801 .28764 .50126 .28481 .48926 .28454 Metetra
0 .438 .191 r
.48926 .28454 .50126 .28481 .52264 .28341 .51082 .28285 Metetra
0 .464 .15 r
.51082 .28285 .52264 .28341 .54429 .28338 .53265 .28247 Metetra
0 .495 .093 r
.53265 .28247 .54429 .28338 .56623 .28462 .55476 .2833 Metetra
0 .53 .019 r
.55476 .2833 .56623 .28462 .5885 .28702 .5772 .28522 Metetra
.077 .57 0 r
.5772 .28522 .5885 .28702 .61112 .29044 .59998 .28809 Metetra
.196 .612 0 r
.59998 .28809 .61112 .29044 .63412 .29472 .62313 .29173 Metetra
.338 .657 0 r
.62313 .29173 .63412 .29472 .6575 .29963 .64666 .29592 Metetra
.503 .704 0 r
.64666 .29592 .6575 .29963 .68129 .30494 .67059 .3004 Metetra
.689 .75 0 r
.67059 .3004 .68129 .30494 .70549 .31037 .6949 .30489 Metetra
.797 .702 0 r
.6949 .30489 .70549 .31037 .73007 .31556 .7196 .30903 Metetra
.841 .58 0 r
.7196 .30903 .73007 .31556 .75502 .32014 .74464 .31243 Metetra
.881 .453 0 r
.74464 .31243 .75502 .32014 .78029 .32367 .76998 .31463 Metetra
.904 .375 0 r
.07854 .53225 .0937 .53866 .11423 .52243 .09906 .51725 Metetra
.868 .496 0 r
.09906 .51725 .11423 .52243 .13493 .505 .11979 .50092 Metetra
.828 .616 0 r
.11979 .50092 .13493 .505 .15574 .48678 .14065 .48368 Metetra
.786 .729 0 r
.14065 .48368 .15574 .48678 .1766 .46817 .1616 .46592 Metetra
.657 .743 0 r
.1616 .46592 .1766 .46817 .19748 .44947 .18259 .44796 Metetra
.487 .699 0 r
.18259 .44796 .19748 .44947 .21834 .43099 .20359 .43011 Metetra
.338 .657 0 r
.20359 .43011 .21834 .43099 .23916 .41298 .22457 .41264 Metetra
.21 .617 0 r
.22457 .41264 .23916 .41298 .25995 .39565 .24551 .39575 Metetra
.104 .58 0 r
.24551 .39575 .25995 .39565 .28069 .37918 .26643 .37965 Metetra
.019 .546 0 r
.26643 .37965 .28069 .37918 .3014 .36373 .28732 .36449 Metetra
0 .517 .048 r
.28732 .36449 .3014 .36373 .32207 .34943 .30819 .35041 Metetra
0 .492 .099 r
.30819 .35041 .32207 .34943 .34274 .33638 .32905 .33752 Metetra
0 .472 .135 r
.32905 .33752 .34274 .33638 .36342 .32466 .34993 .3259 Metetra
0 .458 .159 r
.34993 .3259 .36342 .32466 .38413 .31434 .37084 .31561 Metetra
0 .45 .173 r
.37084 .31561 .38413 .31434 .40491 .30546 .39181 .3067 Metetra
0 .447 .178 r
.39181 .3067 .40491 .30546 .42578 .29805 .41288 .2992 Metetra
0 .45 .173 r
.41288 .2992 .42578 .29805 .44677 .2921 .43408 .29311 Metetra
0 .458 .159 r
.43408 .29311 .44677 .2921 .46792 .28761 .45542 .28842 Metetra
0 .472 .135 r
.45542 .28842 .46792 .28761 .48926 .28454 .47696 .28509 Metetra
0 .492 .099 r
.47696 .28509 .48926 .28454 .51082 .28285 .49872 .28307 Metetra
0 .517 .048 r
.49872 .28307 .51082 .28285 .53265 .28247 .52073 .28229 Metetra
.019 .546 0 r
.52073 .28229 .53265 .28247 .55476 .2833 .54303 .28265 Metetra
.104 .58 0 r
.54303 .28265 .55476 .2833 .5772 .28522 .56564 .28403 Metetra
.21 .617 0 r
.56564 .28403 .5772 .28522 .59998 .28809 .58859 .28626 Metetra
.338 .657 0 r
.58859 .28626 .59998 .28809 .62313 .29173 .6119 .28917 Metetra
.487 .699 0 r
.6119 .28917 .62313 .29173 .64666 .29592 .63559 .29252 Metetra
.657 .743 0 r
.63559 .29252 .64666 .29592 .67059 .3004 .65965 .29606 Metetra
.786 .729 0 r
.65965 .29606 .67059 .3004 .6949 .30489 .6841 .29947 Metetra
.828 .616 0 r
.6841 .29947 .6949 .30489 .7196 .30903 .7089 .3024 Metetra
.868 .496 0 r
.7089 .3024 .7196 .30903 .74464 .31243 .73404 .30445 Metetra
.904 .375 0 r
.73404 .30445 .74464 .31243 .76998 .31463 .75945 .30514 Metetra
.926 .297 0 r
.06319 .52517 .07854 .53225 .09906 .51725 .08366 .51159 Metetra
.895 .407 0 r
.08366 .51159 .09906 .51725 .11979 .50092 .10438 .49653 Metetra
.86 .522 0 r
.10438 .49653 .11979 .50092 .14065 .48368 .12528 .48041 Metetra
.822 .634 0 r
.12528 .48041 .14065 .48368 .1616 .46592 .1463 .46363 Metetra
.782 .738 0 r
.1463 .46363 .1616 .46592 .18259 .44796 .16738 .44654 Metetra
.657 .743 0 r
.16738 .44654 .18259 .44796 .20359 .43011 .1885 .42944 Metetra
.503 .704 0 r
.1885 .42944 .20359 .43011 .22457 .41264 .20961 .4126 Metetra
.369 .666 0 r
.20961 .4126 .22457 .41264 .24551 .39575 .23072 .39625 Metetra
.255 .631 0 r
.23072 .39625 .24551 .39575 .26643 .37965 .25181 .38059 Metetra
.16 .6 0 r
.25181 .38059 .26643 .37965 .28732 .36449 .27288 .36578 Metetra
.084 .572 0 r
.27288 .36578 .28732 .36449 .30819 .35041 .29393 .35197 Metetra
.025 .549 0 r
.29393 .35197 .30819 .35041 .32905 .33752 .31499 .33927 Metetra
0 .53 .019 r
.31499 .33927 .32905 .33752 .34993 .3259 .33607 .32777 Metetra
0 .517 .048 r
.33607 .32777 .34993 .3259 .37084 .31561 .35719 .31753 Metetra
0 .509 .066 r
.35719 .31753 .37084 .31561 .39181 .3067 .37837 .30861 Metetra
0 .506 .071 r
.37837 .30861 .39181 .3067 .41288 .2992 .39965 .30102 Metetra
0 .509 .066 r
.39965 .30102 .41288 .2992 .43408 .29311 .42105 .29477 Metetra
0 .517 .048 r
.42105 .29477 .43408 .29311 .45542 .28842 .44261 .28986 Metetra
0 .53 .019 r
.44261 .28986 .45542 .28842 .47696 .28509 .46435 .28624 Metetra
.025 .549 0 r
.46435 .28624 .47696 .28509 .49872 .28307 .48631 .28385 Metetra
.084 .572 0 r
.48631 .28385 .49872 .28307 .52073 .28229 .50852 .28262 Metetra
.16 .6 0 r
.50852 .28262 .52073 .28229 .54303 .28265 .53101 .28245 Metetra
.255 .631 0 r
.53101 .28245 .54303 .28265 .56564 .28403 .55381 .2832 Metetra
.369 .666 0 r
.55381 .2832 .56564 .28403 .58859 .28626 .57694 .28471 Metetra
.503 .704 0 r
.57694 .28471 .58859 .28626 .6119 .28917 .60042 .28678 Metetra
.657 .743 0 r
.60042 .28678 .6119 .28917 .63559 .29252 .62426 .28918 Metetra
.782 .738 0 r
.62426 .28918 .63559 .29252 .65965 .29606 .64848 .29163 Metetra
.822 .634 0 r
.64848 .29163 .65965 .29606 .6841 .29947 .67305 .29383 Metetra
.86 .522 0 r
.67305 .29383 .6841 .29947 .7089 .3024 .69797 .29539 Metetra
.895 .407 0 r
.69797 .29539 .7089 .3024 .73404 .30445 .72319 .2959 Metetra
.926 .297 0 r
.72319 .2959 .73404 .30445 .75945 .30514 .74867 .29489 Metetra
.945 .223 0 r
.0477 .51709 .06319 .52517 .08366 .51159 .06807 .50512 Metetra
.92 .318 0 r
.06807 .50512 .08366 .51159 .10438 .49653 .08875 .49149 Metetra
.89 .423 0 r
.08875 .49149 .10438 .49653 .12528 .48041 .10965 .47666 Metetra
.857 .531 0 r
.10965 .47666 .12528 .48041 .1463 .46363 .13071 .46102 Metetra
.822 .634 0 r
.13071 .46102 .1463 .46363 .16738 .44654 .15186 .44492 Metetra
.786 .729 0 r
.15186 .44492 .16738 .44654 .1885 .42944 .17308 .42868 Metetra
.689 .75 0 r
.17308 .42868 .1885 .42944 .20961 .4126 .19432 .41258 Metetra
.552 .716 0 r
.19432 .41258 .20961 .4126 .23072 .39625 .21557 .39685 Metetra
.432 .684 0 r
.21557 .39685 .23072 .39625 .25181 .38059 .23682 .38171 Metetra
.33 .655 0 r
.23682 .38171 .25181 .38059 .27288 .36578 .25807 .36732 Metetra
.247 .629 0 r
.25807 .36732 .27288 .36578 .29393 .35197 .27931 .35384 Metetra
.181 .607 0 r
.27931 .35384 .29393 .35197 .31499 .33927 .30057 .34138 Metetra
.132 .59 0 r
.30057 .34138 .31499 .33927 .33607 .32777 .32185 .33003 Metetra
.097 .577 0 r
.32185 .33003 .33607 .32777 .35719 .31753 .34318 .31986 Metetra
.077 .57 0 r
.34318 .31986 .35719 .31753 .37837 .30861 .36458 .31093 Metetra
.07 .567 0 r
.36458 .31093 .37837 .30861 .39965 .30102 .38607 .30325 Metetra
.077 .57 0 r
.38607 .30325 .39965 .30102 .42105 .29477 .40768 .29684 Metetra
.097 .577 0 r
.40768 .29684 .42105 .29477 .44261 .28986 .42945 .29168 Metetra
.132 .59 0 r
.42945 .29168 .44261 .28986 .46435 .28624 .45141 .28773 Metetra
.181 .607 0 r
.45141 .28773 .46435 .28624 .48631 .28385 .47358 .28493 Metetra
.247 .629 0 r
.47358 .28493 .48631 .28385 .50852 .28262 .496 .28319 Metetra
.33 .655 0 r
.496 .28319 .50852 .28262 .53101 .28245 .51869 .28241 Metetra
.432 .684 0 r
.51869 .28241 .53101 .28245 .55381 .2832 .54168 .28245 Metetra
.552 .716 0 r
.54168 .28245 .55381 .2832 .57694 .28471 .565 .28313 Metetra
.689 .75 0 r
.565 .28313 .57694 .28471 .60042 .28678 .58866 .28426 Metetra
.786 .729 0 r
.58866 .28426 .60042 .28678 .62426 .28918 .61267 .28558 Metetra
.822 .634 0 r
.61267 .28558 .62426 .28918 .64848 .29163 .63703 .28681 Metetra
.857 .531 0 r
.63703 .28681 .64848 .29163 .67305 .29383 .66174 .28762 Metetra
.89 .423 0 r
.66174 .28762 .67305 .29383 .69797 .29539 .68677 .28763 Metetra
.92 .318 0 r
.68677 .28763 .69797 .29539 .72319 .2959 .71208 .28642 Metetra
.945 .223 0 r
.71208 .28642 .72319 .2959 .74867 .29489 .73761 .28349 Metetra
.961 .161 0 r
.03213 .50762 .0477 .51709 .06807 .50512 .05236 .49744 Metetra
.942 .235 0 r
.05236 .49744 .06807 .50512 .08875 .49149 .07295 .48544 Metetra
.918 .325 0 r
.07295 .48544 .08875 .49149 .10965 .47666 .09382 .47206 Metetra
.89 .423 0 r
.09382 .47206 .10965 .47666 .13071 .46102 .11487 .4577 Metetra
.86 .522 0 r
.11487 .4577 .13071 .46102 .15186 .44492 .13607 .44274 Metetra
.828 .616 0 r
.13607 .44274 .15186 .44492 .17308 .42868 .15736 .42749 Metetra
.797 .702 0 r
.15736 .42749 .17308 .42868 .19432 .41258 .17871 .41224 Metetra
.754 .766 0 r
.17871 .41224 .19432 .41258 .21557 .39685 .20009 .39724 Metetra
.632 .737 0 r
.20009 .39724 .21557 .39685 .23682 .38171 .22149 .38271 Metetra
.527 .71 0 r
.22149 .38271 .23682 .38171 .25807 .36732 .24291 .36881 Metetra
.439 .686 0 r
.24291 .36881 .25807 .36732 .27931 .35384 .26434 .35571 Metetra
.369 .666 0 r
.26434 .35571 .27931 .35384 .30057 .34138 .28579 .34353 Metetra
.315 .65 0 r
.28579 .34353 .30057 .34138 .32185 .33003 .30727 .33237 Metetra
.277 .638 0 r
.30727 .33237 .32185 .33003 .34318 .31986 .32881 .3223 Metetra
.254 .631 0 r
.32881 .3223 .34318 .31986 .36458 .31093 .35042 .31337 Metetra
.247 .629 0 r
.35042 .31337 .36458 .31093 .38607 .30325 .37213 .3056 Metetra
.254 .631 0 r
.37213 .3056 .38607 .30325 .40768 .29684 .39397 .29901 Metetra
.277 .638 0 r
.39397 .29901 .40768 .29684 .42945 .29168 .41596 .29358 Metetra
.315 .65 0 r
.41596 .29358 .42945 .29168 .45141 .28773 .43814 .28926 Metetra
.369 .666 0 r
.43814 .28926 .45141 .28773 .47358 .28493 .46053 .28599 Metetra
.439 .686 0 r
.46053 .28599 .47358 .28493 .496 .28319 .48316 .28368 Metetra
.527 .71 0 r
.48316 .28368 .496 .28319 .51869 .28241 .50606 .28222 Metetra
.632 .737 0 r
.50606 .28222 .51869 .28241 .54168 .28245 .52926 .28145 Metetra
.754 .766 0 r
.52926 .28145 .54168 .28245 .565 .28313 .55277 .2812 Metetra
.797 .702 0 r
.55277 .2812 .565 .28313 .58866 .28426 .57661 .28125 Metetra
.828 .616 0 r
.57661 .28125 .58866 .28426 .61267 .28558 .60079 .28135 Metetra
.86 .522 0 r
.60079 .28135 .61267 .28558 .63703 .28681 .6253 .2812 Metetra
.89 .423 0 r
.6253 .2812 .63703 .28681 .66174 .28762 .65014 .28046 Metetra
.918 .325 0 r
.65014 .28046 .66174 .28762 .68677 .28763 .67528 .27874 Metetra
.942 .235 0 r
.67528 .27874 .68677 .28763 .71208 .28642 .70067 .2756 Metetra
.961 .161 0 r
.70067 .2756 .71208 .28642 .73761 .28349 .72625 .27055 Metetra
.972 .117 0 r
.01657 .4963 .03213 .50762 .05236 .49744 .0366 .48812 Metetra
.96 .165 0 r
.0366 .48812 .05236 .49744 .07295 .48544 .05705 .47794 Metetra
.942 .235 0 r
.05705 .47794 .07295 .48544 .09382 .47206 .07782 .46619 Metetra
.92 .318 0 r
.07782 .46619 .09382 .47206 .11487 .4577 .09885 .45329 Metetra
.895 .407 0 r
.09885 .45329 .11487 .4577 .13607 .44274 .12005 .43961 Metetra
.868 .496 0 r
.12005 .43961 .13607 .44274 .15736 .42749 .14139 .42549 Metetra
.841 .58 0 r
.14139 .42549 .15736 .42749 .17871 .41224 .16282 .41122 Metetra
.814 .657 0 r
.16282 .41122 .17871 .41224 .20009 .39724 .18431 .39705 Metetra
.788 .725 0 r
.18431 .39705 .20009 .39724 .22149 .38271 .20585 .38321 Metetra
.746 .764 0 r
.20585 .38321 .22149 .38271 .24291 .36881 .22742 .36989 Metetra
.656 .742 0 r
.22742 .36989 .24291 .36881 .26434 .35571 .24902 .35724 Metetra
.583 .724 0 r
.24902 .35724 .26434 .35571 .28579 .34353 .27066 .34539 Metetra
.527 .71 0 r
.27066 .34539 .28579 .34353 .30727 .33237 .29234 .33445 Metetra
.487 .699 0 r
.29234 .33445 .30727 .33237 .32881 .3223 .31409 .3245 Metetra
.463 .693 0 r
.31409 .3245 .32881 .3223 .35042 .31337 .33592 .31558 Metetra
.455 .691 0 r
.33592 .31558 .35042 .31337 .37213 .3056 .35785 .30773 Metetra
.463 .693 0 r
.35785 .30773 .37213 .3056 .39397 .29901 .37991 .30094 Metetra
.487 .699 0 r
.37991 .30094 .39397 .29901 .41596 .29358 .40213 .2952 Metetra
.527 .71 0 r
.40213 .2952 .41596 .29358 .43814 .28926 .42453 .29047 Metetra
.583 .724 0 r
.42453 .29047 .43814 .28926 .46053 .28599 .44715 .28668 Metetra
.656 .742 0 r
.44715 .28668 .46053 .28599 .48316 .28368 .47 .28372 Metetra
.746 .764 0 r
.47 .28372 .48316 .28368 .50606 .28222 .49312 .28149 Metetra
.788 .725 0 r
.49312 .28149 .50606 .28222 .52926 .28145 .51653 .27981 Metetra
.814 .657 0 r
.51653 .27981 .52926 .28145 .55277 .2812 .54024 .27851 Metetra
.841 .58 0 r
.54024 .27851 .55277 .2812 .57661 .28125 .56426 .27736 Metetra
.868 .496 0 r
.56426 .27736 .57661 .28125 .60079 .28135 .58861 .27609 Metetra
.895 .407 0 r
.58861 .27609 .60079 .28135 .6253 .2812 .61328 .27439 Metetra
.92 .318 0 r
.61328 .27439 .6253 .2812 .65014 .28046 .63825 .27192 Metetra
.942 .235 0 r
.63825 .27192 .65014 .28046 .67528 .27874 .66349 .26826 Metetra
.96 .165 0 r
.66349 .26826 .67528 .27874 .70067 .2756 .68895 .26298 Metetra
.972 .117 0 r
.68895 .26298 .70067 .2756 .72625 .27055 .71457 .25558 Metetra
.977 .099 0 r
.0011 .48266 .01657 .4963 .0366 .48812 .02087 .47669 Metetra
.972 .117 0 r
.02087 .47669 .0366 .48812 .05705 .47794 .04112 .46851 Metetra
.961 .161 0 r
.04112 .46851 .05705 .47794 .07782 .46619 .06176 .45858 Metetra
.945 .223 0 r
.06176 .45858 .07782 .46619 .09885 .45329 .0827 .44731 Metetra
.926 .297 0 r
.0827 .44731 .09885 .45329 .12005 .43961 .10387 .43508 Metetra
.904 .375 0 r
.10387 .43508 .12005 .43961 .14139 .42549 .12522 .42223 Metetra
.881 .453 0 r
.12522 .42223 .14139 .42549 .16282 .41122 .1467 .40906 Metetra
.858 .527 0 r
.1467 .40906 .16282 .41122 .18431 .39705 .16827 .39584 Metetra
.836 .594 0 r
.16827 .39584 .18431 .39705 .20585 .38321 .18992 .38279 Metetra
.815 .653 0 r
.18992 .38279 .20585 .38321 .22742 .36989 .21163 .37013 Metetra
.796 .702 0 r
.21163 .37013 .22742 .36989 .24902 .35724 .23339 .358 Metetra
.78 .743 0 r
.23339 .358 .24902 .35724 .27066 .34539 .25521 .34654 Metetra
.762 .767 0 r
.25521 .34654 .27066 .34539 .29234 .33445 .27708 .33587 Metetra
.721 .758 0 r
.27708 .33587 .29234 .33445 .31409 .3245 .29904 .32606 Metetra
.697 .752 0 r
.29904 .32606 .31409 .3245 .33592 .31558 .32108 .31716 Metetra
.689 .75 0 r
.32108 .31716 .33592 .31558 .35785 .30773 .34323 .30921 Metetra
.697 .752 0 r
.34323 .30921 .35785 .30773 .37991 .30094 .36552 .30221 Metetra
.721 .758 0 r
.36552 .30221 .37991 .30094 .40213 .2952 .38797 .29614 Metetra
.762 .767 0 r
.38797 .29614 .40213 .2952 .42453 .29047 .4106 .29095 Metetra
.78 .743 0 r
.4106 .29095 .42453 .29047 .44715 .28668 .43344 .28657 Metetra
.796 .702 0 r
.43344 .28657 .44715 .28668 .47 .28372 .45652 .28289 Metetra
.815 .653 0 r
.45652 .28289 .47 .28372 .49312 .28149 .47986 .27979 Metetra
.836 .594 0 r
.47986 .27979 .49312 .28149 .51653 .27981 .50348 .2771 Metetra
.858 .527 0 r
.50348 .2771 .51653 .27981 .54024 .27851 .52739 .27462 Metetra
.881 .453 0 r
.52739 .27462 .54024 .27851 .56426 .27736 .55161 .27212 Metetra
.904 .375 0 r
.55161 .27212 .56426 .27736 .58861 .27609 .57613 .26932 Metetra
.926 .297 0 r
.57613 .26932 .58861 .27609 .61328 .27439 .60095 .2659 Metetra
.945 .223 0 r
.60095 .2659 .61328 .27439 .63825 .27192 .62604 .26149 Metetra
.961 .161 0 r
.62604 .26149 .63825 .27192 .66349 .26826 .65138 .2557 Metetra
.972 .117 0 r
.65138 .2557 .66349 .26826 .68895 .26298 .67691 .24806 Metetra
.977 .099 0 r
.67691 .24806 .68895 .26298 .71457 .25558 .70256 .23807 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 233.562},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzVfW3sZsV13/jOvc/D8rp4ecewvBnW5mWxDZg1SxYMXgcWnBAaiFNsh4Ax
EBtTwITUhsQvhTZNo9KQ2lHtSqRVTFupcU2j2pbt1C9VjOIPKJXsD64iVZZl
VVY++EOrKl/+nZlzfuecmXvmeZ4/C8Rdae4+/7n3zp2Z85sz55w5c+bmOx+5
9/0fuvOR++6686x3PnTng/fed9fDZx388EMpK74mhNecFUL4X2eF/Hsr/eRL
+Xd2vvAfr+DvL+b/Yv7umH8N+df76dbz5b9yb4v/haFcR5uXf9/9KryxS+r3
C9t+d6e0Mj3PeeW/d5leGKQX5gUcWz9Qfr2rX40oDx0tX6aqLauSTVVK5W6m
H/9NXt/RVIcxchP9/qYUfpRfbX7uz+W50o4weZUIh+jH1+Tjx69/+Cv5v/LZ
1zrdMDh5R0ldtCcvo8K+1FChfnHndj6wGSzeQv//mVTp1A2/UehbOiZu+2vP
Sytf1yu5yTty29/4grTozFfsG/9R2nG2865HwSPkjc4o45L/g9Te63uvRQol
rx06Ghlo/04yzncen5y86+nFP5Ga7XEeWjh519GL/1a+eKHz0NLJezu9+Kx8
8eLtvfivV3aiV4sjnLxrqbDPSvXf4jy0w8m7hl78I6nF5dt78dPyxSudhzwq
H6AXPyIvniHffpvzuMcmfo6KeKT8N0PnaVJyM4lctWENVxd/slT3mg2re/XK
8k6U6l7nvHu0k7d/ZXmvlfq942Upb6fU7+edd49x8qifDYXLbFYKvsF5/Fgn
j5AQPilF3Ly9F39HOuEXnIeOc/L20YuPy4u/5DzkzW2E+/BRqeov914sd/k7
j0mX3OY8fryT91Z68VEpyWPdt26vsIeltXc4D3miwhX04j+QWrzPeWiXk0d8
JTwgX7xzey9+UL7YjOpf37AcnlPukwp8wHnoBCePZ7sPSAXu396Ld8sXP9h7
0U56vy4ZH3YeP8nJexO9+D75TtNDD2yvnDuknEech0528i6lF39Vav6bzkOn
OHl76cU3yxdVQHid5P3W9grzZr6OhHSqfO1jzkuekHkJvVmm5e3KlSdJi7yZ
3mvlaU7exdtupSLs471vlLuXbLvk46VFn9yk5DdLRkeuPE4eeNIpzxPDL+zX
WaXJMkeVjz21vWIPShG/t+GLC3njHCriOumi39+wiMnvG7YDXCsfeNp59wwn
r9PXXN7PSf3+wHm3r5X0yrtKyvNA7tV5+9/YJ33wafnaWfJr9btXyHP/0tT0
b08NTQ3Ocmo1yHeZuJdJhhY25sKifrEugvQY4rSlis/Ii+nN/3tGsRrkEqQU
KlCyO+W+nsq9VCr0jKlQKrb8mlZW7TxThLmVq/DPTVf9nzegq7i2YaAb6U++
wdUPmIvQrLDJl2eE+938/0QtSR9nGqcyJ2pT+tXVbs+1JfsGksK5FlTUT/cl
faB86H+/0baSmqYNRMu9TzI09golPDGtyF3H0Ef/5qbAjU6fR1rQmz/dj0+m
CpVKeVUrfT/KKChfPddUw2UIdd6HpJOnrf/5MHVo3Prx+5K+UPJ+cgs+mqrE
1crX0VYup6WgpEuUs/tV81T6X8vX06kaf/0EfXHY+tG9+HiqGtLRba+lahTA
WtjmvB7xzupXzTMavDtfL6Wq/fCD+MBPbi0p/UXXXq9x5XJS4vkVukTo6qni
Rei/kfolYQef3Eft9Ird3W+nZ10o5skTCRPh0M0TfSpcffAcHuE/eIpGeO6E
qiuILrkr0nXZonxtPc80zW9ueYr7O6We+cbBQ8J1GDThsrczIwkXXs1UCFdc
h7Ro37z1pnBB/rV7e1XzbABFDjiVu3DvAZYdw3n7mOGEPVfxG6UyIQvAVJv/
8Y+onwjxivvEN0oqLctMZL0ocEaLJk97vyZfwbof/U/Kuo9A99x1jeQtuB2X
HBj51+4r0MWnvAmlhDMvlzeOY1LcfuNuvsuN0BqWqq3oX6/W+6V/86cvOYDv
baECI9fqhEvQz6e8SZuQbpy0Fzdybc+8PFcyXTnvwqsLZoZy5byrDyq4ct7t
N1L+XdeGY6mV330+AFSJdZW7iafSG57c87p+oz1jx1trUI2ojnY339t1MdB+
wiVIINPOC3HvpL1Ix6NJt9wshDuK8/b8kUJi4i+mdpa87z9TEtqc2lpTtqn/
6dTciwVxnn2laA1Hcom7ntaPH4fm7m2pvfsKlndSw0H3Y/fs4LupwQYBp7wp
EzVdSTxII1ITPX/Z2xeM2fccPNLphB2clxuf89L8ST3qSfe2yc0tz05TOPTk
DEYMo0M3g3qXvR1JcLD7iqZjFPy7LkbzSjHHXIAbx+4pN2BpCTvOpfyjz88l
0jX/vfNCJJ5104dRxqGbS8VQ79RvDYrGrWe/Gmzdhq0XnxPYpA4U2JzudAqp
xWRUV5G/+eWpPVtWaTdP1cUXs1dpf6ESyHvKH2jvH629P7W9j0aftw8gPOES
MMdjLkDejnPRkUefj4RJ4dg96EgaqflLSrlM1N1XBCCxdHbOf/cNQQh//5Xa
uY+feixnpy4uWT94sqTYwygZPlgS8KXm1uzh5W2J1DST6b1u9173rGplRQc8
92NfbMdh0/r3HGQhPLEy6R4iEsY5C7uZB5huxxgo9AD9jjgHVMvDghKolihq
hhDRcCNKDuXKOMq8DImqcPCQTDDvvoEeumd/YJa0+D0ZZU/+2XyqzpTGSPKM
SRWl14viHomWDoW3RGGbP3+ik1cUQAgLX/qmtgOM96kRjOr+K0GBzFSIsRTi
glhXHxSpg1h4IWwRR0aUSTxOE/G4KdMX08XybFCJqJy/rWOWKJzT8fzZg4fw
PEkBAp579oOtJVqVJy75V8ElGur9vc9oXilFDWkvA72OcOgVfGuN2js8c2vR
n5Zc51/8k6bOMRPtKCbaLTJJZZGJElsNkjglw5IEMqQyUw/KLrl7jzhHP5Iu
i924sTwbVFuevYPv6rSW57skBQ3l6sl5XMEsOVKCaHv7jQKoe/bTQx/ZA8E3
0fLohmy5b07xKTYbJaN0ffm1iuO2BAqd8eWR6kypTrrxrW8rqY5Byx681JIv
CbAGzLffSPK6sKGreTpv5WHuTzBLpt5QpAZnMGEqrEkYjOyx2A2aM/Pl5465
AKTdBoGnlsD4yvXaMkjwdx8ILE4kWlN1lhnQFdtItC//v/ffB5g9Xvw8vect
HdDCCfFLHiKbjdgdK1ChRm4PC141ikAF4QFNoF5PDAps9sFL0V93XasJnYQR
fsNN0nNZP7J8LFqFKsuJRGuVHyFXBhqxyM4kpzSHRx76CQSDnYcJCjlBDL3k
AJ6//sac8vPpynm3Hap41N0HjuCRdPanK4E0ZrLSwF9sff5r1b1MZuHLTfee
tHK8g+0z+bS7yvPc4nmhyog9cbiMeOYkf/hlHj1Trn8LVaIxBFomqQ5w9OkN
NyGhm664TnggdMtE3aI0g0xHnw9evTwbHGA6E91OJCWGDebcEY64EiQc5SSS
7vU3gob50dsOwQ718EVLbnNDxDI0oaP+5fPVPY94JJuEi3rDxnsczOovvk5F
JwoQHfjhTIZcDbT6URkB9+1DAgZLr+dbZI/CYNxzlQ4pUESV2Kw7BJ0Qdaa0
3LSaKaczQZp0XSiB0Dn04uSItH2qbS7SxkqkvY1NbXddUyaea+TGwxfRjU/s
FL1wJmSUfgYyDX3dSXAFcT0lqLgQYH488V9UX/7U0aDho+dTKtn3iSrx3nfg
gVtvQoI8secqNoTy9GSHFNikFXzKr0Wh32jpl1NknjeTVj195OUg3rhC0k0k
5BsPXZyTTASf2AmeZHTokhJFhX6JlCUvDSRqqEfEE/pE9AxMOw1rTEwc1Xjw
T7UKB54FWROR0epPHa2pN2xLLROhoyW0GgON9VnkmT1XgfDESdFBKiklAk2W
kJgnedKruWmRkGDa9gXhubp60paQcVQyUkItZpQc8lWa8Ymd5eaup0G8aevg
v6kJm/QakD/Rs6tDkJ+O6+W428k7Rhmu8vM8OYO2QybtLm5FTRsDVG262v5B
ikQaHp1kHFStRIUYHUVMnLEljiU6cVOMXx3FRKacMI+pmEyGtZzXMVZyHhkw
cl66zuyAqsHg+bsPaN1GHaNb4eOvtVw1UZb7KtEVQpBRVTFOhazl6RMMMUuG
t8J2lLDVIRtRGe3jP9XE9XjiZDSIMMhVZnWaqDi1VESf1zpJYO0SnPTYPeCu
R5yjQosnqmBwKS8lS13+6zCp1bUbHroZLbz7gHATan+mU379469VQoF9YgR+
7IsYlaNV9Xoj8LX9EeiR7wjDUL/+Lcg4GRp5xHOt/t7nsUaVzeRsKo+ZuCDp
EydTCsRZ0EFZv75nf867Zz9kyMRT+S5xVBJHkWeXZdSOBz6m0qQabGRcHnMB
3YJGITegmRD3rIFhBzZZImAWmkFk8K3lSwZygkC0EKDlScCCLOgw7uYn332D
2EloFJOI9PBFghEaw1vHgy0PW9c+CyacUAGgABRbW74zX1FAWLDYqlRVFyXn
9IpAP7GyxH2XQTNa0FDxhwsZiMp3HGzm4yFfpYuIQ4A/pOvCjkwduWy2twIU
db3aG9gONbYSd8LLkK/KYhrRbFhh/B+gV9Xi4VGMGV1uyJZgJHrvnv2Ywh6+
CF+kiRrD8njh6gkXrQH9S99k1HiQ8HwfOi6BQx8p5/ZK4fq9KBhIIEE6pdRz
UtvbHQcpUY9A4rJKK/pBJ4GK8dYCcFkRBq2OuQBThFII03czD7AtIjoEBiV1
MqBF1fxXuk4tddEWdUlQK6ksoZlVnqFcHZYJtlcDIClQTPbjMVuMGQHlibyk
mBJ3mYBA6ONZ67sWim2h4bwmL9frKKrGA38KIORqclXj1mnPCDPIlrinMDl/
9AyM/gf3YupMuJhaXKArrxYeQUarmhvTmmn+i3ExFIsil6bmJoysWhiE6qXq
G6pMgJElhupNFiDiS8LM1GIG9b/l5iX3BhhktmYqRxhVMxszNsoTWR06wNPG
KNAIuiyzteU7j3v2x9WoeKPzxusNP/jeZ8C5Xvgyfj37VSA0gaQAhW8klHBP
JJhI4rY+NWJZ50HpSxo44CuuvhAzapBHfZuf4xWmWFCzVNQggbsE9kBACYyZ
0VEgRKYgY47KFMBKvT7fKvMr8DNsy7HFx9JoV3Cw7Paegxh1CV2joosSUDPT
FWNGFyQZODR88b+WVB545bB1HnOvnJcXa5CopgljfC+7JiARcTLOpoohMVNi
rhSVK1lifvQMyn+wEKALvZihJyIKTIDEpdKVEVYrCuKfMmbMYdbadTH4jqo4
9dqLrR5WQRO2xi7CZvIr7AcJEYsWEfT3/VdifHxEEErGFEBgl05EbH7ZeuQL
JTHfSWBoiKe7ysf612oIlOeK4HG2zBGryDC3iaAtOmtYeR06B9NgsEuJtCIl
VKEpBV1M3Ss3yLigXjZKR8s9Eo0G0EsplRNkDlU2vbGe7U97riKTMvJIcc55
6TqTpeAc956DuJedKyjJGP/IHhA5//Wpo3EDzlqZNzNhQeJ0zYOeKeeKGd3l
MauReOP8LPPQD57EyM3OL0hUgW98G/LEP/svlAKv+3CBl3+upNC2Jzy5zP2V
rtwneaBTkmEMcTVBiqaWqQUWnkwDyUwxAa5UPLjU9orJZbIUZTeu0ddW6kUC
0klrvNEI13Gu8g0QVftLEr4OE2Vdyez2GyG/3X8l3nzsnJzAOYSJFFNySoFn
oWt1VsmsJD/xhT8vqTurkBspcZEomGp+rXIjG+QpTyTebfLY4yq90QfkkAHJ
XCSBkb/Jy0c58TfzVDoBh5oCTzmt1eyhiwWT730HMJi/o1bB7OSZUDjkK/pZ
nfkIgfnu3gMN2cd8BatSNWq2NlVB0U4vEG9USGK1LDrAO3z2Fi3wct4NN/XH
5V3XSsfBoYxw+Ng54PUzMA75CpHa07HGjMgGKJ6TG23TZly9HC54i6oM805/
A2OdV5ZXmF5rQMz3wFWZsxJrBQfKvDWwYLge01OLady7b9/Md4P4abqy4FSb
0sTSOlo8qzMI45nmdECS+KDc0BUBQjbEr/T3wrJgRXSjCXiLbxXIZxYgODeo
PmI9czq+GlnauRQD+jExU1gxdVQeCgsybiTIMs5fAmTrW9vzJfTe9YeA+jWN
2Wn4NBDoSSb9R88g+8Aq/KBXqN/y83ddC6lOp2b2aB7yFT2a4LNU+KhPkdXP
d19haR54IQLvqVRNf/MC8EJAVc3r7OEUHSQdyQxJTV6eWJcN6JRgUFRHr+wA
9uClBBmwt8fEywb2FvHDrFGTEmxMCTU8CCDfBZ6Kgz8LH3X4sPHcITvzdqnl
6TVsuObfF/NS3s3AOxpirjp7+N72HJjUmz+riUZMYmCyPQZrNfcVi6OPsFZ3
wjQMM++ypRj9ravwlxwA11GIMQsZ7TzJq5bRGpYVdjOWBotog7kyRTPpzQc9
uyrbE2IXjJPXtNqWmwUVShAQtMcIqOqx+PipGI9Pjfy97AWUEmRGrGEOBZxR
wJmVzNIBnsn7SAvLGYy4WluV3+aifQp/s/Fp/hHruVUBkUdgAiG/wbIsGvI7
/xlQTKCURLRMoOQKZ32FdZYydtullCdOhmbDDg1gCMoWCJ+5PuxIHws8o6Vh
/kudQogP5jfUEY9hO1lbBa/STY6fYAVgb65krUfQCwcaQuYriM+pxSfqcd8+
Fu8yEx2BTCTpZvYgJXCmK27MFm89E4jGcWCe2a7PreeU5Eq6OradNwnbEfLj
99EmtiFfGbxz3pkSs82XiNWpxSr68NHzAUQfpmAUujwG2W/K1MTLCZ1d/7SE
oNEiaAtMcoY4eEECyz5ucVdVlcrVaj1a+1N7PRIHOxLtCmgHuWNGLjawPM7B
AcpGhZTAP4WVFgc8cdmqFpWtMceb5XesZKcbuMUO8pyHa/vJCp+clzdfppTy
0nUnl88wLCAcXiIU21kJ8zyMZtFiMZNCV+4q5snFkMeyMtKCGlVTeG2qWq/i
XayjRZfa/mu0tsKB3ecUjMYD1d5FazMyztsHi7AaudSzVXtK9LTHTwXIQtkT
w3NdRtloUZZT5LaZVeqcSvaJgg2eq/dIRh8Oo4VDTlDW//vnVFot9XzhK2Bb
z31dUwDwsbVlDTx60nVchw61Q+iA9vzZ2TpTtFmwGd7SNrWQaGFiVU68oezI
2x2jy1wwD6qdyC6QIa+ytHhsicvFov4dB2Fwvk88pOBi+6j4ObOFOSqTMg7u
5XVhUvAwwY35CvdxNYtxVQs3imSZjnn+c6EFxANaGVHDOlzxR3iaTM/nKxXN
5mhq+mnPSPmMuIK3oYc6cBiY7zFrlsIT7JYKOzWDWelHIad+WAy5/FOXpWgC
kxvYGFKZCxfl74XlYMpVVuAQ6oCyRF6MiYeNxKlFIhrAjjWVKkd4rHubl7gK
PpmnZXyOgk9OXFoNUfGe85wwNDaxpxGvgKjuZB5zlIUj6MsJj9zahEVJ1NqE
Rb6XWS4SQcBF4mjcMowXp0i8j54PLOa/6Ko4zG2+/0pwxJr7wbjFYz0DcK1W
rBjQ5dEkOHX87ckdm8AIc0vtCNKKaGzYEXDD4AMO3KDy8PljtKjMeXeIfFsv
X2azA1QQH5Ocx1sZgLa8GZVuYKPKSDcSIkFE6/qhDqCe1WUFFm10Aw5dEkrc
EszAP7q3moHHHPgENhVmkYVBDpuzSQKn72IcZZx2cdn2NObq8qXbBY55CwsS
punA2kYDiAqiLNuPjrtyLEsYMyvwjKmS17f6fuv8jPm8VsLbdZxXFKfR9l7O
U0cRNcROXE/ZUpPxyQn4sxstzb68UVzSs0trSsoiyy8vTMzSALR0kd0hkiFJ
JLdY5N8Fj1zaX/1xSemVfKW873y1JDDZl4ZHIA6mA8zipSxdE505/UW7nEdY
zH/dJvizygagwd4LC/GdnuzCWeVjZpiqaKgLhRxGLTHixQrlenKQhsAy7Ha1
BkFdU/4TJ0M6SP04tVhinndAPKJlLWqUnUfCeRKWDG6EW3rRaSygutP2mINc
ce1yACd6Lgd2ypgausgaLbKooOewOyrbVZB49/E6cEULrtykx08FenxsgcbZ
4RxO5yQZThlcmDN1P42us0XwOyX0FniXsDG4YxOv23MVUOgjDp+rl+2Iwc3Y
HFZEdAmnWjCbGZqxIvLQxR19bhCxZiw7xahUdpc0yCJoAUsh2i2Kduu9F6KY
wXSBc+uoGkwM4p/cAlhtE0JTCyGtOr9iPN2gaDCaZiJFhShghvw26DcpHKN1
RCVI5VfuFtJVjGu0VGNi6nxq1+PsZEaf8Tx81VambgI1Ctu5mEXImYrTCnvW
4h03qik7XMQuPLvWOp1CH9yLBLbXhe6YKccqSQe6nJc3Rj4I72u7izlv9sob
M8tf24TuDplso8Q6tBElf/hBChw45Ct/+SVCN1roBvIKpmKwrSQl0U1odycM
n2L+hMvRIK4ecR1yKSIeI3e1Kj1lIIDRcRiUqYVnC9nZNqdpnYcOezQIeK+X
WpAQsAE8+9wzWnjmPHWd9uZqhSrqxC77Y9nmt/CmLCHU5MCzbPMcehgdFKmC
wRVTtwdZG77BhOlk41QHupyXY2GmlPLSlWfml4LbqcUtP59GMEDpQxYcGN7Y
IEvp77vFaSFjFgncl5ClFGZ0xBYdLZtlF76C4zmiFb1UbcSPaRUii2OUcr0w
w2ZBbuoi1vfoGrsojRalxVomC5Lk1EmInbbASjssxWOkBan85vZRWTqhZCAE
Agev5b9+ul86NUdaZUQSGllaykikDmG5oCR654WviIINkYVcddfAjwHGy0Tg
oQww9TMi/OWKcAyd2LJM2meuu82ZyVTaDO9wi3b3G5FboEiqatertF4l88DZ
wtlTi/c2DPWgaPtz62i7EveSmKwvA0wrGOto/T9nLjsZuD5Ry45dZrbKWD//
NcB6DlzvAJUV7LQs2QFqgHAOhDzlK8TLzEyZgYYSUphBk2WBnr1SXdPY0zAU
51mu+DocR4tjstcCqDMYx3LljkdwkrtFq1UQ3y3LyGoiqrdryrbe0fH+nqyN
RXe0K5js8i8U+KvFPV+3iYCDrl4/quDaaHGHbj4Bn4f5S7ayOAwS844ir/yd
tFKe7PN+f3ov4a1s+VXkFUbJ3YtwS/x/uveXz9NT3ok0iz7ueL5G/PtRGGYJ
zc2iJsHNcEgWP7cJOe483paWE3CNWLEZcUMPd23nYVIv9aiBhyTAWyrw5pp6
fkYN68x1KuCxcW+UgE+TXZLWwArgqYS3heItBItqD3LRgRxWELVylReH79JK
K4MzKyI21X/0DJRF/ZjLEr8nszGQIacBKBiQJRHkxP49VXgEJkv8kQ24IqPz
fOGAoxxYEDmgPzND9GPBJs/etUK0XURGi8gwmH21prnQhhDiSNblvZ6ECSYB
cukB0trjao5IE79O/7zmHfMVoLtF9KLaytyCSrnibHtmFJ1qdBzVKi4HX4vr
bwQSa6EDtds2OqNFJyvmo2WXOWGdW/wH5ttWr5VtuJlVUqm6Vgh8lomay8gh
cZByGV5EaQvIkYrPZ3VQBc1JHVNGJ4NPzzGAwhONwlPZMTHLs8cv47CHRn/w
lT2iPETmQIzlyuwHKjwm6vLwwxcBnbWVWPT0KSMRKEHcZOuMG+2OV1Uiot0x
opG9QHs1rXvbhlEseCUjdLQIldBogzXe98Ti1mekQijEbOt07LvnTNZ0pAhF
jZ9cMlZ1p2ulqLJ2IxGfELkB4J3zSS+UPcMyjFv8Q9nh1kvclKXukUFdy+hc
GpyDU05TYSD8dD/yOtDmvOzOkZfQaSGdKmG8HnlQbg/xZR8s38NqF6tWOVc8
m+sF3a5MoOFRKtbLUNPlzLXoUV1fkXeD4L0OzUP8NVQrORArGhl37G2twLDW
4GnVgoOrJx3OgIh2QOS8Dvv2pF3u/dl+pV1Pg23qesx82zjkw6EZOKHkpV+Q
HhHmbM3AIeelqR0Sin7zmpenRW1rp1h72BYPMWbekHRI1Ck36fgbPQTHnN6D
R6EH0pDrDbypHXj89je+jY5dN9xmnjmYEVYPN45o4A43zovWztb6abBBYxKX
+klC701OuKtqnNl1eJWavJGEtsyWhb2ZZVPZB7vQOiMi2hGR89KVOg0utexW
m+5d/jlwW1XSje7ETz37VfBTDTaGURIl2vLaYVHf2t5utM2GFI2C+VgoJKr0
T36pOhlptoa3CdRHs4HdhKwA32Css02ynl6QqJPP/rQybqie2MpvQY8koO+o
AGoUUeMqAyi2nLgFKVu5Fhb07GgS/YEQ2NSCCWs+uQRjtYMBphWnVi093n4j
YvfqKnnlWsnPq6MqFpMT/qPFfxg0EIpEFyhjgYWozLKipSiNAdCUoV8iZUW+
WgR6hzu/DAPB318X/Hj1+beclBflILgQRccV2DOP+tG9GADrwD61YOd7aQrl
GaeP80lwHu3StUbI4lhIseXnFE1LY2ppxDmFNy1wM7x93XCVUbfw+PkMoJKW
v1cfb/h+ky7fX+hzkK9ouI5tcwjrHcRPLeJRUY3aqVZAVh86yOfnTZyD2fQ9
D8jzAvtUTBsOgskOgpnewB/cqhwbV2+SKh9pdQviXFjiHsw6YfYhI8cfdf+p
9qRghOMgrW98m2WZVZhnavJaE7g9gVj9OnU3ZL7SKxyvALyeAYBQ2xRKksNJ
su482SHAUcRoCCwtZlrn8lxsfZoElTUPkF1GiB++UaWk+SjAqKN80uU742G0
4yEnnpSNVcpbF6w8Qr3BEO1gyHnqf0tOGDkvXad2YHDtVWHoDZGpHSI8DLDS
UY7Tgnnwy5T4N+SnbY2T0G7F2myeWHVQhTf/HOUMx2AnDXV1GnsDh1/ng+dy
4r5cN3aiHTu0/BC5tdDAaUuSbn+bR/mIZdBEO2jyjXT1JpCljp752nyurAKM
tdRq9LC7RbWQrcYndQzXEYUJZjZ26JX1O5Cqo18Gx6Y7vGqjJ9rRw3b9nnLx
5s8CNRK+SdzbB+Nw4a0ZaoRBHkmB10O/95nQ1TZWzy+TM09EmWm4pphPaFjO
lXBeNi2HFPMncALo36ggDMflPDLKmZPcR2Z8MPVffE4mHZzFR8OiMzjm8zQP
0c744CYYwkB7mCSAdWwnFVlndQQRzAIcnmORwY28et6gknWQWCTjjRn2o4ZY
jrqGlgA/viKwXyVBeVDv6xEciIJgz3pEB+Kcl1gjCxilsYiuOWaIuyzaBbt3
eLBybb6BnR7llFfmIn1UThmVDDTMYxD1hi4wvfFN4DMHhuBoGBvwxutNcPFY
rgvFbW32mcSpZbRn0uk24Aj+nbM7R0Yo479DLEHprpHR9URZhrzG4VOXAryq
iGTfmsNh2NgkLZsLZeXFZ7qj2UBt9vkzyTfDo42AJqILwnQSB94cnpcKR9UY
0+lJnDpNp67rsck/nkU1CHqiK6HyxedaGYvlrFA0cx5NPURGQWTe+Vf2/zEP
nAMymhMYjDBhdVWXaxq/AfIdWDvtesvqqphWOq7u7cEdPF6j2kZQQ15l/jHx
GXhscll9DI8WwznBIqNuOpUPOudV5lsqw7iZYlqG0Ut63mOsTPk2hEUJxcIz
eAfQnKcR0kpL51j2DjRnLL/ZlyuY/3RAzHn5MN18IrFGmFmF5LEYWolCxt0B
+uXYgzK/wsGgym/WL6fSo3Q7B5lGoGnWL0cL5k/hLEXjYAAw13sJcoGKYl6/
iXb9pvKZNxBu86wTs4oYDXAHe5Dselfw6jCrwRFyBivkVL67m6J5atHMPXfa
M4GdYTJoowVtoF1plMc+yATgidqt9mQT1g+80B5vuYLtvsWVCgwDxmnvhNAO
TjlPw2bSuzjAmKRynSKw4myXCRi9wToy9sAbLXhTXr46HJnzGMVh0KM2Gt68
tARTJwU2m0yW0MyUR4kMMck5YgsLNc/qqNClQWOCOI0tiIP2opho2vLsYrFI
wnCdSBgeu0ievLGan++gN1r0BvJNpTx2gQmD2VeOHZQpsS2xg2N+noNl5WSM
ATNks3CAk7A9ewgt6YTLnFvqjdDltjMUpyv6FSYaAmwHtlznvD+REwsZq0Gr
q8wd0M5tFxqfW03jzJdGB67RW/cINQNmT7BJNqlOLXZD4zE1C8E4dTcmzgQC
MOfVtvtXmP1OZsnfgJaJcRufcD+ZkFgGqjxG4UJCs7SDoA3EBobt5cJ3FwLW
2ANmcKRthncPndGiM5SdjtwsbMxmBSxVKKNzKeg0vhBGgzj+6dVWA96vP7WU
IuR1lerBRpOZ7xueb6lroOpJFwpVfJzySRVcv5sWgq9okzPcvjJiw6aMN1oM
B2uFngdx+9gXwWYzrqPFdbDBY3k9jzAOPogpnRA4h/eOPrzf6tyyJxVlXkzA
6sAbU8LnJfEQ6YF7FHBzYkZas17ZQ8N3VUpwDQ4V620Wz8pDibxLS942NEB+
SY2mlVOfQSHjdG9wkKmCh8U3ldwJjdErpZIRPB+qbbLl46nQHiY9AZdw2sav
KZvwIjU0Y7LnP/R9FqA9GZeBd2UPeMwve3CLFm6B1mSIJxinXahck9nZWHn9
mvaFoFGbp4I7Ko639pbfrG9N1qSgc7xjY4T0Nlkmwub5CmlM3VHOBp0Kvjwv
QyW/dbWTl1qIFRlVJFCsk7SoWYGuwjxhI5CW1RsuKI/DQwTamEF1N5uFYCNg
r+w1yIsWecEGquE4X4RCtAw+0hTmVYO9skk0DCYULJT3FdP9PueWrjDELgSj
hWAom214KK9HoB1hkx704W4ur3Wp7kL0wmKRJ7QosSomCQA6tX5ogsCa65FQ
uLDwU0z7+BvseoOyJG9mtiAUxMJW3ErUlQf7ppicWkzyV1Jns59RB2YwpOt+
kSU16fsipLK6IlPlCnS9TYRJyxlxftLYQxLn6d5sqjxCrrRLTtXYYXY1R5Xd
IKAzab38VHf5aHevJECJmxtQF+0Rzxo7Ia7wjc+T4945FG3QS+RZtUlQAosW
GW43ghnPX3PFbVjD1NfDLFqYBbs3qnVeHk2UELOdnWXAHhijBWOgOIhUBjs7
5sRlgO1ZZQVw9MITM0T3O7d2mHl5M4jqidVdYDI34YM9pJMKbQ7ILOwoOZMD
zWi2qJkt1etkeHfJ8CE5DkjdcXVfO8EOp5JVU/fooHWwNil/W7cHWe7s+bpF
fNVwW8vig+Eg9ZrM1GK49JFKiqODXBsZ1iCX3/zrJ+hxgi54bGUOWgVkPtXq
aueWBgCKPdAy7jgaGvhrO0cwaoMNh18x1hXdp4cuKY55YZVxvKxw3IQHyBVU
crN7RwVg9iePLYAF1J2NXRzpZurFZKbvezguAuZs5pYVYA/CUz158KrF9DLM
6mMXqtFCtVK1KzbLlnwCqoFoIOdayqscqEqHeh6+jMWfc27ZyHrYaziZMAGM
wPSBb30brHQ1APnMrrUAhLZDAFwKAJGEj5Qamc2DzG9Ga0V64mTY2RVsFQDH
GmylMMWq57LEGnnsxmZxmCiqo8iC+yUtkW084WPNHhvOe8wvrmB+NsIcQi+l
BD2INx0zmDqQ4ry8GklvqX28Upd9wB0QQfNY+TX2wMVjneOCl9+sjpQDjBgh
fLiknAx34Fk73JaCLGf5kvzGm2E9OsiKziKzIGZm1inMDIRX9On87cPMSLA1
uIo4KVwMC04JNeM6D0XPqYCbVIg+mPazP33KU/fiWtOjhpr9VkdynRBghvhW
h3sxJg3u+O2/+mPoLpvBq7+zIVzb42cQkP6CY81SEEgNBckYSzVNV2ZqNQNL
Kf2VrjPFBas01lRY+WUzFOrZQqjZWW4Yut5io2VmREXdjFJt2lJeOMdbDSbS
mlR30sU+lOHvqnDBN9rncmLJvxYr1G19U/xNLf54PGnoA3MqHS+Uq4yHGK5D
uVKeF06RtwXnNDGTyAwQqAQyh+0h8+3OLWWBXSia47ZwCgcrJVNBZFdXWThg
tOcwmN0ztA9/Kcg0QVVF/hnNYoKRx9SWo2pzguKiRSg440Lm5XGTEJOhmvM9
EEYHhMzZVtsO6j7ZFIHRIjAMJnZDvRE8WjQGG0LGrAnyemEPjVOLRh6zP7o3
IGAYY3HdpHudc8uGM2F9ItgTFPQMLT2rqGKDK+Q9MMTRYBCLhev6WzfGq/6H
Fa0KhMwSKxDy5tTY8sMABaZWTgZB49RDI7A62zVsJYI5p5uvCkVzDCbsop4U
cnhcsMYdhebw16KLtAfBj+diDnitYa+9CAnY7WSDHcMRmMd4F4jXC8PbaVjf
atBpheegiw7oaBZWF2G4CbMCsTD9CqVNwy5OEkx1ITbFKaMJvzQ4iZoRMWV3
QAQOC9jWUKzgZDySmfWJaWn1OuPPBodTgunqMHsizsIaqdDXg9bCQkt+B/8M
Mz4W/uAaTsdqRKAT2JbeyBBtdTLgwipIbDha62WG/h1NxIH50lMpSENNmsBA
oxHwjJtEbHYbh9DMvnIskWGQFllclU7gp+aNwbyx2jHupUGxFkBSYlHtcKEW
LdTYCN0X8ziSa05ggzzHms2cywqDDQ5dTsdAfGcPiMzzav5Gtdc21PxtKRA0
C3JmaXgOv8ggNMOb5qXVNlWoHvbYl8pbIVOZszUqil2l8eKJzSE5GDvNBpAM
urKE1cRNvDY9706AkwPI61IHttmmdBx/i0+27gIsdgE2tQDjEn/4wSTyl1Z3
cfPzzi0bSJaVAHZzqPNiw7DIKKemOT3gTxGD7aaEmGWFGDgZQFtdGKjAoSga
5w2Y5izXQOQcylvWkNIYktymDBUT+4uVU/5+FyuMpNVbf1YhhBWG1azds9h6
W5XqxXTKq+I9MOJ4G0FO4D+YgVajK1p0BRvi0gtYjVAktGGdCJC3ySDh77Aa
lzcI77Jh52retRQ0OupqKlyRiHPbCIlL279iS9LQDiqWgGmVaKNM9tOewS/4
wEyWT1n2pVD1fOR0g8I8imcR4GCBgyk6A27djjPAjiG22mj0ysJuamHHzfnu
8wj9M0dSfIlI8s5DZiQd6opovqIymbmy5mpL23DHKxW7WCdxKJgYPfk5s4Ab
Gw+0lonhJPCFQGzsYcnIfDWCNP7w1N1U68AoEm7m6yaeAfLVY2HRYinY/fit
z91kAukZWwbbPnroihZdKe+n+9CzXVzdtEb09/AEdSA2vKl1XKk7rpYYyutz
63jJ7rtZDCucyQdjKmgPo58MLL05WMEYUAPMoQzLeXh35rQeLovEBb4Hd4dN
1pJ/NiAZLSSDPXIdK6fRhCWam9oSPHcRJbuwu3kN7GDSiEbjxIJWs6iVqqFe
x6u7Q9e4VGnylplPk4gA6tVYb+p1eA7bPzCx2tDenncGLHZeWJqhx+u45NU+
hT8bvM6fNycHTHYZvjadTXZWRQzElKuxd3P8rBxAbjBh5PhgkpSnMVPmaHsN
AfFdIqHtNLNpI42lXLW21ZyO+AJ2I6ELCxK0t2AXsrgDlSw14cdtcYcdt6N/
Grd1vK22K5iZ2wEhd0snIhJYF9Z923quQp3Hzs7j8hDJqV0p9wymrlR+a2Da
bxcBHitiBPyic8vGM/Ew8C0RAxX+2BZhj9/Rs6NwhsTCgYBujFh0Cd8yofzc
wlJdSnTIHoJObVBPxd7GmDIeIwyd+Q6OoYuBWjjE+WiDIyAMa7rM207l7WXV
SDS655U3MaY8jZlh4mkcTe2a42lw8BR7eAp+MCe21d+yBk1YpiT7/VLQ5Dio
VdsdgKRo4s4Y+b01A1KN9KgvoyKOjas+fSlhjMle8xMtqNYlB6NLKhOoDeUL
AVb+H1POdrHFSJobaf5u0RUtukLxz+U8LxYX2+hzOoXa0+VHv9RF0GQRJFL4
ZBbB661Z2mSiYm/6dkRwNSB7Hs7Vqeu6yUODQwTcweOEOsaLbsoxpn18uwsn
nrLWb/MVloppDC5OGULkAuVv1hj/jsATu+CZWvAwxY2y50x/Oa50PkYj8jXn
5VMMcgjSwQagZt5lBfNbRR7yFoAs1tgniLG2tD3UhsggEd0IQ5T3wCwsjBXg
1aRQI0zzlhUY+XmxzU4N16K6Kpv0hBgFHD0Nq1pr//XMUAq9ADeTCNjN1vrX
87DJwhDCZWr4ZtCLh823ooVesMvWVZjmw4Fh3AIKQ/hlh+tZl1p4OJLLz1IQ
iITOIsprJ6FTNSBuwR3/UlvXbc+ZXx6b6xxJyFxpDivdj9MPEDNaMOU0m+s2
9R15OeZEnDmNMAyElp8NzBBZFS63deEyWbiIoG49sdHe0YFJbPRZGnNzT7kG
EuopXG95DIKolqfld/29/w8IzySV0YDKWGTXxxwKoTKTTA6qhq5ziD9Blt7h
LaS636LeOUkV5k2+Oe2hMYDjRXieuV3mmWObUS7k4pbWDE+qwVWcx0HWGMnG
rZHvrdrg0t8mbSlYz1SOTfyBmdZP3iC6CxmE4cmxS0tmHus3CfQYBC/Xfkus
zA3DTLk9KkZLxWC3ansBMrwILz924m7B4Wkw8blgrY4mQmKtb9Uzx8jXnJcw
hWSx9W6HOdhINvUGISrK7DanWAdLgRwS+AQNYDWeYsDaaGcQQkbj1g1ly5K0
2ivNJgANI9rBEt+dR9WLEiqcxgjQHDbZaiIMgSeh2t6vrrXefOzDa9wQXvFn
CF7lgJalAdOvdsG0vtFQvSYjocFKahEEJx2LIGxrsgjCLD/y1SCIaqyPVoZc
lXtmcKqxIraqxmygZfR2fzrYarf0Z0CNG8JqaBSN9gxrb7Pqq8nBogOxYUOI
sQNfQdff34BVCadmEiQs8a+EIP6VcMPco4eWlgfl5xYVkYHEUgxk5G5gcPMy
JjSWvzcFCStKtUdO68f6/z9IRguSnIoZkmL4hDtEDGr3D1KV64oT5TIv4TAG
GqUyOj4yJXvuQ99MS88JxBBeYGr4SJCCdMITP8MZX5gfSN8PmuGAJLazj+fp
t12kRAcpb5BhWLqHRl14rzMgjzLsvj1OMhqh1wgKo9G/VY/QxVWIpGNpVB03
oJSqG3C0dwLu4HGio7IAHpPmvCh83CcQFQhjTWs4rHQiMHMsvuri7MtHpdLD
bxSK0IJceF+XIjpYqCt1RENTWBgyaIRvRFS2vKfe61lrcJS3rIjEzxv/iHp8
BBmTTmfyqJiH1BpWhNSi9afe+uS814v0f6H05gnUm7+2pjfBH21vwqg0mrDo
tZ+A1IFr+tzXzS8P3p3jebnwebcNpht63baQNwJPSKxOThvslRB31ZL1Jum2
U6jb7hQ+7XVWYQJcuxeEgAirWfhZ39UnNk6yLQqx43MyeYpWryOpVJ4BjLC5
sF1qx0m3T5kevV12q7s0BK5M6c2S/zrqzbscENqDUkz0OS4lT8y9OONqofqG
7MjKXgazWS+aACu8x5aydS9ZtfV2xiSUayv8PXcaddSch4ks/BbcdN2+Wm+X
T/nrUgHoburSu7td2ooPKuO8IPZS7UJ4/djYWyDmaJxrVWr4jiDL9CmQvDC9
VzFgr/cYbZ3QmkyN3qb30XZcTiVjr/TTudRP71/TT5VOyp98UWzD330eYrb2
BDbIjg2MgiDO4TJcntcR/N7aWLj0HCLkkSVjfecwa9R+uYD65R5hcF5v2NCQ
LBlvydir19lDjR2EgSnxN7jvviNqi45HM0ytw9l80h57Ma75rhdfa1UUjoul
Jy6knrjXQQjtnapNm+Vrqhy8KJqVWseVxau7XLuny3qn9/ZaSwc2AzI6PTUY
8UbnImPH4nudeDnl8YuEYdOBJuE+p08WDU6okqlD+APfFx8kdfTR+U13FJmo
BnYTZbUhSYcfsxqj4qDnqbkLaS4jHZzPa/EgZmaVk+hcgXD/mhZDP4yNfthC
gPfAUy9wM2qCa3+0DRfoAEw8sdWTnZ0Aq5VnHhDzCF+Fa5TGvkGafQU1+zeE
DdiTXjHkedgHikHmjPu8CLSUcW/CQIl3aGn9rB8UF4qVyv8UbXFaShVCKH6V
XWu7Lswne6TFb6MWf8gh9NQQmqqmSr+eGKUeHqaxdEDzUoYvUinuqXk/eG2m
VtnDVlo6UwV6ASy19TwOzpeGU/Si8MCahsPaYRuO5b5olvuUw6vzHphWLJsj
/J5QRNTt1xFUi9E6C3faXO6+XlgXhY4IH3aaOTrNjBJOtASu4KkqVZLzdJeH
Nq5zOLEyQGZHRhMAntpW5ALLe+cKnd5BDXhQhuRkhmQbpZLsT0tLJYm/oX4j
tXtlQMO49Hx30YIZpUyGqWGui72wvqXAc6QlN1BLHnJIERtSEPXVlgb+SRtL
V3icc9ub7YOmnTWxQqhRPI8vW+ay+Zx/lrSKfNjDw2taBQthiTvBJevCONow
ljbUe2yladE2OwyCyrFpgIAoaKg9akRNp/zEGdIOclkMjzjtsIf3cTukFUHP
LcnNKadRcvO0zmB3o9sOISxITSThUjpB+cvd02WYk+NI+IiMkrbv6fPZEruU
0WC8qYprQkC1Zw1Q+ujmeju2+AttbYUSp0o3/wpV9DfNILb/QuE3uqqAQRvN
vrHGE774r7ZVr88EpRJ0OM1PPjpFKngHVeMxQ3NTuYUcqWjdzzC8yCO7U0vp
YEVIrtFYMbL0+ySpClmpwm/5VYn2dEfsoct1GuUEbbtHwNTxlh4IsDd9avoq
5+2SapGSHf6hYI1mEluCPegPDZeq7hey5areOu9OJXrnAKvyxvECftJVwsea
oUstwe6vyfjXADGzKlW9156fJW8cJ13xG/Sdx50vt0utAXWY16btIHMQnRL5
WPkozeXhiWYI5f+xhbIclIttlvs15b+zc9GsMrOTQwOvBZRcYu7ht6XHJ7Og
x+UGclbyv2k6oDoAMuftkM8QUwgfN0wsvcgfVE8o/aCpxGy331Iq+1Eq9hPy
nWicJ9jVKifTstH2JmXjZer28EmpZHHFmJXLS5/SgCgFfIIK+JQOnwjnLobB
356KZlWOguyRgHKepHKeNBXJL47yIheob/wuvfGUvDGIz4gZwpx+n/7+x/m/
QtSnKeOfyNt/SBnlxbNX/36LEONX5NfJzaDJf33AySNTs3vSkueVsMvJ8xR3
CmgeLpH66LFNeuRu6btJfjWUDM7Bvcu6lFHe0PLK9LlwStZfDTlWFdQNFuxV
Ud8d6yZrQ/UbphL8b6hf2tH7TOx9eqxLGZkp2Lby50JbBU76dS/gAK8nF2tW
R7rwTmLuZ8cVJbW7qbR0T3ys87ywuiursGmFqeD5IdH8/2L17e19y2tYP6zN
pg1r6apd7ZNhXFW5bks7J8x7eySnzVqv5F8FPK9ddZ4HjcPFtaf494TvLcu/
NoCtjkhve2GHyF38K0vcNko7dNqkzn63KWfckANIKzajgzZ46b/UjViwurvN
3W4fTvJt7yOvHt4Om4kaInU4zOEBcmXzX0GIrmzSarK+gmjtFL0SvysYzcvS
Zg9C/bauAPrCq2j+r5G8dQiO8kvFJk8uOcJvmB5/q+JQI151x3cjxe3Y8N3B
qbbXqKayW3OZ0PZN8+HoFNgVR7VaXicctrznja2TNidR//wDryZ13okbvuud
reR9d+eGzx3v5B3j5L2uWxejFvWPWXQ+0KgF3ruK+SPlDY8e+pxX9YXc3Sml
eN2ooWI3FWdOd/JYBS1/rNF0D+d3eM3/A57C+6I=\
\>"],ImageRangeCache->{{{145., 432.}, {288., 56.}} -> {-0.7106266823046584, \
0.23446312473461162, 0.003863407310606874, \
0.003863407310606874}},ExpressionUUID->"609d40ef-f4da-43af-9313-106ac2274775"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55061e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -60 0 ]
[.5 .82364 60 9 ]
[.08965 .22175 -18 -8.88375 ]
[.08965 .22175 0 .11625 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60423 .01939 -10.1877 -9 ]
[.60423 .01939 1.81231 0 ]
[.73698 .05037 0 -6.2075 ]
[.73698 .05037 18 2.7925 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95739 .38791 0 -5.88802 ]
[.95739 .38791 12 3.11198 ]
[.02269 .27405 -24 -2.74987 ]
[.02269 .27405 0 6.25013 ]
[.01481 .32345 -30 -2.79165 ]
[.01481 .32345 0 6.20835 ]
[.00667 .37445 -18 -2.83493 ]
[.00667 .37445 0 6.16507 ]
[-0.00174 .42714 -30 -2.8798 ]
[-0.00174 .42714 0 6.1202 ]
[-0.01043 .4816 -24 -2.92632 ]
[-0.01043 .4816 0 6.07368 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Wave Front Intensity)] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72471 .05502 m
.71857 .05735 L
s
[(-10)] .73698 .05037 -1 .37944 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94486 .39177 m
.93859 .39371 L
s
[(10)] .95739 .38791 -1 .30845 Mshowa
.125 Mabswid
.75031 .09419 m
.74662 .09556 L
s
.775 .13196 m
.7713 .1333 L
s
.79883 .16841 m
.79512 .16972 L
s
.82184 .2036 m
.81812 .2049 L
s
.86557 .27049 m
.86184 .27174 L
s
.88636 .3023 m
.88262 .30352 L
s
.90649 .33308 m
.90274 .33428 L
s
.92597 .36289 m
.92222 .36407 L
s
.69814 .01439 m
.69447 .01581 L
s
.96316 .41977 m
.95939 .42091 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03492 .26929 m
.04103 .26691 L
s
[(0.05)] .02269 .27405 1 -0.38892 Mshowa
.02707 .31879 m
.03321 .31646 L
s
[(0.075)] .01481 .32345 1 -0.37963 Mshowa
.01897 .3699 m
.02513 .36762 L
s
[(0.1)] .00667 .37445 1 -0.37001 Mshowa
.01061 .4227 m
.01678 .42047 L
s
[(0.125)] -0.00174 .42714 1 -0.36005 Mshowa
.00196 .47727 m
.00815 .47511 L
s
[(0.15)] -0.01043 .4816 1 -0.34971 Mshowa
.125 Mabswid
.03337 .27907 m
.03704 .27765 L
s
.03181 .2889 m
.03548 .28749 L
s
.03024 .2988 m
.03392 .29739 L
s
.02866 .30876 m
.03234 .30736 L
s
.02547 .32888 m
.02916 .32749 L
s
.02386 .33904 m
.02755 .33765 L
s
.02224 .34926 m
.02593 .34788 L
s
.02061 .35954 m
.0243 .35817 L
s
.01732 .38032 m
.02102 .37896 L
s
.01566 .39081 m
.01936 .38946 L
s
.01399 .40137 m
.01769 .40002 L
s
.0123 .412 m
.016 .41066 L
s
.0089 .43347 m
.01261 .43214 L
s
.00718 .44431 m
.01089 .44299 L
s
.00545 .45522 m
.00916 .45391 L
s
.00371 .46621 m
.00742 .4649 L
s
.03646 .25958 m
.04012 .25815 L
s
.00019 .48841 m
.00391 .48711 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
0 .454 .167 r
.39279 .65964 .40417 .63098 .41929 .67752 .40743 .72342 Metetra
.301 .646 0 r
.40743 .72342 .41929 .67752 .43562 .69986 .42381 .7529 Metetra
.6 .729 0 r
.42381 .7529 .43562 .69986 .45269 .70404 .44123 .75704 Metetra
.693 .751 0 r
.44123 .75704 .45269 .70404 .47006 .70227 .45901 .75322 Metetra
.718 .757 0 r
.45901 .75322 .47006 .70227 .48758 .69934 .47692 .74814 Metetra
.731 .76 0 r
.47692 .74814 .48758 .69934 .50524 .69606 .49495 .74291 Metetra
.741 .763 0 r
.49495 .74291 .50524 .69606 .52303 .69253 .5131 .73764 Metetra
.749 .765 0 r
.5131 .73764 .52303 .69253 .54094 .68877 .53137 .73234 Metetra
.756 .766 0 r
.53137 .73234 .54094 .68877 .55899 .68479 .54975 .72703 Metetra
.762 .767 0 r
.54975 .72703 .55899 .68479 .57716 .68061 .56826 .72172 Metetra
.766 .768 0 r
.56826 .72172 .57716 .68061 .59545 .67623 .58688 .71641 Metetra
.769 .769 0 r
.58688 .71641 .59545 .67623 .61388 .67168 .60563 .71111 Metetra
.77 .768 0 r
.60563 .71111 .61388 .67168 .63242 .66697 .62451 .70583 Metetra
.77 .767 0 r
.62451 .70583 .63242 .66697 .65109 .66209 .64351 .70057 Metetra
.77 .767 0 r
.64351 .70057 .65109 .66209 .66988 .65705 .66265 .69533 Metetra
.77 .766 0 r
.66265 .69533 .66988 .65705 .68879 .65186 .68191 .69011 Metetra
.77 .766 0 r
.68191 .69011 .68879 .65186 .70782 .64651 .70131 .68491 Metetra
.77 .767 0 r
.70131 .68491 .70782 .64651 .72697 .641 .72085 .67974 Metetra
.77 .767 0 r
.72085 .67974 .72697 .641 .74625 .63532 .74053 .67458 Metetra
.77 .769 0 r
.74053 .67458 .74625 .63532 .76564 .62947 .76035 .66945 Metetra
.768 .769 0 r
.76035 .66945 .76564 .62947 .78514 .62344 .78031 .66433 Metetra
.764 .768 0 r
.78031 .66433 .78514 .62344 .80476 .61722 .80042 .65921 Metetra
.759 .767 0 r
.80042 .65921 .80476 .61722 .82449 .61078 .82068 .65409 Metetra
.753 .766 0 r
.82068 .65409 .82449 .61078 .84433 .60413 .84108 .64896 Metetra
.746 .764 0 r
.84108 .64896 .84433 .60413 .86427 .59723 .86164 .64382 Metetra
.737 .762 0 r
.86164 .64382 .86427 .59723 .88431 .59006 .88235 .63864 Metetra
.725 .759 0 r
.88235 .63864 .88431 .59006 .90444 .58258 .9032 .63339 Metetra
.709 .755 0 r
.9032 .63339 .90444 .58258 .92463 .57455 .92417 .62774 Metetra
.666 .745 0 r
.92417 .62774 .92463 .57455 .94461 .56387 .94489 .6188 Metetra
.499 .703 0 r
.94489 .6188 .94461 .56387 .9632 .54189 .96372 .5943 Metetra
.089 .574 0 r
.96372 .5943 .9632 .54189 .97837 .49525 .97779 .53506 Metetra
.14 .593 0 r
.38194 .66675 .39279 .65964 .40743 .72342 .39629 .73684 Metetra
.815 .654 0 r
.39629 .73684 .40743 .72342 .42381 .7529 .41269 .76806 Metetra
.903 .379 0 r
.41269 .76806 .42381 .7529 .44123 .75704 .4303 .7712 Metetra
.92 .318 0 r
.4303 .7712 .44123 .75704 .45901 .75322 .4483 .76581 Metetra
.919 .323 0 r
.4483 .76581 .45901 .75322 .47692 .74814 .46642 .75927 Metetra
.915 .337 0 r
.46642 .75927 .47692 .74814 .49495 .74291 .48465 .75277 Metetra
.911 .351 0 r
.48465 .75277 .49495 .74291 .5131 .73764 .50298 .7464 Metetra
.908 .363 0 r
.50298 .7464 .5131 .73764 .53137 .73234 .52142 .74016 Metetra
.905 .374 0 r
.52142 .74016 .53137 .73234 .54975 .72703 .53997 .73405 Metetra
.902 .383 0 r
.53997 .73405 .54975 .72703 .56826 .72172 .55864 .72806 Metetra
.9 .392 0 r
.55864 .72806 .56826 .72172 .58688 .71641 .57742 .72218 Metetra
.898 .398 0 r
.57742 .72218 .58688 .71641 .60563 .71111 .59633 .71644 Metetra
.896 .404 0 r
.59633 .71644 .60563 .71111 .62451 .70583 .61536 .71081 Metetra
.895 .408 0 r
.61536 .71081 .62451 .70583 .64351 .70057 .63453 .70529 Metetra
.894 .41 0 r
.63453 .70529 .64351 .70057 .66265 .69533 .65383 .69989 Metetra
.894 .411 0 r
.65383 .69989 .66265 .69533 .68191 .69011 .67326 .69461 Metetra
.894 .411 0 r
.67326 .69461 .68191 .69011 .70131 .68491 .69284 .68944 Metetra
.894 .409 0 r
.69284 .68944 .70131 .68491 .72085 .67974 .71256 .68439 Metetra
.895 .406 0 r
.71256 .68439 .72085 .67974 .74053 .67458 .73244 .67946 Metetra
.897 .401 0 r
.73244 .67946 .74053 .67458 .76035 .66945 .75246 .67465 Metetra
.898 .395 0 r
.75246 .67465 .76035 .66945 .78031 .66433 .77265 .66996 Metetra
.901 .388 0 r
.77265 .66996 .78031 .66433 .80042 .65921 .793 .6654 Metetra
.903 .379 0 r
.793 .6654 .80042 .65921 .82068 .65409 .81351 .66096 Metetra
.906 .369 0 r
.81351 .66096 .82068 .65409 .84108 .64896 .8342 .65666 Metetra
.909 .358 0 r
.8342 .65666 .84108 .64896 .86164 .64382 .85507 .6525 Metetra
.913 .345 0 r
.85507 .6525 .86164 .64382 .88235 .63864 .87613 .64848 Metetra
.917 .331 0 r
.87613 .64848 .88235 .63864 .9032 .63339 .89737 .64459 Metetra
.92 .318 0 r
.89737 .64459 .9032 .63339 .92417 .62774 .91877 .64049 Metetra
.917 .33 0 r
.91877 .64049 .92417 .62774 .94489 .6188 .93994 .63305 Metetra
.877 .469 0 r
.93994 .63305 .94489 .6188 .96372 .5943 .95911 .60862 Metetra
.618 .733 0 r
.95911 .60862 .96372 .5943 .97779 .53506 .97301 .54526 Metetra
.288 .642 0 r
.3714 .66177 .38194 .66675 .39629 .73684 .38558 .73239 Metetra
.87 .49 0 r
.38558 .73239 .39629 .73684 .41269 .76806 .40199 .76308 Metetra
.957 .178 0 r
.40199 .76308 .41269 .76806 .4303 .7712 .41969 .76553 Metetra
.971 .124 0 r
.41969 .76553 .4303 .7712 .4483 .76581 .43779 .75961 Metetra
.965 .145 0 r
.43779 .75961 .4483 .76581 .46642 .75927 .45601 .75264 Metetra
.958 .174 0 r
.45601 .75264 .46642 .75927 .48465 .75277 .47434 .74577 Metetra
.951 .2 0 r
.47434 .74577 .48465 .75277 .50298 .7464 .49277 .73908 Metetra
.946 .223 0 r
.49277 .73908 .50298 .7464 .52142 .74016 .5113 .73257 Metetra
.941 .242 0 r
.5113 .73257 .52142 .74016 .53997 .73405 .52995 .72622 Metetra
.936 .259 0 r
.52995 .72622 .53997 .73405 .55864 .72806 .54871 .72003 Metetra
.932 .273 0 r
.54871 .72003 .55864 .72806 .57742 .72218 .56759 .71398 Metetra
.929 .285 0 r
.56759 .71398 .57742 .72218 .59633 .71644 .58659 .70808 Metetra
.927 .294 0 r
.58659 .70808 .59633 .71644 .61536 .71081 .60572 .70232 Metetra
.925 .3 0 r
.60572 .70232 .61536 .71081 .63453 .70529 .62497 .6967 Metetra
.924 .304 0 r
.62497 .6967 .63453 .70529 .65383 .69989 .64437 .69121 Metetra
.924 .306 0 r
.64437 .69121 .65383 .69989 .67326 .69461 .6639 .68586 Metetra
.924 .305 0 r
.6639 .68586 .67326 .69461 .69284 .68944 .68358 .68064 Metetra
.924 .303 0 r
.68358 .68064 .69284 .68944 .71256 .68439 .7034 .67556 Metetra
.926 .297 0 r
.7034 .67556 .71256 .68439 .73244 .67946 .72338 .67061 Metetra
.928 .29 0 r
.72338 .67061 .73244 .67946 .75246 .67465 .74352 .66581 Metetra
.931 .28 0 r
.74352 .66581 .75246 .67465 .77265 .66996 .76381 .66115 Metetra
.934 .267 0 r
.76381 .66115 .77265 .66996 .793 .6654 .78428 .65665 Metetra
.938 .252 0 r
.78428 .65665 .793 .6654 .81351 .66096 .80492 .65231 Metetra
.943 .234 0 r
.80492 .65231 .81351 .66096 .8342 .65666 .82574 .64813 Metetra
.948 .213 0 r
.82574 .64813 .8342 .65666 .85507 .6525 .84674 .64414 Metetra
.954 .189 0 r
.84674 .64414 .85507 .6525 .87613 .64848 .86795 .64034 Metetra
.961 .161 0 r
.86795 .64034 .87613 .64848 .89737 .64459 .88935 .63673 Metetra
.968 .133 0 r
.88935 .63673 .89737 .64459 .91877 .64049 .91092 .633 Metetra
.969 .13 0 r
.91092 .633 .91877 .64049 .93994 .63305 .9323 .62606 Metetra
.932 .275 0 r
.9323 .62606 .93994 .63305 .95911 .60862 .95173 .60224 Metetra
.787 .727 0 r
.95173 .60224 .95911 .60862 .97301 .54526 .9659 .53893 Metetra
.322 .652 0 r
.36086 .65359 .3714 .66177 .38558 .73239 .37491 .72346 Metetra
.878 .465 0 r
.37491 .72346 .38558 .73239 .40199 .76308 .39131 .75326 Metetra
.962 .158 0 r
.39131 .75326 .40199 .76308 .41969 .76553 .40907 .7553 Metetra
.974 .11 0 r
.40907 .7553 .41969 .76553 .43779 .75961 .42724 .74923 Metetra
.968 .135 0 r
.42724 .74923 .43779 .75961 .45601 .75264 .44555 .74218 Metetra
.96 .167 0 r
.44555 .74218 .45601 .75264 .47434 .74577 .46395 .73525 Metetra
.953 .195 0 r
.46395 .73525 .47434 .74577 .49277 .73908 .48246 .72849 Metetra
.946 .219 0 r
.48246 .72849 .49277 .73908 .5113 .73257 .50107 .72192 Metetra
.941 .24 0 r
.50107 .72192 .5113 .73257 .52995 .72622 .5198 .71551 Metetra
.936 .258 0 r
.5198 .71551 .52995 .72622 .54871 .72003 .53864 .70925 Metetra
.932 .273 0 r
.53864 .70925 .54871 .72003 .56759 .71398 .5576 .70313 Metetra
.929 .285 0 r
.5576 .70313 .56759 .71398 .58659 .70808 .57668 .69717 Metetra
.927 .295 0 r
.57668 .69717 .58659 .70808 .60572 .70232 .59589 .69134 Metetra
.925 .302 0 r
.59589 .69134 .60572 .70232 .62497 .6967 .61523 .68565 Metetra
.924 .306 0 r
.61523 .68565 .62497 .6967 .64437 .69121 .63471 .68009 Metetra
.923 .308 0 r
.63471 .68009 .64437 .69121 .6639 .68586 .65433 .67467 Metetra
.923 .307 0 r
.65433 .67467 .6639 .68586 .68358 .68064 .67409 .66938 Metetra
.924 .304 0 r
.67409 .66938 .68358 .68064 .7034 .67556 .694 .66422 Metetra
.925 .299 0 r
.694 .66422 .7034 .67556 .72338 .67061 .71407 .6592 Metetra
.928 .291 0 r
.71407 .6592 .72338 .67061 .74352 .66581 .73429 .65432 Metetra
.93 .28 0 r
.73429 .65432 .74352 .66581 .76381 .66115 .75468 .64958 Metetra
.934 .267 0 r
.75468 .64958 .76381 .66115 .78428 .65665 .77524 .645 Metetra
.938 .251 0 r
.77524 .645 .78428 .65665 .80492 .65231 .79597 .64059 Metetra
.943 .231 0 r
.79597 .64059 .80492 .65231 .82574 .64813 .81688 .63633 Metetra
.949 .209 0 r
.81688 .63633 .82574 .64813 .84674 .64414 .83799 .63226 Metetra
.956 .183 0 r
.83799 .63226 .84674 .64414 .86795 .64034 .85928 .62839 Metetra
.963 .153 0 r
.85928 .62839 .86795 .64034 .88935 .63673 .88078 .6247 Metetra
.971 .121 0 r
.88078 .6247 .88935 .63673 .91092 .633 .90246 .62092 Metetra
.973 .114 0 r
.90246 .62092 .91092 .633 .9323 .62606 .92397 .61408 Metetra
.938 .252 0 r
.92397 .61408 .9323 .62606 .95173 .60224 .94361 .59077 Metetra
.796 .704 0 r
.94361 .59077 .95173 .60224 .9659 .53893 .95813 .52833 Metetra
.326 .654 0 r
.35021 .64486 .36086 .65359 .37491 .72346 .36413 .7139 Metetra
.875 .472 0 r
.36413 .7139 .37491 .72346 .39131 .75326 .38052 .74289 Metetra
.957 .177 0 r
.38052 .74289 .39131 .75326 .40907 .7553 .39834 .7446 Metetra
.968 .132 0 r
.39834 .7446 .40907 .7553 .42724 .74923 .41658 .73846 Metetra
.962 .158 0 r
.41658 .73846 .42724 .74923 .44555 .74218 .43496 .73138 Metetra
.954 .189 0 r
.43496 .73138 .44555 .74218 .46395 .73525 .45344 .72441 Metetra
.947 .216 0 r
.45344 .72441 .46395 .73525 .48246 .72849 .47203 .71762 Metetra
.941 .24 0 r
.47203 .71762 .48246 .72849 .50107 .72192 .49072 .711 Metetra
.936 .261 0 r
.49072 .711 .50107 .72192 .5198 .71551 .50952 .70455 Metetra
.931 .278 0 r
.50952 .70455 .5198 .71551 .53864 .70925 .52844 .69824 Metetra
.927 .293 0 r
.52844 .69824 .53864 .70925 .5576 .70313 .54748 .69207 Metetra
.924 .305 0 r
.54748 .69207 .5576 .70313 .57668 .69717 .56665 .68604 Metetra
.921 .314 0 r
.56665 .68604 .57668 .69717 .59589 .69134 .58594 .68016 Metetra
.92 .32 0 r
.58594 .68016 .59589 .69134 .61523 .68565 .60537 .6744 Metetra
.918 .325 0 r
.60537 .6744 .61523 .68565 .63471 .68009 .62493 .66877 Metetra
.918 .326 0 r
.62493 .66877 .63471 .68009 .65433 .67467 .64464 .66327 Metetra
.918 .326 0 r
.64464 .66327 .65433 .67467 .67409 .66938 .66448 .65791 Metetra
.919 .323 0 r
.66448 .65791 .67409 .66938 .694 .66422 .68448 .65267 Metetra
.92 .318 0 r
.68448 .65267 .694 .66422 .71407 .6592 .70464 .64757 Metetra
.922 .31 0 r
.70464 .64757 .71407 .6592 .73429 .65432 .72495 .6426 Metetra
.925 .3 0 r
.72495 .6426 .73429 .65432 .75468 .64958 .74543 .63778 Metetra
.929 .287 0 r
.74543 .63778 .75468 .64958 .77524 .645 .76608 .6331 Metetra
.933 .271 0 r
.76608 .6331 .77524 .645 .79597 .64059 .7869 .62858 Metetra
.938 .252 0 r
.7869 .62858 .79597 .64059 .81688 .63633 .80791 .62423 Metetra
.944 .23 0 r
.80791 .62423 .81688 .63633 .83799 .63226 .8291 .62005 Metetra
.95 .204 0 r
.8291 .62005 .83799 .63226 .85928 .62839 .85049 .61606 Metetra
.958 .175 0 r
.85049 .61606 .85928 .62839 .88078 .6247 .87209 .61226 Metetra
.966 .144 0 r
.87209 .61226 .88078 .6247 .90246 .62092 .89386 .60837 Metetra
.968 .136 0 r
.89386 .60837 .90246 .62092 .92397 .61408 .91549 .60153 Metetra
.934 .268 0 r
.91549 .60153 .92397 .61408 .94361 .59077 .93533 .57865 Metetra
.795 .706 0 r
.93533 .57865 .94361 .59077 .95813 .52833 .95019 .51705 Metetra
.328 .654 0 r
.33943 .63591 .35021 .64486 .36413 .7139 .35322 .70423 Metetra
.872 .483 0 r
.35322 .70423 .36413 .7139 .38052 .74289 .3696 .73251 Metetra
.952 .198 0 r
.3696 .73251 .38052 .74289 .39834 .7446 .38747 .73393 Metetra
.963 .156 0 r
.38747 .73393 .39834 .7446 .41658 .73846 .40579 .72772 Metetra
.956 .181 0 r
.40579 .72772 .41658 .73846 .43496 .73138 .42425 .7206 Metetra
.949 .211 0 r
.42425 .7206 .43496 .73138 .45344 .72441 .44281 .7136 Metetra
.942 .238 0 r
.44281 .7136 .45344 .72441 .47203 .71762 .46147 .70677 Metetra
.936 .261 0 r
.46147 .70677 .47203 .71762 .49072 .711 .48024 .70011 Metetra
.93 .281 0 r
.48024 .70011 .49072 .711 .50952 .70455 .49913 .6936 Metetra
.926 .297 0 r
.49913 .6936 .50952 .70455 .52844 .69824 .51813 .68724 Metetra
.922 .312 0 r
.51813 .68724 .52844 .69824 .54748 .69207 .53725 .68101 Metetra
.919 .323 0 r
.53725 .68101 .54748 .69207 .56665 .68604 .5565 .67493 Metetra
.916 .332 0 r
.5565 .67493 .56665 .68604 .58594 .68016 .57588 .66898 Metetra
.915 .338 0 r
.57588 .66898 .58594 .68016 .60537 .6744 .59539 .66315 Metetra
.913 .343 0 r
.59539 .66315 .60537 .6744 .62493 .66877 .61504 .65746 Metetra
.913 .344 0 r
.61504 .65746 .62493 .66877 .64464 .66327 .63483 .65189 Metetra
.913 .344 0 r
.63483 .65189 .64464 .66327 .66448 .65791 .65477 .64644 Metetra
.914 .341 0 r
.65477 .64644 .66448 .65791 .68448 .65267 .67485 .64113 Metetra
.915 .336 0 r
.67485 .64113 .68448 .65267 .70464 .64757 .6951 .63594 Metetra
.917 .328 0 r
.6951 .63594 .70464 .64757 .72495 .6426 .7155 .63089 Metetra
.92 .318 0 r
.7155 .63089 .72495 .6426 .74543 .63778 .73607 .62598 Metetra
.924 .306 0 r
.73607 .62598 .74543 .63778 .76608 .6331 .75681 .62121 Metetra
.928 .29 0 r
.75681 .62121 .76608 .6331 .7869 .62858 .77773 .61659 Metetra
.933 .272 0 r
.77773 .61659 .7869 .62858 .80791 .62423 .79883 .61213 Metetra
.938 .251 0 r
.79883 .61213 .80791 .62423 .8291 .62005 .82012 .60785 Metetra
.945 .226 0 r
.82012 .60785 .8291 .62005 .85049 .61606 .8416 .60375 Metetra
.952 .198 0 r
.8416 .60375 .85049 .61606 .87209 .61226 .86329 .59983 Metetra
.96 .168 0 r
.86329 .59983 .87209 .61226 .89386 .60837 .88517 .59583 Metetra
.962 .159 0 r
.88517 .59583 .89386 .60837 .91549 .60153 .90691 .58898 Metetra
.929 .285 0 r
.90691 .58898 .91549 .60153 .93533 .57865 .92695 .56644 Metetra
.793 .71 0 r
.92695 .56644 .93533 .57865 .95019 .51705 .94214 .50556 Metetra
.328 .654 0 r
.32852 .62679 .33943 .63591 .35322 .70423 .34217 .69449 Metetra
.869 .492 0 r
.34217 .69449 .35322 .70423 .3696 .73251 .35854 .72214 Metetra
.947 .217 0 r
.35854 .72214 .3696 .73251 .38747 .73393 .37647 .72331 Metetra
.957 .177 0 r
.37647 .72331 .38747 .73393 .40579 .72772 .39487 .71703 Metetra
.951 .201 0 r
.39487 .71703 .40579 .72772 .42425 .7206 .4134 .70987 Metetra
.944 .23 0 r
.4134 .70987 .42425 .7206 .44281 .7136 .43204 .70283 Metetra
.937 .256 0 r
.43204 .70283 .44281 .7136 .46147 .70677 .45078 .69595 Metetra
.931 .279 0 r
.45078 .69595 .46147 .70677 .48024 .70011 .46964 .68924 Metetra
.926 .298 0 r
.46964 .68924 .48024 .70011 .49913 .6936 .4886 .68268 Metetra
.921 .314 0 r
.4886 .68268 .49913 .6936 .51813 .68724 .50769 .67627 Metetra
.917 .328 0 r
.50769 .67627 .51813 .68724 .53725 .68101 .52689 .66998 Metetra
.914 .339 0 r
.52689 .66998 .53725 .68101 .5565 .67493 .54623 .66383 Metetra
.912 .348 0 r
.54623 .66383 .5565 .67493 .57588 .66898 .56569 .65781 Metetra
.91 .354 0 r
.56569 .65781 .57588 .66898 .59539 .66315 .58529 .65192 Metetra
.909 .358 0 r
.58529 .65192 .59539 .66315 .61504 .65746 .60502 .64615 Metetra
.909 .36 0 r
.60502 .64615 .61504 .65746 .63483 .65189 .6249 .64051 Metetra
.909 .359 0 r
.6249 .64051 .63483 .65189 .65477 .64644 .64493 .63499 Metetra
.909 .357 0 r
.64493 .63499 .65477 .64644 .67485 .64113 .66511 .62959 Metetra
.911 .352 0 r
.66511 .62959 .67485 .64113 .6951 .63594 .68544 .62432 Metetra
.913 .344 0 r
.68544 .62432 .6951 .63594 .7155 .63089 .70594 .61918 Metetra
.916 .335 0 r
.70594 .61918 .7155 .63089 .73607 .62598 .7266 .61418 Metetra
.919 .322 0 r
.7266 .61418 .73607 .62598 .75681 .62121 .74744 .60932 Metetra
.923 .308 0 r
.74744 .60932 .75681 .62121 .77773 .61659 .76845 .6046 Metetra
.928 .29 0 r
.76845 .6046 .77773 .61659 .79883 .61213 .78965 .60004 Metetra
.933 .269 0 r
.78965 .60004 .79883 .61213 .82012 .60785 .81103 .59566 Metetra
.94 .245 0 r
.81103 .59566 .82012 .60785 .8416 .60375 .83262 .59145 Metetra
.947 .218 0 r
.83262 .59145 .8416 .60375 .86329 .59983 .85441 .58741 Metetra
.954 .188 0 r
.85441 .58741 .86329 .59983 .88517 .59583 .87638 .58331 Metetra
.957 .179 0 r
.87638 .58331 .88517 .59583 .90691 .58898 .89824 .57643 Metetra
.925 .3 0 r
.89824 .57643 .90691 .58898 .92695 .56644 .91848 .55418 Metetra
.792 .714 0 r
.91848 .55418 .92695 .56644 .94214 .50556 .93397 .4939 Metetra
.329 .654 0 r
.31748 .6175 .32852 .62679 .34217 .69449 .33098 .68467 Metetra
.867 .501 0 r
.33098 .68467 .34217 .69449 .35854 .72214 .34734 .71179 Metetra
.943 .233 0 r
.34734 .71179 .35854 .72214 .37647 .72331 .36533 .71273 Metetra
.953 .195 0 r
.36533 .71273 .37647 .72331 .39487 .71703 .38381 .70638 Metetra
.947 .219 0 r
.38381 .70638 .39487 .71703 .4134 .70987 .40242 .69918 Metetra
.939 .247 0 r
.40242 .69918 .4134 .70987 .43204 .70283 .42114 .69208 Metetra
.933 .272 0 r
.42114 .69208 .43204 .70283 .45078 .69595 .43996 .68516 Metetra
.927 .294 0 r
.43996 .68516 .45078 .69595 .46964 .68924 .4589 .67839 Metetra
.922 .313 0 r
.4589 .67839 .46964 .68924 .4886 .68268 .47795 .67178 Metetra
.917 .329 0 r
.47795 .67178 .4886 .68268 .50769 .67627 .49712 .6653 Metetra
.913 .343 0 r
.49712 .6653 .50769 .67627 .52689 .66998 .51641 .65895 Metetra
.91 .353 0 r
.51641 .65895 .52689 .66998 .54623 .66383 .53583 .65274 Metetra
.908 .362 0 r
.53583 .65274 .54623 .66383 .56569 .65781 .55538 .64665 Metetra
.906 .368 0 r
.55538 .64665 .56569 .65781 .58529 .65192 .57506 .64069 Metetra
.905 .372 0 r
.57506 .64069 .58529 .65192 .60502 .64615 .59489 .63485 Metetra
.905 .374 0 r
.59489 .63485 .60502 .64615 .6249 .64051 .61486 .62913 Metetra
.905 .373 0 r
.61486 .62913 .6249 .64051 .64493 .63499 .63497 .62353 Metetra
.906 .37 0 r
.63497 .62353 .64493 .63499 .66511 .62959 .65525 .61806 Metetra
.907 .365 0 r
.65525 .61806 .66511 .62959 .68544 .62432 .67567 .6127 Metetra
.909 .358 0 r
.67567 .6127 .68544 .62432 .70594 .61918 .69626 .60748 Metetra
.912 .349 0 r
.69626 .60748 .70594 .61918 .7266 .61418 .71702 .60238 Metetra
.915 .337 0 r
.71702 .60238 .7266 .61418 .74744 .60932 .73795 .59743 Metetra
.919 .322 0 r
.73795 .59743 .74744 .60932 .76845 .6046 .75906 .59262 Metetra
.924 .305 0 r
.75906 .59262 .76845 .6046 .78965 .60004 .78036 .58796 Metetra
.929 .285 0 r
.78036 .58796 .78965 .60004 .81103 .59566 .80184 .58347 Metetra
.936 .261 0 r
.80184 .58347 .81103 .59566 .83262 .59145 .82353 .57915 Metetra
.943 .235 0 r
.82353 .57915 .83262 .59145 .85441 .58741 .84542 .57501 Metetra
.95 .206 0 r
.84542 .57501 .85441 .58741 .87638 .58331 .8675 .5708 Metetra
.952 .197 0 r
.8675 .5708 .87638 .58331 .89824 .57643 .88948 .56389 Metetra
.921 .314 0 r
.88948 .56389 .89824 .57643 .91848 .55418 .9099 .54187 Metetra
.79 .718 0 r
.9099 .54187 .91848 .55418 .93397 .4939 .92569 .48207 Metetra
.33 .655 0 r
.30631 .60803 .31748 .6175 .33098 .68467 .31966 .67477 Metetra
.864 .508 0 r
.31966 .67477 .33098 .68467 .34734 .71179 .336 .70144 Metetra
.939 .247 0 r
.336 .70144 .34734 .71179 .36533 .71273 .35405 .70218 Metetra
.949 .21 0 r
.35405 .70218 .36533 .71273 .38381 .70638 .3726 .69575 Metetra
.943 .234 0 r
.3726 .69575 .38381 .70638 .40242 .69918 .3913 .6885 Metetra
.936 .261 0 r
.3913 .6885 .40242 .69918 .42114 .69208 .4101 .68136 Metetra
.929 .286 0 r
.4101 .68136 .42114 .69208 .43996 .68516 .429 .67438 Metetra
.923 .308 0 r
.429 .67438 .43996 .68516 .4589 .67839 .44802 .66755 Metetra
.918 .326 0 r
.44802 .66755 .4589 .67839 .47795 .67178 .46716 .66087 Metetra
.914 .342 0 r
.46716 .66087 .47795 .67178 .49712 .6653 .48641 .65433 Metetra
.91 .355 0 r
.48641 .65433 .49712 .6653 .51641 .65895 .50579 .64792 Metetra
.907 .365 0 r
.50579 .64792 .51641 .65895 .53583 .65274 .52529 .64164 Metetra
.905 .374 0 r
.52529 .64164 .53583 .65274 .55538 .64665 .54493 .63549 Metetra
.903 .38 0 r
.54493 .63549 .55538 .64665 .57506 .64069 .56471 .62946 Metetra
.902 .383 0 r
.56471 .62946 .57506 .64069 .59489 .63485 .58462 .62354 Metetra
.901 .385 0 r
.58462 .62354 .59489 .63485 .61486 .62913 .60469 .61774 Metetra
.902 .385 0 r
.60469 .61774 .61486 .62913 .63497 .62353 .6249 .61207 Metetra
.902 .382 0 r
.6249 .61207 .63497 .62353 .65525 .61806 .64526 .60651 Metetra
.904 .377 0 r
.64526 .60651 .65525 .61806 .67567 .6127 .66578 .60107 Metetra
.906 .37 0 r
.66578 .60107 .67567 .6127 .69626 .60748 .68647 .59576 Metetra
.908 .361 0 r
.68647 .59576 .69626 .60748 .71702 .60238 .70732 .59057 Metetra
.912 .349 0 r
.70732 .59057 .71702 .60238 .73795 .59743 .72835 .58552 Metetra
.916 .335 0 r
.72835 .58552 .73795 .59743 .75906 .59262 .74956 .58062 Metetra
.92 .318 0 r
.74956 .58062 .75906 .59262 .78036 .58796 .77096 .57587 Metetra
.926 .298 0 r
.77096 .57587 .78036 .58796 .80184 .58347 .79255 .57128 Metetra
.932 .275 0 r
.79255 .57128 .80184 .58347 .82353 .57915 .81433 .56686 Metetra
.939 .249 0 r
.81433 .56686 .82353 .57915 .84542 .57501 .83633 .56261 Metetra
.946 .221 0 r
.83633 .56261 .84542 .57501 .8675 .5708 .85851 .55829 Metetra
.948 .212 0 r
.85851 .55829 .8675 .5708 .88948 .56389 .88061 .55134 Metetra
.918 .325 0 r
.88061 .55134 .88948 .56389 .9099 .54187 .90121 .52948 Metetra
.789 .721 0 r
.90121 .52948 .9099 .54187 .92569 .48207 .91729 .47007 Metetra
.33 .655 0 r
.295 .59839 .30631 .60803 .31966 .67477 .30819 .66478 Metetra
.863 .514 0 r
.30819 .66478 .31966 .67477 .336 .70144 .32451 .69109 Metetra
.936 .258 0 r
.32451 .69109 .336 .70144 .35405 .70218 .34262 .69165 Metetra
.946 .223 0 r
.34262 .69165 .35405 .70218 .3726 .69575 .36125 .68515 Metetra
.94 .246 0 r
.36125 .68515 .3726 .69575 .3913 .6885 .38003 .67784 Metetra
.932 .273 0 r
.38003 .67784 .3913 .6885 .4101 .68136 .39891 .67064 Metetra
.926 .298 0 r
.39891 .67064 .4101 .68136 .429 .67438 .4179 .6636 Metetra
.92 .319 0 r
.4179 .6636 .429 .67438 .44802 .66755 .43701 .65671 Metetra
.915 .337 0 r
.43701 .65671 .44802 .66755 .46716 .66087 .45623 .64997 Metetra
.911 .352 0 r
.45623 .64997 .46716 .66087 .48641 .65433 .47557 .64337 Metetra
.907 .365 0 r
.47557 .64337 .48641 .65433 .50579 .64792 .49503 .63688 Metetra
.904 .376 0 r
.49503 .63688 .50579 .64792 .52529 .64164 .51463 .63054 Metetra
.902 .384 0 r
.51463 .63054 .52529 .64164 .54493 .63549 .53436 .62431 Metetra
.9 .389 0 r
.53436 .62431 .54493 .63549 .56471 .62946 .55422 .6182 Metetra
.899 .393 0 r
.55422 .6182 .56471 .62946 .58462 .62354 .57423 .61221 Metetra
.899 .395 0 r
.57423 .61221 .58462 .62354 .60469 .61774 .59438 .60634 Metetra
.899 .394 0 r
.59438 .60634 .60469 .61774 .6249 .61207 .61469 .60058 Metetra
.899 .392 0 r
.61469 .60058 .6249 .61207 .64526 .60651 .63515 .59494 Metetra
.901 .387 0 r
.63515 .59494 .64526 .60651 .66578 .60107 .65577 .58942 Metetra
.903 .38 0 r
.65577 .58942 .66578 .60107 .68647 .59576 .67655 .58402 Metetra
.905 .371 0 r
.67655 .58402 .68647 .59576 .70732 .59057 .69751 .57874 Metetra
.909 .36 0 r
.69751 .57874 .70732 .59057 .72835 .58552 .71864 .5736 Metetra
.913 .346 0 r
.71864 .5736 .72835 .58552 .74956 .58062 .73995 .5686 Metetra
.917 .329 0 r
.73995 .5686 .74956 .58062 .77096 .57587 .76144 .56375 Metetra
.922 .31 0 r
.76144 .56375 .77096 .57587 .79255 .57128 .78313 .55906 Metetra
.929 .287 0 r
.78313 .55906 .79255 .57128 .81433 .56686 .80503 .55455 Metetra
.935 .262 0 r
.80503 .55455 .81433 .56686 .83633 .56261 .82713 .5502 Metetra
.943 .234 0 r
.82713 .5502 .83633 .56261 .85851 .55829 .84942 .54578 Metetra
.945 .225 0 r
.84942 .54578 .85851 .55829 .88061 .55134 .87164 .53877 Metetra
.916 .335 0 r
.87164 .53877 .88061 .55134 .90121 .52948 .89242 .51703 Metetra
.788 .724 0 r
.89242 .51703 .90121 .52948 .91729 .47007 .90878 .45789 Metetra
.33 .655 0 r
.28355 .58857 .295 .59839 .30819 .66478 .29657 .65472 Metetra
.861 .519 0 r
.29657 .65472 .30819 .66478 .32451 .69109 .31287 .68073 Metetra
.934 .268 0 r
.31287 .68073 .32451 .69109 .34262 .69165 .33104 .68114 Metetra
.943 .234 0 r
.33104 .68114 .34262 .69165 .36125 .68515 .34975 .67456 Metetra
.937 .257 0 r
.34975 .67456 .36125 .68515 .38003 .67784 .36861 .66719 Metetra
.93 .283 0 r
.36861 .66719 .38003 .67784 .39891 .67064 .38758 .65993 Metetra
.923 .307 0 r
.38758 .65993 .39891 .67064 .4179 .6636 .40666 .65282 Metetra
.918 .328 0 r
.40666 .65282 .4179 .6636 .43701 .65671 .42585 .64587 Metetra
.913 .346 0 r
.42585 .64587 .43701 .65671 .45623 .64997 .44516 .63906 Metetra
.908 .361 0 r
.44516 .63906 .45623 .64997 .47557 .64337 .46458 .63239 Metetra
.905 .374 0 r
.46458 .63239 .47557 .64337 .49503 .63688 .48414 .62583 Metetra
.902 .384 0 r
.48414 .62583 .49503 .63688 .51463 .63054 .50382 .61941 Metetra
.899 .392 0 r
.50382 .61941 .51463 .63054 .53436 .62431 .52364 .61311 Metetra
.898 .398 0 r
.52364 .61311 .53436 .62431 .55422 .6182 .5436 .60693 Metetra
.897 .401 0 r
.5436 .60693 .55422 .6182 .57423 .61221 .5637 .60086 Metetra
.896 .403 0 r
.5637 .60086 .57423 .61221 .59438 .60634 .58395 .5949 Metetra
.896 .402 0 r
.58395 .5949 .59438 .60634 .61469 .60058 .60435 .58907 Metetra
.897 .4 0 r
.60435 .58907 .61469 .60058 .63515 .59494 .62491 .58334 Metetra
.898 .395 0 r
.62491 .58334 .63515 .59494 .65577 .58942 .64563 .57773 Metetra
.9 .388 0 r
.64563 .57773 .65577 .58942 .67655 .58402 .66651 .57225 Metetra
.903 .38 0 r
.66651 .57225 .67655 .58402 .69751 .57874 .68756 .56689 Metetra
.906 .368 0 r
.68756 .56689 .69751 .57874 .71864 .5736 .70879 .56166 Metetra
.91 .355 0 r
.70879 .56166 .71864 .5736 .73995 .5686 .73021 .55656 Metetra
.915 .338 0 r
.73021 .55656 .73995 .5686 .76144 .56375 .75181 .55162 Metetra
.92 .319 0 r
.75181 .55162 .76144 .56375 .78313 .55906 .77361 .54683 Metetra
.926 .297 0 r
.77361 .54683 .78313 .55906 .80503 .55455 .79561 .54222 Metetra
.933 .272 0 r
.79561 .54222 .80503 .55455 .82713 .5502 .81782 .53776 Metetra
.94 .245 0 r
.81782 .53776 .82713 .5502 .84942 .54578 .84022 .53325 Metetra
.942 .235 0 r
.84022 .53325 .84942 .54578 .87164 .53877 .86257 .52617 Metetra
.913 .343 0 r
.86257 .52617 .87164 .53877 .89242 .51703 .88351 .5045 Metetra
.787 .726 0 r
.88351 .5045 .89242 .51703 .90878 .45789 .90014 .44554 Metetra
.33 .655 0 r
.27196 .57858 .28355 .58857 .29657 .65472 .2848 .64457 Metetra
.86 .523 0 r
.2848 .64457 .29657 .65472 .31287 .68073 .30108 .67035 Metetra
.932 .276 0 r
.30108 .67035 .31287 .68073 .33104 .68114 .31931 .67063 Metetra
.941 .242 0 r
.31931 .67063 .33104 .68114 .34975 .67456 .3381 .66398 Metetra
.935 .265 0 r
.3381 .66398 .34975 .67456 .36861 .66719 .35705 .65655 Metetra
.928 .291 0 r
.35705 .65655 .36861 .66719 .38758 .65993 .3761 .64921 Metetra
.921 .315 0 r
.3761 .64921 .38758 .65993 .40666 .65282 .39527 .64204 Metetra
.915 .335 0 r
.39527 .64204 .40666 .65282 .42585 .64587 .41454 .63502 Metetra
.911 .353 0 r
.41454 .63502 .42585 .64587 .44516 .63906 .43394 .62814 Metetra
.906 .368 0 r
.43394 .62814 .44516 .63906 .46458 .63239 .45346 .62139 Metetra
.903 .38 0 r
.45346 .62139 .46458 .63239 .48414 .62583 .4731 .61476 Metetra
.9 .39 0 r
.4731 .61476 .48414 .62583 .50382 .61941 .49288 .60827 Metetra
.898 .398 0 r
.49288 .60827 .50382 .61941 .52364 .61311 .51279 .60189 Metetra
.896 .404 0 r
.51279 .60189 .52364 .61311 .5436 .60693 .53284 .59563 Metetra
.895 .408 0 r
.53284 .59563 .5436 .60693 .5637 .60086 .55304 .58948 Metetra
.894 .409 0 r
.55304 .58948 .5637 .60086 .58395 .5949 .57338 .58344 Metetra
.895 .409 0 r
.57338 .58344 .58395 .5949 .60435 .58907 .59388 .57752 Metetra
.895 .406 0 r
.59388 .57752 .60435 .58907 .62491 .58334 .61453 .57171 Metetra
.897 .402 0 r
.61453 .57171 .62491 .58334 .64563 .57773 .63535 .56602 Metetra
.899 .395 0 r
.63535 .56602 .64563 .57773 .66651 .57225 .65633 .56045 Metetra
.901 .386 0 r
.65633 .56045 .66651 .57225 .68756 .56689 .67749 .555 Metetra
.904 .375 0 r
.67749 .555 .68756 .56689 .70879 .56166 .69883 .54968 Metetra
.908 .362 0 r
.69883 .54968 .70879 .56166 .73021 .55656 .72034 .54449 Metetra
.913 .345 0 r
.72034 .54449 .73021 .55656 .75181 .55162 .74205 .53945 Metetra
.918 .327 0 r
.74205 .53945 .75181 .55162 .77361 .54683 .76396 .53457 Metetra
.924 .305 0 r
.76396 .53457 .77361 .54683 .79561 .54222 .78607 .52986 Metetra
.931 .28 0 r
.78607 .52986 .79561 .54222 .81782 .53776 .80839 .52531 Metetra
.938 .253 0 r
.80839 .52531 .81782 .53776 .84022 .53325 .8309 .52069 Metetra
.94 .244 0 r
.8309 .52069 .84022 .53325 .86257 .52617 .85338 .51355 Metetra
.912 .349 0 r
.85338 .51355 .86257 .52617 .88351 .5045 .87449 .49189 Metetra
.787 .728 0 r
.87449 .49189 .88351 .5045 .90014 .44554 .89138 .43301 Metetra
.331 .655 0 r
.26023 .56841 .27196 .57858 .2848 .64457 .27288 .63433 Metetra
.859 .526 0 r
.27288 .63433 .2848 .64457 .30108 .67035 .28913 .65996 Metetra
.93 .281 0 r
.28913 .65996 .30108 .67035 .31931 .67063 .30742 .66013 Metetra
.939 .249 0 r
.30742 .66013 .31931 .67063 .3381 .66398 .32629 .6534 Metetra
.933 .271 0 r
.32629 .6534 .3381 .66398 .35705 .65655 .34532 .64589 Metetra
.926 .297 0 r
.34532 .64589 .35705 .65655 .3761 .64921 .36447 .63849 Metetra
.92 .321 0 r
.36447 .63849 .3761 .64921 .39527 .64204 .38372 .63124 Metetra
.914 .341 0 r
.38372 .63124 .39527 .64204 .41454 .63502 .40308 .62415 Metetra
.909 .358 0 r
.40308 .62415 .41454 .63502 .43394 .62814 .42257 .6172 Metetra
.905 .373 0 r
.42257 .6172 .43394 .62814 .45346 .62139 .44218 .61038 Metetra
.901 .385 0 r
.44218 .61038 .45346 .62139 .4731 .61476 .46192 .60367 Metetra
.898 .395 0 r
.46192 .60367 .4731 .61476 .49288 .60827 .48178 .5971 Metetra
.896 .403 0 r
.48178 .5971 .49288 .60827 .51279 .60189 .50179 .59064 Metetra
.895 .409 0 r
.50179 .59064 .51279 .60189 .53284 .59563 .52194 .5843 Metetra
.893 .412 0 r
.52194 .5843 .53284 .59563 .55304 .58948 .54223 .57806 Metetra
.893 .414 0 r
.54223 .57806 .55304 .58948 .57338 .58344 .56267 .57195 Metetra
.893 .414 0 r
.56267 .57195 .57338 .58344 .59388 .57752 .58327 .56594 Metetra
.894 .411 0 r
.58327 .56594 .59388 .57752 .61453 .57171 .60402 .56005 Metetra
.895 .407 0 r
.60402 .56005 .61453 .57171 .63535 .56602 .62494 .55427 Metetra
.897 .4 0 r
.62494 .55427 .63535 .56602 .65633 .56045 .64603 .54861 Metetra
.9 .391 0 r
.64603 .54861 .65633 .56045 .67749 .555 .66729 .54307 Metetra
.903 .38 0 r
.66729 .54307 .67749 .555 .69883 .54968 .68873 .53766 Metetra
.907 .367 0 r
.68873 .53766 .69883 .54968 .72034 .54449 .71035 .53238 Metetra
.911 .351 0 r
.71035 .53238 .72034 .54449 .74205 .53945 .73217 .52725 Metetra
.916 .332 0 r
.73217 .52725 .74205 .53945 .76396 .53457 .75418 .52227 Metetra
.922 .311 0 r
.75418 .52227 .76396 .53457 .78607 .52986 .77641 .51746 Metetra
.929 .286 0 r
.77641 .51746 .78607 .52986 .80839 .52531 .79884 .51282 Metetra
.936 .259 0 r
.79884 .51282 .80839 .52531 .8309 .52069 .82147 .5081 Metetra
.939 .25 0 r
.82147 .5081 .8309 .52069 .85338 .51355 .84407 .50088 Metetra
.91 .354 0 r
.84407 .50088 .85338 .51355 .87449 .49189 .86535 .47919 Metetra
.786 .729 0 r
.86535 .47919 .87449 .49189 .89138 .43301 .8825 .4203 Metetra
.331 .655 0 r
.24835 .55807 .26023 .56841 .27288 .63433 .2608 .624 Metetra
.858 .528 0 r
.2608 .624 .27288 .63433 .28913 .65996 .27701 .64955 Metetra
.929 .285 0 r
.27701 .64955 .28913 .65996 .30742 .66013 .29536 .64963 Metetra
.938 .253 0 r
.29536 .64963 .30742 .66013 .32629 .6534 .31432 .64282 Metetra
.932 .275 0 r
.31432 .64282 .32629 .6534 .34532 .64589 .33344 .63524 Metetra
.925 .301 0 r
.33344 .63524 .34532 .64589 .36447 .63849 .35267 .62776 Metetra
.918 .324 0 r
.35267 .62776 .36447 .63849 .38372 .63124 .37201 .62044 Metetra
.913 .345 0 r
.37201 .62044 .38372 .63124 .40308 .62415 .39147 .61327 Metetra
.908 .362 0 r
.39147 .61327 .40308 .62415 .42257 .6172 .41105 .60623 Metetra
.904 .377 0 r
.41105 .60623 .42257 .6172 .44218 .61038 .43075 .59933 Metetra
.9 .389 0 r
.43075 .59933 .44218 .61038 .46192 .60367 .45058 .59255 Metetra
.897 .399 0 r
.45058 .59255 .46192 .60367 .48178 .5971 .47054 .58589 Metetra
.895 .407 0 r
.47054 .58589 .48178 .5971 .50179 .59064 .49064 .57935 Metetra
.894 .412 0 r
.49064 .57935 .50179 .59064 .52194 .5843 .51089 .57293 Metetra
.892 .416 0 r
.51089 .57293 .52194 .5843 .54223 .57806 .53127 .56661 Metetra
.892 .417 0 r
.53127 .56661 .54223 .57806 .56267 .57195 .55182 .56041 Metetra
.892 .417 0 r
.55182 .56041 .56267 .57195 .58327 .56594 .57251 .55432 Metetra
.893 .414 0 r
.57251 .55432 .58327 .56594 .60402 .56005 .59337 .54834 Metetra
.894 .41 0 r
.59337 .54834 .60402 .56005 .62494 .55427 .61439 .54248 Metetra
.896 .403 0 r
.61439 .54248 .62494 .55427 .64603 .54861 .63558 .53673 Metetra
.899 .395 0 r
.63558 .53673 .64603 .54861 .66729 .54307 .65695 .5311 Metetra
.902 .384 0 r
.65695 .5311 .66729 .54307 .68873 .53766 .67849 .5256 Metetra
.906 .37 0 r
.67849 .5256 .68873 .53766 .71035 .53238 .70023 .52023 Metetra
.91 .355 0 r
.70023 .52023 .71035 .53238 .73217 .52725 .72216 .51501 Metetra
.915 .336 0 r
.72216 .51501 .73217 .52725 .75418 .52227 .74428 .50993 Metetra
.921 .315 0 r
.74428 .50993 .75418 .52227 .77641 .51746 .76662 .50503 Metetra
.928 .29 0 r
.76662 .50503 .77641 .51746 .79884 .51282 .78917 .50029 Metetra
.935 .264 0 r
.78917 .50029 .79884 .51282 .82147 .5081 .81192 .49548 Metetra
.937 .254 0 r
.81192 .49548 .82147 .5081 .84407 .50088 .83464 .48817 Metetra
.909 .357 0 r
.83464 .48817 .84407 .50088 .86535 .47919 .85609 .46641 Metetra
.786 .73 0 r
.85609 .46641 .86535 .47919 .8825 .4203 .87349 .40741 Metetra
.331 .655 0 r
.23632 .54755 .24835 .55807 .2608 .624 .24856 .61358 Metetra
.858 .529 0 r
.24856 .61358 .2608 .624 .27701 .64955 .26473 .63911 Metetra
.929 .287 0 r
.26473 .63911 .27701 .64955 .29536 .64963 .28313 .63913 Metetra
.937 .255 0 r
.28313 .63913 .29536 .64963 .31432 .64282 .30218 .63224 Metetra
.931 .278 0 r
.30218 .63224 .31432 .64282 .33344 .63524 .32139 .62458 Metetra
.924 .304 0 r
.32139 .62458 .33344 .63524 .35267 .62776 .34071 .61701 Metetra
.918 .327 0 r
.34071 .61701 .35267 .62776 .37201 .62044 .36015 .60961 Metetra
.912 .347 0 r
.36015 .60961 .37201 .62044 .39147 .61327 .3797 .60236 Metetra
.907 .364 0 r
.3797 .60236 .39147 .61327 .41105 .60623 .39936 .59524 Metetra
.903 .379 0 r
.39936 .59524 .41105 .60623 .43075 .59933 .41916 .58826 Metetra
.9 .391 0 r
.41916 .58826 .43075 .59933 .45058 .59255 .43908 .58139 Metetra
.897 .401 0 r
.43908 .58139 .45058 .59255 .47054 .58589 .45914 .57465 Metetra
.895 .408 0 r
.45914 .57465 .47054 .58589 .49064 .57935 .47934 .56803 Metetra
.893 .414 0 r
.47934 .56803 .49064 .57935 .51089 .57293 .49968 .56152 Metetra
.892 .418 0 r
.49968 .56152 .51089 .57293 .53127 .56661 .52017 .55512 Metetra
.892 .419 0 r
.52017 .55512 .53127 .56661 .55182 .56041 .54081 .54883 Metetra
.892 .419 0 r
.54081 .54883 .55182 .56041 .57251 .55432 .56161 .54266 Metetra
.892 .416 0 r
.56161 .54266 .57251 .55432 .59337 .54834 .58257 .53659 Metetra
.894 .412 0 r
.58257 .53659 .59337 .54834 .61439 .54248 .60369 .53064 Metetra
.896 .405 0 r
.60369 .53064 .61439 .54248 .63558 .53673 .62499 .5248 Metetra
.898 .397 0 r
.62499 .5248 .63558 .53673 .65695 .5311 .64647 .51908 Metetra
.901 .386 0 r
.64647 .51908 .65695 .5311 .67849 .5256 .66812 .51349 Metetra
.905 .372 0 r
.66812 .51349 .67849 .5256 .70023 .52023 .68997 .50804 Metetra
.91 .357 0 r
.68997 .50804 .70023 .52023 .72216 .51501 .71201 .50272 Metetra
.915 .338 0 r
.71201 .50272 .72216 .51501 .74428 .50993 .73425 .49755 Metetra
.921 .317 0 r
.73425 .49755 .74428 .50993 .76662 .50503 .7567 .49256 Metetra
.927 .292 0 r
.7567 .49256 .76662 .50503 .78917 .50029 .77937 .48772 Metetra
.934 .266 0 r
.77937 .48772 .78917 .50029 .81192 .49548 .80224 .48282 Metetra
.937 .257 0 r
.80224 .48282 .81192 .49548 .83464 .48817 .82509 .47542 Metetra
.909 .359 0 r
.82509 .47542 .83464 .48817 .85609 .46641 .8467 .45353 Metetra
.785 .73 0 r
.8467 .45353 .85609 .46641 .87349 .40741 .86435 .39433 Metetra
.331 .655 0 r
.22415 .53684 .23632 .54755 .24856 .61358 .23616 .60306 Metetra
.858 .529 0 r
.23616 .60306 .24856 .61358 .26473 .63911 .25227 .62865 Metetra
.928 .288 0 r
.25227 .62865 .26473 .63911 .28313 .63913 .27074 .62862 Metetra
.937 .256 0 r
.27074 .62862 .28313 .63913 .30218 .63224 .28987 .62165 Metetra
.931 .278 0 r
.28987 .62165 .30218 .63224 .32139 .62458 .30917 .6139 Metetra
.924 .304 0 r
.30917 .6139 .32139 .62458 .34071 .61701 .32859 .60625 Metetra
.918 .327 0 r
.32859 .60625 .34071 .61701 .36015 .60961 .34811 .59877 Metetra
.912 .347 0 r
.34811 .59877 .36015 .60961 .3797 .60236 .36776 .59143 Metetra
.907 .364 0 r
.36776 .59143 .3797 .60236 .39936 .59524 .38752 .58423 Metetra
.903 .379 0 r
.38752 .58423 .39936 .59524 .41916 .58826 .40741 .57716 Metetra
.9 .391 0 r
.40741 .57716 .41916 .58826 .43908 .58139 .42743 .5702 Metetra
.897 .401 0 r
.42743 .5702 .43908 .58139 .45914 .57465 .44759 .56338 Metetra
.895 .409 0 r
.44759 .56338 .45914 .57465 .47934 .56803 .46788 .55667 Metetra
.893 .414 0 r
.46788 .55667 .47934 .56803 .49968 .56152 .48832 .55007 Metetra
.892 .418 0 r
.48832 .55007 .49968 .56152 .52017 .55512 .50891 .54359 Metetra
.891 .419 0 r
.50891 .54359 .52017 .55512 .54081 .54883 .52965 .53721 Metetra
.892 .419 0 r
.52965 .53721 .54081 .54883 .56161 .54266 .55056 .53095 Metetra
.892 .417 0 r
.55056 .53095 .56161 .54266 .58257 .53659 .57162 .52479 Metetra
.894 .412 0 r
.57162 .52479 .58257 .53659 .60369 .53064 .59285 .51875 Metetra
.895 .406 0 r
.59285 .51875 .60369 .53064 .62499 .5248 .61426 .51282 Metetra
.898 .397 0 r
.61426 .51282 .62499 .5248 .64647 .51908 .63584 .50702 Metetra
.901 .386 0 r
.63584 .50702 .64647 .51908 .66812 .51349 .65761 .50134 Metetra
.905 .373 0 r
.65761 .50134 .66812 .51349 .68997 .50804 .67956 .49579 Metetra
.909 .357 0 r
.67956 .49579 .68997 .50804 .71201 .50272 .70172 .49038 Metetra
.915 .339 0 r
.70172 .49038 .71201 .50272 .73425 .49755 .72408 .48513 Metetra
.92 .317 0 r
.72408 .48513 .73425 .49755 .7567 .49256 .74665 .48004 Metetra
.927 .293 0 r
.74665 .48004 .7567 .49256 .77937 .48772 .76943 .47512 Metetra
.934 .266 0 r
.76943 .47512 .77937 .48772 .80224 .48282 .79243 .47012 Metetra
.937 .257 0 r
.79243 .47012 .80224 .48282 .82509 .47542 .81541 .46261 Metetra
.909 .36 0 r
.81541 .46261 .82509 .47542 .8467 .45353 .83719 .44056 Metetra
.785 .73 0 r
.83719 .44056 .8467 .45353 .86435 .39433 .85508 .38106 Metetra
.331 .655 0 r
.21182 .52595 .22415 .53684 .23616 .60306 .22359 .59245 Metetra
.858 .528 0 r
.22359 .59245 .23616 .60306 .25227 .62865 .23964 .61817 Metetra
.929 .286 0 r
.23964 .61817 .25227 .62865 .27074 .62862 .25816 .6181 Metetra
.937 .254 0 r
.25816 .6181 .27074 .62862 .28987 .62165 .27738 .61105 Metetra
.931 .277 0 r
.27738 .61105 .28987 .62165 .30917 .6139 .29678 .60321 Metetra
.924 .303 0 r
.29678 .60321 .30917 .6139 .32859 .60625 .31629 .59548 Metetra
.918 .326 0 r
.31629 .59548 .32859 .60625 .34811 .59877 .33591 .5879 Metetra
.913 .346 0 r
.33591 .5879 .34811 .59877 .36776 .59143 .35565 .58047 Metetra
.908 .363 0 r
.35565 .58047 .36776 .59143 .38752 .58423 .37551 .57318 Metetra
.904 .378 0 r
.37551 .57318 .38752 .58423 .40741 .57716 .39549 .56603 Metetra
.9 .39 0 r
.39549 .56603 .40741 .57716 .42743 .5702 .41561 .55898 Metetra
.897 .4 0 r
.41561 .55898 .42743 .5702 .44759 .56338 .43587 .55207 Metetra
.895 .408 0 r
.43587 .55207 .44759 .56338 .46788 .55667 .45626 .54527 Metetra
.893 .413 0 r
.45626 .54527 .46788 .55667 .48832 .55007 .4768 .53858 Metetra
.892 .417 0 r
.4768 .53858 .48832 .55007 .50891 .54359 .49749 .53201 Metetra
.892 .418 0 r
.49749 .53201 .50891 .54359 .52965 .53721 .51834 .52554 Metetra
.892 .418 0 r
.51834 .52554 .52965 .53721 .55056 .53095 .53935 .51919 Metetra
.893 .415 0 r
.53935 .51919 .55056 .53095 .57162 .52479 .56052 .51295 Metetra
.894 .411 0 r
.56052 .51295 .57162 .52479 .59285 .51875 .58186 .50681 Metetra
.896 .404 0 r
.58186 .50681 .59285 .51875 .61426 .51282 .60337 .5008 Metetra
.898 .396 0 r
.60337 .5008 .61426 .51282 .63584 .50702 .62506 .4949 Metetra
.902 .385 0 r
.62506 .4949 .63584 .50702 .65761 .50134 .64694 .48913 Metetra
.905 .372 0 r
.64694 .48913 .65761 .50134 .67956 .49579 .66902 .4835 Metetra
.91 .356 0 r
.66902 .4835 .67956 .49579 .70172 .49038 .69129 .478 Metetra
.915 .337 0 r
.69129 .478 .70172 .49038 .72408 .48513 .71376 .47265 Metetra
.921 .316 0 r
.71376 .47265 .72408 .48513 .74665 .48004 .73645 .46748 Metetra
.928 .291 0 r
.73645 .46748 .74665 .48004 .76943 .47512 .75936 .46246 Metetra
.935 .265 0 r
.75936 .46246 .76943 .47512 .79243 .47012 .78248 .45738 Metetra
.937 .255 0 r
.78248 .45738 .79243 .47012 .81541 .46261 .8056 .44975 Metetra
.909 .358 0 r
.8056 .44975 .81541 .46261 .83719 .44056 .82754 .42749 Metetra
.786 .73 0 r
.82754 .42749 .83719 .44056 .85508 .38106 .84567 .36759 Metetra
.331 .655 0 r
.19934 .51488 .21182 .52595 .22359 .59245 .21085 .58175 Metetra
.858 .527 0 r
.21085 .58175 .22359 .59245 .23964 .61817 .22683 .60766 Metetra
.93 .283 0 r
.22683 .60766 .23964 .61817 .25816 .6181 .2454 .60758 Metetra
.938 .251 0 r
.2454 .60758 .25816 .6181 .27738 .61105 .26471 .60045 Metetra
.932 .273 0 r
.26471 .60045 .27738 .61105 .29678 .60321 .28421 .59251 Metetra
.925 .299 0 r
.28421 .59251 .29678 .60321 .31629 .59548 .30381 .58468 Metetra
.919 .323 0 r
.30381 .58468 .31629 .59548 .33591 .5879 .32353 .57701 Metetra
.913 .343 0 r
.32353 .57701 .33591 .5879 .35565 .58047 .34336 .56949 Metetra
.909 .36 0 r
.34336 .56949 .35565 .58047 .37551 .57318 .36332 .56211 Metetra
.904 .375 0 r
.36332 .56211 .37551 .57318 .39549 .56603 .3834 .55486 Metetra
.901 .387 0 r
.3834 .55486 .39549 .56603 .41561 .55898 .40362 .54772 Metetra
.898 .397 0 r
.40362 .54772 .41561 .55898 .43587 .55207 .42398 .54072 Metetra
.896 .405 0 r
.42398 .54072 .43587 .55207 .45626 .54527 .44447 .53383 Metetra
.894 .411 0 r
.44447 .53383 .45626 .54527 .4768 .53858 .46512 .52705 Metetra
.893 .414 0 r
.46512 .52705 .4768 .53858 .49749 .53201 .48591 .52038 Metetra
.893 .416 0 r
.48591 .52038 .49749 .53201 .51834 .52554 .50686 .51383 Metetra
.893 .415 0 r
.50686 .51383 .51834 .52554 .53935 .51919 .52798 .50738 Metetra
.893 .413 0 r
.52798 .50738 .53935 .51919 .56052 .51295 .54925 .50105 Metetra
.895 .408 0 r
.54925 .50105 .56052 .51295 .58186 .50681 .5707 .49483 Metetra
.897 .402 0 r
.5707 .49483 .58186 .50681 .60337 .5008 .59233 .48872 Metetra
.899 .393 0 r
.59233 .48872 .60337 .5008 .62506 .4949 .61414 .48274 Metetra
.902 .382 0 r
.61414 .48274 .62506 .4949 .64694 .48913 .63613 .47688 Metetra
.906 .369 0 r
.63613 .47688 .64694 .48913 .66902 .4835 .65832 .47115 Metetra
.911 .353 0 r
.65832 .47115 .66902 .4835 .69129 .478 .68071 .46556 Metetra
.916 .334 0 r
.68071 .46556 .69129 .478 .71376 .47265 .70331 .46013 Metetra
.922 .313 0 r
.70331 .46013 .71376 .47265 .73645 .46748 .72612 .45486 Metetra
.928 .288 0 r
.72612 .45486 .73645 .46748 .75936 .46246 .74915 .44976 Metetra
.935 .262 0 r
.74915 .44976 .75936 .46246 .78248 .45738 .7724 .44459 Metetra
.938 .252 0 r
.7724 .44459 .78248 .45738 .8056 .44975 .79565 .43684 Metetra
.91 .356 0 r
.79565 .43684 .8056 .44975 .82754 .42749 .81776 .41432 Metetra
.786 .729 0 r
.81776 .41432 .82754 .42749 .84567 .36759 .83612 .35393 Metetra
.33 .655 0 r
.1867 .50361 .19934 .51488 .21085 .58175 .19794 .57094 Metetra
.859 .524 0 r
.19794 .57094 .21085 .58175 .22683 .60766 .21383 .59712 Metetra
.931 .278 0 r
.21383 .59712 .22683 .60766 .2454 .60758 .23246 .59706 Metetra
.94 .245 0 r
.23246 .59706 .2454 .60758 .26471 .60045 .25186 .58984 Metetra
.934 .268 0 r
.25186 .58984 .26471 .60045 .28421 .59251 .27145 .5818 Metetra
.927 .294 0 r
.27145 .5818 .28421 .59251 .30381 .58468 .29115 .57387 Metetra
.92 .318 0 r
.29115 .57387 .30381 .58468 .32353 .57701 .31097 .5661 Metetra
.915 .338 0 r
.31097 .5661 .32353 .57701 .34336 .56949 .3309 .55848 Metetra
.91 .356 0 r
.3309 .55848 .34336 .56949 .36332 .56211 .35095 .55101 Metetra
.906 .37 0 r
.35095 .55101 .36332 .56211 .3834 .55486 .37114 .54366 Metetra
.902 .383 0 r
.37114 .54366 .3834 .55486 .40362 .54772 .39146 .53643 Metetra
.899 .393 0 r
.39146 .53643 .40362 .54772 .42398 .54072 .41192 .52933 Metetra
.897 .401 0 r
.41192 .52933 .42398 .54072 .44447 .53383 .43251 .52234 Metetra
.895 .406 0 r
.43251 .52234 .44447 .53383 .46512 .52705 .45326 .51547 Metetra
.894 .41 0 r
.45326 .51547 .46512 .52705 .48591 .52038 .47416 .50871 Metetra
.894 .412 0 r
.47416 .50871 .48591 .52038 .50686 .51383 .49522 .50206 Metetra
.894 .411 0 r
.49522 .50206 .50686 .51383 .52798 .50738 .51644 .49553 Metetra
.895 .409 0 r
.51644 .49553 .52798 .50738 .54925 .50105 .53783 .4891 Metetra
.896 .404 0 r
.53783 .4891 .54925 .50105 .5707 .49483 .55939 .48279 Metetra
.898 .397 0 r
.55939 .48279 .5707 .49483 .59233 .48872 .58113 .47659 Metetra
.9 .389 0 r
.58113 .47659 .59233 .48872 .61414 .48274 .60305 .47051 Metetra
.904 .378 0 r
.60305 .47051 .61414 .48274 .63613 .47688 .62516 .46456 Metetra
.907 .364 0 r
.62516 .46456 .63613 .47688 .65832 .47115 .64747 .45875 Metetra
.912 .348 0 r
.64747 .45875 .65832 .47115 .68071 .46556 .66998 .45307 Metetra
.917 .329 0 r
.66998 .45307 .68071 .46556 .70331 .46013 .6927 .44755 Metetra
.923 .308 0 r
.6927 .44755 .70331 .46013 .72612 .45486 .71564 .4422 Metetra
.93 .283 0 r
.71564 .4422 .72612 .45486 .74915 .44976 .7388 .43701 Metetra
.937 .256 0 r
.7388 .43701 .74915 .44976 .7724 .44459 .76217 .43175 Metetra
.939 .247 0 r
.76217 .43175 .7724 .44459 .79565 .43684 .78557 .42387 Metetra
.911 .352 0 r
.78557 .42387 .79565 .43684 .81776 .41432 .80783 .40104 Metetra
.786 .728 0 r
.80783 .40104 .81776 .41432 .83612 .35393 .82643 .34006 Metetra
.33 .655 0 r
.1739 .49214 .1867 .50361 .19794 .57094 .18484 .56003 Metetra
.86 .521 0 r
.18484 .56003 .19794 .57094 .21383 .59712 .20064 .58656 Metetra
.933 .272 0 r
.20064 .58656 .21383 .59712 .23246 .59706 .21932 .58653 Metetra
.942 .238 0 r
.21932 .58653 .23246 .59706 .25186 .58984 .23881 .57923 Metetra
.936 .261 0 r
.23881 .57923 .25186 .58984 .27145 .5818 .2585 .57108 Metetra
.929 .287 0 r
.2585 .57108 .27145 .5818 .29115 .57387 .2783 .56305 Metetra
.922 .311 0 r
.2783 .56305 .29115 .57387 .31097 .5661 .29822 .55517 Metetra
.917 .332 0 r
.29822 .55517 .31097 .5661 .3309 .55848 .31825 .54745 Metetra
.912 .349 0 r
.31825 .54745 .3309 .55848 .35095 .55101 .33841 .53987 Metetra
.907 .364 0 r
.33841 .53987 .35095 .55101 .37114 .54366 .35869 .53242 Metetra
.904 .377 0 r
.35869 .53242 .37114 .54366 .39146 .53643 .37911 .52509 Metetra
.901 .387 0 r
.37911 .52509 .39146 .53643 .41192 .52933 .39967 .5179 Metetra
.899 .395 0 r
.39967 .5179 .41192 .52933 .43251 .52234 .42038 .51082 Metetra
.897 .401 0 r
.42038 .51082 .43251 .52234 .45326 .51547 .44123 .50385 Metetra
.896 .404 0 r
.44123 .50385 .45326 .51547 .47416 .50871 .46224 .49699 Metetra
.895 .406 0 r
.46224 .49699 .47416 .50871 .49522 .50206 .48341 .49025 Metetra
.896 .405 0 r
.48341 .49025 .49522 .50206 .51644 .49553 .50474 .48362 Metetra
.896 .403 0 r
.50474 .48362 .51644 .49553 .53783 .4891 .52624 .4771 Metetra
.898 .398 0 r
.52624 .4771 .53783 .4891 .55939 .48279 .54791 .47069 Metetra
.9 .392 0 r
.54791 .47069 .55939 .48279 .58113 .47659 .56976 .46441 Metetra
.902 .383 0 r
.56976 .46441 .58113 .47659 .60305 .47051 .5918 .45824 Metetra
.905 .372 0 r
.5918 .45824 .60305 .47051 .62516 .46456 .61403 .4522 Metetra
.909 .358 0 r
.61403 .4522 .62516 .46456 .64747 .45875 .63646 .44629 Metetra
.914 .342 0 r
.63646 .44629 .64747 .45875 .66998 .45307 .65909 .44053 Metetra
.919 .323 0 r
.65909 .44053 .66998 .45307 .6927 .44755 .68194 .43492 Metetra
.925 .301 0 r
.68194 .43492 .6927 .44755 .71564 .4422 .705 .42949 Metetra
.932 .276 0 r
.705 .42949 .71564 .4422 .7388 .43701 .72829 .42422 Metetra
.939 .249 0 r
.72829 .42422 .7388 .43701 .76217 .43175 .7518 .41886 Metetra
.941 .239 0 r
.7518 .41886 .76217 .43175 .78557 .42387 .77533 .41084 Metetra
.912 .346 0 r
.77533 .41084 .78557 .42387 .80783 .40104 .79776 .38766 Metetra
.787 .727 0 r
.79776 .38766 .80783 .40104 .82643 .34006 .81659 .32598 Metetra
.33 .655 0 r
.16094 .48046 .1739 .49214 .18484 .56003 .17156 .549 Metetra
.862 .516 0 r
.17156 .549 .18484 .56003 .20064 .58656 .18726 .57596 Metetra
.935 .263 0 r
.18726 .57596 .20064 .58656 .21932 .58653 .20598 .576 Metetra
.944 .228 0 r
.20598 .576 .21932 .58653 .23881 .57923 .22557 .56861 Metetra
.938 .251 0 r
.22557 .56861 .23881 .57923 .2585 .57108 .24536 .56036 Metetra
.931 .278 0 r
.24536 .56036 .2585 .57108 .2783 .56305 .26526 .55222 Metetra
.925 .302 0 r
.26526 .55222 .2783 .56305 .29822 .55517 .28527 .54424 Metetra
.919 .323 0 r
.28527 .54424 .29822 .55517 .31825 .54745 .30541 .53641 Metetra
.914 .341 0 r
.30541 .53641 .31825 .54745 .33841 .53987 .32567 .52872 Metetra
.91 .356 0 r
.32567 .52872 .33841 .53987 .35869 .53242 .34606 .52117 Metetra
.906 .369 0 r
.34606 .52117 .35869 .53242 .37911 .52509 .36659 .51374 Metetra
.903 .379 0 r
.36659 .51374 .37911 .52509 .39967 .5179 .38725 .50644 Metetra
.901 .387 0 r
.38725 .50644 .39967 .5179 .42038 .51082 .40806 .49926 Metetra
.899 .393 0 r
.40806 .49926 .42038 .51082 .44123 .50385 .42902 .49219 Metetra
.898 .397 0 r
.42902 .49219 .44123 .50385 .46224 .49699 .45014 .48524 Metetra
.898 .399 0 r
.45014 .48524 .46224 .49699 .48341 .49025 .47141 .4784 Metetra
.898 .398 0 r
.47141 .4784 .48341 .49025 .50474 .48362 .49286 .47167 Metetra
.898 .396 0 r
.49286 .47167 .50474 .48362 .52624 .4771 .51447 .46506 Metetra
.9 .391 0 r
.51447 .46506 .52624 .4771 .54791 .47069 .53626 .45856 Metetra
.902 .384 0 r
.53626 .45856 .54791 .47069 .56976 .46441 .55823 .45218 Metetra
.904 .375 0 r
.55823 .45218 .56976 .46441 .5918 .45824 .58038 .44592 Metetra
.908 .364 0 r
.58038 .44592 .5918 .45824 .61403 .4522 .60273 .4398 Metetra
.911 .35 0 r
.60273 .4398 .61403 .4522 .63646 .44629 .62529 .4338 Metetra
.916 .334 0 r
.62529 .4338 .63646 .44629 .65909 .44053 .64804 .42795 Metetra
.921 .314 0 r
.64804 .42795 .65909 .44053 .68194 .43492 .67101 .42226 Metetra
.927 .292 0 r
.67101 .42226 .68194 .43492 .705 .42949 .69421 .41674 Metetra
.934 .266 0 r
.69421 .41674 .705 .42949 .72829 .42422 .71763 .41137 Metetra
.941 .239 0 r
.71763 .41137 .72829 .42422 .7518 .41886 .74128 .40593 Metetra
.944 .23 0 r
.74128 .40593 .7518 .41886 .77533 .41084 .76495 .39776 Metetra
.915 .339 0 r
.76495 .39776 .77533 .41084 .79776 .38766 .78755 .37415 Metetra
.788 .725 0 r
.78755 .37415 .79776 .38766 .81659 .32598 .80661 .31167 Metetra
.33 .655 0 r
.14782 .46858 .16094 .48046 .17156 .549 .15809 .53787 Metetra
.864 .511 0 r
.15809 .53787 .17156 .549 .18726 .57596 .17366 .56534 Metetra
.938 .252 0 r
.17366 .56534 .18726 .57596 .20598 .576 .19243 .56547 Metetra
.947 .217 0 r
.19243 .56547 .20598 .576 .22557 .56861 .21212 .55799 Metetra
.941 .24 0 r
.21212 .55799 .22557 .56861 .24536 .56036 .23201 .54963 Metetra
.934 .267 0 r
.23201 .54963 .24536 .56036 .26526 .55222 .25201 .54137 Metetra
.927 .292 0 r
.25201 .54137 .26526 .55222 .28527 .54424 .27213 .53328 Metetra
.922 .313 0 r
.27213 .53328 .28527 .54424 .30541 .53641 .29237 .52534 Metetra
.917 .331 0 r
.29237 .52534 .30541 .53641 .32567 .52872 .31274 .51754 Metetra
.912 .347 0 r
.31274 .51754 .32567 .52872 .34606 .52117 .33323 .50988 Metetra
.909 .36 0 r
.33323 .50988 .34606 .52117 .36659 .51374 .35386 .50234 Metetra
.906 .37 0 r
.35386 .50234 .36659 .51374 .38725 .50644 .37464 .49494 Metetra
.903 .378 0 r
.37464 .49494 .38725 .50644 .40806 .49926 .39556 .48766 Metetra
.902 .384 0 r
.39556 .48766 .40806 .49926 .42902 .49219 .41663 .48049 Metetra
.901 .388 0 r
.41663 .48049 .42902 .49219 .45014 .48524 .43785 .47344 Metetra
.9 .39 0 r
.43785 .47344 .45014 .48524 .47141 .4784 .45924 .4665 Metetra
.9 .389 0 r
.45924 .4665 .47141 .4784 .49286 .47167 .4808 .45967 Metetra
.901 .386 0 r
.4808 .45967 .49286 .47167 .51447 .46506 .50252 .45296 Metetra
.902 .382 0 r
.50252 .45296 .51447 .46506 .53626 .45856 .52443 .44637 Metetra
.904 .375 0 r
.52443 .44637 .53626 .45856 .55823 .45218 .54652 .4399 Metetra
.907 .366 0 r
.54652 .4399 .55823 .45218 .58038 .44592 .56879 .43355 Metetra
.91 .354 0 r
.56879 .43355 .58038 .44592 .60273 .4398 .59127 .42733 Metetra
.914 .34 0 r
.59127 .42733 .60273 .4398 .62529 .4338 .61394 .42125 Metetra
.919 .323 0 r
.61394 .42125 .62529 .4338 .64804 .42795 .63683 .41531 Metetra
.924 .304 0 r
.63683 .41531 .64804 .42795 .67101 .42226 .65993 .40954 Metetra
.93 .281 0 r
.65993 .40954 .67101 .42226 .69421 .41674 .68325 .40393 Metetra
.937 .255 0 r
.68325 .40393 .69421 .41674 .71763 .41137 .70681 .39849 Metetra
.944 .228 0 r
.70681 .39849 .71763 .41137 .74128 .40593 .7306 .39296 Metetra
.947 .218 0 r
.7306 .39296 .74128 .40593 .76495 .39776 .75441 .38462 Metetra
.917 .33 0 r
.75441 .38462 .76495 .39776 .78755 .37415 .77718 .36055 Metetra
.789 .722 0 r
.77718 .36055 .78755 .37415 .80661 .31167 .79647 .29715 Metetra
.329 .655 0 r
.13452 .45648 .14782 .46858 .15809 .53787 .14443 .52663 Metetra
.866 .504 0 r
.14443 .52663 .15809 .53787 .17366 .56534 .15986 .55471 Metetra
.941 .24 0 r
.15986 .55471 .17366 .56534 .19243 .56547 .17867 .55496 Metetra
.951 .202 0 r
.17867 .55496 .19243 .56547 .21212 .55799 .19845 .54739 Metetra
.945 .226 0 r
.19845 .54739 .21212 .55799 .23201 .54963 .21845 .5389 Metetra
.938 .254 0 r
.21845 .5389 .23201 .54963 .25201 .54137 .23856 .53052 Metetra
.931 .279 0 r
.23856 .53052 .25201 .54137 .27213 .53328 .25879 .5223 Metetra
.925 .3 0 r
.25879 .5223 .27213 .53328 .29237 .52534 .27913 .51425 Metetra
.92 .319 0 r
.27913 .51425 .29237 .52534 .31274 .51754 .2996 .50634 Metetra
.916 .335 0 r
.2996 .50634 .31274 .51754 .33323 .50988 .32021 .49857 Metetra
.912 .348 0 r
.32021 .49857 .33323 .50988 .35386 .50234 .34095 .49092 Metetra
.909 .359 0 r
.34095 .49092 .35386 .50234 .37464 .49494 .36183 .48341 Metetra
.907 .367 0 r
.36183 .48341 .37464 .49494 .39556 .48766 .38286 .47602 Metetra
.905 .373 0 r
.38286 .47602 .39556 .48766 .41663 .48049 .40404 .46875 Metetra
.904 .377 0 r
.40404 .46875 .41663 .48049 .43785 .47344 .42538 .46159 Metetra
.903 .379 0 r
.42538 .46159 .43785 .47344 .45924 .4665 .44688 .45455 Metetra
.903 .378 0 r
.44688 .45455 .45924 .4665 .4808 .45967 .46855 .44763 Metetra
.904 .376 0 r
.46855 .44763 .4808 .45967 .50252 .45296 .49039 .44082 Metetra
.905 .371 0 r
.49039 .44082 .50252 .45296 .52443 .44637 .51242 .43413 Metetra
.907 .364 0 r
.51242 .43413 .52443 .44637 .54652 .4399 .53463 .42757 Metetra
.91 .354 0 r
.53463 .42757 .54652 .4399 .56879 .43355 .55703 .42113 Metetra
.913 .343 0 r
.55703 .42113 .56879 .43355 .59127 .42733 .57962 .41482 Metetra
.917 .328 0 r
.57962 .41482 .59127 .42733 .61394 .42125 .60243 .40865 Metetra
.922 .311 0 r
.60243 .40865 .61394 .42125 .63683 .41531 .62544 .40263 Metetra
.928 .291 0 r
.62544 .40263 .63683 .41531 .65993 .40954 .64867 .39678 Metetra
.934 .268 0 r
.64867 .39678 .65993 .40954 .68325 .40393 .67213 .39109 Metetra
.941 .242 0 r
.67213 .39109 .68325 .40393 .70681 .39849 .69583 .38557 Metetra
.948 .213 0 r
.69583 .38557 .70681 .39849 .7306 .39296 .71975 .37995 Metetra
.95 .204 0 r
.71975 .37995 .7306 .39296 .75441 .38462 .74372 .37144 Metetra
.92 .319 0 r
.74372 .37144 .75441 .38462 .77718 .36055 .76665 .34684 Metetra
.79 .719 0 r
.76665 .34684 .77718 .36055 .79647 .29715 .78617 .2824 Metetra
.329 .654 0 r
.12107 .44416 .13452 .45648 .14443 .52663 .13057 .51528 Metetra
.868 .496 0 r
.13057 .51528 .14443 .52663 .15986 .55471 .14584 .54407 Metetra
.945 .225 0 r
.14584 .54407 .15986 .55471 .17867 .55496 .16469 .54446 Metetra
.955 .186 0 r
.16469 .54446 .17867 .55496 .19845 .54739 .18457 .5368 Metetra
.949 .209 0 r
.18457 .5368 .19845 .54739 .21845 .5389 .20467 .52818 Metetra
.942 .238 0 r
.20467 .52818 .21845 .5389 .23856 .53052 .22489 .51967 Metetra
.935 .264 0 r
.22489 .51967 .23856 .53052 .25879 .5223 .24523 .51133 Metetra
.929 .286 0 r
.24523 .51133 .25879 .5223 .27913 .51425 .26568 .50315 Metetra
.924 .305 0 r
.26568 .50315 .27913 .51425 .2996 .50634 .28626 .49512 Metetra
.919 .321 0 r
.28626 .49512 .2996 .50634 .32021 .49857 .30697 .48723 Metetra
.916 .335 0 r
.30697 .48723 .32021 .49857 .34095 .49092 .32782 .47947 Metetra
.913 .346 0 r
.32782 .47947 .34095 .49092 .36183 .48341 .34882 .47184 Metetra
.91 .354 0 r
.34882 .47184 .36183 .48341 .38286 .47602 .36996 .46435 Metetra
.908 .361 0 r
.36996 .46435 .38286 .47602 .40404 .46875 .39125 .45697 Metetra
.907 .364 0 r
.39125 .45697 .40404 .46875 .42538 .46159 .41271 .44971 Metetra
.907 .366 0 r
.41271 .44971 .42538 .46159 .44688 .45455 .43432 .44257 Metetra
.907 .366 0 r
.43432 .44257 .44688 .45455 .46855 .44763 .45611 .43554 Metetra
.908 .363 0 r
.45611 .43554 .46855 .44763 .49039 .44082 .47807 .42864 Metetra
.909 .358 0 r
.47807 .42864 .49039 .44082 .51242 .43413 .50022 .42185 Metetra
.911 .351 0 r
.50022 .42185 .51242 .43413 .53463 .42757 .52255 .41519 Metetra
.914 .341 0 r
.52255 .41519 .53463 .42757 .55703 .42113 .54507 .40866 Metetra
.917 .329 0 r
.54507 .40866 .55703 .42113 .57962 .41482 .5678 .40226 Metetra
.921 .314 0 r
.5678 .40226 .57962 .41482 .60243 .40865 .59073 .39601 Metetra
.926 .297 0 r
.59073 .39601 .60243 .40865 .62544 .40263 .61388 .38991 Metetra
.931 .277 0 r
.61388 .38991 .62544 .40263 .64867 .39678 .63724 .38397 Metetra
.938 .253 0 r
.63724 .38397 .64867 .39678 .67213 .39109 .66084 .37821 Metetra
.945 .226 0 r
.66084 .37821 .67213 .39109 .69583 .38557 .68468 .37261 Metetra
.952 .197 0 r
.68468 .37261 .69583 .38557 .71975 .37995 .70875 .36692 Metetra
.955 .188 0 r
.70875 .36692 .71975 .37995 .74372 .37144 .73286 .35822 Metetra
.923 .307 0 r
.73286 .35822 .74372 .37144 .76665 .34684 .75596 .33301 Metetra
.791 .716 0 r
.75596 .33301 .76665 .34684 .78617 .2824 .77572 .26741 Metetra
.328 .654 0 r
.10744 .43161 .12107 .44416 .13057 .51528 .11652 .50381 Metetra
.871 .487 0 r
.11652 .50381 .13057 .51528 .14584 .54407 .1316 .53341 Metetra
.95 .207 0 r
.1316 .53341 .14584 .54407 .16469 .54446 .15047 .53399 Metetra
.96 .166 0 r
.15047 .53399 .16469 .54446 .18457 .5368 .17045 .52623 Metetra
.954 .19 0 r
.17045 .52623 .18457 .5368 .20467 .52818 .19067 .51747 Metetra
.946 .22 0 r
.19067 .51747 .20467 .52818 .22489 .51967 .211 .50882 Metetra
.939 .246 0 r
.211 .50882 .22489 .51967 .24523 .51133 .23145 .50035 Metetra
.933 .269 0 r
.23145 .50035 .24523 .51133 .26568 .50315 .25201 .49204 Metetra
.928 .289 0 r
.25201 .49204 .26568 .50315 .28626 .49512 .27271 .48389 Metetra
.924 .305 0 r
.27271 .48389 .28626 .49512 .30697 .48723 .29353 .47588 Metetra
.92 .319 0 r
.29353 .47588 .30697 .48723 .32782 .47947 .31449 .468 Metetra
.917 .331 0 r
.31449 .468 .32782 .47947 .34882 .47184 .3356 .46026 Metetra
.914 .339 0 r
.3356 .46026 .34882 .47184 .36996 .46435 .35685 .45265 Metetra
.913 .346 0 r
.35685 .45265 .36996 .46435 .39125 .45697 .37826 .44516 Metetra
.911 .35 0 r
.37826 .44516 .39125 .45697 .41271 .44971 .39983 .4378 Metetra
.911 .351 0 r
.39983 .4378 .41271 .44971 .43432 .44257 .42157 .43055 Metetra
.911 .351 0 r
.42157 .43055 .43432 .44257 .45611 .43554 .44347 .42342 Metetra
.912 .348 0 r
.44347 .42342 .45611 .43554 .47807 .42864 .46556 .41642 Metetra
.913 .343 0 r
.46556 .41642 .47807 .42864 .50022 .42185 .48782 .40954 Metetra
.915 .336 0 r
.48782 .40954 .50022 .42185 .52255 .41519 .51028 .40278 Metetra
.918 .326 0 r
.51028 .40278 .52255 .41519 .54507 .40866 .53293 .39616 Metetra
.921 .313 0 r
.53293 .39616 .54507 .40866 .5678 .40226 .55579 .38967 Metetra
.926 .298 0 r
.55579 .38967 .5678 .40226 .59073 .39601 .57885 .38333 Metetra
.93 .28 0 r
.57885 .38333 .59073 .39601 .61388 .38991 .60213 .37715 Metetra
.936 .259 0 r
.60213 .37715 .61388 .38991 .63724 .38397 .62563 .37113 Metetra
.942 .235 0 r
.62563 .37113 .63724 .38397 .66084 .37821 .64937 .36529 Metetra
.95 .207 0 r
.64937 .36529 .66084 .37821 .68468 .37261 .67335 .35963 Metetra
.957 .178 0 r
.67335 .35963 .68468 .37261 .70875 .36692 .69756 .35386 Metetra
.959 .169 0 r
.69756 .35386 .70875 .36692 .73286 .35822 .72183 .34496 Metetra
.927 .292 0 r
.72183 .34496 .73286 .35822 .75596 .33301 .7451 .31908 Metetra
.793 .712 0 r
.7451 .31908 .75596 .33301 .77572 .26741 .7651 .25218 Metetra
.327 .654 0 r
.09363 .41881 .10744 .43161 .11652 .50381 .10225 .49223 Metetra
.874 .477 0 r
.10225 .49223 .11652 .50381 .1316 .53341 .11713 .52275 Metetra
.955 .187 0 r
.11713 .52275 .1316 .53341 .15047 .53399 .13602 .52355 Metetra
.966 .144 0 r
.13602 .52355 .15047 .53399 .17045 .52623 .1561 .5157 Metetra
.959 .169 0 r
.1561 .5157 .17045 .52623 .19067 .51747 .17643 .5068 Metetra
.952 .199 0 r
.17643 .5068 .19067 .51747 .211 .50882 .19688 .498 Metetra
.945 .226 0 r
.19688 .498 .211 .50882 .23145 .50035 .21744 .48939 Metetra
.939 .25 0 r
.21744 .48939 .23145 .50035 .25201 .49204 .23812 .48095 Metetra
.933 .27 0 r
.23812 .48095 .25201 .49204 .27271 .48389 .25893 .47266 Metetra
.929 .287 0 r
.25893 .47266 .27271 .48389 .29353 .47588 .27986 .46453 Metetra
.925 .301 0 r
.27986 .46453 .29353 .47588 .31449 .468 .30094 .45652 Metetra
.922 .313 0 r
.30094 .45652 .31449 .468 .3356 .46026 .32216 .44867 Metetra
.919 .322 0 r
.32216 .44867 .3356 .46026 .35685 .45265 .34353 .44094 Metetra
.917 .329 0 r
.34353 .44094 .35685 .45265 .37826 .44516 .36506 .43334 Metetra
.916 .333 0 r
.36506 .43334 .37826 .44516 .39983 .4378 .38675 .42586 Metetra
.916 .335 0 r
.38675 .42586 .39983 .4378 .42157 .43055 .4086 .41851 Metetra
.916 .334 0 r
.4086 .41851 .42157 .43055 .44347 .42342 .43063 .41128 Metetra
.917 .331 0 r
.43063 .41128 .44347 .42342 .46556 .41642 .45284 .40417 Metetra
.918 .326 0 r
.45284 .40417 .46556 .41642 .48782 .40954 .47523 .39719 Metetra
.92 .318 0 r
.47523 .39719 .48782 .40954 .51028 .40278 .49781 .39034 Metetra
.923 .308 0 r
.49781 .39034 .51028 .40278 .53293 .39616 .52059 .38362 Metetra
.926 .295 0 r
.52059 .38362 .53293 .39616 .55579 .38967 .54358 .37705 Metetra
.931 .28 0 r
.54358 .37705 .55579 .38967 .57885 .38333 .56677 .37063 Metetra
.936 .261 0 r
.56677 .37063 .57885 .38333 .60213 .37715 .59019 .36437 Metetra
.941 .24 0 r
.59019 .36437 .60213 .37715 .62563 .37113 .61383 .35827 Metetra
.948 .215 0 r
.61383 .35827 .62563 .37113 .64937 .36529 .63771 .35236 Metetra
.955 .186 0 r
.63771 .35236 .64937 .36529 .67335 .35963 .66184 .34663 Metetra
.963 .155 0 r
.66184 .34663 .67335 .35963 .69756 .35386 .6862 .34078 Metetra
.965 .147 0 r
.6862 .34078 .69756 .35386 .72183 .34496 .71063 .33167 Metetra
.932 .276 0 r
.71063 .33167 .72183 .34496 .7451 .31908 .73408 .30503 Metetra
.794 .708 0 r
.73408 .30503 .7451 .31908 .7651 .25218 .75432 .23668 Metetra
.325 .653 0 r
.07968 .40564 .09363 .41881 .10225 .49223 .0878 .48032 Metetra
.877 .467 0 r
.0878 .48032 .10225 .49223 .11713 .52275 .10244 .51189 Metetra
.96 .166 0 r
.10244 .51189 .11713 .52275 .13602 .52355 .12134 .51298 Metetra
.972 .119 0 r
.12134 .51298 .13602 .52355 .1561 .5157 .14153 .50506 Metetra
.965 .145 0 r
.14153 .50506 .1561 .5157 .17643 .5068 .16197 .49602 Metetra
.958 .176 0 r
.16197 .49602 .17643 .5068 .19688 .498 .18253 .48709 Metetra
.95 .204 0 r
.18253 .48709 .19688 .498 .21744 .48939 .20321 .47834 Metetra
.944 .228 0 r
.20321 .47834 .21744 .48939 .23812 .48095 .224 .46977 Metetra
.939 .249 0 r
.224 .46977 .23812 .48095 .25893 .47266 .24492 .46135 Metetra
.934 .267 0 r
.24492 .46135 .25893 .47266 .27986 .46453 .26597 .45309 Metetra
.93 .282 0 r
.26597 .45309 .27986 .46453 .30094 .45652 .28717 .44497 Metetra
.927 .294 0 r
.28717 .44497 .30094 .45652 .32216 .44867 .30851 .43699 Metetra
.924 .303 0 r
.30851 .43699 .32216 .44867 .34353 .44094 .33 .42915 Metetra
.923 .31 0 r
.33 .42915 .34353 .44094 .36506 .43334 .35164 .42143 Metetra
.921 .314 0 r
.35164 .42143 .36506 .43334 .38675 .42586 .37345 .41384 Metetra
.921 .316 0 r
.37345 .41384 .38675 .42586 .4086 .41851 .39543 .40638 Metetra
.921 .315 0 r
.39543 .40638 .4086 .41851 .43063 .41128 .41758 .39904 Metetra
.922 .312 0 r
.41758 .39904 .43063 .41128 .45284 .40417 .43991 .39183 Metetra
.923 .307 0 r
.43991 .39183 .45284 .40417 .47523 .39719 .46243 .38475 Metetra
.925 .299 0 r
.46243 .38475 .47523 .39719 .49781 .39034 .48514 .3778 Metetra
.928 .289 0 r
.48514 .3778 .49781 .39034 .52059 .38362 .50805 .37099 Metetra
.932 .275 0 r
.50805 .37099 .52059 .38362 .54358 .37705 .53117 .36432 Metetra
.936 .259 0 r
.53117 .36432 .54358 .37705 .56677 .37063 .5545 .35781 Metetra
.941 .24 0 r
.5545 .35781 .56677 .37063 .59019 .36437 .57806 .35146 Metetra
.947 .218 0 r
.57806 .35146 .59019 .36437 .61383 .35827 .60184 .34528 Metetra
.954 .192 0 r
.60184 .34528 .61383 .35827 .63771 .35236 .62586 .33929 Metetra
.961 .162 0 r
.62586 .33929 .63771 .35236 .66184 .34663 .65014 .33348 Metetra
.969 .131 0 r
.65014 .33348 .66184 .34663 .6862 .34078 .67465 .32753 Metetra
.971 .123 0 r
.67465 .32753 .6862 .34078 .71063 .33167 .69923 .31815 Metetra
.936 .258 0 r
.69923 .31815 .71063 .33167 .73408 .30503 .72286 .29066 Metetra
.796 .704 0 r
.72286 .29066 .73408 .30503 .75432 .23668 .74335 .22075 Metetra
.31 .649 0 r
.06575 .3908 .07968 .40564 .0878 .48032 .07341 .46625 Metetra
.876 .47 0 r
.07341 .46625 .0878 .48032 .10244 .51189 .08779 .4988 Metetra
.962 .158 0 r
.08779 .4988 .10244 .51189 .12134 .51298 .10667 .50036 Metetra
.975 .107 0 r
.10667 .50036 .12134 .51298 .14153 .50506 .12692 .49259 Metetra
.969 .131 0 r
.12692 .49259 .14153 .50506 .16197 .49602 .14745 .48359 Metetra
.961 .162 0 r
.14745 .48359 .16197 .49602 .18253 .48709 .1681 .47466 Metetra
.954 .19 0 r
.1681 .47466 .18253 .48709 .20321 .47834 .18887 .4659 Metetra
.948 .214 0 r
.18887 .4659 .20321 .47834 .224 .46977 .20977 .45729 Metetra
.943 .235 0 r
.20977 .45729 .224 .46977 .24492 .46135 .23079 .44883 Metetra
.938 .252 0 r
.23079 .44883 .24492 .46135 .26597 .45309 .25195 .4405 Metetra
.934 .267 0 r
.25195 .4405 .26597 .45309 .28717 .44497 .27325 .4323 Metetra
.931 .279 0 r
.27325 .4323 .28717 .44497 .30851 .43699 .2947 .42424 Metetra
.928 .289 0 r
.2947 .42424 .30851 .43699 .33 .42915 .3163 .41631 Metetra
.926 .295 0 r
.3163 .41631 .33 .42915 .35164 .42143 .33805 .4085 Metetra
.925 .3 0 r
.33805 .4085 .35164 .42143 .37345 .41384 .35998 .4008 Metetra
.925 .301 0 r
.35998 .4008 .37345 .41384 .39543 .40638 .38207 .39323 Metetra
.925 .301 0 r
.38207 .39323 .39543 .40638 .41758 .39904 .40434 .38578 Metetra
.926 .298 0 r
.40434 .38578 .41758 .39904 .43991 .39183 .4268 .37844 Metetra
.927 .293 0 r
.4268 .37844 .43991 .39183 .46243 .38475 .44944 .37123 Metetra
.929 .285 0 r
.44944 .37123 .46243 .38475 .48514 .3778 .47227 .36414 Metetra
.932 .274 0 r
.47227 .36414 .48514 .3778 .50805 .37099 .49531 .35718 Metetra
.936 .261 0 r
.49531 .35718 .50805 .37099 .53117 .36432 .51855 .35036 Metetra
.94 .245 0 r
.51855 .35036 .53117 .36432 .5545 .35781 .54202 .34367 Metetra
.945 .226 0 r
.54202 .34367 .5545 .35781 .57806 .35146 .5657 .33713 Metetra
.951 .204 0 r
.5657 .33713 .57806 .35146 .60184 .34528 .58962 .33075 Metetra
.957 .178 0 r
.58962 .33075 .60184 .34528 .62586 .33929 .61377 .32453 Metetra
.964 .149 0 r
.61377 .32453 .62586 .33929 .65014 .33348 .63817 .31847 Metetra
.972 .118 0 r
.63817 .31847 .65014 .33348 .67465 .32753 .66282 .31221 Metetra
.973 .112 0 r
.66282 .31221 .67465 .32753 .69923 .31815 .68753 .30234 Metetra
.937 .255 0 r
.68753 .30234 .69923 .31815 .72286 .29066 .71132 .27385 Metetra
.793 .71 0 r
.71132 .27385 .72286 .29066 .74335 .22075 .73208 .20265 Metetra
.228 .623 0 r
.05279 .36803 .06575 .3908 .07341 .46625 .06046 .44057 Metetra
.85 .553 0 r
.06046 .44057 .07341 .46625 .08779 .4988 .07468 .47282 Metetra
.938 .253 0 r
.07468 .47282 .08779 .4988 .10667 .50036 .09339 .47528 Metetra
.953 .194 0 r
.09339 .47528 .10667 .50036 .12692 .49259 .11353 .46848 Metetra
.949 .209 0 r
.11353 .46848 .12692 .49259 .14745 .48359 .13398 .46032 Metetra
.943 .231 0 r
.13398 .46032 .14745 .48359 .1681 .47466 .15458 .45209 Metetra
.938 .252 0 r
.15458 .45209 .1681 .47466 .18887 .4659 .17532 .44389 Metetra
.933 .27 0 r
.17532 .44389 .18887 .4659 .20977 .45729 .19621 .43575 Metetra
.929 .286 0 r
.19621 .43575 .20977 .45729 .23079 .44883 .21724 .42765 Metetra
.925 .3 0 r
.21724 .42765 .23079 .44883 .25195 .4405 .23842 .41961 Metetra
.922 .312 0 r
.23842 .41961 .25195 .4405 .27325 .4323 .25975 .41161 Metetra
.919 .322 0 r
.25975 .41161 .27325 .4323 .2947 .42424 .28124 .40368 Metetra
.917 .329 0 r
.28124 .40368 .2947 .42424 .3163 .41631 .3029 .39581 Metetra
.916 .335 0 r
.3029 .39581 .3163 .41631 .33805 .4085 .32471 .388 Metetra
.915 .338 0 r
.32471 .388 .33805 .4085 .35998 .4008 .3467 .38026 Metetra
.914 .34 0 r
.3467 .38026 .35998 .4008 .38207 .39323 .36886 .37257 Metetra
.914 .339 0 r
.36886 .37257 .38207 .39323 .40434 .38578 .39121 .36494 Metetra
.915 .337 0 r
.39121 .36494 .40434 .38578 .4268 .37844 .41373 .35738 Metetra
.916 .332 0 r
.41373 .35738 .4268 .37844 .44944 .37123 .43645 .34988 Metetra
.918 .326 0 r
.43645 .34988 .44944 .37123 .47227 .36414 .45936 .34244 Metetra
.92 .318 0 r
.45936 .34244 .47227 .36414 .49531 .35718 .48247 .33505 Metetra
.923 .307 0 r
.48247 .33505 .49531 .35718 .51855 .35036 .50579 .32772 Metetra
.927 .294 0 r
.50579 .32772 .51855 .35036 .54202 .34367 .52931 .32045 Metetra
.931 .28 0 r
.52931 .32045 .54202 .34367 .5657 .33713 .55306 .31322 Metetra
.935 .262 0 r
.55306 .31322 .5657 .33713 .58962 .33075 .57703 .30604 Metetra
.94 .243 0 r
.57703 .30604 .58962 .33075 .61377 .32453 .60122 .2989 Metetra
.946 .221 0 r
.60122 .2989 .61377 .32453 .63817 .31847 .62565 .29177 Metetra
.952 .199 0 r
.62565 .29177 .63817 .31847 .66282 .31221 .6503 .28429 Metetra
.951 .203 0 r
.6503 .28429 .66282 .31221 .68753 .30234 .675 .27307 Metetra
.912 .348 0 r
.675 .27307 .68753 .30234 .71132 .27385 .69886 .24374 Metetra
.758 .767 0 r
.69886 .24374 .71132 .27385 .73208 .20265 .71996 .1738 Metetra
0 .53 .02 r
.04284 .32478 .05279 .36803 .06046 .44057 .05194 .38408 Metetra
.643 .739 0 r
.05194 .38408 .06046 .44057 .07468 .47282 .06649 .41135 Metetra
.826 .623 0 r
.06649 .41135 .07468 .47282 .09339 .47528 .08485 .41448 Metetra
.846 .564 0 r
.08485 .41448 .09339 .47528 .11353 .46848 .1045 .40981 Metetra
.848 .557 0 r
.1045 .40981 .11353 .46848 .13398 .46032 .12451 .40373 Metetra
.848 .558 0 r
.12451 .40373 .13398 .46032 .15458 .45209 .14472 .39733 Metetra
.847 .56 0 r
.14472 .39733 .15458 .45209 .17532 .44389 .16512 .39073 Metetra
.847 .563 0 r
.16512 .39073 .17532 .44389 .19621 .43575 .1857 .38393 Metetra
.846 .565 0 r
.1857 .38393 .19621 .43575 .21724 .42765 .20647 .37697 Metetra
.845 .567 0 r
.20647 .37697 .21724 .42765 .23842 .41961 .22742 .36986 Metetra
.844 .569 0 r
.22742 .36986 .23842 .41961 .25975 .41161 .24855 .3626 Metetra
.844 .571 0 r
.24855 .3626 .25975 .41161 .28124 .40368 .26987 .35523 Metetra
.843 .573 0 r
.26987 .35523 .28124 .40368 .3029 .39581 .29136 .34774 Metetra
.843 .574 0 r
.29136 .34774 .3029 .39581 .32471 .388 .31304 .34014 Metetra
.843 .575 0 r
.31304 .34014 .32471 .388 .3467 .38026 .3349 .33243 Metetra
.842 .575 0 r
.3349 .33243 .3467 .38026 .36886 .37257 .35695 .32461 Metetra
.842 .575 0 r
.35695 .32461 .36886 .37257 .39121 .36494 .37918 .31669 Metetra
.843 .575 0 r
.37918 .31669 .39121 .36494 .41373 .35738 .4016 .30866 Metetra
.843 .574 0 r
.4016 .30866 .41373 .35738 .43645 .34988 .42421 .30051 Metetra
.843 .572 0 r
.42421 .30051 .43645 .34988 .45936 .34244 .44701 .29225 Metetra
.844 .571 0 r
.44701 .29225 .45936 .34244 .48247 .33505 .47 .28385 Metetra
.845 .569 0 r
.47 .28385 .48247 .33505 .50579 .32772 .49318 .27532 Metetra
.845 .566 0 r
.49318 .27532 .50579 .32772 .52931 .32045 .51656 .26662 Metetra
.846 .564 0 r
.51656 .26662 .52931 .32045 .55306 .31322 .54013 .25775 Metetra
.847 .562 0 r
.54013 .25775 .55306 .31322 .57703 .30604 .5639 .24869 Metetra
.848 .559 0 r
.5639 .24869 .57703 .30604 .60122 .2989 .58786 .2394 Metetra
.848 .558 0 r
.58786 .2394 .60122 .2989 .62565 .29177 .61201 .22986 Metetra
.848 .558 0 r
.61201 .22986 .62565 .29177 .6503 .28429 .63633 .21972 Metetra
.841 .579 0 r
.63633 .21972 .6503 .28429 .675 .27307 .6607 .20622 Metetra
.799 .696 0 r
.6607 .20622 .675 .27307 .69886 .24374 .68442 .17785 Metetra
.353 .662 0 r
.68442 .17785 .69886 .24374 .71996 .1738 .70603 .11699 Metetra
0 .333 .297 r
.03634 .26033 .04284 .32478 .05194 .38408 .04859 .2952 Metetra
0 .496 .092 r
.04859 .2952 .05194 .38408 .06649 .41135 .06425 .31112 Metetra
.076 .569 0 r
.06425 .31112 .06649 .41135 .08485 .41448 .08236 .31262 Metetra
.142 .594 0 r
.08236 .31262 .08485 .41448 .1045 .40981 .10136 .30927 Metetra
.171 .604 0 r
.10136 .30927 .1045 .40981 .12451 .40373 .1207 .30485 Metetra
.192 .611 0 r
.1207 .30485 .12451 .40373 .14472 .39733 .14027 .3 Metetra
.211 .617 0 r
.14027 .3 .14472 .39733 .16512 .39073 .16007 .29479 Metetra
.227 .622 0 r
.16007 .29479 .16512 .39073 .1857 .38393 .18008 .28924 Metetra
.241 .627 0 r
.18008 .28924 .1857 .38393 .20647 .37697 .20031 .28336 Metetra
.253 .631 0 r
.20031 .28336 .20647 .37697 .22742 .36986 .22075 .27715 Metetra
.262 .634 0 r
.22075 .27715 .22742 .36986 .24855 .3626 .2414 .27062 Metetra
.27 .637 0 r
.2414 .27062 .24855 .3626 .26987 .35523 .26225 .2638 Metetra
.277 .638 0 r
.26225 .2638 .26987 .35523 .29136 .34774 .2833 .25667 Metetra
.281 .64 0 r
.2833 .25667 .29136 .34774 .31304 .34014 .30455 .24925 Metetra
.284 .641 0 r
.30455 .24925 .31304 .34014 .3349 .33243 .32599 .24154 Metetra
.285 .641 0 r
.32599 .24154 .3349 .33243 .35695 .32461 .34762 .23354 Metetra
.285 .641 0 r
.34762 .23354 .35695 .32461 .37918 .31669 .36945 .22524 Metetra
.283 .64 0 r
.36945 .22524 .37918 .31669 .4016 .30866 .39146 .21665 Metetra
.279 .639 0 r
.39146 .21665 .4016 .30866 .42421 .30051 .41365 .20775 Metetra
.274 .638 0 r
.41365 .20775 .42421 .30051 .44701 .29225 .43603 .19855 Metetra
.267 .635 0 r
.43603 .19855 .44701 .29225 .47 .28385 .45859 .18904 Metetra
.258 .633 0 r
.45859 .18904 .47 .28385 .49318 .27532 .48132 .17919 Metetra
.247 .629 0 r
.48132 .17919 .49318 .27532 .51656 .26662 .50423 .169 Metetra
.235 .625 0 r
.50423 .169 .51656 .26662 .54013 .25775 .5273 .15846 Metetra
.22 .62 0 r
.5273 .15846 .54013 .25775 .5639 .24869 .55053 .14755 Metetra
.203 .615 0 r
.55053 .14755 .5639 .24869 .58786 .2394 .57392 .13625 Metetra
.183 .608 0 r
.57392 .13625 .58786 .2394 .61201 .22986 .59747 .12454 Metetra
.16 .6 0 r
.59747 .12454 .61201 .22986 .63633 .21972 .62115 .11221 Metetra
.121 .586 0 r
.62115 .11221 .63633 .21972 .6607 .20622 .64488 .09765 Metetra
.016 .545 0 r
.64488 .09765 .6607 .20622 .68442 .17785 .6683 .07412 Metetra
0 .434 .196 r
.6683 .07412 .68442 .17785 .70603 .11699 .69056 .0314 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 233.562},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{145., 432.}, {528., 295.}} -> {-0.6542809413851561, \
1.1319388078367045, 0.00372925066927552, \
0.00372925066927552}},ExpressionUUID->"b0504dab-9996-4580-b6d6-702903beab61"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
9.02522e-17 1.04977 -0.0679587 1.04977 [
[.5 .82364 -111 0 ]
[.5 .82364 111 9 ]
[.08965 .22175 -18 -8.88375 ]
[.08965 .22175 0 .11625 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.60423 .01939 -10.1877 -9 ]
[.60423 .01939 1.81231 0 ]
[.73698 .05037 0 -6.2075 ]
[.73698 .05037 18 2.7925 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95739 .38791 0 -5.88802 ]
[.95739 .38791 12 3.11198 ]
[.02412 .26509 -6 -2.7423 ]
[.02412 .26509 0 6.2577 ]
[.01077 .34875 -12 -2.8131 ]
[.01077 .34875 0 6.1869 ]
[-0.00332 .43708 -12 -2.88827 ]
[-0.00332 .43708 0 6.11173 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
[(Optical Path Difference \\(wavelengths\\))] .5 .82364 0 -1 Mshowa
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72471 .05502 m
.71857 .05735 L
s
[(-10)] .73698 .05037 -1 .37944 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94486 .39177 m
.93859 .39371 L
s
[(10)] .95739 .38791 -1 .30845 Mshowa
.125 Mabswid
.75031 .09419 m
.74662 .09556 L
s
.775 .13196 m
.7713 .1333 L
s
.79883 .16841 m
.79512 .16972 L
s
.82184 .2036 m
.81812 .2049 L
s
.86557 .27049 m
.86184 .27174 L
s
.88636 .3023 m
.88262 .30352 L
s
.90649 .33308 m
.90274 .33428 L
s
.92597 .36289 m
.92222 .36407 L
s
.69814 .01439 m
.69447 .01581 L
s
.96316 .41977 m
.95939 .42091 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03634 .26032 m
.04245 .25793 L
s
[(0)] .02412 .26509 1 -0.3906 Mshowa
.02306 .34414 m
.0292 .34184 L
s
[(20)] .01077 .34875 1 -0.37487 Mshowa
.00903 .43265 m
.01521 .43044 L
s
[(40)] -0.00332 .43708 1 -0.35816 Mshowa
.125 Mabswid
.03308 .28085 m
.03676 .27943 L
s
.02979 .30167 m
.03346 .30026 L
s
.02644 .32276 m
.03013 .32137 L
s
.01962 .36581 m
.02331 .36445 L
s
.01614 .38779 m
.01984 .38643 L
s
.01261 .41006 m
.01631 .40872 L
s
.0054 .45556 m
.00911 .45425 L
s
.00172 .47879 m
.00543 .47749 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.976 .099 0 r
.38757 .79726 .39809 .8049 .41556 .80118 .40517 .79142 Metetra
.972 .117 0 r
.40517 .79142 .41556 .80118 .4332 .7955 .42294 .78377 Metetra
.961 .161 0 r
.42294 .78377 .4332 .7955 .45097 .78828 .44082 .77474 Metetra
.946 .223 0 r
.44082 .77474 .45097 .78828 .46885 .77987 .45879 .76468 Metetra
.926 .296 0 r
.45879 .76468 .46885 .77987 .48683 .77063 .47684 .75394 Metetra
.904 .374 0 r
.47684 .75394 .48683 .77063 .50488 .76084 .49496 .74281 Metetra
.882 .452 0 r
.49496 .74281 .50488 .76084 .523 .75079 .51312 .73155 Metetra
.859 .526 0 r
.51312 .73155 .523 .75079 .54118 .7407 .53135 .72041 Metetra
.836 .593 0 r
.53135 .72041 .54118 .7407 .55944 .7308 .54963 .70957 Metetra
.815 .652 0 r
.54963 .70957 .55944 .7308 .57776 .72124 .56798 .69922 Metetra
.797 .702 0 r
.56798 .69922 .57776 .72124 .59618 .71219 .58641 .68949 Metetra
.781 .742 0 r
.58641 .68949 .59618 .71219 .61469 .70376 .60493 .68051 Metetra
.763 .768 0 r
.60493 .68051 .61469 .70376 .63332 .69606 .62356 .67238 Metetra
.722 .758 0 r
.62356 .67238 .63332 .69606 .65207 .68916 .64232 .66515 Metetra
.698 .752 0 r
.64232 .66515 .65207 .68916 .67096 .6831 .66122 .65889 Metetra
.69 .75 0 r
.66122 .65889 .67096 .6831 .69002 .67792 .68028 .65362 Metetra
.698 .752 0 r
.68028 .65362 .69002 .67792 .70925 .67362 .69952 .64934 Metetra
.722 .758 0 r
.69952 .64934 .70925 .67362 .72868 .67019 .71897 .64604 Metetra
.763 .768 0 r
.71897 .64604 .72868 .67019 .74831 .66757 .73862 .64368 Metetra
.781 .742 0 r
.73862 .64368 .74831 .66757 .76816 .66571 .75851 .6422 Metetra
.797 .702 0 r
.75851 .6422 .76816 .66571 .78824 .66451 .77864 .64151 Metetra
.815 .652 0 r
.77864 .64151 .78824 .66451 .80856 .66386 .79902 .64149 Metetra
.836 .593 0 r
.79902 .64149 .80856 .66386 .8291 .66361 .81965 .64201 Metetra
.859 .526 0 r
.81965 .64201 .8291 .66361 .84987 .66357 .84053 .64289 Metetra
.882 .452 0 r
.84053 .64289 .84987 .66357 .87085 .66354 .86165 .64393 Metetra
.904 .374 0 r
.86165 .64393 .87085 .66354 .89202 .66327 .88299 .64489 Metetra
.926 .296 0 r
.88299 .64489 .89202 .66327 .91335 .66247 .90453 .64549 Metetra
.946 .223 0 r
.90453 .64549 .91335 .66247 .93478 .66082 .92621 .64541 Metetra
.961 .161 0 r
.92621 .64541 .93478 .66082 .95627 .65795 .948 .64429 Metetra
.972 .117 0 r
.948 .64429 .95627 .65795 .97774 .65345 .96982 .64173 Metetra
.976 .099 0 r
.96982 .64173 .97774 .65345 .99909 .64687 .99158 .63727 Metetra
.972 .117 0 r
.37699 .7876 .38757 .79726 .40517 .79142 .39474 .77978 Metetra
.96 .165 0 r
.39474 .77978 .40517 .79142 .42294 .78377 .41262 .77031 Metetra
.942 .235 0 r
.41262 .77031 .42294 .78377 .44082 .77474 .43061 .75961 Metetra
.92 .318 0 r
.43061 .75961 .44082 .77474 .45879 .76468 .44868 .74804 Metetra
.895 .406 0 r
.44868 .74804 .45879 .76468 .47684 .75394 .4668 .73593 Metetra
.868 .495 0 r
.4668 .73593 .47684 .75394 .49496 .74281 .48497 .72356 Metetra
.841 .58 0 r
.48497 .72356 .49496 .74281 .51312 .73155 .50319 .7112 Metetra
.814 .657 0 r
.50319 .7112 .51312 .73155 .53135 .72041 .52146 .69909 Metetra
.788 .724 0 r
.52146 .69909 .53135 .72041 .54963 .70957 .53977 .6874 Metetra
.746 .764 0 r
.53977 .6874 .54963 .70957 .56798 .69922 .55814 .67632 Metetra
.657 .743 0 r
.55814 .67632 .56798 .69922 .58641 .68949 .57659 .66597 Metetra
.584 .725 0 r
.57659 .66597 .58641 .68949 .60493 .68051 .59512 .65649 Metetra
.528 .71 0 r
.59512 .65649 .60493 .68051 .62356 .67238 .61375 .64795 Metetra
.488 .699 0 r
.61375 .64795 .62356 .67238 .64232 .66515 .63251 .64042 Metetra
.464 .693 0 r
.63251 .64042 .64232 .66515 .66122 .65889 .65141 .63397 Metetra
.456 .691 0 r
.65141 .63397 .66122 .65889 .68028 .65362 .67048 .6286 Metetra
.464 .693 0 r
.67048 .6286 .68028 .65362 .69952 .64934 .68973 .62433 Metetra
.488 .699 0 r
.68973 .62433 .69952 .64934 .71897 .64604 .70918 .62114 Metetra
.528 .71 0 r
.70918 .62114 .71897 .64604 .73862 .64368 .72885 .619 Metetra
.584 .725 0 r
.72885 .619 .73862 .64368 .75851 .6422 .74877 .61785 Metetra
.657 .743 0 r
.74877 .61785 .75851 .6422 .77864 .64151 .76893 .6176 Metetra
.746 .764 0 r
.76893 .6176 .77864 .64151 .79902 .64149 .78936 .61814 Metetra
.788 .724 0 r
.78936 .61814 .79902 .64149 .81965 .64201 .81007 .61935 Metetra
.814 .657 0 r
.81007 .61935 .81965 .64201 .84053 .64289 .83104 .62105 Metetra
.841 .58 0 r
.83104 .62105 .84053 .64289 .86165 .64393 .85228 .62304 Metetra
.868 .495 0 r
.85228 .62304 .86165 .64393 .88299 .64489 .87376 .62511 Metetra
.895 .406 0 r
.87376 .62511 .88299 .64489 .90453 .64549 .89548 .62697 Metetra
.92 .318 0 r
.89548 .62697 .90453 .64549 .92621 .64541 .91738 .62831 Metetra
.942 .235 0 r
.91738 .62831 .92621 .64541 .948 .64429 .93943 .62878 Metetra
.96 .165 0 r
.93943 .62878 .948 .64429 .96982 .64173 .96156 .62799 Metetra
.972 .117 0 r
.96156 .62799 .96982 .64173 .99158 .63727 .98368 .62548 Metetra
.961 .161 0 r
.36636 .77629 .37699 .7876 .39474 .77978 .38424 .76666 Metetra
.942 .235 0 r
.38424 .76666 .39474 .77978 .41262 .77031 .40225 .75553 Metetra
.918 .325 0 r
.40225 .75553 .41262 .77031 .43061 .75961 .42034 .7433 Metetra
.89 .423 0 r
.42034 .7433 .43061 .75961 .44868 .74804 .4385 .73034 Metetra
.86 .522 0 r
.4385 .73034 .44868 .74804 .4668 .73593 .4567 .71697 Metetra
.828 .616 0 r
.4567 .71697 .4668 .73593 .48497 .72356 .47494 .70347 Metetra
.797 .702 0 r
.47494 .70347 .48497 .72356 .50319 .7112 .49321 .69012 Metetra
.755 .766 0 r
.49321 .69012 .50319 .7112 .52146 .69909 .51151 .67711 Metetra
.633 .737 0 r
.51151 .67711 .52146 .69909 .53977 .6874 .52986 .66466 Metetra
.528 .71 0 r
.52986 .66466 .53977 .6874 .55814 .67632 .54826 .6529 Metetra
.44 .686 0 r
.54826 .6529 .55814 .67632 .57659 .66597 .56672 .642 Metetra
.369 .666 0 r
.56672 .642 .57659 .66597 .59512 .65649 .58526 .63204 Metetra
.315 .65 0 r
.58526 .63204 .59512 .65649 .61375 .64795 .6039 .62313 Metetra
.277 .639 0 r
.6039 .62313 .61375 .64795 .63251 .64042 .62266 .61533 Metetra
.255 .632 0 r
.62266 .61533 .63251 .64042 .65141 .63397 .64156 .60869 Metetra
.247 .629 0 r
.64156 .60869 .65141 .63397 .67048 .6286 .66063 .60323 Metetra
.255 .632 0 r
.66063 .60323 .67048 .6286 .68973 .62433 .67988 .59895 Metetra
.277 .639 0 r
.67988 .59895 .68973 .62433 .70918 .62114 .69934 .59585 Metetra
.315 .65 0 r
.69934 .59585 .70918 .62114 .72885 .619 .71902 .5939 Metetra
.369 .666 0 r
.71902 .5939 .72885 .619 .74877 .61785 .73895 .59302 Metetra
.44 .686 0 r
.73895 .59302 .74877 .61785 .76893 .6176 .75915 .59315 Metetra
.528 .71 0 r
.75915 .59315 .76893 .6176 .78936 .61814 .77962 .59419 Metetra
.633 .737 0 r
.77962 .59419 .78936 .61814 .81007 .61935 .80038 .596 Metetra
.755 .766 0 r
.80038 .596 .81007 .61935 .83104 .62105 .82143 .59842 Metetra
.797 .702 0 r
.82143 .59842 .83104 .62105 .85228 .62304 .84277 .60127 Metetra
.828 .616 0 r
.84277 .60127 .85228 .62304 .87376 .62511 .86438 .60432 Metetra
.86 .522 0 r
.86438 .60432 .87376 .62511 .89548 .62697 .88625 .60731 Metetra
.89 .423 0 r
.88625 .60731 .89548 .62697 .91738 .62831 .90834 .60994 Metetra
.918 .325 0 r
.90834 .60994 .91738 .62831 .93943 .62878 .93062 .61185 Metetra
.942 .235 0 r
.93062 .61185 .93943 .62878 .96156 .62799 .95302 .61265 Metetra
.961 .161 0 r
.95302 .61265 .96156 .62799 .98368 .62548 .97547 .61191 Metetra
.946 .223 0 r
.35566 .76372 .36636 .77629 .38424 .76666 .37369 .75242 Metetra
.92 .318 0 r
.37369 .75242 .38424 .76666 .40225 .75553 .39181 .73976 Metetra
.89 .423 0 r
.39181 .73976 .40225 .75553 .42034 .7433 .41001 .72614 Metetra
.857 .531 0 r
.41001 .72614 .42034 .7433 .4385 .73034 .42826 .71192 Metetra
.822 .634 0 r
.42826 .71192 .4385 .73034 .4567 .71697 .44654 .69741 Metetra
.786 .729 0 r
.44654 .69741 .4567 .71697 .47494 .70347 .46485 .6829 Metetra
.69 .751 0 r
.46485 .6829 .47494 .70347 .49321 .69012 .48317 .66863 Metetra
.552 .716 0 r
.48317 .66863 .49321 .69012 .51151 .67711 .50152 .65482 Metetra
.432 .684 0 r
.50152 .65482 .51151 .67711 .52986 .66466 .5199 .64166 Metetra
.331 .655 0 r
.5199 .64166 .52986 .66466 .54826 .6529 .53832 .62931 Metetra
.247 .629 0 r
.53832 .62931 .54826 .6529 .56672 .642 .5568 .61788 Metetra
.182 .607 0 r
.5568 .61788 .56672 .642 .58526 .63204 .57536 .6075 Metetra
.132 .59 0 r
.57536 .6075 .58526 .63204 .6039 .62313 .59401 .59825 Metetra
.098 .577 0 r
.59401 .59825 .6039 .62313 .62266 .61533 .61277 .5902 Metetra
.077 .57 0 r
.61277 .5902 .62266 .61533 .64156 .60869 .63168 .58337 Metetra
.071 .567 0 r
.63168 .58337 .64156 .60869 .66063 .60323 .65074 .57782 Metetra
.077 .57 0 r
.65074 .57782 .66063 .60323 .67988 .59895 .67 .57353 Metetra
.098 .577 0 r
.67 .57353 .67988 .59895 .69934 .59585 .68946 .5705 Metetra
.132 .59 0 r
.68946 .5705 .69934 .59585 .71902 .5939 .70915 .56869 Metetra
.182 .607 0 r
.70915 .56869 .71902 .5939 .73895 .59302 .7291 .56806 Metetra
.247 .629 0 r
.7291 .56806 .73895 .59302 .75915 .59315 .74932 .56852 Metetra
.331 .655 0 r
.74932 .56852 .75915 .59315 .77962 .59419 .76982 .56998 Metetra
.432 .684 0 r
.76982 .56998 .77962 .59419 .80038 .596 .79063 .57232 Metetra
.552 .716 0 r
.79063 .57232 .80038 .596 .82143 .59842 .81174 .57538 Metetra
.69 .751 0 r
.81174 .57538 .82143 .59842 .84277 .60127 .83316 .57898 Metetra
.786 .729 0 r
.83316 .57898 .84277 .60127 .86438 .60432 .85488 .5829 Metetra
.822 .634 0 r
.85488 .5829 .86438 .60432 .88625 .60731 .87688 .58689 Metetra
.857 .531 0 r
.87688 .58689 .88625 .60731 .90834 .60994 .89914 .59066 Metetra
.89 .423 0 r
.89914 .59066 .90834 .60994 .93062 .61185 .92162 .59386 Metetra
.92 .318 0 r
.92162 .59386 .93062 .61185 .95302 .61265 .94427 .59611 Metetra
.946 .223 0 r
.94427 .59611 .95302 .61265 .97547 .61191 .96701 .59697 Metetra
.926 .296 0 r
.3449 .75021 .35566 .76372 .37369 .75242 .36306 .7374 Metetra
.895 .406 0 r
.36306 .7374 .37369 .75242 .39181 .73976 .38131 .72336 Metetra
.86 .522 0 r
.38131 .72336 .39181 .73976 .41001 .72614 .39962 .70847 Metetra
.822 .634 0 r
.39962 .70847 .41001 .72614 .42826 .71192 .41796 .69311 Metetra
.782 .738 0 r
.41796 .69311 .42826 .71192 .44654 .69741 .43632 .67757 Metetra
.657 .743 0 r
.43632 .67757 .44654 .69741 .46485 .6829 .4547 .66213 Metetra
.504 .704 0 r
.4547 .66213 .46485 .6829 .48317 .66863 .47308 .64704 Metetra
.369 .666 0 r
.47308 .64704 .48317 .66863 .50152 .65482 .49148 .63251 Metetra
.255 .632 0 r
.49148 .63251 .50152 .65482 .5199 .64166 .5099 .61872 Metetra
.16 .6 0 r
.5099 .61872 .5199 .64166 .53832 .62931 .52835 .60581 Metetra
.084 .572 0 r
.52835 .60581 .53832 .62931 .5568 .61788 .54685 .59392 Metetra
.025 .549 0 r
.54685 .59392 .5568 .61788 .57536 .6075 .56542 .58316 Metetra
0 .53 .018 r
.56542 .58316 .57536 .6075 .59401 .59825 .58408 .57359 Metetra
0 .517 .048 r
.58408 .57359 .59401 .59825 .61277 .5902 .60286 .5653 Metetra
0 .509 .065 r
.60286 .5653 .61277 .5902 .63168 .58337 .62177 .55831 Metetra
0 .506 .071 r
.62177 .55831 .63168 .58337 .65074 .57782 .64084 .55265 Metetra
0 .509 .065 r
.64084 .55265 .65074 .57782 .67 .57353 .66009 .54834 Metetra
0 .517 .048 r
.66009 .54834 .67 .57353 .68946 .5705 .67956 .54536 Metetra
0 .53 .018 r
.67956 .54536 .68946 .5705 .70915 .56869 .69926 .54367 Metetra
.025 .549 0 r
.69926 .54367 .70915 .56869 .7291 .56806 .71921 .54324 Metetra
.084 .572 0 r
.71921 .54324 .7291 .56806 .74932 .56852 .73945 .54398 Metetra
.16 .6 0 r
.73945 .54398 .74932 .56852 .76982 .56998 .75998 .54581 Metetra
.255 .632 0 r
.75998 .54581 .76982 .56998 .79063 .57232 .78083 .5486 Metetra
.369 .666 0 r
.78083 .5486 .79063 .57232 .81174 .57538 .80199 .55222 Metetra
.504 .704 0 r
.80199 .55222 .81174 .57538 .83316 .57898 .82348 .55647 Metetra
.657 .743 0 r
.82348 .55647 .83316 .57898 .85488 .5829 .84529 .56116 Metetra
.782 .738 0 r
.84529 .56116 .85488 .5829 .87688 .58689 .86741 .56604 Metetra
.822 .634 0 r
.86741 .56604 .87688 .58689 .89914 .59066 .88982 .57082 Metetra
.86 .522 0 r
.88982 .57082 .89914 .59066 .92162 .59386 .91248 .57516 Metetra
.895 .406 0 r
.91248 .57516 .92162 .59386 .94427 .59611 .93534 .57869 Metetra
.926 .296 0 r
.93534 .57869 .94427 .59611 .96701 .59697 .95834 .58099 Metetra
.904 .374 0 r
.33406 .73606 .3449 .75021 .36306 .7374 .35236 .72188 Metetra
.868 .495 0 r
.35236 .72188 .36306 .7374 .38131 .72336 .37073 .70659 Metetra
.828 .616 0 r
.37073 .70659 .38131 .72336 .39962 .70847 .38915 .69058 Metetra
.786 .729 0 r
.38915 .69058 .39962 .70847 .41796 .69311 .40759 .67418 Metetra
.657 .743 0 r
.40759 .67418 .41796 .69311 .43632 .67757 .42604 .65771 Metetra
.488 .699 0 r
.42604 .65771 .43632 .67757 .4547 .66213 .44448 .64145 Metetra
.338 .657 0 r
.44448 .64145 .4547 .66213 .47308 .64704 .46293 .62562 Metetra
.211 .617 0 r
.46293 .62562 .47308 .64704 .49148 .63251 .48138 .61044 Metetra
.104 .58 0 r
.48138 .61044 .49148 .63251 .5099 .61872 .49984 .59607 Metetra
.019 .546 0 r
.49984 .59607 .5099 .61872 .52835 .60581 .51833 .58267 Metetra
0 .517 .048 r
.51833 .58267 .52835 .60581 .54685 .59392 .53686 .57036 Metetra
0 .492 .099 r
.53686 .57036 .54685 .59392 .56542 .58316 .55545 .55924 Metetra
0 .473 .135 r
.55545 .55924 .56542 .58316 .58408 .57359 .57413 .54939 Metetra
0 .458 .159 r
.57413 .54939 .58408 .57359 .60286 .5653 .59291 .54087 Metetra
0 .45 .173 r
.59291 .54087 .60286 .5653 .62177 .55831 .61183 .53373 Metetra
0 .447 .177 r
.61183 .53373 .62177 .55831 .64084 .55265 .63091 .52798 Metetra
0 .45 .173 r
.63091 .52798 .64084 .55265 .66009 .54834 .65017 .52363 Metetra
0 .458 .159 r
.65017 .52363 .66009 .54834 .67956 .54536 .66964 .52068 Metetra
0 .473 .135 r
.66964 .52068 .67956 .54536 .69926 .54367 .68935 .51909 Metetra
0 .492 .099 r
.68935 .51909 .69926 .54367 .71921 .54324 .70932 .51882 Metetra
0 .517 .048 r
.70932 .51882 .71921 .54324 .73945 .54398 .72957 .5198 Metetra
.019 .546 0 r
.72957 .5198 .73945 .54398 .75998 .54581 .75013 .52194 Metetra
.104 .58 0 r
.75013 .52194 .75998 .54581 .78083 .5486 .771 .52512 Metetra
.211 .617 0 r
.771 .52512 .78083 .5486 .80199 .55222 .79221 .52921 Metetra
.338 .657 0 r
.79221 .52921 .80199 .55222 .82348 .55647 .81377 .53404 Metetra
.488 .699 0 r
.81377 .53404 .82348 .55647 .84529 .56116 .83566 .5394 Metetra
.657 .743 0 r
.83566 .5394 .84529 .56116 .86741 .56604 .85788 .54505 Metetra
.786 .729 0 r
.85788 .54505 .86741 .56604 .88982 .57082 .88041 .55071 Metetra
.828 .616 0 r
.88041 .55071 .88982 .57082 .91248 .57516 .90323 .55607 Metetra
.868 .495 0 r
.90323 .55607 .91248 .57516 .93534 .57869 .92628 .56073 Metetra
.904 .374 0 r
.92628 .56073 .93534 .57869 .95834 .58099 .9495 .56429 Metetra
.882 .452 0 r
.32313 .72153 .33406 .73606 .35236 .72188 .34156 .70614 Metetra
.841 .58 0 r
.34156 .70614 .35236 .72188 .37073 .70659 .36006 .68973 Metetra
.797 .702 0 r
.36006 .68973 .37073 .70659 .38915 .69058 .37859 .6727 Metetra
.69 .751 0 r
.37859 .6727 .38915 .69058 .40759 .67418 .39713 .65538 Metetra
.504 .704 0 r
.39713 .65538 .40759 .67418 .42604 .65771 .41567 .63809 Metetra
.338 .657 0 r
.41567 .63809 .42604 .65771 .44448 .64145 .43419 .62108 Metetra
.196 .612 0 r
.43419 .62108 .44448 .64145 .46293 .62562 .45271 .6046 Metetra
.077 .57 0 r
.45271 .6046 .46293 .62562 .48138 .61044 .47122 .58883 Metetra
0 .531 .018 r
.47122 .58883 .48138 .61044 .49984 .59607 .48973 .57395 Metetra
0 .495 .093 r
.48973 .57395 .49984 .59607 .51833 .58267 .50826 .56011 Metetra
0 .464 .15 r
.50826 .56011 .51833 .58267 .53686 .57036 .52682 .54742 Metetra
0 .438 .191 r
.52682 .54742 .53686 .57036 .55545 .55924 .54544 .53598 Metetra
0 .417 .219 r
.54544 .53598 .55545 .55924 .57413 .54939 .56414 .52587 Metetra
0 .403 .237 r
.56414 .52587 .57413 .54939 .59291 .54087 .58294 .51715 Metetra
0 .393 .247 r
.58294 .51715 .59291 .54087 .61183 .53373 .60187 .50985 Metetra
0 .39 .25 r
.60187 .50985 .61183 .53373 .63091 .52798 .62096 .504 Metetra
0 .393 .247 r
.62096 .504 .63091 .52798 .65017 .52363 .64023 .49962 Metetra
0 .403 .237 r
.64023 .49962 .65017 .52363 .66964 .52068 .65971 .49668 Metetra
0 .417 .219 r
.65971 .49668 .66964 .52068 .68935 .51909 .67943 .49516 Metetra
0 .438 .191 r
.67943 .49516 .68935 .51909 .70932 .51882 .69941 .49502 Metetra
0 .464 .15 r
.69941 .49502 .70932 .51882 .72957 .5198 .71968 .4962 Metetra
0 .495 .093 r
.71968 .4962 .72957 .5198 .75013 .52194 .74026 .49859 Metetra
0 .531 .018 r
.74026 .49859 .75013 .52194 .771 .52512 .76117 .50211 Metetra
.077 .57 0 r
.76117 .50211 .771 .52512 .79221 .52921 .78242 .50661 Metetra
.196 .612 0 r
.78242 .50661 .79221 .52921 .81377 .53404 .80402 .51192 Metetra
.338 .657 0 r
.80402 .51192 .81377 .53404 .83566 .5394 .82598 .51785 Metetra
.504 .704 0 r
.82598 .51785 .83566 .5394 .85788 .54505 .8483 .52417 Metetra
.69 .751 0 r
.8483 .52417 .85788 .54505 .88041 .55071 .87094 .53061 Metetra
.797 .702 0 r
.87094 .53061 .88041 .55071 .90323 .55607 .89389 .53684 Metetra
.841 .58 0 r
.89389 .53684 .90323 .55607 .92628 .56073 .91711 .5425 Metetra
.882 .452 0 r
.91711 .5425 .92628 .56073 .9495 .56429 .94054 .54717 Metetra
.859 .526 0 r
.31209 .70688 .32313 .72153 .34156 .70614 .33066 .6904 Metetra
.814 .657 0 r
.33066 .6904 .34156 .70614 .36006 .68973 .34929 .67301 Metetra
.755 .766 0 r
.34929 .67301 .36006 .68973 .37859 .6727 .36794 .65507 Metetra
.552 .716 0 r
.36794 .65507 .37859 .6727 .39713 .65538 .38658 .63694 Metetra
.369 .666 0 r
.38658 .63694 .39713 .65538 .41567 .63809 .40521 .61891 Metetra
.211 .617 0 r
.40521 .61891 .41567 .63809 .43419 .62108 .42382 .60125 Metetra
.077 .57 0 r
.42382 .60125 .43419 .62108 .45271 .6046 .44241 .58417 Metetra
0 .525 .03 r
.44241 .58417 .45271 .6046 .47122 .58883 .46098 .56789 Metetra
0 .484 .114 r
.46098 .56789 .47122 .58883 .48973 .57395 .47955 .55255 Metetra
0 .447 .177 r
.47955 .55255 .48973 .57395 .50826 .56011 .49813 .53831 Metetra
0 .414 .223 r
.49813 .53831 .50826 .56011 .52682 .54742 .51673 .52528 Metetra
0 .387 .254 r
.51673 .52528 .52682 .54742 .54544 .53598 .53539 .51355 Metetra
0 .366 .274 r
.53539 .51355 .54544 .53598 .56414 .52587 .55412 .5032 Metetra
0 .35 .286 r
.55412 .5032 .56414 .52587 .58294 .51715 .57294 .49429 Metetra
0 .341 .292 r
.57294 .49429 .58294 .51715 .60187 .50985 .59189 .48685 Metetra
0 .338 .294 r
.59189 .48685 .60187 .50985 .62096 .504 .61099 .48091 Metetra
0 .341 .292 r
.61099 .48091 .62096 .504 .64023 .49962 .63028 .47648 Metetra
0 .35 .286 r
.63028 .47648 .64023 .49962 .65971 .49668 .64977 .47354 Metetra
0 .366 .274 r
.64977 .47354 .65971 .49668 .67943 .49516 .6695 .47207 Metetra
0 .387 .254 r
.6695 .47207 .67943 .49516 .69941 .49502 .6895 .47204 Metetra
0 .414 .223 r
.6895 .47204 .69941 .49502 .71968 .4962 .70978 .47336 Metetra
0 .447 .177 r
.70978 .47336 .71968 .4962 .74026 .49859 .73039 .47597 Metetra
0 .484 .114 r
.73039 .47597 .74026 .49859 .76117 .50211 .75132 .47976 Metetra
0 .525 .03 r
.75132 .47976 .76117 .50211 .78242 .50661 .77262 .4846 Metetra
.077 .57 0 r
.77262 .4846 .78242 .50661 .80402 .51192 .79427 .49033 Metetra
.211 .617 0 r
.79427 .49033 .80402 .51192 .82598 .51785 .81629 .49675 Metetra
.369 .666 0 r
.81629 .49675 .82598 .51785 .8483 .52417 .83869 .50364 Metetra
.552 .716 0 r
.83869 .50364 .8483 .52417 .87094 .53061 .86143 .51074 Metetra
.755 .766 0 r
.86143 .51074 .87094 .53061 .89389 .53684 .88451 .51772 Metetra
.814 .657 0 r
.88451 .51772 .89389 .53684 .91711 .5425 .90788 .52424 Metetra
.859 .526 0 r
.90788 .52424 .91711 .5425 .94054 .54717 .93149 .52988 Metetra
.836 .593 0 r
.30094 .69231 .31209 .70688 .33066 .6904 .31965 .67487 Metetra
.788 .724 0 r
.31965 .67487 .33066 .6904 .34929 .67301 .3384 .65661 Metetra
.633 .737 0 r
.3384 .65661 .34929 .67301 .36794 .65507 .35717 .63788 Metetra
.432 .684 0 r
.35717 .63788 .36794 .65507 .38658 .63694 .37592 .61903 Metetra
.255 .632 0 r
.37592 .61903 .38658 .63694 .40521 .61891 .39465 .60036 Metetra
.105 .58 0 r
.39465 .60036 .40521 .61891 .42382 .60125 .41335 .58211 Metetra
0 .531 .018 r
.41335 .58211 .42382 .60125 .44241 .58417 .43202 .56452 Metetra
0 .484 .114 r
.43202 .56452 .44241 .58417 .46098 .56789 .45066 .54777 Metetra
0 .441 .186 r
.45066 .54777 .46098 .56789 .47955 .55255 .46929 .53203 Metetra
0 .403 .237 r
.46929 .53203 .47955 .55255 .49813 .53831 .48793 .51744 Metetra
0 .369 .271 r
.48793 .51744 .49813 .53831 .51673 .52528 .50658 .5041 Metetra
0 .341 .292 r
.50658 .5041 .51673 .52528 .53539 .51355 .52528 .49211 Metetra
0 .319 .303 r
.52528 .49211 .53539 .51355 .55412 .5032 .54404 .48155 Metetra
0 .296 .303 r
.54404 .48155 .55412 .5032 .57294 .49429 .5629 .47246 Metetra
0 .274 .293 r
.5629 .47246 .57294 .49429 .59189 .48685 .58187 .46489 Metetra
0 .267 .29 r
.58187 .46489 .59189 .48685 .61099 .48091 .601 .45885 Metetra
0 .274 .293 r
.601 .45885 .61099 .48091 .63028 .47648 .6203 .45437 Metetra
0 .296 .303 r
.6203 .45437 .63028 .47648 .64977 .47354 .63982 .45142 Metetra
0 .319 .303 r
.63982 .45142 .64977 .47354 .6695 .47207 .65957 .44998 Metetra
0 .341 .292 r
.65957 .44998 .6695 .47207 .6895 .47204 .67958 .45002 Metetra
0 .369 .271 r
.67958 .45002 .6895 .47204 .70978 .47336 .69989 .45147 Metetra
0 .403 .237 r
.69989 .45147 .70978 .47336 .73039 .47597 .72052 .45425 Metetra
0 .441 .186 r
.72052 .45425 .73039 .47597 .75132 .47976 .74148 .45826 Metetra
0 .484 .114 r
.74148 .45826 .75132 .47976 .77262 .4846 .76281 .46338 Metetra
0 .531 .018 r
.76281 .46338 .77262 .4846 .79427 .49033 .78451 .46944 Metetra
.105 .58 0 r
.78451 .46944 .79427 .49033 .81629 .49675 .8066 .47627 Metetra
.255 .632 0 r
.8066 .47627 .81629 .49675 .83869 .50364 .82906 .48364 Metetra
.432 .684 0 r
.82906 .48364 .83869 .50364 .86143 .51074 .8519 .4913 Metetra
.633 .737 0 r
.8519 .4913 .86143 .51074 .88451 .51772 .87509 .49892 Metetra
.788 .724 0 r
.87509 .49892 .88451 .51772 .90788 .52424 .89859 .50617 Metetra
.836 .593 0 r
.89859 .50617 .90788 .52424 .93149 .52988 .92237 .51263 Metetra
.815 .652 0 r
.28965 .67799 .30094 .69231 .31965 .67487 .3085 .65973 Metetra
.747 .764 0 r
.3085 .65973 .31965 .67487 .3384 .65661 .32738 .64071 Metetra
.528 .71 0 r
.32738 .64071 .3384 .65661 .35717 .63788 .34627 .62129 Metetra
.331 .655 0 r
.34627 .62129 .35717 .63788 .37592 .61903 .36514 .60182 Metetra
.16 .6 0 r
.36514 .60182 .37592 .61903 .39465 .60036 .38397 .58258 Metetra
.019 .546 0 r
.38397 .58258 .39465 .60036 .41335 .58211 .40277 .56383 Metetra
0 .495 .093 r
.40277 .56383 .41335 .58211 .43202 .56452 .42152 .54579 Metetra
0 .447 .177 r
.42152 .54579 .43202 .56452 .45066 .54777 .44024 .52864 Metetra
0 .403 .237 r
.44024 .52864 .45066 .54777 .46929 .53203 .45895 .51254 Metetra
0 .363 .276 r
.45895 .51254 .46929 .53203 .48793 .51744 .47764 .49763 Metetra
0 .328 .299 r
.47764 .49763 .48793 .51744 .50658 .5041 .49635 .48402 Metetra
0 .289 .299 r
.49635 .48402 .50658 .5041 .52528 .49211 .5151 .4718 Metetra
0 .239 .277 r
.5151 .4718 .52528 .49211 .54404 .48155 .53391 .46104 Metetra
0 .206 .26 r
.53391 .46104 .54404 .48155 .5629 .47246 .5528 .45179 Metetra
0 .187 .25 r
.5528 .45179 .5629 .47246 .58187 .46489 .57182 .44409 Metetra
0 .181 .247 r
.57182 .44409 .58187 .46489 .601 .45885 .59097 .43796 Metetra
0 .187 .25 r
.59097 .43796 .601 .45885 .6203 .45437 .6103 .43342 Metetra
0 .206 .26 r
.6103 .43342 .6203 .45437 .63982 .45142 .62984 .43044 Metetra
0 .239 .277 r
.62984 .43044 .63982 .45142 .65957 .44998 .64962 .42902 Metetra
0 .289 .299 r
.64962 .42902 .65957 .44998 .67958 .45002 .66966 .42911 Metetra
0 .328 .299 r
.66966 .42911 .67958 .45002 .69989 .45147 .68999 .43064 Metetra
0 .363 .276 r
.68999 .43064 .69989 .45147 .72052 .45425 .71065 .43355 Metetra
0 .403 .237 r
.71065 .43355 .72052 .45425 .74148 .45826 .73165 .43774 Metetra
0 .447 .177 r
.73165 .43774 .74148 .45826 .76281 .46338 .75301 .44308 Metetra
0 .495 .093 r
.75301 .44308 .76281 .46338 .78451 .46944 .77476 .44942 Metetra
.019 .546 0 r
.77476 .44942 .78451 .46944 .8066 .47627 .7969 .45659 Metetra
.16 .6 0 r
.7969 .45659 .8066 .47627 .82906 .48364 .81943 .46435 Metetra
.331 .655 0 r
.81943 .46435 .82906 .48364 .8519 .4913 .84236 .47246 Metetra
.528 .71 0 r
.84236 .47246 .8519 .4913 .87509 .49892 .86565 .48062 Metetra
.747 .764 0 r
.86565 .48062 .87509 .49892 .89859 .50617 .88927 .48847 Metetra
.815 .652 0 r
.88927 .48847 .89859 .50617 .92237 .51263 .91319 .49562 Metetra
.797 .702 0 r
.27821 .66407 .28965 .67799 .3085 .65973 .2972 .64511 Metetra
.657 .743 0 r
.2972 .64511 .3085 .65973 .32738 .64071 .31622 .62545 Metetra
.44 .686 0 r
.31622 .62545 .32738 .64071 .34627 .62129 .33523 .60545 Metetra
.247 .629 0 r
.33523 .60545 .34627 .62129 .36514 .60182 .35422 .58544 Metetra
.084 .572 0 r
.35422 .58544 .36514 .60182 .38397 .58258 .37316 .56572 Metetra
0 .517 .048 r
.37316 .56572 .38397 .58258 .40277 .56383 .39205 .54653 Metetra
0 .464 .15 r
.39205 .54653 .40277 .56383 .42152 .54579 .4109 .52809 Metetra
0 .414 .223 r
.4109 .52809 .42152 .54579 .44024 .52864 .42971 .51059 Metetra
0 .369 .271 r
.42971 .51059 .44024 .52864 .45895 .51254 .44849 .49419 Metetra
0 .328 .299 r
.44849 .49419 .45895 .51254 .47764 .49763 .46726 .479 Metetra
0 .274 .293 r
.46726 .479 .47764 .49763 .49635 .48402 .48604 .46515 Metetra
0 .213 .263 r
.48604 .46515 .49635 .48402 .5151 .4718 .50484 .45272 Metetra
0 .169 .24 r
.50484 .45272 .5151 .4718 .53391 .46104 .52371 .44178 Metetra
0 .141 .223 r
.52371 .44178 .53391 .46104 .5528 .45179 .54265 .43238 Metetra
0 .125 .213 r
.54265 .43238 .5528 .45179 .57182 .44409 .5617 .42456 Metetra
0 .12 .209 r
.5617 .42456 .57182 .44409 .59097 .43796 .5809 .41834 Metetra
0 .125 .213 r
.5809 .41834 .59097 .43796 .6103 .43342 .60027 .41374 Metetra
0 .141 .223 r
.60027 .41374 .6103 .43342 .62984 .43044 .61984 .41073 Metetra
0 .169 .24 r
.61984 .41073 .62984 .43044 .64962 .42902 .63964 .4093 Metetra
0 .213 .263 r
.63964 .4093 .64962 .42902 .66966 .42911 .65972 .40941 Metetra
0 .274 .293 r
.65972 .40941 .66966 .42911 .68999 .43064 .68008 .41101 Metetra
0 .328 .299 r
.68008 .41101 .68999 .43064 .71065 .43355 .70077 .41401 Metetra
0 .369 .271 r
.70077 .41401 .71065 .43355 .73165 .43774 .72181 .41833 Metetra
0 .414 .223 r
.72181 .41833 .73165 .43774 .75301 .44308 .74322 .42384 Metetra
0 .464 .15 r
.74322 .42384 .75301 .44308 .77476 .44942 .76501 .4304 Metetra
0 .517 .048 r
.76501 .4304 .77476 .44942 .7969 .45659 .78721 .43782 Metetra
.084 .572 0 r
.78721 .43782 .7969 .45659 .81943 .46435 .80981 .44589 Metetra
.247 .629 0 r
.80981 .44589 .81943 .46435 .84236 .47246 .83281 .45437 Metetra
.44 .686 0 r
.83281 .45437 .84236 .47246 .86565 .48062 .85619 .46295 Metetra
.657 .743 0 r
.85619 .46295 .86565 .48062 .88927 .48847 .87993 .47129 Metetra
.797 .702 0 r
.87993 .47129 .88927 .48847 .91319 .49562 .90398 .479 Metetra
.781 .742 0 r
.2666 .6507 .27821 .66407 .2972 .64511 .28573 .63115 Metetra
.584 .725 0 r
.28573 .63115 .2972 .64511 .31622 .62545 .30488 .61095 Metetra
.369 .666 0 r
.30488 .61095 .31622 .62545 .33523 .60545 .32403 .59046 Metetra
.182 .607 0 r
.32403 .59046 .33523 .60545 .35422 .58544 .34313 .57 Metetra
.025 .549 0 r
.34313 .57 .35422 .58544 .37316 .56572 .36219 .54987 Metetra
0 .492 .099 r
.36219 .54987 .37316 .56572 .39205 .54653 .3812 .53032 Metetra
0 .438 .191 r
.3812 .53032 .39205 .54653 .4109 .52809 .40015 .51155 Metetra
0 .387 .254 r
.40015 .51155 .4109 .52809 .42971 .51059 .41905 .49375 Metetra
0 .341 .292 r
.41905 .49375 .42971 .51059 .44849 .49419 .43792 .47707 Metetra
0 .289 .299 r
.43792 .47707 .44849 .49419 .46726 .479 .45677 .46165 Metetra
0 .213 .263 r
.45677 .46165 .46726 .479 .48604 .46515 .47562 .44758 Metetra
0 .158 .233 r
.47562 .44758 .48604 .46515 .50484 .45272 .49449 .43497 Metetra
0 .12 .209 r
.49449 .43497 .50484 .45272 .52371 .44178 .51342 .42386 Metetra
0 .096 .192 r
.51342 .42386 .52371 .44178 .54265 .43238 .53242 .41433 Metetra
0 .082 .182 r
.53242 .41433 .54265 .43238 .5617 .42456 .55153 .4064 Metetra
0 .078 .178 r
.55153 .4064 .5617 .42456 .5809 .41834 .57077 .40009 Metetra
0 .082 .182 r
.57077 .40009 .5809 .41834 .60027 .41374 .59018 .39541 Metetra
0 .096 .192 r
.59018 .39541 .60027 .41374 .61984 .41073 .6098 .39236 Metetra
0 .12 .209 r
.6098 .39236 .61984 .41073 .63964 .4093 .62964 .39091 Metetra
0 .158 .233 r
.62964 .39091 .63964 .4093 .65972 .40941 .64975 .39103 Metetra
0 .213 .263 r
.64975 .39103 .65972 .40941 .68008 .41101 .67016 .39266 Metetra
0 .289 .299 r
.67016 .39266 .68008 .41101 .70077 .41401 .69088 .39572 Metetra
0 .341 .292 r
.69088 .39572 .70077 .41401 .72181 .41833 .71196 .40013 Metetra
0 .387 .254 r
.71196 .40013 .72181 .41833 .74322 .42384 .73342 .40576 Metetra
0 .438 .191 r
.73342 .40576 .74322 .42384 .76501 .4304 .75526 .41247 Metetra
0 .492 .099 r
.75526 .41247 .76501 .4304 .78721 .43782 .77752 .42008 Metetra
.025 .549 0 r
.77752 .42008 .78721 .43782 .80981 .44589 .80018 .42839 Metetra
.182 .607 0 r
.80018 .42839 .80981 .44589 .83281 .45437 .82326 .43715 Metetra
.369 .666 0 r
.82326 .43715 .83281 .45437 .85619 .46295 .84673 .44605 Metetra
.584 .725 0 r
.84673 .44605 .85619 .46295 .87993 .47129 .87057 .45477 Metetra
.781 .742 0 r
.87057 .45477 .87993 .47129 .90398 .479 .89475 .4629 Metetra
.763 .768 0 r
.2548 .63796 .2666 .6507 .28573 .63115 .27407 .61795 Metetra
.528 .71 0 r
.27407 .61795 .28573 .63115 .30488 .61095 .29337 .59731 Metetra
.315 .65 0 r
.29337 .59731 .30488 .61095 .32403 .59046 .31264 .57642 Metetra
.132 .59 0 r
.31264 .57642 .32403 .59046 .34313 .57 .33188 .5556 Metetra
0 .53 .018 r
.33188 .5556 .34313 .57 .36219 .54987 .35106 .53513 Metetra
0 .473 .135 r
.35106 .53513 .36219 .54987 .3812 .53032 .37018 .51527 Metetra
0 .417 .219 r
.37018 .51527 .3812 .53032 .40015 .51155 .38924 .49622 Metetra
0 .366 .274 r
.38924 .49622 .40015 .51155 .41905 .49375 .40824 .47817 Metetra
0 .319 .303 r
.40824 .47817 .41905 .49375 .43792 .47707 .42721 .46127 Metetra
0 .239 .277 r
.42721 .46127 .43792 .47707 .45677 .46165 .44615 .44564 Metetra
0 .169 .24 r
.44615 .44564 .45677 .46165 .47562 .44758 .46508 .43139 Metetra
0 .12 .209 r
.46508 .43139 .47562 .44758 .49449 .43497 .48403 .41861 Metetra
0 .087 .185 r
.48403 .41861 .49449 .43497 .51342 .42386 .50303 .40736 Metetra
0 .066 .168 r
.50303 .40736 .51342 .42386 .53242 .41433 .5221 .3977 Metetra
0 .055 .157 r
.5221 .3977 .53242 .41433 .55153 .4064 .54127 .38966 Metetra
0 .051 .154 r
.54127 .38966 .55153 .4064 .57077 .40009 .56057 .38327 Metetra
0 .055 .157 r
.56057 .38327 .57077 .40009 .59018 .39541 .58004 .37852 Metetra
0 .066 .168 r
.58004 .37852 .59018 .39541 .6098 .39236 .5997 .37542 Metetra
0 .087 .185 r
.5997 .37542 .6098 .39236 .62964 .39091 .6196 .37393 Metetra
0 .12 .209 r
.6196 .37393 .62964 .39091 .64975 .39103 .63975 .37403 Metetra
0 .169 .24 r
.63975 .37403 .64975 .39103 .67016 .39266 .6602 .37566 Metetra
0 .239 .277 r
.6602 .37566 .67016 .39266 .69088 .39572 .68098 .37875 Metetra
0 .319 .303 r
.68098 .37875 .69088 .39572 .71196 .40013 .70211 .38321 Metetra
0 .366 .274 r
.70211 .38321 .71196 .40013 .73342 .40576 .72361 .38891 Metetra
0 .417 .219 r
.72361 .38891 .73342 .40576 .75526 .41247 .74551 .39573 Metetra
0 .473 .135 r
.74551 .39573 .75526 .41247 .77752 .42008 .76782 .40347 Metetra
0 .53 .018 r
.76782 .40347 .77752 .42008 .80018 .42839 .79055 .41194 Metetra
.132 .59 0 r
.79055 .41194 .80018 .42839 .82326 .43715 .8137 .42089 Metetra
.315 .65 0 r
.8137 .42089 .82326 .43715 .84673 .44605 .83726 .43002 Metetra
.528 .71 0 r
.83726 .43002 .84673 .44605 .87057 .45477 .86121 .439 Metetra
.763 .768 0 r
.86121 .439 .87057 .45477 .89475 .4629 .88549 .44744 Metetra
.722 .758 0 r
.2428 .62593 .2548 .63796 .27407 .61795 .26222 .60556 Metetra
.488 .699 0 r
.26222 .60556 .27407 .61795 .29337 .59731 .28165 .5846 Metetra
.277 .639 0 r
.28165 .5846 .29337 .59731 .31264 .57642 .30106 .5634 Metetra
.098 .577 0 r
.30106 .5634 .31264 .57642 .33188 .5556 .32043 .5423 Metetra
0 .517 .048 r
.32043 .5423 .33188 .5556 .35106 .53513 .33973 .52157 Metetra
0 .458 .159 r
.33973 .52157 .35106 .53513 .37018 .51527 .35898 .50146 Metetra
0 .403 .237 r
.35898 .50146 .37018 .51527 .38924 .49622 .37815 .48219 Metetra
0 .35 .286 r
.37815 .48219 .38924 .49622 .40824 .47817 .39727 .46393 Metetra
0 .296 .303 r
.39727 .46393 .40824 .47817 .42721 .46127 .41634 .44684 Metetra
0 .206 .26 r
.41634 .44684 .42721 .46127 .44615 .44564 .43538 .43103 Metetra
0 .141 .223 r
.43538 .43103 .44615 .44564 .46508 .43139 .45441 .41663 Metetra
0 .096 .192 r
.45441 .41663 .46508 .43139 .48403 .41861 .47345 .40371 Metetra
0 .066 .168 r
.47345 .40371 .48403 .41861 .50303 .40736 .49252 .39233 Metetra
0 .048 .15 r
.49252 .39233 .50303 .40736 .5221 .3977 .51167 .38256 Metetra
0 .038 .139 r
.51167 .38256 .5221 .3977 .54127 .38966 .53091 .37442 Metetra
0 .035 .136 r
.53091 .37442 .54127 .38966 .56057 .38327 .55028 .36793 Metetra
0 .038 .139 r
.55028 .36793 .56057 .38327 .58004 .37852 .56981 .36311 Metetra
0 .048 .15 r
.56981 .36311 .58004 .37852 .5997 .37542 .58954 .35994 Metetra
0 .066 .168 r
.58954 .35994 .5997 .37542 .6196 .37393 .60949 .35841 Metetra
0 .096 .192 r
.60949 .35841 .6196 .37393 .63975 .37403 .62971 .35848 Metetra
0 .141 .223 r
.62971 .35848 .63975 .37403 .6602 .37566 .65021 .36009 Metetra
0 .206 .26 r
.65021 .36009 .6602 .37566 .68098 .37875 .67104 .36317 Metetra
0 .296 .303 r
.67104 .36317 .68098 .37875 .70211 .38321 .69222 .36764 Metetra
0 .35 .286 r
.69222 .36764 .70211 .38321 .72361 .38891 .71378 .37337 Metetra
0 .403 .237 r
.71378 .37337 .72361 .38891 .74551 .39573 .73574 .38023 Metetra
0 .458 .159 r
.73574 .38023 .74551 .39573 .76782 .40347 .75812 .38804 Metetra
0 .517 .048 r
.75812 .38804 .76782 .40347 .79055 .41194 .78092 .3966 Metetra
.098 .577 0 r
.78092 .3966 .79055 .41194 .8137 .42089 .80415 .40565 Metetra
.277 .639 0 r
.80415 .40565 .8137 .42089 .83726 .43002 .82779 .41492 Metetra
.488 .699 0 r
.82779 .41492 .83726 .43002 .86121 .439 .85183 .42406 Metetra
.722 .758 0 r
.85183 .42406 .86121 .439 .88549 .44744 .87622 .43269 Metetra
.698 .752 0 r
.23058 .61466 .2428 .62593 .26222 .60556 .25013 .59406 Metetra
.464 .693 0 r
.25013 .59406 .26222 .60556 .28165 .5846 .26971 .57287 Metetra
.255 .632 0 r
.26971 .57287 .28165 .5846 .30106 .5634 .28926 .55145 Metetra
.077 .57 0 r
.28926 .55145 .30106 .5634 .32043 .5423 .30876 .53014 Metetra
0 .509 .065 r
.30876 .53014 .32043 .5423 .33973 .52157 .3282 .50922 Metetra
0 .45 .173 r
.3282 .50922 .33973 .52157 .35898 .50146 .34757 .48893 Metetra
0 .393 .247 r
.34757 .48893 .35898 .50146 .37815 .48219 .36687 .46949 Metetra
0 .341 .292 r
.36687 .46949 .37815 .48219 .39727 .46393 .38611 .45107 Metetra
0 .274 .293 r
.38611 .45107 .39727 .46393 .41634 .44684 .40529 .43382 Metetra
0 .187 .25 r
.40529 .43382 .41634 .44684 .43538 .43103 .42444 .41788 Metetra
0 .125 .213 r
.42444 .41788 .43538 .43103 .45441 .41663 .44357 .40334 Metetra
0 .082 .182 r
.44357 .40334 .45441 .41663 .47345 .40371 .46271 .3903 Metetra
0 .055 .157 r
.46271 .3903 .47345 .40371 .49252 .39233 .48188 .37881 Metetra
0 .038 .139 r
.48188 .37881 .49252 .39233 .51167 .38256 .50112 .36893 Metetra
0 .029 .129 r
.50112 .36893 .51167 .38256 .53091 .37442 .52044 .3607 Metetra
0 .026 .125 r
.52044 .3607 .53091 .37442 .55028 .36793 .53989 .35412 Metetra
0 .029 .129 r
.53989 .35412 .55028 .36793 .56981 .36311 .5595 .34922 Metetra
0 .038 .139 r
.5595 .34922 .56981 .36311 .58954 .35994 .5793 .34599 Metetra
0 .055 .157 r
.5793 .34599 .58954 .35994 .60949 .35841 .59932 .34439 Metetra
0 .082 .182 r
.59932 .34439 .60949 .35841 .62971 .35848 .6196 .3444 Metetra
0 .125 .213 r
.6196 .3444 .62971 .35848 .65021 .36009 .64017 .34597 Metetra
0 .187 .25 r
.64017 .34597 .65021 .36009 .67104 .36317 .66106 .34902 Metetra
0 .274 .293 r
.66106 .34902 .67104 .36317 .69222 .36764 .68231 .35346 Metetra
0 .341 .292 r
.68231 .35346 .69222 .36764 .71378 .37337 .70393 .35918 Metetra
0 .393 .247 r
.70393 .35918 .71378 .37337 .73574 .38023 .72595 .36603 Metetra
0 .45 .173 r
.72595 .36603 .73574 .38023 .75812 .38804 .7484 .37385 Metetra
0 .509 .065 r
.7484 .37385 .75812 .38804 .78092 .3966 .77127 .38242 Metetra
.077 .57 0 r
.77127 .38242 .78092 .3966 .80415 .40565 .79457 .39151 Metetra
.255 .632 0 r
.79457 .39151 .80415 .40565 .82779 .41492 .8183 .40082 Metetra
.464 .693 0 r
.8183 .40082 .82779 .41492 .85183 .42406 .84243 .41001 Metetra
.698 .752 0 r
.84243 .41001 .85183 .42406 .87622 .43269 .86692 .4187 Metetra
.69 .751 0 r
.21812 .6042 .23058 .61466 .25013 .59406 .23781 .58347 Metetra
.456 .691 0 r
.23781 .58347 .25013 .59406 .26971 .57287 .25753 .56215 Metetra
.247 .629 0 r
.25753 .56215 .26971 .57287 .28926 .55145 .27722 .54061 Metetra
.071 .567 0 r
.27722 .54061 .28926 .55145 .30876 .53014 .29686 .51917 Metetra
0 .506 .071 r
.29686 .51917 .30876 .53014 .3282 .50922 .31644 .49812 Metetra
0 .447 .177 r
.31644 .49812 .3282 .50922 .34757 .48893 .33595 .47771 Metetra
0 .39 .25 r
.33595 .47771 .34757 .48893 .36687 .46949 .35538 .45815 Metetra
0 .338 .294 r
.35538 .45815 .36687 .46949 .38611 .45107 .37474 .43961 Metetra
0 .267 .29 r
.37474 .43961 .38611 .45107 .40529 .43382 .39405 .42225 Metetra
0 .181 .247 r
.39405 .42225 .40529 .43382 .42444 .41788 .41332 .4062 Metetra
0 .12 .209 r
.41332 .4062 .42444 .41788 .44357 .40334 .43256 .39156 Metetra
0 .078 .178 r
.43256 .39156 .44357 .40334 .46271 .3903 .45181 .37841 Metetra
0 .051 .154 r
.45181 .37841 .46271 .3903 .48188 .37881 .47108 .36683 Metetra
0 .035 .136 r
.47108 .36683 .48188 .37881 .50112 .36893 .49042 .35685 Metetra
0 .026 .125 r
.49042 .35685 .50112 .36893 .52044 .3607 .50984 .34853 Metetra
0 .023 .121 r
.50984 .34853 .52044 .3607 .53989 .35412 .52938 .34187 Metetra
0 .026 .125 r
.52938 .34187 .53989 .35412 .5595 .34922 .54907 .33688 Metetra
0 .035 .136 r
.54907 .33688 .5595 .34922 .5793 .34599 .56895 .33357 Metetra
0 .051 .154 r
.56895 .33357 .5793 .34599 .59932 .34439 .58905 .3319 Metetra
0 .078 .178 r
.58905 .3319 .59932 .34439 .6196 .3444 .60941 .33184 Metetra
0 .12 .209 r
.60941 .33184 .6196 .3444 .64017 .34597 .63005 .33333 Metetra
0 .181 .247 r
.63005 .33333 .64017 .34597 .66106 .34902 .65102 .33632 Metetra
0 .267 .29 r
.65102 .33632 .66106 .34902 .68231 .35346 .67233 .3407 Metetra
0 .338 .294 r
.67233 .3407 .68231 .35346 .70393 .35918 .69403 .34635 Metetra
0 .39 .25 r
.69403 .34635 .70393 .35918 .72595 .36603 .71613 .35315 Metetra
0 .447 .177 r
.71613 .35315 .72595 .36603 .7484 .37385 .73865 .36091 Metetra
0 .506 .071 r
.73865 .36091 .7484 .37385 .77127 .38242 .7616 .36943 Metetra
.071 .567 0 r
.7616 .36943 .77127 .38242 .79457 .39151 .78498 .37847 Metetra
.247 .629 0 r
.78498 .37847 .79457 .39151 .8183 .40082 .80879 .38773 Metetra
.456 .691 0 r
.80879 .38773 .8183 .40082 .84243 .41001 .83301 .39687 Metetra
.69 .751 0 r
.83301 .39687 .84243 .41001 .86692 .4187 .8576 .4055 Metetra
.698 .752 0 r
.20541 .59453 .21812 .6042 .23781 .58347 .22524 .57379 Metetra
.464 .693 0 r
.22524 .57379 .23781 .58347 .25753 .56215 .24509 .55245 Metetra
.255 .632 0 r
.24509 .55245 .25753 .56215 .27722 .54061 .26492 .53087 Metetra
.077 .57 0 r
.26492 .53087 .27722 .54061 .29686 .51917 .28471 .50938 Metetra
0 .509 .065 r
.28471 .50938 .29686 .51917 .31644 .49812 .30443 .48828 Metetra
0 .45 .173 r
.30443 .48828 .31644 .49812 .33595 .47771 .32408 .46781 Metetra
0 .393 .247 r
.32408 .46781 .33595 .47771 .35538 .45815 .34365 .44817 Metetra
0 .341 .292 r
.34365 .44817 .35538 .45815 .37474 .43961 .36315 .42957 Metetra
0 .274 .293 r
.36315 .42957 .37474 .43961 .39405 .42225 .38259 .41213 Metetra
0 .187 .25 r
.38259 .41213 .39405 .42225 .41332 .4062 .40198 .396 Metetra
0 .125 .213 r
.40198 .396 .41332 .4062 .43256 .39156 .42135 .38128 Metetra
0 .082 .182 r
.42135 .38128 .43256 .39156 .45181 .37841 .44072 .36805 Metetra
0 .055 .157 r
.44072 .36805 .45181 .37841 .47108 .36683 .46011 .35639 Metetra
0 .038 .139 r
.46011 .35639 .47108 .36683 .49042 .35685 .47955 .34633 Metetra
0 .029 .129 r
.47955 .34633 .49042 .35685 .50984 .34853 .49908 .33792 Metetra
0 .026 .125 r
.49908 .33792 .50984 .34853 .52938 .34187 .51872 .33117 Metetra
0 .029 .129 r
.51872 .33117 .52938 .34187 .54907 .33688 .53851 .3261 Metetra
0 .038 .139 r
.53851 .3261 .54907 .33688 .56895 .33357 .55848 .3227 Metetra
0 .055 .157 r
.55848 .3227 .56895 .33357 .58905 .3319 .57867 .32094 Metetra
0 .082 .182 r
.57867 .32094 .58905 .3319 .60941 .33184 .59912 .32079 Metetra
0 .125 .213 r
.59912 .32079 .60941 .33184 .63005 .33333 .61985 .32219 Metetra
0 .187 .25 r
.61985 .32219 .63005 .33333 .65102 .33632 .6409 .32508 Metetra
0 .274 .293 r
.6409 .32508 .65102 .33632 .67233 .3407 .6623 .32936 Metetra
0 .341 .292 r
.6623 .32936 .67233 .3407 .69403 .34635 .68407 .33491 Metetra
0 .393 .247 r
.68407 .33491 .69403 .34635 .71613 .35315 .70625 .3416 Metetra
0 .45 .173 r
.70625 .3416 .71613 .35315 .73865 .36091 .72885 .34925 Metetra
0 .509 .065 r
.72885 .34925 .73865 .36091 .7616 .36943 .75188 .35765 Metetra
.077 .57 0 r
.75188 .35765 .7616 .36943 .78498 .37847 .77535 .36655 Metetra
.255 .632 0 r
.77535 .36655 .78498 .37847 .80879 .38773 .79925 .37566 Metetra
.464 .693 0 r
.79925 .37566 .80879 .38773 .83301 .39687 .82355 .38465 Metetra
.698 .752 0 r
.82355 .38465 .83301 .39687 .8576 .4055 .84823 .39311 Metetra
.722 .758 0 r
.19243 .58565 .20541 .59453 .22524 .57379 .21239 .56502 Metetra
.488 .699 0 r
.21239 .56502 .22524 .57379 .24509 .55245 .23238 .54376 Metetra
.277 .639 0 r
.23238 .54376 .24509 .55245 .26492 .53087 .25236 .52223 Metetra
.098 .577 0 r
.25236 .52223 .26492 .53087 .28471 .50938 .27229 .50078 Metetra
0 .517 .048 r
.27229 .50078 .28471 .50938 .30443 .48828 .29216 .47969 Metetra
0 .458 .159 r
.29216 .47969 .30443 .48828 .32408 .46781 .31195 .45922 Metetra
0 .403 .237 r
.31195 .45922 .32408 .46781 .34365 .44817 .33167 .43957 Metetra
0 .35 .286 r
.33167 .43957 .34365 .44817 .36315 .42957 .35131 .42093 Metetra
0 .296 .303 r
.35131 .42093 .36315 .42957 .38259 .41213 .37089 .40347 Metetra
0 .206 .26 r
.37089 .40347 .38259 .41213 .40198 .396 .39042 .38729 Metetra
0 .141 .223 r
.39042 .38729 .40198 .396 .42135 .38128 .40993 .37251 Metetra
0 .096 .192 r
.40993 .37251 .42135 .38128 .44072 .36805 .42942 .35922 Metetra
0 .066 .168 r
.42942 .35922 .44072 .36805 .46011 .35639 .44894 .34749 Metetra
0 .048 .15 r
.44894 .34749 .46011 .35639 .47955 .34633 .4685 .33736 Metetra
0 .038 .139 r
.4685 .33736 .47955 .34633 .49908 .33792 .48815 .32887 Metetra
0 .035 .136 r
.48815 .32887 .49908 .33792 .51872 .33117 .5079 .32204 Metetra
0 .038 .139 r
.5079 .32204 .51872 .33117 .53851 .3261 .5278 .31687 Metetra
0 .048 .15 r
.5278 .31687 .53851 .3261 .55848 .3227 .54788 .31337 Metetra
0 .066 .168 r
.54788 .31337 .55848 .3227 .57867 .32094 .56817 .31151 Metetra
0 .096 .192 r
.56817 .31151 .57867 .32094 .59912 .32079 .58871 .31125 Metetra
0 .141 .223 r
.58871 .31125 .59912 .32079 .61985 .32219 .60954 .31254 Metetra
0 .206 .26 r
.60954 .31254 .61985 .32219 .6409 .32508 .63068 .3153 Metetra
0 .296 .303 r
.63068 .3153 .6409 .32508 .6623 .32936 .65217 .31944 Metetra
0 .35 .286 r
.65217 .31944 .6623 .32936 .68407 .33491 .67404 .32485 Metetra
0 .403 .237 r
.67404 .32485 .68407 .33491 .70625 .3416 .69631 .33137 Metetra
0 .458 .159 r
.69631 .33137 .70625 .3416 .72885 .34925 .71899 .33884 Metetra
0 .517 .048 r
.71899 .33884 .72885 .34925 .75188 .35765 .74211 .34705 Metetra
.098 .577 0 r
.74211 .34705 .75188 .35765 .77535 .36655 .76567 .35574 Metetra
.277 .639 0 r
.76567 .35574 .77535 .36655 .79925 .37566 .78965 .36461 Metetra
.488 .699 0 r
.78965 .36461 .79925 .37566 .82355 .38465 .81405 .37333 Metetra
.722 .758 0 r
.81405 .37333 .82355 .38465 .84823 .39311 .83882 .3815 Metetra
.763 .768 0 r
.17918 .57752 .19243 .58565 .21239 .56502 .19927 .55712 Metetra
.528 .71 0 r
.19927 .55712 .21239 .56502 .23238 .54376 .21939 .53603 Metetra
.315 .65 0 r
.21939 .53603 .23238 .54376 .25236 .52223 .23951 .51466 Metetra
.132 .59 0 r
.23951 .51466 .25236 .52223 .27229 .50078 .25958 .49332 Metetra
0 .53 .018 r
.25958 .49332 .27229 .50078 .29216 .47969 .2796 .47232 Metetra
0 .473 .135 r
.2796 .47232 .29216 .47969 .31195 .45922 .29954 .45191 Metetra
0 .417 .219 r
.29954 .45191 .31195 .45922 .33167 .43957 .31941 .43231 Metetra
0 .366 .274 r
.31941 .43231 .33167 .43957 .35131 .42093 .33921 .41369 Metetra
0 .319 .303 r
.33921 .41369 .35131 .42093 .37089 .40347 .35893 .39622 Metetra
0 .239 .277 r
.35893 .39622 .37089 .40347 .39042 .38729 .37861 .38004 Metetra
0 .169 .24 r
.37861 .38004 .39042 .38729 .40993 .37251 .39826 .36523 Metetra
0 .12 .209 r
.39826 .36523 .40993 .37251 .42942 .35922 .41789 .3519 Metetra
0 .087 .185 r
.41789 .3519 .42942 .35922 .44894 .34749 .43755 .34012 Metetra
0 .066 .168 r
.43755 .34012 .44894 .34749 .4685 .33736 .45724 .32992 Metetra
0 .055 .157 r
.45724 .32992 .4685 .33736 .48815 .32887 .47702 .32136 Metetra
0 .051 .154 r
.47702 .32136 .48815 .32887 .5079 .32204 .4969 .31444 Metetra
0 .055 .157 r
.4969 .31444 .5079 .32204 .5278 .31687 .51692 .30918 Metetra
0 .066 .168 r
.51692 .30918 .5278 .31687 .54788 .31337 .53711 .30558 Metetra
0 .087 .185 r
.53711 .30558 .54788 .31337 .56817 .31151 .55752 .3036 Metetra
0 .12 .209 r
.55752 .3036 .56817 .31151 .58871 .31125 .57817 .30321 Metetra
0 .169 .24 r
.57817 .30321 .58871 .31125 .60954 .31254 .59911 .30435 Metetra
0 .239 .277 r
.59911 .30435 .60954 .31254 .63068 .3153 .62035 .30695 Metetra
0 .319 .303 r
.62035 .30695 .63068 .3153 .65217 .31944 .64195 .31092 Metetra
0 .366 .274 r
.64195 .31092 .65217 .31944 .67404 .32485 .66391 .31613 Metetra
0 .417 .219 r
.66391 .31613 .67404 .32485 .69631 .33137 .68628 .32244 Metetra
0 .473 .135 r
.68628 .32244 .69631 .33137 .71899 .33884 .70906 .32967 Metetra
0 .53 .018 r
.70906 .32967 .71899 .33884 .74211 .34705 .73227 .33761 Metetra
.132 .59 0 r
.73227 .33761 .74211 .34705 .76567 .35574 .75592 .34599 Metetra
.315 .65 0 r
.75592 .34599 .76567 .35574 .78965 .36461 .78 .35453 Metetra
.528 .71 0 r
.78 .35453 .78965 .36461 .81405 .37333 .80448 .36288 Metetra
.763 .768 0 r
.80448 .36288 .81405 .37333 .83882 .3815 .82934 .37062 Metetra
.781 .742 0 r
.16565 .57007 .17918 .57752 .19927 .55712 .18585 .55001 Metetra
.584 .725 0 r
.18585 .55001 .19927 .55712 .21939 .53603 .2061 .52923 Metetra
.369 .666 0 r
.2061 .52923 .21939 .53603 .23951 .51466 .22635 .5081 Metetra
.182 .607 0 r
.22635 .5081 .23951 .51466 .25958 .49332 .24657 .48697 Metetra
.025 .549 0 r
.24657 .48697 .25958 .49332 .2796 .47232 .26674 .46613 Metetra
0 .492 .099 r
.26674 .46613 .2796 .47232 .29954 .45191 .28684 .44585 Metetra
0 .438 .191 r
.28684 .44585 .29954 .45191 .31941 .43231 .30686 .42634 Metetra
0 .387 .254 r
.30686 .42634 .31941 .43231 .33921 .41369 .32681 .4078 Metetra
0 .341 .292 r
.32681 .4078 .33921 .41369 .35893 .39622 .3467 .39037 Metetra
0 .289 .299 r
.3467 .39037 .35893 .39622 .37861 .38004 .36653 .37421 Metetra
0 .213 .263 r
.36653 .37421 .37861 .38004 .39826 .36523 .38633 .3594 Metetra
0 .158 .233 r
.38633 .3594 .39826 .36523 .41789 .3519 .40612 .34606 Metetra
0 .12 .209 r
.40612 .34606 .41789 .3519 .43755 .34012 .42592 .33423 Metetra
0 .096 .192 r
.42592 .33423 .43755 .34012 .45724 .32992 .44576 .32399 Metetra
0 .082 .182 r
.44576 .32399 .45724 .32992 .47702 .32136 .46567 .31535 Metetra
0 .078 .178 r
.46567 .31535 .47702 .32136 .4969 .31444 .48568 .30835 Metetra
0 .082 .182 r
.48568 .30835 .4969 .31444 .51692 .30918 .50584 .303 Metetra
0 .096 .192 r
.50584 .303 .51692 .30918 .53711 .30558 .52616 .29927 Metetra
0 .12 .209 r
.52616 .29927 .53711 .30558 .55752 .3036 .5467 .29716 Metetra
0 .158 .233 r
.5467 .29716 .55752 .3036 .57817 .30321 .56747 .29662 Metetra
0 .213 .263 r
.56747 .29662 .57817 .30321 .59911 .30435 .58852 .29759 Metetra
0 .289 .299 r
.58852 .29759 .59911 .30435 .62035 .30695 .60989 .3 Metetra
0 .341 .292 r
.60989 .3 .62035 .30695 .64195 .31092 .63159 .30375 Metetra
0 .387 .254 r
.63159 .30375 .64195 .31092 .66391 .31613 .65367 .30872 Metetra
0 .438 .191 r
.65367 .30872 .66391 .31613 .68628 .32244 .67614 .31475 Metetra
0 .492 .099 r
.67614 .31475 .68628 .32244 .70906 .32967 .69903 .32168 Metetra
.025 .549 0 r
.69903 .32168 .70906 .32967 .73227 .33761 .72234 .32927 Metetra
.182 .607 0 r
.72234 .32927 .73227 .33761 .75592 .34599 .74609 .33726 Metetra
.369 .666 0 r
.74609 .33726 .75592 .34599 .78 .35453 .77026 .34537 Metetra
.584 .725 0 r
.77026 .34537 .78 .35453 .80448 .36288 .79484 .35322 Metetra
.781 .742 0 r
.79484 .35322 .80448 .36288 .82934 .37062 .81978 .36041 Metetra
.797 .702 0 r
.15182 .56321 .16565 .57007 .18585 .55001 .17212 .54363 Metetra
.657 .743 0 r
.17212 .54363 .18585 .55001 .2061 .52923 .19249 .52325 Metetra
.44 .686 0 r
.19249 .52325 .2061 .52923 .22635 .5081 .21288 .50247 Metetra
.247 .629 0 r
.21288 .50247 .22635 .5081 .24657 .48697 .23324 .48164 Metetra
.084 .572 0 r
.23324 .48164 .24657 .48697 .26674 .46613 .25356 .46105 Metetra
0 .517 .048 r
.25356 .46105 .26674 .46613 .28684 .44585 .27382 .44096 Metetra
0 .464 .15 r
.27382 .44096 .28684 .44585 .30686 .42634 .294 .42161 Metetra
0 .414 .223 r
.294 .42161 .30686 .42634 .32681 .4078 .31411 .40319 Metetra
0 .369 .271 r
.31411 .40319 .32681 .4078 .3467 .39037 .33416 .38586 Metetra
0 .328 .299 r
.33416 .38586 .3467 .39037 .36653 .37421 .35416 .36975 Metetra
0 .274 .293 r
.35416 .36975 .36653 .37421 .38633 .3594 .37412 .35497 Metetra
0 .213 .263 r
.37412 .35497 .38633 .3594 .40612 .34606 .39406 .34163 Metetra
0 .169 .24 r
.39406 .34163 .40612 .34606 .42592 .33423 .41402 .32979 Metetra
0 .141 .223 r
.41402 .32979 .42592 .33423 .44576 .32399 .43402 .3195 Metetra
0 .125 .213 r
.43402 .3195 .44576 .32399 .46567 .31535 .45408 .31081 Metetra
0 .12 .209 r
.45408 .31081 .46567 .31535 .48568 .30835 .47424 .30372 Metetra
0 .125 .213 r
.47424 .30372 .48568 .30835 .50584 .303 .49454 .29826 Metetra
0 .141 .223 r
.49454 .29826 .50584 .303 .52616 .29927 .51501 .29441 Metetra
0 .169 .24 r
.51501 .29441 .52616 .29927 .5467 .29716 .53568 .29215 Metetra
0 .213 .263 r
.53568 .29215 .5467 .29716 .56747 .29662 .55659 .29143 Metetra
0 .274 .293 r
.55659 .29143 .56747 .29662 .58852 .29759 .57777 .2922 Metetra
0 .328 .299 r
.57777 .2922 .58852 .29759 .60989 .3 .59926 .29438 Metetra
0 .369 .271 r
.59926 .29438 .60989 .3 .63159 .30375 .62109 .29787 Metetra
0 .414 .223 r
.62109 .29787 .63159 .30375 .65367 .30872 .64329 .30255 Metetra
0 .464 .15 r
.64329 .30255 .65367 .30872 .67614 .31475 .66588 .30825 Metetra
0 .517 .048 r
.66588 .30825 .67614 .31475 .69903 .32168 .68888 .31479 Metetra
.084 .572 0 r
.68888 .31479 .69903 .32168 .72234 .32927 .7123 .32195 Metetra
.247 .629 0 r
.7123 .32195 .72234 .32927 .74609 .33726 .73615 .32946 Metetra
.44 .686 0 r
.73615 .32946 .74609 .33726 .77026 .34537 .76042 .33702 Metetra
.657 .743 0 r
.76042 .33702 .77026 .34537 .79484 .35322 .78509 .34426 Metetra
.797 .702 0 r
.78509 .34426 .79484 .35322 .81978 .36041 .81012 .35076 Metetra
.815 .652 0 r
.13771 .55681 .15182 .56321 .17212 .54363 .1581 .53784 Metetra
.747 .764 0 r
.1581 .53784 .17212 .54363 .19249 .52325 .17857 .518 Metetra
.528 .71 0 r
.17857 .518 .19249 .52325 .21288 .50247 .19908 .49768 Metetra
.331 .655 0 r
.19908 .49768 .21288 .50247 .23324 .48164 .21959 .47724 Metetra
.16 .6 0 r
.21959 .47724 .23324 .48164 .25356 .46105 .24005 .45698 Metetra
.019 .546 0 r
.24005 .45698 .25356 .46105 .27382 .44096 .26047 .43717 Metetra
0 .495 .093 r
.26047 .43717 .27382 .44096 .294 .42161 .28081 .41804 Metetra
0 .447 .177 r
.28081 .41804 .294 .42161 .31411 .40319 .30109 .39979 Metetra
0 .403 .237 r
.30109 .39979 .31411 .40319 .33416 .38586 .32131 .38259 Metetra
0 .363 .276 r
.32131 .38259 .33416 .38586 .35416 .36975 .34147 .36658 Metetra
0 .328 .299 r
.34147 .36658 .35416 .36975 .37412 .35497 .3616 .35187 Metetra
0 .289 .299 r
.3616 .35187 .37412 .35497 .39406 .34163 .38172 .33856 Metetra
0 .239 .277 r
.38172 .33856 .39406 .34163 .41402 .32979 .40184 .32672 Metetra
0 .206 .26 r
.40184 .32672 .41402 .32979 .43402 .3195 .422 .3164 Metetra
0 .187 .25 r
.422 .3164 .43402 .3195 .45408 .31081 .44223 .30765 Metetra
0 .181 .247 r
.44223 .30765 .45408 .31081 .47424 .30372 .46255 .30048 Metetra
0 .187 .25 r
.46255 .30048 .47424 .30372 .49454 .29826 .48301 .29491 Metetra
0 .206 .26 r
.48301 .29491 .49454 .29826 .51501 .29441 .50363 .29092 Metetra
0 .239 .277 r
.50363 .29092 .51501 .29441 .53568 .29215 .52445 .28849 Metetra
0 .289 .299 r
.52445 .28849 .53568 .29215 .55659 .29143 .54551 .28757 Metetra
0 .328 .299 r
.54551 .28757 .55659 .29143 .57777 .2922 .56683 .28811 Metetra
0 .363 .276 r
.56683 .28811 .57777 .2922 .59926 .29438 .58846 .29003 Metetra
0 .403 .237 r
.58846 .29003 .59926 .29438 .62109 .29787 .61043 .29321 Metetra
0 .447 .177 r
.61043 .29321 .62109 .29787 .64329 .30255 .63276 .29753 Metetra
0 .495 .093 r
.63276 .29753 .64329 .30255 .66588 .30825 .65547 .30283 Metetra
.019 .546 0 r
.65547 .30283 .66588 .30825 .68888 .31479 .67859 .30891 Metetra
.16 .6 0 r
.67859 .30891 .68888 .31479 .7123 .32195 .70213 .31555 Metetra
.331 .655 0 r
.70213 .31555 .7123 .32195 .73615 .32946 .72609 .32248 Metetra
.528 .71 0 r
.72609 .32248 .73615 .32946 .76042 .33702 .75046 .32938 Metetra
.747 .764 0 r
.75046 .32938 .76042 .33702 .78509 .34426 .77522 .33588 Metetra
.815 .652 0 r
.77522 .33588 .78509 .34426 .81012 .35076 .80033 .34154 Metetra
.836 .593 0 r
.12331 .55072 .13771 .55681 .1581 .53784 .14377 .53251 Metetra
.788 .724 0 r
.14377 .53251 .1581 .53784 .17857 .518 .16434 .51333 Metetra
.633 .737 0 r
.16434 .51333 .17857 .518 .19908 .49768 .18496 .49359 Metetra
.432 .684 0 r
.18496 .49359 .19908 .49768 .21959 .47724 .2056 .47364 Metetra
.255 .632 0 r
.2056 .47364 .21959 .47724 .24005 .45698 .22621 .4538 Metetra
.105 .58 0 r
.22621 .4538 .24005 .45698 .26047 .43717 .24677 .43434 Metetra
0 .531 .018 r
.24677 .43434 .26047 .43717 .28081 .41804 .26728 .41551 Metetra
0 .484 .114 r
.26728 .41551 .28081 .41804 .30109 .39979 .28773 .3975 Metetra
0 .441 .186 r
.28773 .3975 .30109 .39979 .32131 .38259 .30812 .38049 Metetra
0 .403 .237 r
.30812 .38049 .32131 .38259 .34147 .36658 .32846 .36461 Metetra
0 .369 .271 r
.32846 .36461 .34147 .36658 .3616 .35187 .34877 .35 Metetra
0 .341 .292 r
.34877 .35 .3616 .35187 .38172 .33856 .36906 .33675 Metetra
0 .319 .303 r
.36906 .33675 .38172 .33856 .40184 .32672 .38936 .32492 Metetra
0 .296 .303 r
.38936 .32492 .40184 .32672 .422 .3164 .4097 .31459 Metetra
0 .274 .293 r
.4097 .31459 .422 .3164 .44223 .30765 .4301 .30579 Metetra
0 .267 .29 r
.4301 .30579 .44223 .30765 .46255 .30048 .45059 .29854 Metetra
0 .274 .293 r
.45059 .29854 .46255 .30048 .48301 .29491 .47122 .29285 Metetra
0 .296 .303 r
.47122 .29285 .48301 .29491 .50363 .29092 .492 .28871 Metetra
0 .319 .303 r
.492 .28871 .50363 .29092 .52445 .28849 .51298 .28609 Metetra
0 .341 .292 r
.51298 .28609 .52445 .28849 .54551 .28757 .5342 .28495 Metetra
0 .369 .271 r
.5342 .28495 .54551 .28757 .56683 .28811 .55568 .28522 Metetra
0 .403 .237 r
.55568 .28522 .56683 .28811 .58846 .29003 .57746 .28682 Metetra
0 .441 .186 r
.57746 .28682 .58846 .29003 .61043 .29321 .59957 .28964 Metetra
0 .484 .114 r
.59957 .28964 .61043 .29321 .63276 .29753 .62204 .29355 Metetra
0 .531 .018 r
.62204 .29355 .63276 .29753 .65547 .30283 .64489 .29837 Metetra
.105 .58 0 r
.64489 .29837 .65547 .30283 .67859 .30891 .66814 .30392 Metetra
.255 .632 0 r
.66814 .30392 .67859 .30891 .70213 .31555 .6918 .30995 Metetra
.432 .684 0 r
.6918 .30995 .70213 .31555 .72609 .32248 .71587 .31619 Metetra
.633 .737 0 r
.71587 .31619 .72609 .32248 .75046 .32938 .74035 .3223 Metetra
.788 .724 0 r
.74035 .3223 .75046 .32938 .77522 .33588 .7652 .32791 Metetra
.836 .593 0 r
.7652 .32791 .77522 .33588 .80033 .34154 .7904 .3326 Metetra
.859 .526 0 r
.10863 .54476 .12331 .55072 .14377 .53251 .12914 .52745 Metetra
.814 .657 0 r
.12914 .52745 .14377 .53251 .16434 .51333 .14978 .50908 Metetra
.755 .766 0 r
.14978 .50908 .16434 .51333 .18496 .49359 .17051 .49003 Metetra
.552 .716 0 r
.17051 .49003 .18496 .49359 .2056 .47364 .19126 .47069 Metetra
.369 .666 0 r
.19126 .47069 .2056 .47364 .22621 .4538 .21201 .45137 Metetra
.211 .617 0 r
.21201 .45137 .22621 .4538 .24677 .43434 .23273 .43235 Metetra
.077 .57 0 r
.23273 .43235 .24677 .43434 .26728 .41551 .2534 .41389 Metetra
0 .525 .03 r
.2534 .41389 .26728 .41551 .28773 .3975 .27402 .39618 Metetra
0 .484 .114 r
.27402 .39618 .28773 .3975 .30812 .38049 .29458 .37941 Metetra
0 .447 .177 r
.29458 .37941 .30812 .38049 .32846 .36461 .31511 .36372 Metetra
0 .414 .223 r
.31511 .36372 .32846 .36461 .34877 .35 .3356 .34924 Metetra
0 .387 .254 r
.3356 .34924 .34877 .35 .36906 .33675 .35607 .33607 Metetra
0 .366 .274 r
.35607 .33607 .36906 .33675 .38936 .32492 .37656 .32429 Metetra
0 .35 .286 r
.37656 .32429 .38936 .32492 .4097 .31459 .39708 .31396 Metetra
0 .341 .292 r
.39708 .31396 .4097 .31459 .4301 .30579 .41766 .30511 Metetra
0 .338 .294 r
.41766 .30511 .4301 .30579 .45059 .29854 .43834 .29778 Metetra
0 .341 .292 r
.43834 .29778 .45059 .29854 .47122 .29285 .45914 .29197 Metetra
0 .35 .286 r
.45914 .29197 .47122 .29285 .492 .28871 .4801 .28766 Metetra
0 .366 .274 r
.4801 .28766 .492 .28871 .51298 .28609 .50126 .28483 Metetra
0 .387 .254 r
.50126 .28483 .51298 .28609 .5342 .28495 .52264 .28343 Metetra
0 .414 .223 r
.52264 .28343 .5342 .28495 .55568 .28522 .54429 .2834 Metetra
0 .447 .177 r
.54429 .2834 .55568 .28522 .57746 .28682 .56623 .28464 Metetra
0 .484 .114 r
.56623 .28464 .57746 .28682 .59957 .28964 .5885 .28704 Metetra
0 .525 .03 r
.5885 .28704 .59957 .28964 .62204 .29355 .61112 .29047 Metetra
.077 .57 0 r
.61112 .29047 .62204 .29355 .64489 .29837 .63412 .29474 Metetra
.211 .617 0 r
.63412 .29474 .64489 .29837 .66814 .30392 .6575 .29966 Metetra
.369 .666 0 r
.6575 .29966 .66814 .30392 .6918 .30995 .6813 .30498 Metetra
.552 .716 0 r
.6813 .30498 .6918 .30995 .71587 .31619 .70549 .3104 Metetra
.755 .766 0 r
.70549 .3104 .71587 .31619 .74035 .3223 .73007 .3156 Metetra
.814 .657 0 r
.73007 .3156 .74035 .3223 .7652 .32791 .75502 .32019 Metetra
.859 .526 0 r
.75502 .32019 .7652 .32791 .7904 .3326 .78029 .32372 Metetra
.882 .452 0 r
.0937 .5387 .10863 .54476 .12914 .52745 .11423 .52246 Metetra
.841 .58 0 r
.11423 .52246 .12914 .52745 .14978 .50908 .13493 .50503 Metetra
.797 .702 0 r
.13493 .50503 .14978 .50908 .17051 .49003 .15574 .48682 Metetra
.69 .751 0 r
.15574 .48682 .17051 .49003 .19126 .47069 .1766 .4682 Metetra
.504 .704 0 r
.1766 .4682 .19126 .47069 .21201 .45137 .19747 .4495 Metetra
.338 .657 0 r
.19747 .4495 .21201 .45137 .23273 .43235 .21833 .43102 Metetra
.196 .612 0 r
.21833 .43102 .23273 .43235 .2534 .41389 .23916 .41301 Metetra
.077 .57 0 r
.23916 .41301 .2534 .41389 .27402 .39618 .25995 .39567 Metetra
0 .531 .018 r
.25995 .39567 .27402 .39618 .29458 .37941 .28069 .3792 Metetra
0 .495 .093 r
.28069 .3792 .29458 .37941 .31511 .36372 .30139 .36375 Metetra
0 .464 .15 r
.30139 .36375 .31511 .36372 .3356 .34924 .32207 .34945 Metetra
0 .438 .191 r
.32207 .34945 .3356 .34924 .35607 .33607 .34274 .3364 Metetra
0 .417 .219 r
.34274 .3364 .35607 .33607 .37656 .32429 .36342 .32469 Metetra
0 .403 .237 r
.36342 .32469 .37656 .32429 .39708 .31396 .38413 .31437 Metetra
0 .393 .247 r
.38413 .31437 .39708 .31396 .41766 .30511 .40491 .30549 Metetra
0 .39 .25 r
.40491 .30549 .41766 .30511 .43834 .29778 .42577 .29807 Metetra
0 .393 .247 r
.42577 .29807 .43834 .29778 .45914 .29197 .44677 .29212 Metetra
0 .403 .237 r
.44677 .29212 .45914 .29197 .4801 .28766 .46792 .28763 Metetra
0 .417 .219 r
.46792 .28763 .4801 .28766 .50126 .28483 .48926 .28456 Metetra
0 .438 .191 r
.48926 .28456 .50126 .28483 .52264 .28343 .51082 .28288 Metetra
0 .464 .15 r
.51082 .28288 .52264 .28343 .54429 .2834 .53265 .2825 Metetra
0 .495 .093 r
.53265 .2825 .54429 .2834 .56623 .28464 .55476 .28333 Metetra
0 .531 .018 r
.55476 .28333 .56623 .28464 .5885 .28704 .5772 .28525 Metetra
.077 .57 0 r
.5772 .28525 .5885 .28704 .61112 .29047 .59998 .28812 Metetra
.196 .612 0 r
.59998 .28812 .61112 .29047 .63412 .29474 .62313 .29176 Metetra
.338 .657 0 r
.62313 .29176 .63412 .29474 .6575 .29966 .64666 .29595 Metetra
.504 .704 0 r
.64666 .29595 .6575 .29966 .6813 .30498 .67059 .30043 Metetra
.69 .751 0 r
.67059 .30043 .6813 .30498 .70549 .3104 .6949 .30492 Metetra
.797 .702 0 r
.6949 .30492 .70549 .3104 .73007 .3156 .7196 .30906 Metetra
.841 .58 0 r
.7196 .30906 .73007 .3156 .75502 .32019 .74464 .31246 Metetra
.882 .452 0 r
.74464 .31246 .75502 .32019 .78029 .32372 .76999 .31467 Metetra
.904 .374 0 r
.07854 .53228 .0937 .5387 .11423 .52246 .09906 .51728 Metetra
.868 .495 0 r
.09906 .51728 .11423 .52246 .13493 .50503 .11978 .50095 Metetra
.828 .616 0 r
.11978 .50095 .13493 .50503 .15574 .48682 .14065 .48371 Metetra
.786 .729 0 r
.14065 .48371 .15574 .48682 .1766 .4682 .1616 .46595 Metetra
.657 .743 0 r
.1616 .46595 .1766 .4682 .19747 .4495 .18259 .44799 Metetra
.488 .699 0 r
.18259 .44799 .19747 .4495 .21833 .43102 .20358 .43014 Metetra
.338 .657 0 r
.20358 .43014 .21833 .43102 .23916 .41301 .22456 .41267 Metetra
.211 .617 0 r
.22456 .41267 .23916 .41301 .25995 .39567 .24551 .39578 Metetra
.104 .58 0 r
.24551 .39578 .25995 .39567 .28069 .3792 .26643 .37968 Metetra
.019 .546 0 r
.26643 .37968 .28069 .3792 .30139 .36375 .28732 .36452 Metetra
0 .517 .048 r
.28732 .36452 .30139 .36375 .32207 .34945 .30819 .35044 Metetra
0 .492 .099 r
.30819 .35044 .32207 .34945 .34274 .3364 .32905 .33755 Metetra
0 .473 .135 r
.32905 .33755 .34274 .3364 .36342 .32469 .34992 .32593 Metetra
0 .458 .159 r
.34992 .32593 .36342 .32469 .38413 .31437 .37084 .31564 Metetra
0 .45 .173 r
.37084 .31564 .38413 .31437 .40491 .30549 .39181 .30673 Metetra
0 .447 .177 r
.39181 .30673 .40491 .30549 .42577 .29807 .41288 .29923 Metetra
0 .45 .173 r
.41288 .29923 .42577 .29807 .44677 .29212 .43407 .29314 Metetra
0 .458 .159 r
.43407 .29314 .44677 .29212 .46792 .28763 .45542 .28844 Metetra
0 .473 .135 r
.45542 .28844 .46792 .28763 .48926 .28456 .47696 .28512 Metetra
0 .492 .099 r
.47696 .28512 .48926 .28456 .51082 .28288 .49872 .2831 Metetra
0 .517 .048 r
.49872 .2831 .51082 .28288 .53265 .2825 .52073 .28232 Metetra
.019 .546 0 r
.52073 .28232 .53265 .2825 .55476 .28333 .54303 .28268 Metetra
.104 .58 0 r
.54303 .28268 .55476 .28333 .5772 .28525 .56564 .28406 Metetra
.211 .617 0 r
.56564 .28406 .5772 .28525 .59998 .28812 .58859 .28629 Metetra
.338 .657 0 r
.58859 .28629 .59998 .28812 .62313 .29176 .6119 .2892 Metetra
.488 .699 0 r
.6119 .2892 .62313 .29176 .64666 .29595 .63559 .29255 Metetra
.657 .743 0 r
.63559 .29255 .64666 .29595 .67059 .30043 .65966 .29609 Metetra
.786 .729 0 r
.65966 .29609 .67059 .30043 .6949 .30492 .6841 .2995 Metetra
.828 .616 0 r
.6841 .2995 .6949 .30492 .7196 .30906 .7089 .30244 Metetra
.868 .495 0 r
.7089 .30244 .7196 .30906 .74464 .31246 .73404 .30448 Metetra
.904 .374 0 r
.73404 .30448 .74464 .31246 .76999 .31467 .75946 .30518 Metetra
.926 .296 0 r
.06319 .5252 .07854 .53228 .09906 .51728 .08366 .51162 Metetra
.895 .406 0 r
.08366 .51162 .09906 .51728 .11978 .50095 .10438 .49656 Metetra
.86 .522 0 r
.10438 .49656 .11978 .50095 .14065 .48371 .12528 .48044 Metetra
.822 .634 0 r
.12528 .48044 .14065 .48371 .1616 .46595 .1463 .46366 Metetra
.782 .738 0 r
.1463 .46366 .1616 .46595 .18259 .44799 .16738 .44657 Metetra
.657 .743 0 r
.16738 .44657 .18259 .44799 .20358 .43014 .18849 .42947 Metetra
.504 .704 0 r
.18849 .42947 .20358 .43014 .22456 .41267 .20961 .41263 Metetra
.369 .666 0 r
.20961 .41263 .22456 .41267 .24551 .39578 .23072 .39628 Metetra
.255 .632 0 r
.23072 .39628 .24551 .39578 .26643 .37968 .2518 .38062 Metetra
.16 .6 0 r
.2518 .38062 .26643 .37968 .28732 .36452 .27287 .36581 Metetra
.084 .572 0 r
.27287 .36581 .28732 .36452 .30819 .35044 .29393 .352 Metetra
.025 .549 0 r
.29393 .352 .30819 .35044 .32905 .33755 .31499 .3393 Metetra
0 .53 .018 r
.31499 .3393 .32905 .33755 .34992 .32593 .33607 .3278 Metetra
0 .517 .048 r
.33607 .3278 .34992 .32593 .37084 .31564 .35719 .31757 Metetra
0 .509 .065 r
.35719 .31757 .37084 .31564 .39181 .30673 .37837 .30864 Metetra
0 .506 .071 r
.37837 .30864 .39181 .30673 .41288 .29923 .39965 .30105 Metetra
0 .509 .065 r
.39965 .30105 .41288 .29923 .43407 .29314 .42105 .29481 Metetra
0 .517 .048 r
.42105 .29481 .43407 .29314 .45542 .28844 .4426 .28989 Metetra
0 .53 .018 r
.4426 .28989 .45542 .28844 .47696 .28512 .46435 .28627 Metetra
.025 .549 0 r
.46435 .28627 .47696 .28512 .49872 .2831 .48631 .28388 Metetra
.084 .572 0 r
.48631 .28388 .49872 .2831 .52073 .28232 .50852 .28266 Metetra
.16 .6 0 r
.50852 .28266 .52073 .28232 .54303 .28268 .53101 .28248 Metetra
.255 .632 0 r
.53101 .28248 .54303 .28268 .56564 .28406 .55381 .28323 Metetra
.369 .666 0 r
.55381 .28323 .56564 .28406 .58859 .28629 .57694 .28474 Metetra
.504 .704 0 r
.57694 .28474 .58859 .28629 .6119 .2892 .60042 .28681 Metetra
.657 .743 0 r
.60042 .28681 .6119 .2892 .63559 .29255 .62427 .28921 Metetra
.782 .738 0 r
.62427 .28921 .63559 .29255 .65966 .29609 .64848 .29166 Metetra
.822 .634 0 r
.64848 .29166 .65966 .29609 .6841 .2995 .67305 .29386 Metetra
.86 .522 0 r
.67305 .29386 .6841 .2995 .7089 .30244 .69797 .29542 Metetra
.895 .406 0 r
.69797 .29542 .7089 .30244 .73404 .30448 .72319 .29593 Metetra
.926 .296 0 r
.72319 .29593 .73404 .30448 .75946 .30518 .74867 .29491 Metetra
.946 .223 0 r
.0477 .51711 .06319 .5252 .08366 .51162 .06807 .50514 Metetra
.92 .318 0 r
.06807 .50514 .08366 .51162 .10438 .49656 .08875 .49152 Metetra
.89 .423 0 r
.08875 .49152 .10438 .49656 .12528 .48044 .10965 .47669 Metetra
.857 .531 0 r
.10965 .47669 .12528 .48044 .1463 .46366 .13071 .46105 Metetra
.822 .634 0 r
.13071 .46105 .1463 .46366 .16738 .44657 .15186 .44495 Metetra
.786 .729 0 r
.15186 .44495 .16738 .44657 .18849 .42947 .17307 .42871 Metetra
.69 .751 0 r
.17307 .42871 .18849 .42947 .20961 .41263 .19432 .41261 Metetra
.552 .716 0 r
.19432 .41261 .20961 .41263 .23072 .39628 .21557 .39689 Metetra
.432 .684 0 r
.21557 .39689 .23072 .39628 .2518 .38062 .23682 .38175 Metetra
.331 .655 0 r
.23682 .38175 .2518 .38062 .27287 .36581 .25807 .36736 Metetra
.247 .629 0 r
.25807 .36736 .27287 .36581 .29393 .352 .27931 .35388 Metetra
.182 .607 0 r
.27931 .35388 .29393 .352 .31499 .3393 .30057 .34142 Metetra
.132 .59 0 r
.30057 .34142 .31499 .3393 .33607 .3278 .32185 .33007 Metetra
.098 .577 0 r
.32185 .33007 .33607 .3278 .35719 .31757 .34318 .3199 Metetra
.077 .57 0 r
.34318 .3199 .35719 .31757 .37837 .30864 .36457 .31097 Metetra
.071 .567 0 r
.36457 .31097 .37837 .30864 .39965 .30105 .38607 .30329 Metetra
.077 .57 0 r
.38607 .30329 .39965 .30105 .42105 .29481 .40768 .29688 Metetra
.098 .577 0 r
.40768 .29688 .42105 .29481 .4426 .28989 .42945 .29172 Metetra
.132 .59 0 r
.42945 .29172 .4426 .28989 .46435 .28627 .45141 .28777 Metetra
.182 .607 0 r
.45141 .28777 .46435 .28627 .48631 .28388 .47358 .28497 Metetra
.247 .629 0 r
.47358 .28497 .48631 .28388 .50852 .28266 .496 .28323 Metetra
.331 .655 0 r
.496 .28323 .50852 .28266 .53101 .28248 .51869 .28245 Metetra
.432 .684 0 r
.51869 .28245 .53101 .28248 .55381 .28323 .54168 .28249 Metetra
.552 .716 0 r
.54168 .28249 .55381 .28323 .57694 .28474 .565 .28317 Metetra
.69 .751 0 r
.565 .28317 .57694 .28474 .60042 .28681 .58866 .28429 Metetra
.786 .729 0 r
.58866 .28429 .60042 .28681 .62427 .28921 .61267 .28561 Metetra
.822 .634 0 r
.61267 .28561 .62427 .28921 .64848 .29166 .63703 .28684 Metetra
.857 .531 0 r
.63703 .28684 .64848 .29166 .67305 .29386 .66174 .28765 Metetra
.89 .423 0 r
.66174 .28765 .67305 .29386 .69797 .29542 .68677 .28766 Metetra
.92 .318 0 r
.68677 .28766 .69797 .29542 .72319 .29593 .71208 .28644 Metetra
.946 .223 0 r
.71208 .28644 .72319 .29593 .74867 .29491 .73762 .28351 Metetra
.961 .161 0 r
.03213 .50762 .0477 .51711 .06807 .50514 .05236 .49745 Metetra
.942 .235 0 r
.05236 .49745 .06807 .50514 .08875 .49152 .07295 .48546 Metetra
.918 .325 0 r
.07295 .48546 .08875 .49152 .10965 .47669 .09381 .47208 Metetra
.89 .423 0 r
.09381 .47208 .10965 .47669 .13071 .46105 .11487 .45773 Metetra
.86 .522 0 r
.11487 .45773 .13071 .46105 .15186 .44495 .13607 .44277 Metetra
.828 .616 0 r
.13607 .44277 .15186 .44495 .17307 .42871 .15736 .42753 Metetra
.797 .702 0 r
.15736 .42753 .17307 .42871 .19432 .41261 .17871 .41228 Metetra
.755 .766 0 r
.17871 .41228 .19432 .41261 .21557 .39689 .20009 .39729 Metetra
.633 .737 0 r
.20009 .39729 .21557 .39689 .23682 .38175 .22149 .38275 Metetra
.528 .71 0 r
.22149 .38275 .23682 .38175 .25807 .36736 .2429 .36886 Metetra
.44 .686 0 r
.2429 .36886 .25807 .36736 .27931 .35388 .26433 .35576 Metetra
.369 .666 0 r
.26433 .35576 .27931 .35388 .30057 .34142 .28578 .34358 Metetra
.315 .65 0 r
.28578 .34358 .30057 .34142 .32185 .33007 .30727 .33242 Metetra
.277 .639 0 r
.30727 .33242 .32185 .33007 .34318 .3199 .32881 .32235 Metetra
.255 .632 0 r
.32881 .32235 .34318 .3199 .36457 .31097 .35042 .31342 Metetra
.247 .629 0 r
.35042 .31342 .36457 .31097 .38607 .30329 .37213 .30565 Metetra
.255 .632 0 r
.37213 .30565 .38607 .30329 .40768 .29688 .39397 .29906 Metetra
.277 .639 0 r
.39397 .29906 .40768 .29688 .42945 .29172 .41596 .29363 Metetra
.315 .65 0 r
.41596 .29363 .42945 .29172 .45141 .28777 .43814 .28931 Metetra
.369 .666 0 r
.43814 .28931 .45141 .28777 .47358 .28497 .46053 .28604 Metetra
.44 .686 0 r
.46053 .28604 .47358 .28497 .496 .28323 .48316 .28373 Metetra
.528 .71 0 r
.48316 .28373 .496 .28323 .51869 .28245 .50606 .28226 Metetra
.633 .737 0 r
.50606 .28226 .51869 .28245 .54168 .28249 .52926 .28149 Metetra
.755 .766 0 r
.52926 .28149 .54168 .28249 .565 .28317 .55277 .28124 Metetra
.797 .702 0 r
.55277 .28124 .565 .28317 .58866 .28429 .57661 .28129 Metetra
.828 .616 0 r
.57661 .28129 .58866 .28429 .61267 .28561 .60079 .28138 Metetra
.86 .522 0 r
.60079 .28138 .61267 .28561 .63703 .28684 .62531 .28123 Metetra
.89 .423 0 r
.62531 .28123 .63703 .28684 .66174 .28765 .65014 .28049 Metetra
.918 .325 0 r
.65014 .28049 .66174 .28765 .68677 .28766 .67528 .27876 Metetra
.942 .235 0 r
.67528 .27876 .68677 .28766 .71208 .28644 .70067 .27561 Metetra
.961 .161 0 r
.70067 .27561 .71208 .28644 .73762 .28351 .72626 .27056 Metetra
.972 .117 0 r
.01657 .4963 .03213 .50762 .05236 .49745 .0366 .48813 Metetra
.96 .165 0 r
.0366 .48813 .05236 .49745 .07295 .48546 .05705 .47795 Metetra
.942 .235 0 r
.05705 .47795 .07295 .48546 .09381 .47208 .07782 .46621 Metetra
.92 .318 0 r
.07782 .46621 .09381 .47208 .11487 .45773 .09884 .45332 Metetra
.895 .406 0 r
.09884 .45332 .11487 .45773 .13607 .44277 .12005 .43964 Metetra
.868 .495 0 r
.12005 .43964 .13607 .44277 .15736 .42753 .14139 .42553 Metetra
.841 .58 0 r
.14139 .42553 .15736 .42753 .17871 .41228 .16282 .41126 Metetra
.814 .657 0 r
.16282 .41126 .17871 .41228 .20009 .39729 .18431 .3971 Metetra
.788 .724 0 r
.18431 .3971 .20009 .39729 .22149 .38275 .20584 .38326 Metetra
.746 .764 0 r
.20584 .38326 .22149 .38275 .2429 .36886 .22741 .36994 Metetra
.657 .743 0 r
.22741 .36994 .2429 .36886 .26433 .35576 .24901 .35729 Metetra
.584 .725 0 r
.24901 .35729 .26433 .35576 .28578 .34358 .27065 .34545 Metetra
.528 .71 0 r
.27065 .34545 .28578 .34358 .30727 .33242 .29234 .33451 Metetra
.488 .699 0 r
.29234 .33451 .30727 .33242 .32881 .32235 .31409 .32456 Metetra
.464 .693 0 r
.31409 .32456 .32881 .32235 .35042 .31342 .33591 .31564 Metetra
.456 .691 0 r
.33591 .31564 .35042 .31342 .37213 .30565 .35785 .30778 Metetra
.464 .693 0 r
.35785 .30778 .37213 .30565 .39397 .29906 .37991 .301 Metetra
.488 .699 0 r
.37991 .301 .39397 .29906 .41596 .29363 .40213 .29526 Metetra
.528 .71 0 r
.40213 .29526 .41596 .29363 .43814 .28931 .42453 .29053 Metetra
.584 .725 0 r
.42453 .29053 .43814 .28931 .46053 .28604 .44715 .28673 Metetra
.657 .743 0 r
.44715 .28673 .46053 .28604 .48316 .28373 .47 .28377 Metetra
.746 .764 0 r
.47 .28377 .48316 .28373 .50606 .28226 .49312 .28154 Metetra
.788 .724 0 r
.49312 .28154 .50606 .28226 .52926 .28149 .51653 .27986 Metetra
.814 .657 0 r
.51653 .27986 .52926 .28149 .55277 .28124 .54024 .27856 Metetra
.841 .58 0 r
.54024 .27856 .55277 .28124 .57661 .28129 .56426 .2774 Metetra
.868 .495 0 r
.56426 .2774 .57661 .28129 .60079 .28138 .58861 .27612 Metetra
.895 .406 0 r
.58861 .27612 .60079 .28138 .62531 .28123 .61328 .27442 Metetra
.92 .318 0 r
.61328 .27442 .62531 .28123 .65014 .28049 .63825 .27194 Metetra
.942 .235 0 r
.63825 .27194 .65014 .28049 .67528 .27876 .66349 .26828 Metetra
.96 .165 0 r
.66349 .26828 .67528 .27876 .70067 .27561 .68895 .26299 Metetra
.972 .117 0 r
.68895 .26299 .70067 .27561 .72626 .27056 .71457 .25558 Metetra
.976 .099 0 r
.00111 .48265 .01657 .4963 .0366 .48813 .02087 .47669 Metetra
.972 .117 0 r
.02087 .47669 .0366 .48813 .05705 .47795 .04112 .46852 Metetra
.961 .161 0 r
.04112 .46852 .05705 .47795 .07782 .46621 .06175 .4586 Metetra
.946 .223 0 r
.06175 .4586 .07782 .46621 .09884 .45332 .08269 .44733 Metetra
.926 .296 0 r
.08269 .44733 .09884 .45332 .12005 .43964 .10387 .43511 Metetra
.904 .374 0 r
.10387 .43511 .12005 .43964 .14139 .42553 .12521 .42226 Metetra
.882 .452 0 r
.12521 .42226 .14139 .42553 .16282 .41126 .14669 .4091 Metetra
.859 .526 0 r
.14669 .4091 .16282 .41126 .18431 .3971 .16827 .39589 Metetra
.836 .593 0 r
.16827 .39589 .18431 .3971 .20584 .38326 .18992 .38285 Metetra
.815 .652 0 r
.18992 .38285 .20584 .38326 .22741 .36994 .21162 .37018 Metetra
.797 .702 0 r
.21162 .37018 .22741 .36994 .24901 .35729 .23339 .35806 Metetra
.781 .742 0 r
.23339 .35806 .24901 .35729 .27065 .34545 .2552 .34661 Metetra
.763 .768 0 r
.2552 .34661 .27065 .34545 .29234 .33451 .27708 .33594 Metetra
.722 .758 0 r
.27708 .33594 .29234 .33451 .31409 .32456 .29903 .32613 Metetra
.698 .752 0 r
.29903 .32613 .31409 .32456 .33591 .31564 .32107 .31723 Metetra
.69 .75 0 r
.32107 .31723 .33591 .31564 .35785 .30778 .34323 .30928 Metetra
.698 .752 0 r
.34323 .30928 .35785 .30778 .37991 .301 .36552 .30228 Metetra
.722 .758 0 r
.36552 .30228 .37991 .301 .40213 .29526 .38797 .29621 Metetra
.763 .768 0 r
.38797 .29621 .40213 .29526 .42453 .29053 .4106 .29101 Metetra
.781 .742 0 r
.4106 .29101 .42453 .29053 .44715 .28673 .43344 .28663 Metetra
.797 .702 0 r
.43344 .28663 .44715 .28673 .47 .28377 .45652 .28295 Metetra
.815 .652 0 r
.45652 .28295 .47 .28377 .49312 .28154 .47986 .27984 Metetra
.836 .593 0 r
.47986 .27984 .49312 .28154 .51653 .27986 .50348 .27715 Metetra
.859 .526 0 r
.50348 .27715 .51653 .27986 .54024 .27856 .52739 .27466 Metetra
.882 .452 0 r
.52739 .27466 .54024 .27856 .56426 .2774 .55161 .27216 Metetra
.904 .374 0 r
.55161 .27216 .56426 .2774 .58861 .27612 .57613 .26935 Metetra
.926 .296 0 r
.57613 .26935 .58861 .27612 .61328 .27442 .60095 .26592 Metetra
.946 .223 0 r
.60095 .26592 .61328 .27442 .63825 .27194 .62604 .26151 Metetra
.961 .161 0 r
.62604 .26151 .63825 .27194 .66349 .26828 .65138 .25571 Metetra
.972 .117 0 r
.65138 .25571 .66349 .26828 .68895 .26299 .67691 .24806 Metetra
.976 .099 0 r
.67691 .24806 .68895 .26299 .71457 .25558 .70256 .23806 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.09905 .2309 m
.10374 .23548 L
s
[(-10)] .08965 .22175 1 .97417 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.61174 .03015 m
.6155 .03553 L
s
[(10)] .60423 .01939 .69795 1 Mshowa
.125 Mabswid
.14604 .2125 m
.14882 .2153 L
s
.19392 .19376 m
.19664 .1966 L
s
.24269 .17466 m
.24537 .17754 L
s
.2924 .15519 m
.29503 .15813 L
s
.39471 .11513 m
.39723 .11816 L
s
.44737 .09451 m
.44983 .09759 L
s
.50108 .07348 m
.50347 .07661 L
s
.55586 .05203 m
.55818 .05521 L
s
.0529 .24897 m
.05577 .25167 L
s
.66877 .00782 m
.67095 .0111 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 233.562},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{145., 432.}, {288., 56.}} -> {-0.5784220080805098, \
0.2514653599029323, 0.0035800367244681977, \
0.0035800367244681977}},ExpressionUUID->"930851c3-b045-4b1e-9b37-\
6562f8ab70bd"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"87.6`", " ", "Second"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ComponentNumber", "\[Rule]", "2"}], ",", 
      RowBox[{"Energy", "\[Rule]", "100.`100."}], ",", 
      RowBox[{
      "Offset", "\[Rule]", 
       "155.232506248847761379305938354363980526609162928548052945496238317578\
723695021302672111530991186568523004075`97.94170503318654"}], ",", 
      RowBox[{"OpticalLengthFunction", "\[Rule]", 
       TagBox[
        RowBox[{"CompiledFunction", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#1", "\[Equal]", "0"}], "&&", 
             RowBox[{"#2", "\[Equal]", "0"}]}], ",", 
            "155.2324515677627310951283801273301414454985648440678835079251908\
18610684184786449747318424891019189`84.96526438775636", ",", 
            RowBox[{
            "155.2508988570726453956837320936001403579104665190019246993846928\
86448529577538846650008183279346303`85.75702700524849", "-", 
             RowBox[{
             "2.88389727142502815460147434209356362168818283401124959700124620\
5739719460006388036521436`76.89606811354653*^-9", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["#1", "2"], "+", 
                SuperscriptBox["#2", "2"]}], ")"}]}], "+", 
             RowBox[{
             "0.01371211204741918163907299067041164458007184628593011645130901\
3211930180833544591907864374608883`81.39468969297788", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                "0.00620906753284250747650092141725550605611938332103260609476\
83495580559778790344959080642016356320766677413554640145`94.58401161724137", 
                 " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{
             "8.65815982391425704469994136164033123336598994172732363144792317\
410040722401946192180825578`76.94557620799411*^-7", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "-", "0.\
009313601299263761214751382125883259084179074981548909142152524337083966818551\
7438620963024534481150016120331960218`94.58401161724137"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "+", 
                RowBox[{
                "0.00003855251962739894266032806712788912505666394656412475122\
61343953269041599115546332140888247796271563865605031005`94.28298162157739", 
                 " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}]}], ")"}]}], 
             "-", 
             RowBox[{
             "0.00489348232444206214908354011116490094982931986968796030513297\
3818479831569435680611519934680599`80.96212738430674", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{
                "0.01862720259852752242950276425176651816835814996309781828430\
5048674167933637103487724192604906896230003224`94.58401161724137", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "+", 
                RowBox[{
                "0.00005782877944109841399049210069183368758499591984618712683\
92015929903562398673319498211332371694407345798407546508`94.28298162157739", 
                 " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}]}], ")"}]}], 
             "+", 
             RowBox[{
             "6.37851820320707232500940782282128198777282847264323315785857854\
8236769096785953714543024779`78.06995560681887*^-6", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"4", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "-", "0.\
000048190649534248678325410083909861406320829933205155939032667994158630199889\
4432915176110309745339454832006288757`94.28298162157739"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}], "+", 
                RowBox[{
                "1.79531398445817223880553624351331481908703484810904331813355\
4151043016247540663836121000056902780230009273374`94.10689036252174*^-7", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "3"]}]}], ")"}]}], 
             "-", 
             RowBox[{
             "4.34943563202199806263800985319814321939372255990553240727007520\
366503399937029723996860389`76.86521783018696*^-7", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                "0.01862720259852752242950276425176651816835814996309781828430\
5048674167933637103487724192604906896230003224`94.58401161724137", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "-", 
                RowBox[{
                "0.00019276259813699471330164033563944562528331973282062375613\
06719766345207995577731660704441238981357819328025155026`94.28298162157739", 
                 " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}], "+", 
                RowBox[{
                "4.48828496114543059701384060878328704771758712027260829533388\
5377607540618851659590302500142256950575023183435`94.10689036252174*^-7", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "3"]}]}], ")"}]}], 
             "-", 
             RowBox[{
             "0.00015830506194694323280456451157763311799949122157688529693991\
9192564619650583369829625920962368`79.68976640240584", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                "0.03725440519705504485900552850353303633671629992619563656861\
0097348335867274206975448385209813792460006448`94.58401161724137", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "-", 
                RowBox[{
                "0.00028914389720549206995246050345916843792497959923093563419\
60079649517811993366597491056661858472036728992037732539`94.28298162157739", 
                 " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}], "+", 
                RowBox[{
                "5.98437994819390746268512081171104939695678282703014439377851\
3836810054158468879453736666856342600766697577913`94.10689036252174*^-7", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "3"]}]}], ")"}]}]}]}],
            "]"}], ",", "\<\"-CompiledCode-\"\>"}], "]"}],
        False,
        Editable->False]}], ",", 
      RowBox[{"OpticalPathDifference", "\[Rule]", 
       TagBox[
        RowBox[{"CompiledFunction", "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"#1", "\[Equal]", "0"}], "&&", 
             RowBox[{"#2", "\[Equal]", "0"}]}], ",", 
            RowBox[{
            "-", "0.1027839944178274014252387854118065988685798499425518252772\
53699322387659497978934409962681827502`81.73323293788266"}], ",", 
            RowBox[{
            "34.57257185128574507104086322586434455132253844712735693318527983\
0462185183353341911000541649772223`85.05252442378168", "-", 
             RowBox[{
             "5.42085953275381232067946304904805192046650908648731127255873346\
9435562894748849692709464692`80.11207068225917*^-6", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["#1", "2"], "+", 
                SuperscriptBox["#2", "2"]}], ")"}]}], "+", 
             RowBox[{
             "1.53415256799622981129776513339598898253380534942848335856006523\
206780861188408521708571714924402422`81.10619931279086*^-7", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"4", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["#1", "2"], "+", 
                 SuperscriptBox["#2", "2"]}], ")"}], "2"]}], "+", 
             RowBox[{
             "25.7746467056751534569041178015256477069019667028761587430620549\
09643197055534947195233786859223835`84.61274359855912", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                "0.00620906753284250747650092141725550605611938332103260609476\
83495580559778790344959080642016356320766677413554640145`94.58401161724137", 
                 " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}]}], ")"}]}], "-", 
             RowBox[{
             "0.00162747365111170245201126717324066376567029886122694053222705\
3228214362260154034195828619539248`80.16158040944755", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "-", "0.\
009313601299263761214751382125883259084179074981548909142152524337083966818551\
7438620963024534481150016120331960218`94.58401161724137"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "+", 
                RowBox[{
                "0.00003855251962739894266032806712788912505666394656412475122\
61343953269041599115546332140888247796271563865605031005`94.28298162157739", 
                 " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}]}], ")"}]}], 
             "-", 
             RowBox[{
             "9.19827504594372584414199269015958825155887193550368478408453725\
2781638288412933480300629080006006`84.18383851442343", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{
                "0.01862720259852752242950276425176651816835814996309781828430\
5048674167933637103487724192604906896230003224`94.58401161724137", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "+", 
                RowBox[{
                "0.00005782877944109841399049210069183368758499591984618712683\
92015929903562398673319498211332371694407345798407546508`94.28298162157739", 
                 " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}]}], ")"}]}], 
             "+", 
             RowBox[{
             "0.01198969587068998557332595455417534208227975276812637811627552\
3586911220106740514501020725622911`81.27672197512814", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"4", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                 "-", "0.\
000048190649534248678325410083909861406320829933205155939032667994158630199889\
4432915176110309745339454832006288757`94.28298162157739"}], " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}], "+", 
                RowBox[{
                "1.79531398445817223880553624351331481908703484810904331813355\
4151043016247540663836121000056902780230009273374`94.10689036252174*^-7", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "3"]}]}], ")"}]}], 
             "-", 
             RowBox[{
             "0.00081756308872593948545827252879664346229205311276419782091542\
7669861848496122236323302369568805`80.08146262302121", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"2", " ", 
                RowBox[{"ArcTan", "[", 
                 RowBox[{"#1", ",", "#2"}], "]"}]}], "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                "0.01862720259852752242950276425176651816835814996309781828430\
5048674167933637103487724192604906896230003224`94.58401161724137", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "-", 
                RowBox[{
                "0.00019276259813699471330164033563944562528331973282062375613\
06719766345207995577731660704441238981357819328025155026`94.28298162157739", 
                 " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}], "+", 
                RowBox[{
                "4.48828496114543059701384060878328704771758712027260829533388\
5377607540618851659590302500142256950575023183435`94.10689036252174*^-7", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "3"]}]}], ")"}]}], 
             "-", 
             RowBox[{
             "0.29756590591530682858000848040908480826972034130993476868405863\
2640262501096559830123911607630117`82.91450772112995", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{
                "0.03725440519705504485900552850353303633671629992619563656861\
0097348335867274206975448385209813792460006448`94.58401161724137", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["#1", "2"], "+", 
                   SuperscriptBox["#2", "2"]}], ")"}]}], "-", 
                RowBox[{
                "0.00028914389720549206995246050345916843792497959923093563419\
60079649517811993366597491056661858472036728992037732539`94.28298162157739", 
                 " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "2"]}], "+", 
                RowBox[{
                "5.98437994819390746268512081171104939695678282703014439377851\
3836810054158468879453736666856342600766697577913`94.10689036252174*^-7", " ", 
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{
                    SuperscriptBox["#1", "2"], "+", 
                    SuperscriptBox["#2", "2"]}], ")"}], "3"]}]}], ")"}]}]}]}],
            "]"}], ",", "\<\"-CompiledCode-\"\>"}], "]"}],
        False,
        Editable->False]}], ",", 
      RowBox[{"OpticalPathRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "155.23250624884776137930593835436398052660916292854805294549623831757\
8723695021302672111530991186568523004075`97.94170503318654", ",", 
         "155.2596319299072893627460886903983131581657537586283844248841300337\
57431855094160716248026641915708744386461`97.86824855726309"}], "}"}]}], ",", 
      
      RowBox[{"OutputGraphics", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"OpticalLengthFunction", "\[Rule]", 
          RowBox[{"(", 
           TagBox[
            RowBox[{
            "\[SkeletonIndicator]", "SurfaceGraphics", 
             "\[SkeletonIndicator]"}],
            False,
            Editable->False], ")"}]}], ",", 
         RowBox[{"WaveFrontIntensity", "\[Rule]", 
          RowBox[{"(", 
           TagBox[
            RowBox[{
            "\[SkeletonIndicator]", "SurfaceGraphics", 
             "\[SkeletonIndicator]"}],
            False,
            Editable->False], ")"}]}], ",", 
         RowBox[{"OpticalPathDifference", "\[Rule]", 
          RowBox[{"(", 
           TagBox[
            RowBox[{
            "\[SkeletonIndicator]", "SurfaceGraphics", 
             "\[SkeletonIndicator]"}],
            False,
            Editable->False], ")"}]}]}], "}"}]}], ",", 
      RowBox[{"RayBoundary", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "-", "12.\
690848130961540774529783920099831969220066416547840619200370956863771802038538\
526986732335291052173835775`94.88504161290534"}], ",", 
           "12.690848130961540774529783920099831969220066416547840619200370956\
863771802038538526986732335291052173835775`94.88504161290534"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "-", "12.\
690623780688746469834732040116666512021117049454197365912556495965982353840910\
685047474840323996662370812`94.88504161290535"}], ",", 
           "12.690623780688746469834732040116666512021117049454197365912556495\
965982353840910685047474840323996662370812`94.88504161290535"}], "}"}]}], 
        "}"}]}], ",", 
      RowBox[{"RayTracePrecision", "\[Rule]", "100"}], ",", 
      RowBox[{
      "RefractiveIndex", "\[Rule]", 
       "1.00026945123656960044678954120630419914365239859390836686281923187135\
47103645960880847666416701543099632836105995966`100.30102025365451"}], ",", 
      RowBox[{
      "ResidualFitError", "\[Rule]", 
       "0.00335451099048078469460470285062547533192203644186882240560283871702\
4584255281712718408709460256`80.39363950245694"}], ",", 
      RowBox[{"Source", "\[Rule]", "1"}], ",", 
      RowBox[{"SpatialScale", "\[Rule]", "1"}], ",", 
      RowBox[{"SurfaceNumber", "\[Rule]", "1"}], ",", 
      RowBox[{"WaveFrontID", "\[Rule]", "1"}], ",", 
      RowBox[{"WaveFrontIntensity", "\[Rule]", 
       TagBox[
        RowBox[{"InterpolatingFunction", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "17.007735850509498`"}], ",", 
              "17.007735850509498`"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "17.007511500236703`"}], ",", 
              "17.007511500236703`"}], "}"}]}], "}"}], ",", "\<\"<>\"\>"}], 
         "]"}],
        False,
        Editable->False]}], ",", 
      RowBox[{
      "WaveLength", "\[Rule]", 
       "0.53199999999999999999999999999999999999999999999999999999999999999999\
99999999999999999999999999999999999999999999943`100."}], ",", 
      RowBox[{"WaveTilt", "\[Rule]", "WaveTilt"}]}], "}"}], "}"}]}], 
  "}"}]], "Output",ExpressionUUID->"c4f11378-2c2a-44d1-9e18-81b5882c6d94"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussianPlot", "SubsubsectionIcon",ExpressionUUID->"bfe8cf03-f866-47f9-b828-44268815a1e9"],

Cell[TextData[{
 StyleBox["GaussianPlot", "Input"],
 " is used to calculate the diffractive behavior of Gaussian beams through \
space. We now examine how arbitrary precision calculations are made with ",
 StyleBox["GaussianPlot", "Input"],
 ". Here is ",
 StyleBox["RayTracePrecision->50", "Input"],
 "."
}], "Text",ExpressionUUID->"b1abc1af-1551-4905-94b2-12610c1fa741"],

Cell[CellGroupData[{

Cell["\<\
GaussianPlot[{GaussianBeam[.2,4.9], \
Move[Screen[200],300]},RayTracePrecision->50]\
\>", "Input",
 CellLabel->"In[12]:=",ExpressionUUID->"05131e89-ae16-4331-add1-4310f365d64a"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0 0.000727723 [
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -9 -9 ]
[.65873 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .14554 -18 -4.5 ]
[.01131 .14554 0 4.5 ]
[.01131 .29109 -18 -4.5 ]
[.01131 .29109 0 4.5 ]
[.01131 .43663 -18 -4.5 ]
[.01131 .43663 0 4.5 ]
[.01131 .58218 -18 -4.5 ]
[.01131 .58218 0 4.5 ]
[.5 .63053 -44.0625 0 ]
[.5 .63053 44.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .00625 L
s
[(50)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(100)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(150)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(200)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(250)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(300)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .14554 m
.03006 .14554 L
s
[(200)] .01131 .14554 1 0 Mshowa
.02381 .29109 m
.03006 .29109 L
s
[(400)] .01131 .29109 1 0 Mshowa
.02381 .43663 m
.03006 .43663 L
s
[(600)] .01131 .43663 1 0 Mshowa
.02381 .58218 m
.03006 .58218 L
s
[(800)] .01131 .58218 1 0 Mshowa
.125 Mabswid
.02381 .03639 m
.02756 .03639 L
s
.02381 .07277 m
.02756 .07277 L
s
.02381 .10916 m
.02756 .10916 L
s
.02381 .18193 m
.02756 .18193 L
s
.02381 .21832 m
.02756 .21832 L
s
.02381 .2547 m
.02756 .2547 L
s
.02381 .32748 m
.02756 .32748 L
s
.02381 .36386 m
.02756 .36386 L
s
.02381 .40025 m
.02756 .40025 L
s
.02381 .47302 m
.02756 .47302 L
s
.02381 .50941 m
.02756 .50941 L
s
.02381 .54579 m
.02756 .54579 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
93.125 13.000 moveto
(Spot) show
123.125 13.000 moveto
(Size) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
.02381 .00015 m
.09004 .03734 L
.16227 .07791 L
.23011 .11601 L
.29535 .15265 L
.36479 .19165 L
.43164 .22919 L
.50269 .26909 L
.57114 .30754 L
.63699 .34452 L
.70705 .38387 L
.77451 .42175 L
.83937 .45818 L
.90843 .49697 L
.9749 .5343 L
.97619 .53502 L
s
0 0 0 r
gsave
.97619 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 0 m
.97619 .56185 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"From In[12]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{145., 432.}, {602., 426.}} -> {-234.86605698201438, \
2360.0631196271024, 1.3068172782027982, \
5.7008259068115255}},ExpressionUUID->"d3199495-d0f3-47e3-9432-fc17edb12838"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"BeamSpotSizeGraphics", "\[Rule]", 
    RowBox[{"(", 
     TagBox[
      RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
      False,
      Editable->False], ")"}]}], ",", 
   RowBox[{"BeamSpotSizeFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{"#1", "<", "300"}], ",", 
        RowBox[{
        "0.0000691000990203533441385501556545406520738139595984620106709030744\
`50.", " ", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
            "1.257114481390024629366121227821572403225308588460198607845083946\
05`49.69897000433602*^9", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
               "0.081632648188955207927970679642923977274042018817580975044750\
2004967`50.", "+", "#1"}], ")"}], "2"]}]}], ")"}]}]}], ",", 
        RowBox[{"#1", "\[GreaterEqual]", "300"}], ",", 
        RowBox[{
        "0.0000691094079544586665287732696008762051897744596472973719856626684\
`45.98973899457993", " ", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{
            "1.257114481390024629366121227821572403225308588460198607845`45.\
08662780041855*^9", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
               "0.081632648188955207927970679642923977274042018817580975044750\
2010063`49.67339358106304", "+", "#1"}], ")"}], "2"]}]}], ")"}]}]}]}], "]"}], 
      "&"}], ")"}]}], ",", 
   RowBox[{"BeamCurvatureFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{"#1", "<", "300"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
           "0.0816326481889552079279706796429239772740420188175809750447502004\
967`50.", "+", "#1"}], ")"}]}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
           "7.9547250055879845743230522085705663966168478768809401517007830519\
137`49.69897000433602*^-10", "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
              "0.0816326481889552079279706796429239772740420188175809750447502\
004967`50.", "+", "#1"}], ")"}], "2"]}]}], ")"}]}], ",", 
        RowBox[{"#1", "\[GreaterEqual]", "300"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
           "0.0816326481889552079279706796429239772740420188175809750447502010\
063`49.67339358106304", "+", "#1"}], ")"}]}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{
           "7.954725005587984574323052208570566396616847876880940151702`45.\
08662780041855*^-10", "/", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
              "0.0816326481889552079279706796429239772740420188175809750447502\
010063`49.67339358106304", "+", "#1"}], ")"}], "2"]}]}], ")"}]}]}], "]"}], 
      "&"}], ")"}]}], ",", 
   RowBox[{"ComplexBeamParameterFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{"#1", "<", "300"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "0.08163264818895520792797067964292397727404201881758097504475020049\
67`50.", "+", 
           RowBox[{
           "0.0000282041220490693249558434502806876210474319977637918609089648\
731`50.", " ", "\[ImaginaryI]"}]}], ")"}], "-", "#1"}], ",", 
        RowBox[{"#1", "\[GreaterEqual]", "300"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
          "600.081632648188955207927970679642923977274042018817580975044750201\
0063`53.53974002973011", "+", 
           RowBox[{
           "0.0000282041220490693249558434502806876210474319977637918609089673\
564`45.38765779608253", " ", "\[ImaginaryI]"}]}], ")"}], "-", "#1"}]}], "]"}],
       "&"}], ")"}]}], ",", 
   RowBox[{"WaveLength", "\[Rule]", "0.532`"}], ",", 
   RowBox[{"PlotDomain", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "300"}], "}"}]}]}], "}"}]], "Output",
 CellLabel->"Out[12]=",ExpressionUUID->"a6740055-3c05-4eee-ba70-f54d27420480"]
}, Open  ]],

Cell[TextData[{
 "When you use ",
 StyleBox["RayTracePrecision->Infinity", "Input"],
 ", the result is calculated with fractional integers rather than floating \
point numbers."
}], "Text",ExpressionUUID->"c52ea5c3-c409-4bad-b9eb-43ccb339c7f8"],

Cell[CellGroupData[{

Cell["\<\
GaussianPlot[{GaussianBeam[.2,4.9], \
Move[Screen[200],300]},RayTracePrecision->Infinity]\
\>", "Input",
 CellLabel->"In[13]:=",ExpressionUUID->"dda75078-241d-4d7c-9057-0c61f32a937a"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0 0.000727723 [
[.18254 -0.0125 -6 -9 ]
[.18254 -0.0125 6 0 ]
[.34127 -0.0125 -9 -9 ]
[.34127 -0.0125 9 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -9 -9 ]
[.65873 -0.0125 9 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -9 -9 ]
[.97619 -0.0125 9 0 ]
[.01131 .14554 -18 -4.5 ]
[.01131 .14554 0 4.5 ]
[.01131 .29109 -18 -4.5 ]
[.01131 .29109 0 4.5 ]
[.01131 .43663 -18 -4.5 ]
[.01131 .43663 0 4.5 ]
[.01131 .58218 -18 -4.5 ]
[.01131 .58218 0 4.5 ]
[.5 .63053 -44.0625 0 ]
[.5 .63053 44.0625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .00625 L
s
[(50)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(100)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(150)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(200)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(250)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(300)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
.02381 .14554 m
.03006 .14554 L
s
[(200)] .01131 .14554 1 0 Mshowa
.02381 .29109 m
.03006 .29109 L
s
[(400)] .01131 .29109 1 0 Mshowa
.02381 .43663 m
.03006 .43663 L
s
[(600)] .01131 .43663 1 0 Mshowa
.02381 .58218 m
.03006 .58218 L
s
[(800)] .01131 .58218 1 0 Mshowa
.125 Mabswid
.02381 .03639 m
.02756 .03639 L
s
.02381 .07277 m
.02756 .07277 L
s
.02381 .10916 m
.02756 .10916 L
s
.02381 .18193 m
.02756 .18193 L
s
.02381 .21832 m
.02756 .21832 L
s
.02381 .2547 m
.02756 .2547 L
s
.02381 .32748 m
.02756 .32748 L
s
.02381 .36386 m
.02756 .36386 L
s
.02381 .40025 m
.02756 .40025 L
s
.02381 .47302 m
.02756 .47302 L
s
.02381 .50941 m
.02756 .50941 L
s
.02381 .54579 m
.02756 .54579 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -105.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Beam) show
93.125 13.000 moveto
(Spot) show
123.125 13.000 moveto
(Size) show
147.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.039 .916 .04 r
.5 Mabswid
.02381 .00015 m
.09004 .03734 L
.16227 .07791 L
.23011 .11601 L
.29535 .15265 L
.36479 .19165 L
.43164 .22919 L
.50269 .26909 L
.57114 .30754 L
.63699 .34452 L
.70705 .38387 L
.77451 .42175 L
.83937 .45818 L
.90843 .49697 L
.9749 .5343 L
.97619 .53502 L
s
0 0 0 r
gsave
.97619 .5787 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.97619 0 m
.97619 .56185 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 177.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"From In[13]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztm2lsFVUUx6dvKW1ZCgItYJWHS1CDO1GI4lJJlRDc9wV5NMXWBbAUl2Dc
NwTElRAJwS2EqERxicG4xBU17vuuFT/51Y9+qG/unfnPnem5982/79FiQpN2
pvfe3/mfc+69M/fN3Dev2NPZcU2xp6u9WDi1u7i0s6t9WaFtSXepKFvjeTUF
z/O2FTz/vK90GvxRP1P8P553in/I+uU5/yzjn+0tlEVnzajNCu1UbR61CbYJ
tRkba9Udox1uVQdlo8/88UKjJcSsC+PxsmaxramluNkhmnVZiouOp0QtxSqH
Xm2yODwS7ox1RMX5NFof29JrTxTKBtIncQv59A40DbUDzZSYZGGUrvs/Zd01
kYjIpc7LpcfVPMyUnS22Ya4uQTkHXq0LTi6ZJ5eozkk1ZrO+TNVKlso5MZES
cgzqVqHK0sOT/GN0s+AupMYoSCVW7SwPs2VZWax1oVW8cKtsJ+7aLUJSpHv6
BMFyf2uqVYo1RUZgU60LlOiU9OcqvH8MA/sl4qj/u8H/lcZGPmVZbojY3cmX
PXHIrJ7DwajrP5VLI8/rLYcJd5iMT/7OgTmAv3JgLcCfObAO4I8c2BCU+ZMz
LPuOMzEc2iQ4EuA3HNgI8CsOHAPwCw4cC/AzDhwP8BMODNeFZsd8xJmYAG0S
nARwBwe2AHyfA/cF+C4HFgC+zYFhmZnfNzkT+0ObBA8E+DoHThWc3s6ZOAja
JHgIwFc5cJrg9MuciUOhTYKHA3yRA48E+AIHHi1Eu5UzMR3aDlBdPK3PhaSb
5jEw+6zdrP60UOETFen2PEPIyxa7H41CVeVOzEQKHNJ6CV/xR+pg9VAqOh6q
m+2qIweqmirwWUGZmf2nhsqZE5APhwtqIFo/o0jj+ySYfcJuVppvrQA3ceBs
gBs5sA3gBg48LSgz+3E9Z2IOtElwLsB1HDgP4CMceAbAhzjwLIAPcOA5Qn7X
cCbOhTYJng9wFQdeCHAlB14M8B4OvFRI052cicugTYKXA7ydA4sAb+XAdoA3
c2CHkKYVnIlF0CbBToA3cuCVAK/nwKsBLufAxUKaujkTS6BNgtcCXMqBywAu
5sAwOWa0V9lNqIWQqkm7zrsOnjnMVnORkyi7Afpddv1o+TqA9YQKfQVkrigj
098K95ZCWsPcBPUOoTa2mI6qvKpIhxchcwAttDvRiIxVLn0LonYIjhaqosWw
e+zeBoEFdgFpVt0BcD4H3iVk8xLOxN3QJsF7AV7EgfcBvIADVwM8jwPvF9J0
NmdiLbRJ8EGAZ3LgwwBP58BHhWjncibWQZsE1wOcw4GPCU63cSY2QJsENwKc
zYGbBKdP5kw8Dm0SfBLgiRz4NMBZHLgZ4HEcuAXgTA58BuCxHPhcUGZ2zHTO
xFZok+DzAI/iwG0Aj+DAlwAeZgf5RxKvwOw0u9ld+7AlfFhr9uPBg+aMysx2
ZKGcsGsnBBHzaxCcKtTGIo1XcfsdJOnwgb6Z7gPsTiRXiPq/Sp14A/E7pKN1
YdrR/BbMWt90ybMrfDVjJmUyZ+IdaJPgewD34cAPAEq7jxzghwCl3WEO8GOA
0qYwBxi+WjTzO44z8Sm0SfBzgHtx4JcApQ8MDvBrgNLscYDfAhzBgd8L+a3n
TPwAbRL8CeAwDvwFoDSXHeBvAKWtOg7wD/U3Z6bJr2+2E72QSq+yk3NqT/Mq
Nf9XV/GLoF4QwUjYtQueXrlp02Bo/yWUjUvmbQD3d5XbnTgbxDzGy3aDDuTH
358gAhOO0T2YVeofYoPlWsShH8Z40rst/c5JP1COVtPRuFNlep8ZOONYF2+d
OIvyXI8y1bFqKOiGypr+L6xVZ+26Tr0ksH/ZwrnzPS95rF22IdX4Vodlz7B0
cywjusjMQV5q5SW+y+MKfHi6EDx7tKMER0JE6om+oKcXGnEYbrq3Xus2dbbc
hEc1sozH1WwPjgCfc0RnuRxJfbrACNaS7WiaZOJnxpTQwfc3rwwkZmpUJi0W
E5KJERObZ/LWfttAiMvUy0179DG6wLRAWrLSEHc2UatfnVmveF7Nf8VMJuk=
\
\>"],ImageRangeCache->{{{145., 432.}, {232., 56.}} -> {-234.86605698201438, \
250.75753410683825, 1.3068172782027982, \
5.7008259068115255}},ExpressionUUID->"3341a27f-3666-4a2a-9aa9-7825dc0b4ab8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"BeamSpotSizeGraphics", "\[Rule]", 
    RowBox[{"(", 
     TagBox[
      RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
      False,
      Editable->False], ")"}]}], ",", 
   RowBox[{"BeamSpotSizeFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{"#1", "<", "300"}], ",", 
        FractionBox[
         RowBox[{"4682", " ", 
          SqrtBox[
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{"29363540516600761", " ", 
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{
                 FractionBox["4445083", "54452270"], "+", "#1"}], ")"}], 
               "2"]}], "23357889"]}]]}], "67756777"], ",", 
        RowBox[{"#1", "\[GreaterEqual]", "300"}], ",", 
        RowBox[{
         FractionBox["3", "500"], " ", 
         SqrtBox[
          RowBox[{"1", "+", 
           FractionBox[
            RowBox[{"29363540516600761", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                FractionBox["4445083", "54452270"], "+", "#1"}], ")"}], 
              "2"]}], "23357889"]}]], " ", 
         SqrtBox[
          FractionBox["71421", 
           RowBox[{"171357931", " ", "\[Pi]"}]]]}]}], "]"}], "&"}], ")"}]}], 
   ",", 
   RowBox[{"BeamCurvatureFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{"#1", "<", "300"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["4445083", "54452270"], "+", "#1"}], ")"}]}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           FractionBox["23357889", 
            RowBox[{"29363540516600761", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                FractionBox["4445083", "54452270"], "+", "#1"}], ")"}], 
              "2"]}]]}], ")"}]}], ",", 
        RowBox[{"#1", "\[GreaterEqual]", "300"}], ",", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["4445083", "54452270"], "+", "#1"}], ")"}]}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           FractionBox["23357889", 
            RowBox[{"29363540516600761", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                FractionBox["4445083", "54452270"], "+", "#1"}], ")"}], 
              "2"]}]]}], ")"}]}]}], "]"}], "&"}], ")"}]}], ",", 
   RowBox[{"ComplexBeamParameterFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Which", "[", 
       RowBox[{
        RowBox[{"#1", "<", "300"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["4445083", "54452270"], "+", 
           FractionBox[
            RowBox[{"4833", " ", "\[ImaginaryI]"}], "171357931"]}], ")"}], 
         "-", "#1"}], ",", 
        RowBox[{"#1", "\[GreaterEqual]", "300"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["32675807083", "54452270"], "+", 
           FractionBox[
            RowBox[{"4833", " ", "\[ImaginaryI]"}], "171357931"]}], ")"}], 
         "-", "#1"}]}], "]"}], "&"}], ")"}]}], ",", 
   RowBox[{"WaveLength", "\[Rule]", "0.532`"}], ",", 
   RowBox[{"PlotDomain", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "300"}], "}"}]}]}], "}"}]], "Output",
 CellLabel->"Out[13]=",ExpressionUUID->"d4d68f07-60ca-4999-bdff-346e1881d969"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
PrintingStyleEnvironment->"Working",
WindowSize->{1481, 1093},
WindowMargins->{{53, Automatic}, {Automatic, 6}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
CellLabelAutoDelete->False,
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3334565137-3359157"->{
  Cell[1594, 54, 233, 4, 20, "Print",ExpressionUUID->"55d5504a-4b1d-4a78-bcb5-cb9b90ee8220",
   CellTags->"Info3334565137-3359157"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3334565137-3359157", 770775, 23418}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 164, 2, 21, "SubsubsectionIcon",ExpressionUUID->"f1c24be5-c154-445b-b950-acb3e019791c"],
Cell[747, 26, 223, 3, 25, "Input",ExpressionUUID->"12a082e9-158c-49af-8ade-5b7c7736f195"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1007, 34, 113, 0, 35, "SubsectionIcon",ExpressionUUID->"a40f6c74-e359-4bda-bbb1-704ba4b4fb56"],
Cell[1123, 36, 330, 11, 21, "Text",ExpressionUUID->"c58dcaf7-983b-453b-b235-cf406f55a926"],
Cell[CellGroupData[{
Cell[1478, 51, 113, 1, 24, "Input",ExpressionUUID->"9b700b31-0698-40f7-be6a-e0e740f52937"],
Cell[1594, 54, 233, 4, 20, "Print",ExpressionUUID->"55d5504a-4b1d-4a78-bcb5-cb9b90ee8220",
 CellTags->"Info3334565137-3359157"]
}, Open  ]],
Cell[1842, 61, 146, 2, 20, "Text",ExpressionUUID->"daaebc82-8484-4895-bff1-24eee1f41d9b"],
Cell[CellGroupData[{
Cell[2013, 67, 216, 4, 24, "Input",ExpressionUUID->"ec2e949a-c574-4752-ae5b-63f12c51949d"],
Cell[2232, 73, 988, 34, 24, "Output",ExpressionUUID->"c2a27611-f080-4b19-8d95-271d7098c98d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3257, 112, 111, 1, 24, "Input",ExpressionUUID->"d17b6ecb-1487-4af1-9260-6344dec8281a"],
Cell[3371, 115, 12399, 606, 304, 6848, 513, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"bec5f790-c4e3-48f1-95bc-7f55426d0295"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15819, 727, 176, 4, 35, "SubsectionIcon",ExpressionUUID->"0f8643fb-6443-4419-93f9-b08c5366be3f"],
Cell[15998, 733, 495, 12, 34, "Text",ExpressionUUID->"4a835959-78c6-4838-a6d3-536aa17bf0cb"],
Cell[CellGroupData[{
Cell[16518, 749, 135, 1, 24, "Input",ExpressionUUID->"221f8583-fcc2-4529-af7b-98cfa60962cb"],
Cell[16656, 752, 168, 2, 34, "Output",ExpressionUUID->"654a5ca6-aad8-4a96-88b5-870cc39bb388"]
}, Open  ]],
Cell[16839, 757, 218, 4, 21, "Text",ExpressionUUID->"17bc8269-9b04-4f63-9af1-9294bb659b15"],
Cell[CellGroupData[{
Cell[17082, 765, 146, 1, 24, "Input",ExpressionUUID->"540e2212-617d-4989-8790-81dafb49e7da"],
Cell[17231, 768, 415, 9, 24, "Output",ExpressionUUID->"224389ed-a940-4aa4-acd2-c2a0811540e1"]
}, Open  ]],
Cell[17661, 780, 394, 10, 21, "Text",ExpressionUUID->"17755b88-c29d-4cf4-876e-7518f7dae9ab"],
Cell[CellGroupData[{
Cell[18080, 794, 209, 4, 24, "Input",ExpressionUUID->"93de173d-b4bb-4943-b98b-102318de105d"],
Cell[18292, 800, 202, 2, 24, "Output",ExpressionUUID->"861419b3-2b92-4ab7-bac8-2cf17ee26876"]
}, Open  ]],
Cell[18509, 805, 336, 9, 21, "Text",ExpressionUUID->"41c43e70-1af0-4492-8f61-cbb6bca0ccc6"],
Cell[CellGroupData[{
Cell[18870, 818, 114, 1, 24, "Input",ExpressionUUID->"9b4bf6a4-48f3-417a-8c2f-772b79f31ef7"],
Cell[18987, 821, 413, 9, 24, "Output",ExpressionUUID->"711234df-1c75-483f-a96a-ff79cf2f0f5b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19437, 835, 116, 1, 24, "Input",ExpressionUUID->"81e3ab02-ecb8-4cb5-bf6a-fd13d00294d0"],
Cell[19556, 838, 416, 9, 24, "Output",ExpressionUUID->"a05f5ec8-d46b-4ee4-861f-36da6332a0a4"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20021, 853, 176, 4, 35, "SubsectionIcon",ExpressionUUID->"992480c7-7194-4e63-958b-949315e67e29"],
Cell[20200, 859, 664, 23, 38, "Text",ExpressionUUID->"17002cae-d316-48a7-a004-629ee37b81b6"],
Cell[CellGroupData[{
Cell[20889, 886, 115, 0, 21, "SubsubsectionIcon",ExpressionUUID->"063d93be-132e-4b1a-990b-3cbf1272b8c0"],
Cell[21007, 888, 260, 5, 21, "Text",ExpressionUUID->"7aa4cd7f-904b-42f6-aa8a-3a240dabb20b"],
Cell[CellGroupData[{
Cell[21292, 897, 91, 0, 24, "Input",ExpressionUUID->"1a249aed-f4b0-4657-ac40-6bbff6442f89"],
Cell[21386, 899, 548, 13, 20, "Print",ExpressionUUID->"44a71fbd-d5ad-4ed2-8198-f0e3fa7a30f7"],
Cell[CellGroupData[{
Cell[21959, 916, 11335, 671, 184, 7861, 611, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"aa6d3689-7f0b-4aff-863c-2921af87781c"],
Cell[33297, 1589, 9348, 588, 185, 6927, 546, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"56ebce11-de08-447e-b8e6-d0eb3374c6e8"],
Cell[42648, 2179, 11513, 683, 185, 8178, 626, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"0970782e-12f3-46ae-b0ea-139c83d904c4"]
}, Open  ]],
Cell[54176, 2865, 2873, 77, 121, "Output",ExpressionUUID->"2aa7c747-3929-4f7e-8872-a9c76941dd02"]
}, Open  ]],
Cell[57064, 2945, 171, 4, 24, "Text",ExpressionUUID->"d3839665-09f6-4321-b574-efbea8d51702"],
Cell[CellGroupData[{
Cell[57260, 2953, 119, 0, 22, "Input",ExpressionUUID->"a1c8e8e5-7ac2-48e8-9812-6d9b1384838c"],
Cell[57382, 2955, 548, 13, 29, "Print",ExpressionUUID->"4878dabf-74ae-4e05-8373-89c71059af74"],
Cell[CellGroupData[{
Cell[57955, 2972, 11334, 671, 185, 7861, 611, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"9cf38bf0-7b71-4e6f-9368-7c20d95942a6"],
Cell[69292, 3645, 9347, 588, 185, 6927, 546, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"f28c17df-f99b-4353-b0e1-103c9ac844ce"],
Cell[78642, 4235, 11512, 683, 185, 8178, 626, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"4ce1abe7-8a3c-4679-908b-1b2e76f51ab4"]
}, Open  ]],
Cell[90169, 4921, 3704, 99, 200, "Output",ExpressionUUID->"fa2ca38f-f4dc-45f7-bb71-f906b75fb366"]
}, Open  ]],
Cell[CellGroupData[{
Cell[93910, 5025, 109, 0, 22, "Input",ExpressionUUID->"93e61411-f77a-4499-a329-d5ca058c8f28"],
Cell[94022, 5027, 164, 2, 22, "Output",ExpressionUUID->"410f0167-df30-42b1-b165-5230a53fe154"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[94235, 5035, 116, 0, 30, "SubsubsectionIcon",ExpressionUUID->"938d0893-c70a-41d0-9f6f-7f8fe26f9bb0"],
Cell[94354, 5037, 527, 12, 46, "Text",ExpressionUUID->"fe43564d-075d-4f90-a102-63c32f77165a"],
Cell[CellGroupData[{
Cell[94906, 5053, 223, 4, 30, "Input",ExpressionUUID->"36c55432-4f13-4980-b5f0-56c5268f9fd1"],
Cell[95132, 5059, 1046, 36, 42, "Output",ExpressionUUID->"c86fbfc9-0d47-4fdb-b9f6-eb80b754eed6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96215, 5100, 113, 1, 22, "Input",ExpressionUUID->"034329ec-524a-4663-82eb-29938f6415aa"],
Cell[96331, 5103, 15823, 773, 319, 8460, 651, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"f653d658-9208-4899-9a63-adc6069033c3"]
}, Open  ]],
Cell[112169, 5879, 214, 4, 24, "Text",ExpressionUUID->"70885550-4cb0-4ddf-a29e-8136a2d680d2"],
Cell[CellGroupData[{
Cell[112408, 5887, 108, 0, 22, "Input",ExpressionUUID->"b873214f-1215-460d-bd42-d9eabdfa2ebb"],
Cell[112519, 5889, 548, 13, 29, "Print",ExpressionUUID->"4231de0b-e89f-4823-b23b-22a0ed08d223"],
Cell[CellGroupData[{
Cell[113092, 5906, 98428, 2582, 241, 78274, 2250, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"285fabd7-5af2-4c44-9e5c-492205829844"],
Cell[211523, 8490, 98768, 2609, 241, 78787, 2280, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"1ee85426-478a-4d6d-8c4c-9b9c5c3253c4"],
Cell[310294, 11101, 99819, 2596, 241, 78133, 2238, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"38662434-5d71-400a-adcf-6e4c8d065159"]
}, Open  ]],
Cell[410128, 13700, 14729, 357, 427, "Output",ExpressionUUID->"0fa3aee2-16aa-46d3-b6d5-723ca666fcfc"]
}, Open  ]],
Cell[424872, 14060, 261, 6, 33, "Text",ExpressionUUID->"3076462c-e28c-49c0-80b9-8eb6f3245d77"],
Cell[CellGroupData[{
Cell[425158, 14070, 130, 0, 22, "Input",ExpressionUUID->"713d1d20-fff2-46a5-9251-480d37633767"],
Cell[425291, 14072, 548, 13, 29, "Print",ExpressionUUID->"5bd116b9-0725-4057-a301-4bc78c856a8a"],
Cell[CellGroupData[{
Cell[425864, 14089, 98427, 2582, 241, 78273, 2250, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"609d40ef-f4da-43af-9313-106ac2274775"],
Cell[524294, 16673, 98768, 2609, 241, 78787, 2280, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"b0504dab-9996-4580-b6d6-702903beab61"],
Cell[623065, 19284, 99818, 2596, 241, 78132, 2238, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"930851c3-b045-4b1e-9b37-6562f8ab70bd"]
}, Open  ]],
Cell[722898, 21883, 21557, 484, 1403, "Output",ExpressionUUID->"c4f11378-2c2a-44d1-9e18-81b5882c6d94"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[744504, 22373, 96, 0, 30, "SubsubsectionIcon",ExpressionUUID->"bfe8cf03-f866-47f9-b828-44268815a1e9"],
Cell[744603, 22375, 372, 8, 34, "Text",ExpressionUUID->"b1abc1af-1551-4905-94b2-12610c1fa741"],
Cell[CellGroupData[{
Cell[745000, 22387, 187, 4, 22, "Input",ExpressionUUID->"05131e89-ae16-4331-add1-4310f365d64a"],
Cell[745190, 22393, 8382, 384, 185, 5936, 342, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"d3199495-d0f3-47e3-9432-fc17edb12838"],
Cell[753575, 22779, 4271, 113, 260, "Output",ExpressionUUID->"a6740055-3c05-4eee-ba70-f54d27420480"]
}, Open  ]],
Cell[757861, 22895, 244, 5, 33, "Text",ExpressionUUID->"c52ea5c3-c409-4bad-b9eb-43ccb339c7f8"],
Cell[CellGroupData[{
Cell[758130, 22904, 193, 4, 30, "Input",ExpressionUUID->"dda75078-241d-4d7c-9057-0c61f32a937a"],
Cell[758326, 22910, 8381, 384, 184, 5936, 342, "GraphicsData", "PostScript", "Graphics",ExpressionUUID->"3341a27f-3666-4a2a-9aa9-7825dc0b4ab8"],
Cell[766710, 23296, 3583, 102, 156, "Output",ExpressionUUID->"d4d68f07-60ca-4999-bdff-346e1881d969"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

